---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2001-03-30;165
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20010509&codiceRedaz=001G0219&dataVigenza=20251104
dataGU: 20010509
codiceRedaz: 001G0219
dataVigenza: 20251104
---

# Norme generali sull'ordinamento del lavoro alle dipendenze delle
amministrazioni pubbliche.

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 ed 87 della Costituzione.

Vista la legge 23 ottobre1992, n. 421, ed in particolare l'articolo 2;

Vista la legge 15 marzo 1997, n. 59;

Visto il decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni ed integrazioni;

Visto l'articolo 1, comma 8, della legge 24 novembre 2000. n. 340:

Vista la preliminare deliberazione del Consiglio dei Ministri adottata nella seduta del 7 febbraio 2001;

Acquisito il parere dalla Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, espresso in data 8 febbraio 2001;

Acquisito il parere delle competenti Commissioni del Senato della Repubblica e della Camera dei Deputati, rispettivamente in data 27 e 28 febbraio 2001;

Viste le deliberazioni del Consiglio dei Ministri, adottate nelle sedute del 21 e 30 marzo 2001;

Su proposta del Presidente del Consiglio dei Ministri e del Ministro per la funzione pubblica;

EMANA il seguente decreto legislativo:

## PRINCIPI GENERALI

### Art. 1. - Finalita' ed ambito di applicazione (Art. 1 del d.lgs. n. 29 del 1993, come modificato dall'art. 1 del d.lgs. n. 80 del 1998)

1. Le disposizioni del presente decreto disciplinano l'organizzazione degli uffici e i rapporti di lavoro e di impiego alle dipendenze delle amministrazioni pubbliche, tenuto conto delle autonomie locali e di quelle delle regioni e delle province autonome, nel rispetto dell'articolo 97, comma primo, della Costituzione, al fine di:

- a) accrescere l'efficienza delle amministrazioni in relazione a quella dei corrispondenti uffici e servizi dei Paesi dell'Unione europea, anche mediante il coordinato sviluppo di sistemi informativi pubblici;
- b) razionalizzare il costo del lavoro pubblico, contenendo la spesa complessiva per il personale, diretta e indiretta, entro i vincoli di finanza pubblica;
- c) realizzare la migliore utilizzazione delle risorse umane nelle pubbliche amministrazioni, assicurando la formazione e lo sviluppo professionale dei dipendenti, applicando condizioni uniformi rispetto a quelle del lavoro privato, garantendo pari opportunita' alle lavoratrici ed ai lavoratori nonche' l'assenza di qualunque forma di discriminazione e di violenza morale o psichica.

2. Per amministrazioni pubbliche si intendono tutte le amministrazioni dello Stato, ivi compresi gli istituti e scuole di ogni ordine e grado e le istituzioni educative, le aziende ed amministrazioni dello Stato ad ordinamento autonomo, le Regioni, le Province, i Comuni, le Comunita' montane, e loro consorzi e associazioni, le istituzioni universitarie, gli Istituti autonomi case popolari, le Camere di commercio, industria, artigianato e agricoltura e loro associazioni, tutti gli enti pubblici non economici nazionali, regionali e locali, le amministrazioni, le aziende e gli enti del Servizio sanitario nazionale l'Agenzia per la rappresentanza negoziale delle pubbliche amministrazioni (ARAN) e le Agenzie di cui al decreto legislativo 30 luglio 1999, n. 300. ((Fino alla revisione organica della disciplina di settore, le disposizioni di cui al presente decreto continuano ad applicarsi anche al CONI)).

3. Le disposizioni del presente decreto costituiscono principi fondamentali ai sensi dell'articolo 117 della Costituzione. Le Regioni a statuto ordinario si attengono ad esse tenendo conto delle peculiarita' dei rispettivi ordinamenti. I principi desumibili dall'articolo 2 della legge 23 ottobre 1992, n. 421, e successive modificazioni, e dall'articolo 11, comma 4, della legge 15 marzo 1997, n. 59, e successive modificazioni ed integrazioni, costituiscono altresi', per le Regioni a statuto speciale e per le province autonome di Trento e di Bolzano, norme fondamentali di riforma economico-sociale della Repubblica.

### Art. 2. - Fonti (Art. 2, commi da 1 a 3 del d.lgs. n. 29 del 1993, come sostituiti prima dall'art. 2 del d.lgs. n. 546 del 1993 e poi dall'art. 2 del d.lgs. n. 80 del 1998)

1. Le amministrazioni pubbliche definiscono, secondo principi generali fissati da disposizioni di legge e, sulla base dei medesimi, mediante atti organizzativi secondo i rispettivi ordinamenti, le linee fondamentali di organizzazione degli uffici; individuano gli uffici di maggiore rilevanza e i modi di conferimento della titolarita' dei medesimi; determinano le dotazioni organiche complessive. Esse ispirano la loro organizzazione ai seguenti criteri:

- a) funzionalita' rispetto ai compiti e ai programmi di attivita', nel perseguimento degli obiettivi di efficienza, efficacia ed economicita'. A tal fine, periodicamente e comunque all'atto della definizione dei programmi operativi e dell'assegnazione delle risorse, si procede a specifica verifica e ad eventuale revisione;
- b) ampia flessibilita', garantendo adeguati margini alle determinazioni operative e gestionali da assumersi ai sensi dell'articolo 5, comma 2;
- c) collegamento delle attivita' degli uffici, adeguandosi al dovere di comunicazione interna ed esterna, ed interconnessione mediante sistemi informatici e statistici pubblici;
- d) garanzia dell'imparzialita' e della trasparenza dell'azione amministrativa, anche attraverso l'istituzione di apposite strutture per l'informazione ai cittadini e attribuzione ad un unico ufficio, per ciascun procedimento, della responsabilita' complessiva dello stesso;
- e) armonizzazione degli orari di servizio e di apertura degli uffici con le esigenze dell'utenza e con gli orari delle amministrazioni pubbliche dei Paesi dell'Unione europea.

1-bis. I criteri di organizzazione di cui al presente articolo sono attuati nel rispetto della disciplina in materia di trattamento dei dati personali.

2. I rapporti di lavoro dei dipendenti delle amministrazioni pubbliche sono disciplinati dalle disposizioni del capo I, titolo II, del libro V del codice civile e dalle leggi sui rapporti di lavoro subordinato nell'impresa, fatte salve le diverse disposizioni contenute nel presente decreto, che costituiscono disposizioni a carattere imperativo. Eventuali disposizioni di legge, regolamento o statuto, che introducano ((o che abbiano introdotto)) discipline dei rapporti di lavoro la cui applicabilita' sia limitata ai dipendenti delle amministrazioni pubbliche, o a categorie di essi, possono essere derogate ((nelle materie affidate alla contrattazione collettiva ai sensi dell'articolo 40, comma 1, e nel rispetto dei principi stabiliti dal presente decreto,)) da successivi contratti o accordi collettivi ((nazionali)) e, per la parte derogata, non sono ulteriormente applicabili ((...)).

3. I rapporti individuali di lavoro di cui al comma 2 sono regolati contrattualmente. I contratti collettivi sono stipulati secondo i criteri e le modalita' previste nel titolo III del presente decreto; i contratti individuali devono conformarsi ai principi di cui all'articolo 45, comma 2. L'attribuzione di trattamenti economici puo' avvenire esclusivamente mediante contratti collettivi e salvo i casi previsti dal comma 3-ter e 3-quater dell'articolo 40 e le ipotesi di tutela delle retribuzioni di cui all'articolo 47-bis, o, alle condizioni previste, mediante contratti individuali. Le disposizioni di legge, regolamenti o atti amministrativi che attribuiscono incrementi retributivi non previsti da contratti cessano di avere efficacia a far data dall'entrata in vigore dal relativo rinnovo contrattuale. I trattamenti economici piu' favorevoli in godimento sono riassorbiti con le modalita' e nelle misure previste dai contratti collettivi e i risparmi di spesa che ne conseguono incrementano le risorse disponibili per la contrattazione collettiva.

3-bis. Nel caso di nullita' delle disposizioni contrattuali per violazione di norme imperative o dei limiti fissati alla contrattazione collettiva, si applicano gli articoli 1339 e 1419, secondo comma, del codice civile.

### Art. 3. - Personale in regime di diritto pubblico (Art. 2, commi 4 e 5 del d.lgs n. 29 del 1993, come sostituiti dall'art. 2 del d.lgs. n. 546 del 1993 e successivamente modificati dall'art. 2, comma 2 del d.lgs. n. 80 del 1998)

1. In deroga all'articolo 2, commi 2 e 3, rimangono disciplinati dai rispettivi ordinamenti: i magistrati ordinari, amministrativi e contabili, gli avvocati e procuratori dello Stato, il personale militare e delle Forze di polizia di Stato, il personale della carriera diplomatica e della carriera prefettizia nonche' i dipendenti degli enti che svolgono la loro attivita' nelle materie contemplate dall'articolo 1 del decreto legislativo del Capo provvisorio dello Stato 17 luglio 1947, n.691, e dalle leggi 4 giugno 1985, n.281, e successive modificazioni ed integrazioni, e 10 ottobre 1990, n.287.

1-bis. In deroga all'articolo 2, commi 2 e 3, il rapporto di impiego del personale, anche di livello dirigenziale, del Corpo nazionale dei vigili del fuoco, esclusi il personale volontario previsto dal regolamento di cui al decreto del Presidente della Repubblica 2 novembre 2000, n. 362, e il personale volontario di leva, e' disciplinato in regime di diritto pubblico secondo autonome disposizioni ordinamentali.

1-ter. In deroga all'articolo 2, commi 2 e 3, il personale della carriera dirigenziale penitenziaria e' disciplinato dal rispettivo ordinamento.

2. Il rapporto di impiego dei professori e dei ricercatori universitari ((, a tempo indeterminato o determinato,)) resta disciplinato dalle disposizioni rispettivamente vigenti, in attesa della specifica disciplina che la regoli in modo organico ed in conformita' ai principi della autonomia universitaria di cui all'articolo 33 della Costituzione ed agli articoli 6 e seguenti della legge 9 maggio 1989, n.168, e successive modificazioni ed integrazioni, tenuto conto dei principi di cui all'articolo 2, comma 1, della legge 23 ottobre 1992. n. 421. (28)

--------------- AGGIORNAMENTO (28) Il D.L. 25 giugno 2008, n. 112, convertito, con modificazioni, dalla L. 6 agosto 2008, n. 133 ha disposto (con l'art. 69, comma 1) che "Con effetto dal 1° gennaio 2009, per le categorie di personale di cui all'articolo 3 del decreto legislativo 30 marzo 2001, n. 165, la maturazione dell'aumento biennale o della classe di stipendio, nei limiti del 2,5 per cento, previsti dai rispettivi ordinamenti e' differita, una tantum, per un periodo di dodici mesi, alla scadenza del quale e' attribuito il corrispondente valore economico maturato. Il periodo di dodici mesi di differimento e' utile anche ai fini della maturazione delle ulteriori successive classi di stipendio o degli ulteriori aumenti biennali."

### Art. 4. - Indirizzo politico-amministrativo. Funzioni e responsabilita' (Art. 3 del d.lgs n. 29 del 1993, come sostituito prima dall'art. 2 del d.lgs n. 470 del 1993 poi dall'art. 3 del d.lgs n. 80 del 1998 e successivamente modificato dall'art. 1 del d.lgs n.387 del 1998)

1. Gli organi di governo esercitano le funzioni di indirizzo politico-amministrativo, definendo gli obiettivi ed i programmi da attuare ed adottando gli altri atti rientranti nello svolgimento ditali funzioni, e verificano la rispondenza dei risultati dell'attivita' amministrativa e della gestione agli indirizzi impartiti. Ad essi spettano, in particolare:

- a) le decisioni in materia di atti normativi e l'adozione dei relativi atti di indirizzo interpretativo ed applicativo;
- b) la definizione di obiettivi, priorita', piani, programmi e direttive generali per l'azione amministrativa e per la gestione;
- c) la individuazione delle risorse umane, materiali ed economico-finanziarie da destinare alle diverse finalita' e la loro ripartizione tra gli uffici di livello dirigenziale generale;
- d) la definizione dei criteri generali in materia di ausili finanziari a terzi e di determinazione di tariffe, canoni e analoghi oneri a carico di terzi;
- e) le nomine, designazioni ed atti analoghi ad essi attribuiti da specifiche disposizioni;
- f) le richieste di pareri alle autorita' amministrative indipendenti ed al Consiglio di Stato;
- g) gli altri atti indicati dal presente decreto.

2. Ai dirigenti spetta l'adozione degli atti e provvedimenti amministrativi, compresi tutti gli atti che impegnano l'amministrazione verso l'esterno, nonche' la gestione finanziaria, tecnica e amministrativa mediante autonomi poteri di spesa di organizzazione delle risorse umane, strumentali e di controllo. Essi sono responsabili in via esclusiva dell'attivita' amministrativa, della gestione e dei relativi risultati.

3. Le attribuzioni dei dirigenti indicate dal comma 2 possono essere derogate soltanto espressamente e ad opera di specifiche disposizioni legislative.

4. Le amministrazioni pubbliche i cui organi di vertice non siano direttamente o indirettamente espressione di rappresentanza politica, adeguano i propri ordinamenti al principio della distinzione tra indirizzo e controllo, da un lato, e attuazione e gestione dall'altro. ((A tali amministrazioni e' fatto divieto di istituire uffici di diretta collaborazione, posti alle dirette dipendenze dell'organo di vertice dell'ente)).

### Articolo 5 - Potere di organizzazione (Art.4 del d.lgs n.29 del 1993, come sostituito prima dall'art.3 del d.lgs n.546 del 1993, successivamente modificato dall'art.9 del d.lgs n.396 del 1997, e nuovamente sostituito dall'art.4 del d.lgs n.80 del 1998)

1. Le amministrazioni pubbliche assumono ogni determinazione organizzativa al fine di assicurare l'attuazione dei principi di cui all'articolo 2, comma 1, e la rispondenza al pubblico interesse dell'azione amministrativa.

2. Nell'ambito delle leggi e degli atti organizzativi di cui all'articolo 2, comma 1, le determinazioni per l'organizzazione degli uffici e le misure inerenti alla gestione dei rapporti di lavoro ((, nel rispetto del principio di pari opportunita', e in particolare la direzione e l'organizzazione del lavoro nell'ambito degli uffici)) sono assunte in via esclusiva dagli organi preposti alla gestione con la capacita' e i poteri del privato datore di lavoro, ((fatte salve la sola informazione ai sindacati ovvero le ulteriori forme di partecipazione,)) ove previsti nei contratti di cui all'articolo 9. ((PERIODO SOPPRESSO DAL D.LGS. 25 MAGGIO 2017, N. 75)).

3. Gli organismi di controllo interno verificano periodicamente la rispondenza delle determinazioni organizzative ai principi indicati all'articolo 2, comma 1, anche al fine di propone l'adozione di eventuali interventi correttivi e di fornire elementi per l'adozione delle misure previste nei confronti dei responsabili della gestione.

3-bis. Le disposizioni del presente articolo si applicano anche alle Autorita' amministrative indipendenti.

### Art. 6. - Organizzazione degli uffici e fabbisogni di personale (Art. 6 del d.lgs n. 29 del 1993, come sostituito prima dall'art. 4 del d.lgs n. 546 del 1993 e poi dall'art. 5 del d.lgs n. 80 del 1998 e successivamente modificato dall'art. 2 del d.lgs n. 387 del 1998)

1. Le amministrazioni pubbliche definiscono l'organizzazione degli uffici per le finalita' indicate all'articolo 1, comma 1, adottando, in conformita' al piano triennale dei fabbisogni di cui al comma 2, gli atti previsti dai rispettivi ordinamenti, previa informazione sindacale, ove prevista nei contratti collettivi nazionali. (89) ((116))

2. Allo scopo di ottimizzare l'impiego delle risorse pubbliche disponibili e perseguire obiettivi di performance organizzativa, efficienza, economicita' e qualita' dei servizi ai cittadini, le amministrazioni pubbliche adottano il piano triennale dei fabbisogni di personale, in coerenza con la pianificazione pluriennale delle attivita' e della performance, nonche' con le linee di indirizzo emanate ai sensi dell'articolo 6-ter. Qualora siano individuate eccedenze di personale, si applica l'articolo 33. Nell'ambito del piano, le amministrazioni pubbliche curano l'ottimale distribuzione delle risorse umane attraverso la coordinata attuazione dei processi di mobilita' e di reclutamento del personale, anche con riferimento alle unita' di cui all'articolo 35, comma 2. Il piano triennale indica le risorse finanziarie destinate all'attuazione del piano, nei limiti delle risorse quantificate sulla base della spesa per il personale in servizio e di quelle connesse alle facolta' assunzionali previste a legislazione vigente. (89)

3. In sede di definizione del piano di cui al comma 2, ciascuna amministrazione indica la consistenza della dotazione organica e la sua eventuale rimodulazione in base ai fabbisogni programmati e secondo le linee di indirizzo di cui all'articolo 6-ter, nell'ambito del potenziale limite finanziario massimo della medesima e di quanto previsto dall'articolo 2, comma 10-bis, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, garantendo la neutralita' finanziaria della rimodulazione. Resta fermo che la copertura dei posti vacanti avviene nei limiti delle assunzioni consentite a legislazione vigente. (89)

4. Nelle amministrazioni statali, il piano di cui al comma 2, adottato annualmente dall'organo di vertice, e' approvato, anche per le finalita' di cui all'articolo 35, comma 4, con decreto del Presidente del Consiglio dei ministri o del Ministro delegato, su proposta del Ministro competente, di concerto con il Ministro dell'economia e delle finanze. Per le altre amministrazioni pubbliche il piano triennale dei fabbisogni, adottato annualmente nel rispetto delle previsioni di cui ai commi 2 e 3, e' approvato secondo le modalita' previste dalla disciplina dei propri ordinamenti. Nell'adozione degli atti di cui al presente comma, e' assicurata la preventiva informazione sindacale, ove prevista nei contratti collettivi nazionali. (89) ((116))

4-bis. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75.

5. Per la Presidenza del Consiglio dei ministri, per il Ministero degli affari esteri, nonche' per le amministrazioni che esercitano competenze istituzionali in materia di difesa e sicurezza dello Stato, di polizia e di giustizia, sono fatte salve le particolari disposizioni dettate dalle normative di settore. L'articolo 5, comma 3, del decreto legislativo 30 dicembre 1992, n. 503, relativamente al personale appartenente alle Forze di polizia ad ordinamento civile, si interpreta nel senso che al predetto personale non si applica l'articolo 16 dello stesso decreto. Restano salve le disposizioni vigenti per la determinazione delle dotazioni organiche del personale degli istituti e scuole di ogni ordine e grado e delle istituzioni educative. Le attribuzioni del Ministero dell'universita' e della ricerca scientifica e tecnologica, relative a tutto il personale tecnico e amministrativo universitario, ivi compresi i dirigenti, sono devolute all'universita' di appartenenza. Parimenti sono attribuite agli osservatori astronomici, astrofisici e vesuviano tutte le attribuzioni del Ministero dell'universita' e della ricerca scientifica e tecnologica in materia di personale, ad eccezione di quelle relative al reclutamento del personale di ricerca. (71)

6. Le amministrazioni pubbliche che non provvedono agli adempimenti di cui al presente articolo non possono assumere nuovo personale. (71) (89) ((116))

6-bis. Sono fatte salve le procedure di reclutamento del personale docente, educativo e amministrativo, tecnico e ausiliario (ATA) delle istituzioni scolastiche ed educative statali, delle istituzioni di alta formazione artistica, musicale e coreutica e delle istituzioni universitarie, nonche' degli enti pubblici di ricerca di cui al decreto legislativo 25 novembre 2016, n. 218. Per gli enti del servizio sanitario nazionale sono fatte salve le particolari disposizioni dettate dalla normativa di settore.

------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75, ha disposto (con l'art. 22, comma 1) che "In sede di prima applicazione, il divieto di cui all'articolo 6, comma 6, del decreto legislativo n. 165 del 2001, come modificato dal presente decreto, si applica a decorrere dal 30 marzo 2018 e comunque solo decorso il termine di sessanta giorni dalla pubblicazione delle linee di indirizzo di cui al primo periodo". Ha inoltre disposto (con l'art. 22, comma 4, lettera a)) che che nel presente decreto le parole "Ministero della ricerca scientifica", ovunque ricorrano, sono sostituite dalle seguenti: "Ministero dell'istruzione, dell'universita' e della ricerca". -------------- AGGIORNAMENTO (89) La L. 27 dicembre 2019, n. 160 ha disposto (con l'art. 1, comma 328) che "Al fine di rafforzare lo svolgimento dell'attivita' a completamento dell'avvio del Centro di valutazione e certificazione nazionale (CVCN) delle funzioni aggiuntive attribuite al Ministero dello sviluppo economico in materia di laboratorio di certificazione, di normativa tecnica e vigilanza sulla sicurezza dei prodotti e dei processi produttivi, di crisi di impresa, di amministrazioni straordinarie, di contenzioso e arbitrati internazionali in materia di energia, di vigilanza e controllo del corretto uso delle frequenze, il Ministero dello sviluppo economico e' autorizzato a bandire concorsi pubblici e, conseguentemente, ad assumere a tempo indeterminato, in aggiunta alle settantasette unita' gia' autorizzate ai sensi dell'articolo 2, comma 1, del decreto-legge 21 settembre 2019, n. 105, convertito, con modificazioni, dalla legge 18 novembre 2019, n. 133, e in deroga all'articolo 6, commi 1, 2, 3, 4 e 6, e all'articolo 34-bis del decreto legislativo 30 marzo 2001, n. 165, all'articolo 4, comma 3, del decreto-legge 31 agosto 2013 n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, nonche' ai limiti di cui all'articolo 66 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, con conseguente incremento della vigente dotazione organica nel limite delle unita' eccedenti, in aggiunta alle ordinarie facolta' assunzionali, trecentonove unita' di personale da inquadrare nella III area del personale non dirigenziale, posizione economica F1, e trecentodiciotto unita' di personale da inquadrare nella II area del personale non dirigenziale, posizione economica F1, con professionalita' pertinenti alle funzioni di cui al presente comma". -------------- AGGIORNAMENTO (116) Il D.P.R. 24 giugno 2022, n. 81, ha disposto (con l'art. 1, comma 1, lettera a)) che "Ai sensi di quanto previsto dall'articolo 6, comma 1, del decreto-legge 9 giugno 2021, n. 80, convertito, con modificazioni, dalla legge 6 agosto 2021, n. 113, per le amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, con piu' di cinquanta dipendenti, sono soppressi, in quanto assorbiti nelle apposite sezioni del Piano integrato di attivita' e organizzazione (PIAO), gli adempimenti inerenti ai piani di cui alle seguenti disposizioni: a) articolo 6, commi 1, 4 (Piano dei fabbisogni) e 6, [...] del decreto legislativo 30 marzo 2001, n. 165".

### Art. 6-bis. - Misure in materia di organizzazione e razionalizzazione della spesa per il funzionamento delle pubbliche amministrazioni).

1. Le pubbliche amministrazioni di cui all'articolo 1, comma 2, nonche' gli enti finanziati direttamente o indirettamente a carico del bilancio dello Stato sono autorizzati, nel rispetto dei principi di concorrenza e di trasparenza, ad acquistare sul mercato i servizi, originariamente prodotti al proprio interno, a condizione di ottenere conseguenti economie di gestione e di adottare le necessarie misure in materia di personale ((...)).

2. ((Le amministrazioni interessate dai processi di cui al presente articolo provvedono al congelamento dei posti e alla temporanea riduzione dei fondi della contrattazione in misura corrispondente, fermi restando i processi di riallocazione e di mobilita' del personale.))

3. I collegi dei revisori dei conti e gli organi di controllo interno delle amministrazioni che attivano i processi di cui al comma 1 vigilano sull'applicazione del presente articolo, dando evidenza, nei propri verbali, dei risparmi derivanti dall'adozione dei provvedimenti in materia di organizzazione e di personale, anche ai fini della valutazione del personale con incarico dirigenziale di cui all'articolo 5 del decreto legislativo 30 luglio 1999, n. 286.

### Art. 6-ter. - Linee di indirizzo per la pianificazione dei fabbisogni di personale).

1. Con decreti di natura non regolamentare adottati dal Ministro per la pubblica amministrazione di concerto con il Ministro dell'economia e delle finanze, sono definite, nel rispetto degli equilibri di finanza pubblica, linee di indirizzo per orientare le amministrazioni pubbliche nella predisposizione dei rispettivi piani dei fabbisogni di personale ai sensi dell'articolo 6, comma 2, anche con riferimento a fabbisogni prioritari o emergenti e alla definizione dei nuovi profili professionali individuati dalla contrattazione collettiva, con particolare riguardo all'insieme di conoscenze, ((competenze e capacita' del personale)) da assumere anche per sostenere la transizione digitale ed ecologica della pubblica amministrazione ((e relative anche a strumenti e tecniche di progettazione e partecipazione a bandi nazionali ed europei, nonche' alla gestione dei relativi finanziamenti)).

2. Le linee di indirizzo di cui al comma 1 sono definite anche sulla base delle informazioni rese disponibili dal sistema informativo del personale del Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, di cui all'articolo 60.

3. Con riguardo alle regioni, agli enti regionali, al sistema sanitario nazionale e agli enti locali, i decreti di cui al comma 1 sono adottati previa intesa in sede di Conferenza unificata di cui all'articolo 8, comma 6, della legge 5 giugno 2003, n. 131. Con riguardo alle aziende e agli enti del Servizio sanitario nazionale, i decreti di cui al comma 1 sono adottati di concerto anche con il Ministro della salute.

4. Le modalita' di acquisizione dei dati del personale di cui all'articolo 60 sono a tal fine implementate per consentire l'acquisizione delle informazioni riguardanti le professioni e relative competenze professionali, nonche' i dati correlati ai fabbisogni.

5. Ciascuna amministrazione pubblica comunica secondo le modalita' definite dall'articolo 60 le predette informazioni e i relativi aggiornamenti annuali che vengono resi tempestivamente disponibili al Dipartimento della funzione pubblica. La comunicazione dei contenuti dei piani e' effettuata entro trenta giorni dalla loro adozione e, in assenza di tale comunicazione, e' fatto divieto alle amministrazioni di procedere alle assunzioni.

6. Qualora, sulla base del monitoraggio effettuato dal Ministero dell'economia e delle finanze di intesa con il Dipartimento della funzione pubblica attraverso il sistema informativo di cui al comma 2, con riferimento alle amministrazioni dello Stato, si rilevino incrementi di spesa correlati alle politiche assunzionali tali da compromettere gli obiettivi e gli equilibri di finanza pubblica, il Ministro per la semplificazione e la pubblica amministrazione, con decreto di natura non regolamentare, di concerto con il Ministro dell'economia e delle finanze, adotta le necessarie misure correttive delle linee di indirizzo di cui al comma 1. Con riguardo alle regioni, agli enti regionali, al sistema sanitario nazionale ed agli enti locali, le misure correttive sono adottate con le modalita' di cui al comma 3. ((114))

--------------- AGGIORNAMENTO (114) Il D.L. 30 aprile 2022, n. 36, convertito con modificazioni dalla L. 29 giugno 2022, n. 79, ha disposto (con l'art. 1, comma 2) che "In fase di prima applicazione delle disposizioni di cui all'articolo 6-ter del decreto legislativo 30 marzo 2001, n. 165, come modificato dal presente articolo, le linee di indirizzo sono emanate entro il 30 giugno 2022, previo accordo in sede di Conferenza unificata ai sensi dell'articolo 9, comma 2, lettera c), del decreto legislativo 28 agosto 1997, n. 281".

### Art. 7. - Gestione delle risorse umane (Art. 7 del d.lgs n. 29 del 1993, come sostituito prima dall'art. 5 del d.lgs n. 546 del 1993 e poi modificato dall'art. 3 del d.lgs n. 387 del 1998)

1. Le pubbliche amministrazioni garantiscono parita' e pari opportunita' tra uomini e donne e l'assenza di ogni forma di discriminazione, diretta e indiretta, relativa al genere, all'eta', all'orientamento sessuale, alla razza, all'origine etnica, alla disabilita', alla religione o alla lingua, nell'accesso al lavoro, nel trattamento e nelle condizioni di lavoro, nella formazione professionale, nelle promozioni e nella sicurezza sul lavoro. Le pubbliche amministrazioni garantiscono altresi' un ambiente di lavoro improntato al benessere organizzativo e si impegnano a rilevare, contrastare ed eliminare ogni forma di violenza morale o psichica al proprio interno.

2. Le amministrazioni pubbliche garantiscono la liberta' di insegnamento e l'autonomia professionale nello svolgimento dell'attivita' didattica, scientifica e di ricerca.

3. Le amministrazioni pubbliche individuano criteri certi di' priorita' nell'impiego flessibile del personale, purche' compatibile con l'organizzazione degli uffici e del lavoro, a favore dei dipendenti in situazioni di svantaggio personale, sociale e familiare e dei dipendenti impegnati in attivita' di volontariato ai sensi della legge 11 agosto 1991, n. 266.

4. Le amministrazioni pubbliche curano la formazione e l'aggiornamento del personale, ivi compreso quello con qualifiche dirigenziali, garantendo altresi' l'adeguamento dei programmi formativi. al fine di contribuire allo sviluppo della cultura di genere della pubblica amministrazione.

5. Le amministrazioni pubbliche non possono erogare trattamenti economici accessori che non corrispondano alle prestazioni effettivamente rese.

5-bis. E' fatto divieto alle amministrazioni pubbliche di stipulare contratti di collaborazione che si concretano in prestazioni di lavoro esclusivamente personali, continuative e le cui modalita' di esecuzione siano organizzate dal committente anche con riferimento ai tempi e al luogo di lavoro. I contratti posti in essere in violazione del presente comma sono nulli e determinano responsabilita' erariale. I dirigenti che operano in violazione delle disposizioni del presente comma sono, altresi', responsabili ai sensi dell'articolo 21 e ad essi non puo' essere erogata la retribuzione di risultato. Resta fermo che la disposizione di cui all'articolo 2, comma 1, del decreto legislativo 15 giugno 2015, n. 81, non si applica alle pubbliche amministrazioni. (71) (76) (80) (89)

6. Fermo restando quanto previsto dal comma 5-bis, per specifiche esigenze cui non possono far fronte con personale in servizio, le amministrazioni pubbliche possono conferire esclusivamente incarichi individuali, con contratti di lavoro autonomo, ad esperti di particolare e comprovata specializzazione anche universitaria, in presenza dei seguenti presupposti di legittimita':

- a) l'oggetto della prestazione deve corrispondere alle competenze attribuite dall'ordinamento all'amministrazione conferente, ad obiettivi e progetti specifici e determinati e deve risultare coerente con le esigenze di funzionalita' dell'amministrazione conferente;
- b) l'amministrazione deve avere preliminarmente accertato l'impossibilita' oggettiva di utilizzare le risorse umane disponibili al suo interno;
- c) la prestazione deve essere di natura temporanea e altamente qualificata; non e' ammesso il rinnovo; l'eventuale proroga dell'incarico originario e' consentita, in via eccezionale, al solo fine di completare il progetto e per ritardi non imputabili al collaboratore, ferma restando la misura del compenso pattuito in sede di affidamento dell'incarico;
- d) devono essere preventivamente determinati durata, oggetto e compenso della collaborazione. Si prescinde dal requisito della comprovata specializzazione universitaria in caso di stipulazione di contratti di collaborazione per attivita' che debbano essere svolte da professionisti iscritti in ordini o albi o con soggetti che operino nel campo dell'arte, dello spettacolo , dei mestieri artigianali o dell'attivita' informatica nonche' a supporto dell'attivita' didattica e di ricerca, per i servizi di orientamento, compreso il collocamento, e di certificazione dei contratti di lavoro di cui al decreto legislativo 10 settembre 2003, n. 276, purche' senza nuovi o maggiori oneri a carico della finanza pubblica , ferma restando la necessita' di accertare la maturata esperienza nel settore. Il ricorso ai contratti di cui al presente comma per lo svolgimento di funzioni ordinarie o l'utilizzo dei soggetti incaricati ai sensi del medesimo comma come lavoratori subordinati e' causa di responsabilita' amministrativa per il dirigente che ha stipulato i contratti. Il secondo periodo dell'articolo 1, comma 9, del decreto-legge 12 luglio 2004, n. 168, convertito, con modificazioni, dalla legge 30 luglio 2004, n. 191, e' soppresso. Si applicano le disposizioni previste dall'articolo 36, comma 3, del presente decreto e, in caso di violazione delle disposizioni di cui al presente comma, fermo restando il divieto di costituzione di rapporti di lavoro a tempo indeterminato, si applica quanto previsto dal citato articolo 36, comma 5-quater.

6-bis. Le amministrazioni pubbliche disciplinano e rendono pubbliche, secondo i propri ordinamenti, procedure comparative per il conferimento degli incarichi di collaborazione.

6-ter. I regolamenti di cui all'articolo 110, comma 6, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, si adeguano ai principi di cui al comma 6.

6-quater. Le disposizioni di cui ai commi 6, 6-bis e 6-ter non si applicano ai componenti degli organismi indipendenti di valutazione di cui all'articolo 14 del decreto legislativo 27 ottobre 2009, n. 150 e dei nuclei di valutazione, nonche' degli organismi operanti per le finalita' di cui all'articolo 1, comma 5, della legge 17 maggio 1999, n. 144.

6-quinquies. Rimangono ferme le speciali disposizioni previste per gli enti pubblici di ricerca dall'articolo 14 del decreto legislativo 25 novembre 2016, n. 218. (97) (100) ((102))

-------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75, ha disposto (con l'art. 22, comma 8) che "Il divieto di cui all'articolo 7, comma 5-bis, del decreto legislativo n. 165 del 2001, come introdotto dal presente decreto, si applica a decorrere dal 1° gennaio 2018". La L. 11 dicembre 2016, n. 232, come modificata dal D.Lgs. 25 maggio 2017, n. 75, ha disposto (con l'art. 1, comma 410) che "Al fine di garantire la continuita' delle attivita' di ricerca, in deroga a quanto disposto dall'articolo 7, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, gli Istituti di ricovero e cura a carattere scientifico e gli Istituti zooprofilattici sperimentali possono continuare ad avvalersi del personale addetto alla ricerca, sia con qualifica di ricercatore, sia con qualifiche afferenti alle professionalita' della ricerca, assunto con contratti flessibili, in servizio presso tali istituti alla data del 31 dicembre 2016". -------------- AGGIORNAMENTO (76) La L. 27 dicembre 2017, n. 205, ha disposto (con l'art. 1, comma 433) che "Al fine di garantire la continuita' nell'attuazione delle attivita' di ricerca, nelle more dell'assunzione del personale di cui al comma 432, gli Istituti, in deroga all'articolo 7, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, possono continuare ad avvalersi, con le forme contrattuali di lavoro in essere, del personale in servizio alla data del 31 dicembre 2017, nei limiti delle risorse finanziarie di cui al comma 424". Il D.Lgs. 25 maggio 2017, n. 75, come modificato dalla L. 27 dicembre 2017, n. 205, ha disposto (con l'art. 22, comma 8) che "Il divieto di cui all'articolo 7, comma 5-bis, del decreto legislativo n. 165 del 2001, come introdotto dal presente decreto, si applica a decorrere dal 1° gennaio 2019". --------------- AGGIORNAMENTO (80) Il D.Lgs. 25 maggio 2017, n. 75, come modificato dalla L. 30 dicembre 2018, n. 145, ha disposto (con l'art. 22, comma 8) che "Il divieto di cui all'articolo 7, comma 5-bis, del decreto legislativo n. 165 del 2001, come introdotto dal presente decreto, si applica a decorrere dal 1° luglio 2019". -------------- AGGIORNAMENTO (89) La L. 27 dicembre 2019, n. 160 ha disposto (con l'art. 1, comma 284) che "Per le esigenze didattiche derivanti dalla legge 21 dicembre 1999, n. 508, cui non si possa far fronte con il personale di ruolo o con contratto a tempo determinato nell'ambito delle dotazioni organiche, le istituzioni di cui all'articolo 2, comma 1, della predetta legge provvedono, con oneri a carico del proprio bilancio, in deroga a quanto disposto dall'articolo 7, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, mediante l'attribuzione di incarichi di insegnamento della durata di un anno accademico e rinnovabili annualmente per un periodo massimo di tre anni, anche ove temporaneamente conferiti a personale incluso nelle graduatorie nazionali". -------------- AGGIORNAMENTO (97) Il D.L. 17 marzo 2020, n. 18, convertito con modificazioni dalla L. 24 aprile 2020, n. 27, ha disposto: - (con l'art. 2-bis, comma 1, lettera a)) che "Al fine di far fronte alle esigenze straordinarie ed urgenti derivanti dalla diffusione del COVID-19 e di garantire i livelli essenziali di assistenza nonche' per assicurare sull'intero territorio nazionale un incremento dei posti letto per la terapia intensiva e sub-intensiva necessari alla cura dei pazienti affetti dal predetto virus, le aziende e gli enti del Servizio sanitario nazionale, fino al perdurare dello stato di emergenza dichiarato dal Consiglio dei ministri con deliberazione in data 31 gennaio 2020, pubblicata nella Gazzetta Ufficiale n. 26 del 1° febbraio 2020, possono: a) procedere al reclutamento del personale delle professioni sanitarie, come individuate dall'articolo 1 del decreto legislativo del Capo provvisorio dello Stato 13 settembre 1946, n. 233, ratificato dalla legge 17 aprile 1956, n. 561, e dalla legge 18 febbraio 1989, n. 56, e degli operatori socio-sanitari, nonche' di medici specializzandi, iscritti all'ultimo e al penultimo anno di corso delle scuole di specializzazione, anche ove non collocati nelle graduatorie di cui all'articolo 1, comma 547, della legge 30 dicembre 2018, n. 145, conferendo incarichi di lavoro autonomo, anche di collaborazione coordinata e continuativa, di durata non superiore a sei mesi, prorogabili in ragione del perdurare dello stato di emergenza sino al 31 dicembre 2020, in deroga all'articolo 7 del decreto legislativo 30 marzo 2001, n. 165, e all'articolo 6 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122"; - (con l'art. 2-bis, comma 5) che "Fino al 31 luglio 2020, al fine di far fronte alle esigenze straordinarie e urgenti derivanti dalla diffusione del COVID-19 e di garantire i livelli essenziali di assistenza, le regioni e le province autonome di Trento e di Bolzano, in deroga all'articolo 5, comma 9, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e all'articolo 7 del decreto legislativo 30 marzo 2001, n. 165, verificata l'impossibilita' di assumere personale, anche facendo ricorso agli idonei collocati in graduatorie concorsuali in vigore, possono conferire incarichi di lavoro autonomo, anche di collaborazione coordinata e continuativa, con durata non superiore a sei mesi, e comunque entro il termine dello stato di emergenza, a dirigenti medici, veterinari e sanitari nonche' al personale del ruolo sanitario del comparto sanita', collocati in quiescenza, anche ove non iscritti al competente albo professionale in conseguenza del collocamento a riposo, nonche' agli operatori socio-sanitari collocati in quiescenza"; - (con l'art. 10, comma 1) che "l'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro, anche quale soggetto attuatore degli interventi di protezione civile ai sensi dell'articolo 1, comma 1, dell'Ordinanza del Capo del Dipartimento della Protezione civile n. 630 del 3 febbraio 2020, e' autorizzato ad acquisire un contingente di 200 medici specialisti e di 100 infermieri con le medesime modalita' di cui all'articolo 2-bis del presente decreto, conferendo incarichi di lavoro autonomo, anche di collaborazione coordinata e continuativa, di durata non superiore a sei mesi, eventualmente prorogabili in ragione del perdurare dello stato di emergenza, e comunque non oltre il 31 dicembre 2020, in deroga all'articolo 7 del decreto legislativo 30 marzo 2001, n. 165, e all'articolo 9, comma 28, del decreto legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122." -------------- AGGIORNAMENTO (100) Il D.L. 30 luglio 2020, n. 83 ha disposto (con l'art. 1, comma 3) che i termini di cui all'art. 2-bis, commi 1 e 5 del D.L. 17 marzo 2020, n. 18, convertito con modificazioni dalla L. 24 aprile 2020, n. 27, sono prorogati al 15 ottobre 2020. -------------- AGGIORNAMENTO (102) Il D.L. 7 ottobre 2020, n. 125 ha disposto (con l'art. 1, comma 3) che i termini di cui all'art. 2-bis, commi 1 e 5 del D.L. 17 marzo 2020, n. 18, convertito con modificazioni dalla L. 24 aprile 2020, n. 27, sono prorogati al 31 dicembre 2020.

### Art. 7-bis.

((ARTICOLO ABROGATO DAL D.P.R. 16 APRILE 2013, N.70))

### Articolo 8 - (Costo del lavoro, risorse finanziarie e controlli (Art. 9 del d.lgs n.29 del 1993)

1. Le amministrazioni pubbliche adottano tutte le misure affinche' la spesa per il proprio personale sia evidente, certa e prevedibile nella evoluzione. Le risorse finanziarie destinate a tale spesa sono determinate in base alle compatibilita' economico-finanziarie definite nei documenti di programmazione e di bilancio.

2. L'incremento del costo del lavoro negli enti pubblici economici e nelle aziende pubbliche che producono servizi di pubblica utilita', nonche' negli enti di cui all'articolo 70, comma 4, e' soggetto a limiti compatibili con gli obiettivi e i vincoli di finanza pubblica.

### Articolo 9 - (( (Partecipazione sindacale). ))

((

1. Fermo restando quanto previsto dall'articolo 5, comma 2, i contratti collettivi nazionali disciplinano le modalita' e gli istituti della partecipazione.

))

## ORGANIZZAZIONE Capo I Relazioni con il pubblico

### Articolo 10 - Trasparenza delle amministrazioni pubbliche (Art.11 del d.lgs n.29 del 1993, come modificato dall'art.43, comma 9 del d.lgs n.80 del 1998)

1. L'organismo di cui all'articolo 2, comma 1, lettera mm), della legge 23 ottobre 1992, n.421, ai fini della trasparenza e rapidita' del procedimento, definisce, ai sensi dell'articolo 2, comma 1, lettera c), i modelli e sistemi informativi utili alla interconnessione tra le amministrazioni pubbliche.

2. La Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica ed i comitati metropolitani di cui all'articolo 18 del decreto-legge 24 novembre 1990, n. 344, convertito, con modificazioni, dalla legge 23 gennaio 1991, n. 21, promuovono, utilizzando il personale degli uffici di cui all'articolo 11, la costituzione di servizi di accesso polifunzionale alle amministrazioni pubbliche nell'ambito dei progetti finalizzati di cui all'articolo 26 della legge 11 marzo 1988, n. 67, e successive modificazioni ed integrazioni.

### Articolo 11 - Ufficio relazioni con il pubblico (Art.l2, commi da 1 a 5-ter del d.lgs n.29 del 1993, come sostituiti dall'art.7 del d.lgs n.546 del 1993 e successivamente modificati dall'art.3 del decreto legge n.163 del 1995, convertito con modificazioni dalla legge n.273 del 1995)

1. Le amministrazioni pubbliche, al fine di garantire la piena attuazione della legge 7 agosto 1990, n. 241, e successive modificazioni ed integrazioni, individuano, nell'ambito della propria struttura uffici per le relazioni con il pubblico.

2. Gli uffici per le relazioni con il pubblico provvedono, anche mediante l'utilizzo di tecnologie informatiche:

- a) al servizio all'utenza per i diritti di partecipazione di cui al capo III della legge 7 agosto 1990, n. 241, e successive modificazioni ed integrazioni;
- b) all'informazione all'utenza relativa agli atti e allo stato dei procedimenti;
- c) alla ricerca ed analisi finalizzate alla formulazione di proposte alla propria amministrazione sugli aspetti organizzativi e logistici del rapporto con l'utenza.

3. Agli uffici per le relazioni con il pubblico viene assegnato, nell'ambito delle attuali dotazioni organiche delle singole amministrazioni, personale con idonea qualificazione e con elevata capacita' di avere contatti con il pubblico, eventualmente assicurato da apposita formazione.

4. Al fine di assicurare la conoscenza di normative, servizi e strutture, le amministrazioni pubbliche programmano ed attuano iniziative di comunicazione di pubblica utilita'; in particolare, le amministrazioni dello Stato, per l'attuazione delle iniziative individuate nell'ambito delle proprie competenze, si avvalgono del Dipartimento per l'informazione e l'editoria della Presidenza del Consiglio dei ministri quale struttura centrale di servizio, secondo un piano annuale di coordinamento del fabbisogno di prodotti e servizi, da sottopone all'approvazione del Presidente del Consiglio dei ministri.

5. Per le comunicazioni previste dalla legge 7 agosto 1990, n. 241, e successive modificazioni ed integrazioni, non si applicano le norme vigenti che dispongono la tassa a carico del destinatario.

6. Il responsabile dell'ufficio per le relazioni con il pubblico e il personale da lui indicato possono promuovere iniziative volte, anche con il supporto delle procedure informatiche, al miglioramento dei servizi per il pubblico, alla semplificazione e all'accelerazione delle procedure e all'incremento delle modalita' di accesso informale alle informazioni in possesso dell'amministrazione e ai documenti amministrativi.

7. L'organo di vertice della gestione dell'amministrazione o dell'ente verifica l'efficacia dell'applicazione delle iniziative di cui al comma 6, ai fini dell'inserimento della verifica positiva nel fascicolo personale del dipendente. Tale riconoscimento costituisce titolo autonomamente valutabile in concorsi pubblici e nella progressione di' carriera del dipendente. Gli organi di vertice trasmettono le iniziative riconosciute ai sensi del presente comma al Dipartimento della funzione pubblica, ai fini di un'adeguata pubblicizzazione delle stesse. Il Dipartimento annualmente individua le forme di pubblicazione.

### Articolo 12 - Uffici per la gestione del contenzioso del lavoro (Art. 12-bis del d.lgs n.29 del 1999, aggiunto dall'art. 7 del d.lgs n. 80 del 1998)

1. Le amministrazioni pubbliche provvedono, nell'ambito dei rispettivi ordinamenti, ad organizzare la gestione del contenzioso del lavoro, anche creando appositi uffici, in modo da assicurare l'efficace svolgimento di tutte le attivita' stragiudiziali e giudiziali inerenti alle controversie. Piu' amministrazioni omogenee o affini possono istituire, mediante convenzione che ne regoli le modalita' di costituzione e di funzionamento, un unico ufficio per la gestione di tutto o parte del contenzioso comune.

### Dirigenza Sezione I Qualifiche, uffici dirigenziali ed attribuzioni

#### Articolo 13 - Amministrazioni destinatarie (Art.13 del d.lgs n.29 del 1993,come sostituito prima dall'art.3 del d.lgs n.470 del 1993 e poi dall'art.8 del d.lgs n.80 del 1998)

1. Le disposizioni del presente capo si applicano alle amministrazioni dello Stato, anche ad ordinamento autonomo.

#### Art. 14. - Indirizzo politico-amministrativo (Art. 14 del d.lgs n. 29 del 1993, come sostituito prima dall'art. 8 del d.lgs n. 546 del 1993 e poi dall'art. 9 del d.lgs n.80 del 1998)

1. Il Ministro esercita le funzioni di cui all'articolo 4, comma 1. A tal fine periodicamente, e comunque ogni anno entro dieci giorni dalla pubblicazione della legge di bilancio, anche sulla base delle proposte dei dirigenti di cui all'articolo 16:

- a) definisce obiettivi, priorita', piani e programmi da attuare ed emana le conseguenti direttive generali per l'attivita' amministrativa e per la gestione;
- b) effettua, ai fini' dell'adempimento dei compiti definiti ai sensi della lettera a), l'assegnazione ai dirigenti preposti ai centri di responsabilita' delle rispettive amministrazioni delle risorse di cui all'articolo 4, comma 1, lettera c), del presente decreto, ivi comprese quelle di cui all'articolo 3 del decreto legislativo 7 agosto 1997, n. 279, e successive modificazioni ed integrazioni, ad esclusione delle risorse necessarie per il funzionamento degli uffici di cui al comma 2; provvede alle variazioni delle assegnazioni con le modalita' previste dal medesimo decreto legislativo 7 agosto 1997, n. 279, tenendo altresi' conto dei procedimenti e subprocedimenti attribuiti ed adotta gli altri provvedimenti ivi previsti.

2. Per l'esercizio delle funzioni di cui al comma 1 il Ministro si avvale di uffici di diretta collaborazione, aventi esclusive competenze di supporto e di raccordo con l'amministrazione, istituiti e disciplinati con regolamento adottato ai sensi dell'articolo 17, comma 4-bis, della legge 23 agosto 1988, n. 400. A tali uffici sono assegnati, nei limiti stabiliti dallo stesso regolamento: dipendenti pubblici anche in posizione di aspettativa, fuori ruolo o comando; collaboratori assunti con contratti a tempo determinato disciplinati dalle norme di diritto privato; esperti e consulenti per particolari professionalita' e specializzazioni con incarichi di collaborazione coordinata e continuativa. All'atto del giuramento del Ministro, tutte le assegnazioni di personale, ivi compresi gli incarichi anche di livello dirigenziale e le consulenze e i contratti, anche a termine, conferiti nell'ambito degli uffici di cui al presente comma, decadono automaticamente ove non confermati entro trenta giorni dal giuramento del nuovo Ministro. Per i dipendenti pubblici si applica la disposizione di cui all'articolo 17, comma 14, della legge 15 maggio 1997, n. 127. Con lo stesso regolamento si provvede al riordino delle segreterie particolari dei Sottosegretari di Stato. Con decreto adottato dall'autorita' di governo competente, di concerto con il Ministro ((dell'economia e delle finanze)), e' determinato, in attuazione dell'articolo 12, comma 1, lettera n) della legge 15 marzo 1997, n.59, senza aggravi di spesa e, per il personale disciplinato dai contratti collettivi nazionali di lavoro, fino ad una specifica disciplina contrattuale, il trattamento economico accessorio, da corrispondere mensilmente, a fronte delle responsabilita', degli obblighi di reperibilita' e di disponibilita' ad orari disagevoli, ai dipendenti assegnati agli uffici dei Ministri e dei Sottosegretari di Stato. Tale trattamento, consistente in un unico emolumento, e' sostitutivo dei compensi per il lavoro straordinario, per la produttivita' collettiva e per la qualita' della prestazione individuale. Con effetto dall'entrata in vigore del regolamento di cui al presente comma sono abrogate le norme del regio decreto legge 10 luglio 1924, n. 1100, e successive modificazioni ed integrazioni, ed ogni altra norma riguardante la costituzione e la disciplina dei gabinetti dei Ministri e delle segreterie particolari dei Ministri e dei Sottosegretari di Stato. (23)

3. Il Ministro non puo' revocare, riformare, riservare o avocare a se' o altrimenti adottare provvedimenti o atti di competenza dei dirigenti. In caso di inerzia o ritardo il Ministro puo' fissare un termine perentorio entro il quale il dirigente deve adottare gli atti o i provvedimenti. Qualora l'inerzia permanga, o in caso di grave inosservanza delle direttive generali da parte del dirigente competente, che determinino pregiudizio per l'interesse pubblico, il Ministro puo' nominare, salvi i casi di urgenza previa contestazione, un commissario ad acta, dando comunicazione al Presidente del Consiglio dei ministri del relativo provvedimento. Resta salvo quanto previsto dall'articolo 2, comma 3, lett. p) della legge 23 agosto 1988, n. 400. Resta altresi' salvo quanto previsto dalL'articolo 6 del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n.773, e successive modificazioni ed integrazioni, e dall'articolo 10 del relativo regolamento emanato con regio decreto 6 maggio 1940, n. 635. Resta salvo il potere di annullamento ministeriale per motivi di legittimita'.

--------------- AGGIORNAMENTO (23) Il D.L. 18 maggio 2006, n. 181, convertito con modificazioni dalla L. 17 luglio 2006, n. 233, ha disposto (con l'art. 1, comma 24-ter) che "Il termine di cui all'articolo 14, comma 2, del decreto legislativo 30 marzo 2001, n. 165, come modificato dal comma 24-bis del presente articolo, decorre, rispetto al giuramento dei Ministri in carica alla data di entrata in vigore della legge di conversione del presente decreto, da tale ultima data."

#### Art. 15. - Dirigenti (Art. 15 del d.lgs. n. 29 del 1993, come sostituito dall'art. 4 del d.lgs. n. 470 del 1993 e successivamente modificato dall'art. 10 del d.lgs. n. 80 del 1998; Art. 27 del d.lgs. n. 29 del 1993, commi 1 e 3, come sostituiti dall'art.7 del d.lgs n.470 del 1993)

1. Nelle amministrazioni pubbliche di cui al presente capo, la dirigenza e' articolata nelle due fasce dei ruoli di cui all'articolo 23. Restano salve le particolari disposizioni concernenti le carriere diplomatica e prefettizia e le carriere delle Forze di polizia e delle Forze armate. Per le amministrazioni dello Stato, anche ad ordinamento autonomo, e' fatto salvo quanto previsto dall'articolo 6.

2. Nelle istituzioni e negli enti di ricerca e sperimentazione, nonche' negli altri istituti pubblici di cui al sesto comma dell'articolo 33 della Costituzione, le attribuzioni della dirigenza amministrativa non si estendono alla gestione della ricerca e dell'insegnamento.

3. In ciascuna struttura organizzativa non affidata alla direzione del dirigente generale, il dirigente preposto all'ufficio di piu' elevato livello e' sovraordinato al dirigente preposto ad ufficio di livello inferiore.

4. Per le regioni, il dirigente cui sono conferite funzioni di coordinamento e' sovraordinato, limitatamente alla durata dell'incarico, al restante personale dirigenziale.

5. Per il Consiglio di Stato e per i tribunali amministrativi regionali, per la Corte dei conti ((, per il Consiglio nazionale dell'economia e del lavoro)) e per l'Avvocatura generale dello Stato, le attribuzioni che il presente decreto demanda agli organi di Governo sono di competenza rispettivamente, del Presidente del Consiglio di Stato, del Presidente della Corte dei conti ((, del Presidente del Consiglio nazionale dell'economia e del lavoro)) e dell'Avvocato generale dello Stato; le attribuzioni che il presente decreto demanda ai dirigenti preposti ad uffici dirigenziali di livello generate sono di competenza dei segretari generali dei predetti istituti.

#### Articolo 16 - Funzioni dei dirigenti di uffici dirigenziali generali (Art.16 del d.lgs n.29 del 1993, come sostituito prima dall'art.9 del d.lgs n.546 del 1993 e poi dall'art.11 del d.lgs n. 80 del 1998 e successivamente modificato dall'art.4 del d.lgs n.387 del 1998)

1. I dirigenti di uffici dirigenziali generali, comunque denominati, nell'ambito di quanto stabilito dall'articolo 4 esercitano, fra gli altri, i seguenti compiti e poteri:

- a) formulano proposte ed esprimono pareri al Ministro, nelle materie di sua competenza;
- a-bis) propongono le risorse e i profili professionali necessari allo svolgimento dei compiti dell'ufficio cui sono preposti anche al fine dell'elaborazione del documento di programmazione triennale del fabbisogno di personale di cui all'articolo 6, comma 4;
- b) curano l'attuazione dei piani, programmi e direttive generali definite dal Ministro e attribuiscono ai dirigenti gli incarichi e la responsabilita' di specifici progetti e gestioni; definiscono gli obiettivi che i dirigenti devono perseguire e attribuiscono le conseguenti risorse umane, finanziarie e materiali;
- c) adottano gli atti relativi all'organizzazione degli uffici di livello dirigenziale non generale;
- d) adottano gli atti e i provvedimenti amministrativi ed esercitano i poteri di spesa e quelli di acquisizione delle entrate rientranti nella competenza dei propri uffici, salvo quelli delegati ai dirigenti;
- d-bis) adottano i provvedimenti previsti dall'articolo 17, comma 2, del decreto legislativo 12 aprile 2006, n. 163, e successive modificazioni;
- e) dirigono, coordinano e controllano l'attivita' dei dirigenti e dei responsabili dei procedimenti amministrativi, anche con potere sostitutivo in caso di inerzia, e propongono l'adozione, nei confronti dei dirigenti, delle misure previste dall'articolo 21;
- f) promuovono e resistono alle liti ed hanno il potere di conciliare e di transigere, fermo restando quanto disposto dall'articolo 12, comma 1, della legge 3 aprile 1979, n.103;
- g) richiedono direttamente pareri agli organi consultivi dell'amministrazione e rispondono ai rilievi degli organi di controllo sugli atti di competenza;
- h) svolgono le attivita' di organizzazione e gestione del personale e di gestione dei rapporti sindacali e di lavoro;
- i) decidono sui ricorsi gerarchici contro gli atti e i provvedimenti amministrativi non definitivi dei dirigenti;
- l) curano i rapporti con gli uffici dell'Unione europea e degli organismi internazionali nelle materie di competenza secondo le specifiche direttive dell'organo di direzione politica, sempreche' tali rapporti non siano espressamente affidati ad apposito ufficio o organo.
- l-bis) concorrono alla definizione di misure idonee a prevenire e contrastare i fenomeni di corruzione e a controllarne il rispetto da parte dei dipendenti dell'ufficio cui sono preposti.
- l-ter) forniscono le informazioni richieste dal soggetto competente per l'individuazione delle attivita' nell'ambito delle quali e' piu' elevato il rischio corruzione e formulano specifiche proposte volte alla prevenzione del rischio medesimo.
- l-quater) provvedono al monitoraggio delle attivita' nell'ambito delle quali e' piu' elevato il rischio corruzione svolte nell'ufficio a cui sono preposti, disponendo, con provvedimento motivato, la rotazione del personale nei casi di avvio di procedimenti penali o disciplinari per condotte di natura corruttiva.

2. I dirigenti di uffici dirigenziali generali riferiscono al Ministro sull'attivita' da essi svolta correntemente e in tutti i casi in cui il Ministro lo richieda o lo ritenga opportuno.

3. L'esercizio dei compiti e dei poteri di cui al comma 1 puo' essere conferito anche a dirigenti preposti a strutture organizzative comuni a piu' amministrazioni pubbliche, ovvero alla attuazione di particolari programmi, progetti e gestioni.

4. Gli atti e i provvedimenti adottati dai dirigenti preposti al vertice dell'amministrazione e dai dirigenti di uffici dirigenziali generali di cui al presente articolo non sono suscettibili di ricorso gerarchico.

5. Gli ordinamenti delle amministrazioni pubbliche al cui vertice e' preposto un segretario generale, capo dipartimento o altro dirigente comunque denominato, con funzione di coordinamento di uffici dirigenziali di livello generale, ne definiscono i compiti ed i poteri.

#### Art. 17. - Funzioni dei dirigenti (Art. 17 del d.lgs. n. 29 del 1993, come sostituito prima dall'art. 10 del d.lgs. n. 546 del 1993 e poi dall'art.12 del d.lgs n.80 del 1998)

1. I dirigenti, nell'ambito di quanto stabilito dall'articolo 4, esercitano, fra gli altri, i seguenti compiti e poteri:

- a) formulano proposte ed esprimono pareri ai dirigenti degli uffici dirigenziali generali;
- b) curano l'attuazione dei progetti e delle gestioni ad essi assegnati dai dirigenti degli uffici dirigenziali generali, adottando i relativi atti e provvedimenti amministrativi ed esercitando i poteri di spesa e di acquisizione delle entrate;
- c) svolgono tutti gli altri compiti ad essi delegati dai dirigenti degli uffici dirigenziali generali;
- d) dirigono, coordinano e controllano l'attivita' degli uffici che da essi dipendono e dei responsabili dei procedimenti amministrativi, anche con poteri sostitutivi in caso di inerzia;
- d-bis) concorrono all'individuazione delle risorse e dei profili professionali necessari allo svolgimento dei compiti dell'ufficio cui sono preposti anche al fine dell'elaborazione del documento di programmazione triennale del fabbisogno di personale di cui all'articolo 6, comma 4;
- e) provvedono alla gestione del personale e delle risorse finanziarie e strumentali assegnate ai propri uffici ((, anche ai sensi di quanto previsto all'articolo 16, comma 1, lettera l-bis)).
- e-bis) effettuano la valutazione del personale assegnato ai propri uffici, nel rispetto del principio del merito, ai fini della progressione economica e tra le aree, nonche' della corresponsione di indennita' e premi incentivanti.

1-bis. I dirigenti, per specifiche e comprovate ragioni di servizio, possono delegare per un periodo di tempo determinato, con atto scritto e motivato, alcune delle competenze comprese nelle funzioni di cui alle lettere b), d) ed e) del comma 1 a dipendenti che ricoprano le posizioni funzionali piu' elevate nell'ambito degli uffici ad essi affidati. Non si applica in ogni caso l'articolo 2103 del codice civile.

#### Art. 17-bis.

((ARTICOLO ABROGATO DAL D.L. 6 LUGLIO 2012, N. 95, CONVERTITO CON MODIFICAZIONI DALLA L. 7 AGOSTO 2012, N. 135))

#### Articolo 18 - Criteri di rilevazione e analisi dei costi e dei rendimenti (Art.18 del d.lgs n.29 del 1993, come sostituito dall'art.5 del d.lgs n.470 del 1993)

1. Sulla base delle indicazioni di cui all'articolo 59 del presente decreto, i dirigenti preposti ad uffici dirigenziali di livello generale adottano misure organizzative idonee a consentire la rilevazione e l'analisi dei costi e dei rendimenti dell'attivita' amministrativa, della gestione e delle decisioni organizzative.

2. Il Dipartimento della funzione pubblica puo' chiedere all'Istituto nazionale di statistica - ISTAT - l'elaborazione di norme tecniche e criteri per le rilevazioni ed analisi di cui al comma 1 e, all'Autorita' per l'informatica nella pubblica amministrazione - AIPA, l'elaborazione di procedure informatiche standardizzate allo scopo di evidenziare gli scostamenti dei costi e dei rendimenti rispetto a valori medi e standards.

#### Art. 19. - Incarichi di funzioni dirigenziali (Art. 19 del d.lgs. n. 29 del 1993, come sostituito prima dall'art. 11 del d.lgs. n. 546 del 1993 e poi dall'art. 13 del d.lgs. n. 80 del 1998 e successivamente modificato dall'art. 5 del d.lgs. n. 387 del 1998)

1. Ai fini del conferimento di ciascun incarico di funzione dirigenziale si tiene conto, in relazione alla natura e alle caratteristiche degli obiettivi prefissati ed alla complessita' della struttura interessata, delle attitudini e delle capacita' professionali del singolo dirigente, dei risultati conseguiti in precedenza nell'amministrazione di appartenenza e della relativa valutazione, delle specifiche competenze organizzative possedute, nonche' delle esperienze di direzione eventualmente maturate all'estero, presso il settore privato o presso altre amministrazioni pubbliche, purche' attinenti al conferimento dell'incarico. Al conferimento degli incarichi e al passaggio ad incarichi diversi non si applica l'articolo 2103 del codice civile. (65)

1-bis. L'amministrazione rende conoscibili, anche mediante pubblicazione di apposito avviso sul sito istituzionale, il numero e la tipologia dei posti di funzione che si rendono disponibili nella dotazione organica ed i criteri di scelta; acquisisce le disponibilita' dei dirigenti interessati e le valuta.

1-ter. Gli incarichi dirigenziali possono essere revocati esclusivamente nei casi e con le modalita' di cui all'articolo 21, comma 1, secondo periodo. PERIODO ABROGATO DAL D.L. 31 MAGGIO 2010, N. 78, CONVERTITO CON MODIFICAZIONI DALLA L. 30 LUGLIO 2010, N. 122.

2. Tutti gli incarichi di funzione dirigenziale nelle amministrazioni dello Stato, anche ad ordinamento autonomo, sono conferiti secondo le disposizioni del presente articolo. Con il provvedimento di conferimento dell'incarico, ovvero con separato provvedimento del Presidente del Consiglio dei ministri o del Ministro competente per gli incarichi di cui al comma 3, sono individuati l'oggetto dell'incarico e gli obiettivi da conseguire, con riferimento alle priorita', ai piani e ai programmi definiti dall'organo di vertice nei propri atti di indirizzo e alle eventuali modifiche degli stessi che intervengano nel corso del rapporto, nonche' la durata dell'incarico, che deve essere correlata agli obiettivi prefissati e che, comunque, non puo' essere inferiore a tre anni ne' eccedere il termine di cinque anni. La durata dell'incarico puo' essere inferiore a tre anni se coincide con il conseguimento del limite di eta' per il collocamento a riposo dell'interessato. Gli incarichi sono rinnovabili. Al provvedimento di conferimento dell'incarico accede un contratto individuale con cui e' definito il corrispondente trattamento economico, nel rispetto dei principi definiti dall'articolo 24. E' sempre ammessa la risoluzione consensuale del rapporto. In caso di primo conferimento ad un dirigente della seconda fascia di incarichi di uffici dirigenziali generali o di funzioni equiparate, la durata dell'incarico e' pari a tre anni. Resta fermo che per i dipendenti statali titolari di incarichi di funzioni dirigenziali ai sensi del presente articolo, ai fini dell'applicazione dell'articolo 43, comma 1, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, e successive modificazioni, l'ultimo stipendio va individuato nell'ultima retribuzione percepita in relazione all'incarico svolto. Nell'ipotesi prevista dal terzo periodo del presente comma, ai fini della liquidazione del trattamento di fine servizio, comunque denominato, nonche' dell'applicazione dell'articolo 43, comma 1, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, e successive modificazioni, l'ultimo stipendio va individuato nell'ultima retribuzione percepita prima del conferimento dell'incarico avente durata inferiore a tre anni. (42) (65)

3. Gli incarichi di Segretario generale di ministeri, gli incarichi di direzione di strutture articolate al loro interno in uffici dirigenziali generali e quelli di livello equivalente sono conferiti con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro competente, a dirigenti della prima fascia dei ruoli di cui all'articolo 23 o, con contratto a tempo determinato, a persone in possesso delle specifiche qualita' professionali e nelle percentuali previste dal comma 6.

4. Gli incarichi di funzione dirigenziale di livello generale sono conferiti con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro competente, a dirigenti della prima fascia dei ruoli di cui all'articolo 23 o, in misura non superiore al 70 per cento della relativa dotazione, agli altri dirigenti appartenenti ai medesimi ruoli ovvero, con contratto a tempo determinato, a persone in possesso delle specifiche qualita' professionali richieste dal comma 6. (65) (90) (114) (124)

4-bis. I criteri di conferimento degli incarichi di funzione dirigenziale di livello generale, conferiti ai sensi del comma 4 del presente articolo, tengono conto delle condizioni di pari opportunita' di cui all'articolo 7.

5. Gli incarichi di direzione degli uffici di livello dirigenziale sono conferiti, dal dirigente dell'ufficio di livello dirigenziale generale, ai dirigenti assegnati al suo ufficio ai sensi dell'articolo 4, comma 1, lettera c). (65)

5-bis. Ferma restando la dotazione effettiva di ciascuna amministrazione, gli incarichi di cui ai commi da 1 a 5 possono essere conferiti, da ciascuna amministrazione, anche a dirigenti non appartenenti ai ruoli di cui all'articolo 23, purche' dipendenti delle amministrazioni di cui all'articolo 1, comma 2, ovvero di organi costituzionali, previo collocamento fuori ruolo, aspettativa non retribuita, comando o analogo provvedimento secondo i rispettivi ordinamenti. PERIODO SOPPRESSO DAL D.L. 9 GIUGNO 2021, N. 80, CONVERTITO, CON MODIFICAZIONI DALLA L. 6 AGOSTO 2021, N. 113. I suddetti limiti percentuali possono essere aumentati, rispettivamente, fino ad un massimo del 25 e del 18 per cento, con contestuale diminuzione delle corrispondenti percentuali fissate dal comma 6. (65) (91) (105) (106) (119)

5-ter. I criteri di conferimento degli incarichi di direzione degli uffici di livello dirigenziale, conferiti ai sensi del comma 5 del presente articolo, tengono conto delle condizioni di pari opportunita' di cui all'articolo 7.

6. Gli incarichi di cui ai commi da 1 a 5 possono essere conferiti, da ciascuna amministrazione, entro il limite del 10 per cento della dotazione organica dei dirigenti appartenenti alla prima fascia dei ruoli di cui all'articolo 23 e dell'8 per cento della dotazione organica di quelli appartenenti alla seconda fascia, a tempo determinato ai soggetti indicati dal presente comma. La durata di tali incarichi, comunque, non puo' eccedere, per gli incarichi di funzione dirigenziale di cui ai commi 3 e 4, il termine di tre anni, e, per gli altri incarichi di funzione dirigenziale, il termine di cinque anni. Tali incarichi sono conferiti, fornendone esplicita motivazione, a persone di particolare e comprovata qualificazione professionale, non rinvenibile nei ruoli dell'Amministrazione, che abbiano svolto attivita' in organismi ed enti pubblici o privati ovvero aziende pubbliche o private con esperienza acquisita per almeno un quinquennio in funzioni dirigenziali, o che abbiano conseguito una particolare specializzazione professionale, culturale e scientifica desumibile dalla formazione universitaria e postuniversitaria, da pubblicazioni scientifiche e da concrete esperienze di lavoro maturate per almeno un quinquennio, anche presso amministrazioni statali, ivi comprese quelle che conferiscono gli incarichi, in posizioni funzionali previste per l'accesso alla dirigenza, o che provengano dai settori della ricerca, della docenza universitaria, delle magistrature e dei ruoli degli avvocati e procuratori dello Stato. Il trattamento economico puo' essere integrato da una indennita' commisurata alla specifica qualificazione professionale, tenendo conto della temporaneita' del rapporto e delle condizioni di mercato relative alle specifiche competenze professionali. Per il periodo di durata dell'incarico, i dipendenti delle pubbliche amministrazioni sono collocati in aspettativa senza assegni, con riconoscimento dell'anzianita' di servizio. La formazione universitaria richiesta dal presente comma non puo' essere inferiore al possesso della laurea specialistica o magistrale ovvero del diploma di laurea conseguito secondo l'ordinamento didattico previgente al regolamento di cui al decreto del Ministro dell'universita' e della ricerca scientifica e tecnologica 3 novembre 1999, n. 509. (48) (61) (70) (71) (80) (90) (89) (97) (105)(117)(118) (119) (122) (129) (132) ((138))

6-bis. Fermo restando il contingente complessivo dei dirigenti di prima o seconda fascia il quoziente derivante dall'applicazione delle percentuali previste dai commi 4, 5-bis e 6, e' arrotondato all'unita' inferiore, se il primo decimale e' inferiore a cinque, o all'unita' superiore, se esso e' uguale o superiore a cinque.

6-ter. Il comma 6 ed il comma 6-bis si applicano alle amministrazioni di cui all'articolo 1, comma 2.

6-quater. Per gli enti di ricerca di cui all'articolo 8 del regolamento di cui al decreto del Presidente del Consiglio dei ministri 30 dicembre 1993, n. 593, il numero complessivo degli incarichi conferibili ai sensi del comma 6 e' elevato rispettivamente al 20 per cento della dotazione organica dei dirigenti appartenenti alla prima fascia e al 30 per cento della dotazione organica dei dirigenti appartenenti alla seconda fascia, a condizione che gli incarichi eccedenti le percentuali di cui al comma 6 siano conferiti a personale in servizio con qualifica di ricercatore o tecnologo previa selezione interna volta ad accertare il possesso di comprovata esperienza pluriennale e specifica professionalita' da parte dei soggetti interessati nelle materie oggetto dell'incarico, nell'ambito delle risorse disponibili a legislazione vigente. (90)

7. COMMA ABROGATO DALLA L. 15 LUGLIO 2002, N. 145.

8. Gli incarichi di funzione dirigenziale di cui al comma 3 cessano decorsi novanta giorni dal voto sulla fiducia al Governo. (37) (40)

9. Degli incarichi di cui ai commi 3 e 4 e' data comunicazione al Senato della Repubblica ed alla Camera dei deputati, allegando una scheda relativa ai titoli ed alle esperienze professionali dei soggetti prescelti.

10. I dirigenti ai quali non sia affidata la titolarita' di uffici dirigenziali svolgono, su richiesta degli organi di vertice delle amministrazioni che ne abbiano interesse, funzioni ispettive, di consulenza, studio e ricerca o altri incarichi specifici previsti dall'ordinamento, ivi compresi quelli presso i collegi di revisione degli enti pubblici in rappresentanza di amministrazioni ministeriali.

11. Per la Presidenza del Consiglio dei ministri, per il Ministero degli affari esteri nonche' per le amministrazioni che esercitano competenze in materia di difesa e sicurezza dello Stato, di polizia e di giustizia, la ripartizione delle attribuzioni tra livelli dirigenziali differenti e' demandata ai rispettivi ordinamenti.

12. Per il personale di cui all'articolo 3, comma 1, il conferimento degli incarichi di funzioni dirigenziali continuera' ad essere regolato secondo i rispettivi ordinamenti di settore. Restano ferme le disposizioni di cui all'articolo 2 della legge 10 agosto 2000, n. 246.

12-bis. Le disposizioni del presente articolo costituiscono norme non derogabili dai contratti o accordi collettivi.

------------- AGGIORNAMENTO (37) La Corte Costituzionale, con sentenza 4 - 7 aprile 2011, n. 124 (in G.U. 1a s.s. 13/4/2011, n. 16), ha dichiarato "l'illegittimita' costituzionale dell'art. 19, comma 8, del decreto legislativo 30 marzo 2001, n. 165 (Norme generali sull'ordinamento del lavoro alle dipendenze delle amministrazioni pubbliche), nel testo vigente prima dell'entrata in vigore dell'art. 40 del decreto legislativo 27 ottobre 2009, n. 150 (Attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni), nella parte in cui dispone che gli incarichi di funzione dirigenziale generale di cui al comma 5-bis, limitatamente al personale non appartenente ai ruoli di cui all'art. 23 del d.lgs. n. 165 del 2001, cessano decorsi novanta giorni dal voto sulla fiducia al Governo". ------------- AGGIORNAMENTO (40) La Corte Costituzionale, con sentenza 20 - 25 luglio 2011, n. 246 (in G.U. 1a s.s. 27/7/2011, n. 32) ha dichiarato "l'illegittimita' costituzionale dell'articolo 19, comma 8, del decreto legislativo 30 marzo 2001, n. 165 (Norme generali sull'ordinamento del lavoro alle dipendenze delle amministrazioni pubbliche), come modificato dall'art. 2, comma 159, del decreto-legge 3 ottobre 2006, n. 262 (Disposizioni urgenti in materia tributaria e finanziaria), convertito, con modificazioni, dalla legge 24 novembre 2006, n. 286, nel testo vigente prima dell'entrata in vigore dell'art. 40 del decreto legislativo 27 ottobre 2009, n. 150 (Attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni), nella parte in cui dispone che gli incarichi di funzione dirigenziale conferiti ai sensi del comma 6 del medesimo art. 19 del d.lgs. n. 165 del 2001, cessano decorsi novanta giorni dal voto sulla fiducia al Governo". ------------- AGGIORNAMENTO (42) Il D.L. 13 agosto 2011, n. 138, convertito con modificazioni dalla L. 14 settembre 2011, n. 148, ha disposto (con l'art. 1, comma 32) che "La disposizione del presente comma si applica agli incarichi conferiti successivamente alla data di entrata in vigore del presente decreto nonche' agli incarichi aventi comunque decorrenza successiva al 1° ottobre 2011". ------------- AGGIORNAMENTO (48) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 2, comma 20) che "Ai fini dell'attuazione della riduzione del 20 per cento operata sulle dotazioni organiche dirigenziali di prima e seconda fascia dei propri ruoli, la Presidenza del Consiglio dei Ministri provvede alla immediata riorganizzazione delle proprie strutture sulla base di criteri di contenimento della spesa e di ridimensionamento strutturale. All'esito di tale processo, e comunque non oltre il 1º novembre 2012, cessano tutti gli incarichi, in corso a quella data, di prima e seconda fascia conferiti ai sensi dell'articolo 19, commi 5-bis e 6, del decreto legislativo 30 marzo 2001, n. 165. Fino al suddetto termine non possono essere conferiti o rinnovati incarichi di cui alla citata normativa". ------------- AGGIORNAMENTO (61) Il D.L. 24 giugno 2014, n. 90 convertito con modificazioni dalla L. 11 agosto 2014, n. 114 ha disposto (con l'art. 11, comma 3) che "Per la dirigenza regionale e la dirigenza professionale, tecnica ed amministrativa degli enti e delle aziende del Servizio sanitario nazionale, il limite dei posti di dotazione organica attribuibili tramite assunzioni a tempo determinato ai sensi dell'articolo 19, comma 6, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, nonche' ai sensi di disposizioni normative di settore riguardanti incarichi della medesima natura, previa selezione pubblica ai sensi dell'articolo 110, comma 1, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, come sostituito dal comma 1, lettera a), del presente articolo, puo' raggiungere il livello massimo del dieci per cento". ------------- AGGIORNAMENTO (65) La L. 28 dicembre 2015, n. 221 ha disposto (con l'art. 29, comma 3) che "Limitatamente all'attuazione del regolamento di cui al decreto del Presidente del Consiglio dei ministri 10 luglio 2014, n. 142, e comunque non oltre la data del 31 dicembre 2017, i limiti percentuali per il conferimento degli incarichi di cui ai commi 1, 2, 4 e 5 dell'articolo 19 del decreto legislativo n. 165 del 2001, e successive modificazioni, fissati nel 15 e nel 10 per cento della dotazione organica di dirigenti appartenenti alla prima e alla seconda fascia dal comma 5-bis del medesimo articolo 19, sono elevati rispettivamente al 30 e al 20 per cento". ------------- AGGIORNAMENTO (70) Il D.L. 9 febbraio 2017, n. 8, convertito con modificazioni dalla L. 7 aprile 2017, n. 45, ha disposto (con l'art. 19, comma 2-bis) che "Nelle more dell'espletamento del concorso di cui al comma 1, il Capo del Dipartimento della protezione civile della Presidenza del Consiglio dei ministri, in caso di esito non favorevole delle procedure di interpello svolte ai sensi delle vigenti disposizioni, e' autorizzato a provvedere all'attribuzione di incarichi dirigenziali ai sensi del comma 6 dell'articolo 19 del decreto legislativo 30 marzo 2001, n. 165, oltre i limiti percentuali ivi previsti, nella misura del 75 per cento delle posizioni dirigenziali vacanti, comunque entro il limite massimo di ulteriori dieci incarichi. Gli incarichi conferiti ai sensi del presente comma, in deroga alla previsione del citato articolo 19, comma 6, del decreto legislativo n. 165 del 2001, hanno durata annuale, sono rinnovabili per una sola volta e, comunque, cessano alla data dell'entrata in servizio dei vincitori del concorso di cui al comma 1". ------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 22, comma 4, lettera a)) che che nel presente decreto le parole "Ministero della ricerca scientifica", ovunque ricorrano, sono sostituite dalle seguenti: "Ministero dell'istruzione, dell'universita' e della ricerca". ------------- AGGIORNAMENTO (80) La L. 30 dicembre 2018, n. 145 ha disposto (con l'art. 1, comma 352) che "Per le medesime finalita' del comma 348, per il triennio 2019-2021, la percentuale stabilita al primo periodo del comma 6 dell'articolo 19 del decreto legislativo 30 marzo 2001, n. 165, per gli incarichi di livello dirigenziale non generale da conferire al personale in servizio presso il Ministero dell'economia e delle finanze in possesso di comprovate professionalita' tecniche, con oneri a valere sulle facolta' assunzionali del medesimo Ministero, e' pari al 12 per cento". -------------- AGGIORNAMENTO (89) La L. 27 dicembre 2019, n. 160 ha disposto (con l'art. 1, comma 158) che "Per le medesime finalita' di cui al comma 155, nonche' al fine di sostenere le attivita' in materia di programmazione, realizzazione e monitoraggio delle opere pubbliche, nel triennio 2020-2022, la percentuale stabilita al primo periodo del comma 6 dell'articolo 19 del decreto legislativo 30 marzo 2001, n. 165, per gli incarichi di livello dirigenziale non generale da conferire al personale in servizio presso il Ministero delle infrastrutture e dei trasporti in possesso di comprovate professionalita', con oneri a valere sulle facolta' assunzionali del medesimo Ministero, e' pari al 12 per cento". La L. 30 dicembre 2018, n. 145, come modificata dalla L. 27 dicembre 2019, n. 160, ha disposto (con l'art. 1, comma 352) che "Per le medesime finalita' del comma 348 la percentuale stabilita al primo periodo del comma 6 dell'articolo 19 del decreto legislativo 30 marzo 2001, n. 165, per gli incarichi di livello dirigenziale non generale da conferire al personale in servizio presso il Ministero dell'economia e delle finanze in possesso di comprovate professionalita' tecniche, con oneri a valere sulle facolta' assunzionali del medesimo Ministero, e' pari al 12 per cento". -------------- AGGIORNAMENTO (90) Il D.L. 30 dicembre 2019, n. 162, convertito con modificazioni dalla L. 28 febbraio 2020, n. 8, ha disposto (con l'art. 1, comma 6) che "La percentuale di cui al comma 6 dell'articolo 19 del decreto legislativo 30 marzo 2001, n. 165, puo' essere elevata dall'8 per cento al 10 per cento, a valere sulle facolta' assunzionali di ciascuna amministrazione. La percentuale del 30 per cento di cui al comma 6-quater del citato articolo 19 del decreto legislativo n. 165 del 2001 puo' essere elevata al 38 per cento, a valere sulle facolta' assunzionali di ciascuno degli enti di ricerca indicati nel predetto comma 6-quater e ferma restando la disciplina ivi prevista". Ha inoltre disposto (con l'art. 22, comma 4) che "Per le esigenze di cui all'articolo 51, comma 2, lettera b), del decreto-legge 26 ottobre 2019, n. 124, convertito, con modificazioni, dalla legge 19 dicembre 2019, n. 157, il Consiglio di Stato e' autorizzato a conferire, nell'ambito della dotazione organica vigente, a persona dotata di alte competenze informatiche, un incarico dirigenziale di livello generale, in deroga ai limiti percentuali previsti dall'articolo 19, commi 4 e 6, del decreto legislativo 30 marzo 2001, n. 165. Agli oneri di cui al presente comma si fa fronte nei limiti delle facolta' assunzionali disponibili a legislazione vigente". -------------- AGGIORNAMENTO (91) Il D.L. 9 gennaio 2020, n. 1, convertito con modificazioni dalla L. 5 marzo 2020, n. 12, ha disposto (con l'art. 3, comma 9-ter) che "Nelle more di un organico intervento volto ad aumentare le percentuali per il conferimento di incarichi dirigenziali fissate dall'articolo 19, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, al fine di agevolare la mobilita' dei dirigenti all'interno delle pubbliche amministrazioni, nell'ottica di potenziarne la qualificazione professionale e di favorire l'efficacia e l'efficienza dell'azione amministrativa, in sede di prima applicazione delle disposizioni di cui al presente decreto e comunque non oltre la data del 31 dicembre 2022, i limiti percentuali previsti dall'articolo 19, comma 5-bis, del decreto legislativo n. 165 del 2001 sono elevati per il Ministero dell'universita' e della ricerca al 20 per cento". ----------- AGGIORNAMENTO (97) Il D.L. 9 febbraio 2017, n. 8, convertito con modificazioni dalla L. 7 aprile 2017, n. 45, come modificato dal D.L. 17 marzo 2020, n. 18, convertito con modificazioni dalla L. 24 aprile 2020, n. 27, ha disposto (con l'art. 19, comma 2-bis) che "Nelle more dell'espletamento del concorso di cui al comma 1, il Capo del Dipartimento della protezione civile della Presidenza del Consiglio dei ministri, in caso di esito non favorevole delle procedure di interpello svolte ai sensi delle vigenti disposizioni, e' autorizzato a provvedere all'attribuzione di incarichi dirigenziali ai sensi del comma 6 dell'articolo 19 del decreto legislativo 30 marzo 2001, n. 165, oltre i limiti percentuali ivi previsti, nella misura del 75 per cento delle posizioni dirigenziali vacanti, comunque entro il limite massimo di ulteriori dieci incarichi. Gli incarichi conferiti ai sensi del presente comma, in deroga alla previsione del citato articolo 19, comma 6, del decreto legislativo n. 165 del 2001, hanno durata annuale, sono rinnovabili fino al 31 dicembre 2021 e, comunque, cessano alla data dell'entrata in servizio dei vincitori del concorso di cui al comma 1. Alla relativa copertura finanziaria si provvede con le risorse di cui al comma 2. Gli incarichi conferiti ai sensi del presente comma non costituiscono titolo ne' requisito valutabile ai fini della procedura concorsuale di cui al comma 1". ----------- AGGIORNAMENTO (105) Il D.L. 1 marzo 2021, n. 22 ha disposto (con l'art. 7, comma 13) che "Nelle more della conclusione delle procedure concorsuali per il reclutamento del personale dirigenziale, nell'anno 2021, per il conferimento di incarichi dirigenziali di livello generale presso il Ministero del turismo, non si applicano i limiti percentuali di cui all'articolo 19, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, e, per il conferimento di incarichi dirigenziali di livello non generale, i limiti percentuali di cui all'articolo 19, commi 5-bis e 6, sono elevati rispettivamente fino al 50 e al 30 per cento". ----------- AGGIORNAMENTO (106) Il D.L. 9 giugno 2021, n. 80, convertito, con modificazioni dalla L. 6 agosto 2021, n. 113, ha disposto (con l'art. 3, comma 3-bis) che "A decorrere dalla data di entrata in vigore della legge di conversione del presente decreto, le percentuali di cui all'articolo 19, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, cessano di avere efficacia". ----------- AGGIORNAMENTO (114) Il D.L. 30 aprile 2022, n. 36, convertito con modificazioni dalla L. 29 giugno 2022, n. 79, ha disposto (con l'art. 16-ter, comma 1) che "In considerazione della riduzione della dotazione organica del personale civile ai sensi della legge 31 dicembre 2012, n. 244, in coerenza con gli obiettivi di modernizzazione della pubblica amministrazione e valorizzazione delle competenze contenuti nel PNRR, al fine di favorire il ricambio generazionale, promuovendo i percorsi di carriera del personale civile di livello dirigenziale che ha acquisito specifiche professionalita', fino al 31 dicembre 2027 gli incarichi di funzione dirigenziale di livello generale previsti nella dotazione organica del Ministero della difesa possono essere conferiti a dirigenti di seconda fascia appartenenti ai ruoli del medesimo Ministero in deroga al limite percentuale di cui all'articolo 19, comma 4, del decreto legislativo 30 marzo 2001, n. 165, e comunque nel limite massimo di tre unita' ulteriori". ----------- AGGIORNAMENTO (117) Il D.L. 21 marzo 2022, n. 21, convertito con modificazioni dalla L. 20 maggio 2022, n. 51, come modificato dal D.L. 9 agosto 2022, n. 115, ha disposto (con l'art. 7, comma 3) che "Il Ministero dello sviluppo economico e' autorizzato a conferire gli incarichi dirigenziali di cui al comma 2, anche in deroga ai limiti percentuali previsti dall'articolo 19, comma 6, del decreto legislativo 30 marzo 2001, n. 165. Conseguentemente, il numero di incarichi dirigenziali appartenenti alla prima fascia dei ruoli del Ministero dello sviluppo economico conferibili ai sensi dell'articolo 19, comma 6, del decreto legislativo 30 marzo 2001, n. 165, e' innalzato di una unita' a valere sulle facolta' assunzionali". ----------- AGGIORNAMENTO (118) La L. 27 dicembre 2019, n. 160, come modificata dal D.L. 29 dicembre 2022, n. 198 ha disposto (con l'art. 1, comma 158) che "Per le medesime finalita' di cui al comma 155, nonche' al fine di sostenere le attivita' in materia di programmazione, realizzazione e monitoraggio delle opere pubbliche, nel triennio 2020-2022, la percentuale stabilita al primo periodo del comma 6 dell'articolo 19 del decreto legislativo 30 marzo 2001, n. 165, per gli incarichi di livello dirigenziale non generale da conferire al personale in servizio presso il Ministero delle infrastrutture e dei trasporti in possesso di comprovate professionalita', con oneri a valere sulle facolta' assunzionali del medesimo Ministero, e' pari al 12 per cento". ----------- AGGIORNAMENTO (119) Il D.L. 1 marzo 2021, n. 22, come modificato dal D.L. 24 febbraio 2023, n. 13, ha disposto (con l'art. 7, comm 13) che "I titolari di incarichi dirigenziali nell'ambito della Direzione generale Turismo del Ministero per i beni e le attivita' culturali e per il turismo appartenenti ai ruoli dirigenziali di altre amministrazioni e trasferiti al Ministero del turismo ai sensi del comma 5 possono optare per il transito nel ruolo di quest'ultimo Ministero. Nelle more della conclusione delle procedure concorsuali per il reclutamento del personale dirigenziale, fino al 31 dicembre 2026, per il conferimento di incarichi dirigenziali di livello generale presso il Ministero del turismo, non si applicano i limiti percentuali di cui all'articolo 19, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, e, per il conferimento di incarichi dirigenziali di livello non generale, i limiti percentuali di cui all'articolo 19, commi 5-bis e 6, sono elevati rispettivamente fino al 50 e al 30 per cento. I predetti incarichi dirigenziali di livello non generale cessano all'atto dell'assunzione in servizio, nei ruoli del personale del Ministero del turismo, dei vincitori delle predette procedure concorsuali". ----------- AGGIORNAMENTO (122) Il D.L. 9 giugno 2021, n. 80, convertito con modificazioni dalla L. 6 agosto 2021, n. 113, come modificato dal D.L. 22 aprile 2023, n. 44, convertito con modificazioni dalla L. 21 giugno 2023, n. 74, ha disposto (con l'art. 1, comm 15) che "Fino al 31 dicembre 2026, per le predette amministrazioni, per la copertura dei posti delle rispettive articolazioni che rivestono la qualifica di soggetti attuatori del PNRR, le quote di cui all'articolo 19, comma 6, del medesimo decreto legislativo n. 165 del 2001, riferite agli incarichi dirigenziali generali e non generali, si applicano nella misura del 12 per cento.". ----------- AGGIORNAMENTO (124) Il D.L. 22 giugno 2023, n. 75 ha disposto (con l'art. 22, comma 1) che "In coerenza con gli obiettivi di valorizzazione delle competenze acquisite dal personale della pubblica amministrazione contenuti nel Piano nazionale di ripresa e resilienza (PNRR), al fine di agevolare i percorsi di carriera del personale civile di livello dirigenziale che ha acquisito specifiche professionalita', fino al 31 dicembre 2027, gli incarichi di funzione dirigenziale di livello generale previsti nella dotazione organica del Ministero dell'interno possono essere conferiti a dirigenti di seconda fascia appartenenti ai ruoli dei dirigenti del medesimo Ministero, in deroga al limite percentuale di cui all'articolo 19, comma 4, del decreto legislativo 30 marzo 2001, n. 165 e, comunque, nel limite massimo di due unita' ulteriori". --------------- AGGIORNAMENTO (129) Il D.L. 2 marzo 2024, n. 19, convertito con modificazioni dalla L. 29 aprile 2024, n. 56, ha disposto (con l'art. 8, comma 15-bis) che "Al fine di garantire le capacita' tecnico-amministrative dell'Agenzia industrie difesa, in coerenza con gli obiettivi di modernizzazione della pubblica amministrazione e di valorizzazione delle competenze previsti nel PNRR, fino al 31 dicembre 2026 la percentuale stabilita al primo periodo del comma 6 dell'articolo 19 del decreto legislativo 30 marzo 2001, n. 165, e' elevata al 20 per cento per il conferimento degli incarichi di livello dirigenziale non generale previsti nella dotazione organica della stessa Agenzia industrie difesa, con oneri a valere sulle facolta' assunzionali della medesima disponibili a legislazione vigente. Le disposizioni del primo periodo non si applicano per il conferimento di incarichi di livello dirigenziale non generale al personale militare". --------------- AGGIORNAMENTO (132) Il D.L. 29 giugno 2024, n. 89 ha disposto (con l'art. 4, comma 1) che, fermo restando quanto previsto dall'articolo 95, comma 15, del decreto-legge 14 agosto 2020, n. 104, convertito, con modificazioni, dalla legge 13 ottobre 2020, n. 126, al fine di consentire l'avvio delle attivita' prodromiche all'operativita' dell'Autorita' per la Laguna di Venezia, istituita dall'articolo 95 del medesimo decreto-legge n. 104 del 2020, e di predisporre gli atti necessari al funzionamento della stessa, il Presidente della suddetta Autorita', in fase di prima applicazione, e' autorizzato a conferire gli incarichi di livello dirigenziale generale previsti dall'articolo 95, comma 10, del decreto-legge n. 104 del 2020, anche in deroga alle percentuali di cui all'articolo 19, comma 6, del decreto legislativo 30 marzo 2001, n. 165, a stipulare un numero massimo di otto contratti di collaborazione, della durata massima di un anno e per un importo annuo non superiore a euro 40.000, al lordo dei contributi previdenziali e degli oneri fiscali a carico dell'amministrazione, per ciascun incarico ai sensi dell'articolo 7, comma 6, del predetto decreto legislativo n. 165 del 2001, e a deliberare il bilancio del primo esercizio finanziario entro 45 giorni dall'insediamento, previo parere del Collegio dei revisori dei conti. --------------- AGGIORNAMENTO (139) Il D.L. 24 giugno 2025, n. 90 ha disposto (con l'art. 3, comma 4) che "Fino al 31 dicembre 2026, e' autorizzato il conferimento di un incarico dirigenziale generale presso il Ministero dell'universita' e della ricerca, oltre il limite percentuale di cui all'articolo 19, comma 6, del decreto legislativo 30 marzo 2001, n. 165. Agli oneri di cui al presente comma si provvede nei limiti delle facolta' assunzionali disponibili a legislazione vigente".

#### Articolo 20 - Verifica dei risultati (Art.20 del d.lgs n.29 del 1993, come sostituito dall'art.6 del d.lgs n.470 del 1993 e successivamente modificato prima dall'art.43, comma 1 del d.lgs n.80 del 1998 poi dall'art.6 del d.lgs n.387 del 1998 e, infine, dagli artt.5, comma 5 e 10, comma 2 del d.lgs n.286 del 1999)

1. Per la Presidenza del Consiglio dei ministri e per le amministrazioni che esercitano competenze in materia di difesa e sicurezza dello Stato, di polizia e di giustizia, le operazioni di verifica sono effettuate dal Ministro per i dirigenti e dal Consiglio dei ministri per i dirigenti preposti ad ufficio di livello dirigenziale generale. I termini e le modalita' di attuazione del procedimento di verifica dei risultati da parte del Ministro competente e del Consiglio dei ministri sono stabiliti rispettivamente con regolamento ministeriale e con decreto del Presidente della Repubblica adottato ai sensi dell'articolo 17 della legge 23 agosto 1988, n. 400, e successive modificazioni ed integrazioni, ovvero, fino alla data di entrata in vigore di tale decreto, con provvedimenti dei singoli ministeri interessati.

#### Art. 21. - Responsabilita' dirigenziale (Art. 2l, commi 1, 2 e 5 del d.lgs. n. 29 del 1993, come sostituiti prima dall'art. 12 del d.lgs. n. 546 del 1993 e poi dall'art. 14 del d.lgs. n. 80 del 1998 e successivamente modificati dall'art. 7 del d.lgs. n. 387 del 1998)

1. Il mancato raggiungimento degli obiettivi accertato attraverso le risultanze del sistema di valutazione di cui al Titolo II del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni ovvero l'inosservanza delle direttive imputabili al dirigente comportano, previa contestazione e ferma restando l'eventuale responsabilita' disciplinare secondo la disciplina contenuta nel contratto collettivo, l'impossibilita' di rinnovo dello stesso incarico dirigenziale. In relazione alla gravita' dei casi, l'amministrazione puo' inoltre, previa contestazione e nel rispetto del principio del contraddittorio, revocare l'incarico collocando il dirigente a disposizione dei ruoli di cui all'articolo 23 ovvero recedere dal rapporto di lavoro secondo le disposizioni del contratto collettivo.

1-bis. Al di fuori dei casi di cui al comma 1, al dirigente nei confronti del quale sia stata accertata, previa contestazione e nel rispetto del principio del contraddittorio secondo le procedure previste dalla legge e dai contratti collettivi nazionali, la colpevole violazione del dovere di vigilanza sul rispetto, da parte del personale assegnato ai propri uffici, degli standard quantitativi e qualitativi fissati dall'amministrazione, conformemente agli indirizzi deliberati dalla Commissione di cui all'articolo 13 del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni, la retribuzione di risultato e' decurtata, sentito il Comitato dei garanti, in relazione alla gravita' della violazione di una quota fino all'ottanta per cento.

2. COMMA ABROGATO DALLA L. 15 LUGLIO 2002, N. 145.

3. Restano ferme le disposizioni vigenti per il personale delle qualifiche dirigenziali delle Forze di polizia, delle carriere diplomatica e prefettizia e delle Forze armate nonche' del Corpo nazionale dei vigili del fuoco ((nonche' del Corpo nazionale dei vigili del fuoco)).((79))

--------------- AGGIORNAMENTO (79) Il D.Lgs. 6 ottobre 2018, n. 127, nel modificare l'art. 205 del D.Lgs. 13 ottobre 2005, n. 217, ha conseguentemente disposto (con l'art. 12, comma 1) che gli effetti giuridici ed economici della presente modifica decorrono dalla data del 1° gennaio 2018.

#### Art. 22. - (( (Comitato dei garanti). ))

((

1. I provvedimenti di cui all'articolo 21, commi 1 e 1-bis, sono adottati sentito il Comitato dei garanti, i cui componenti, nel rispetto del principio di genere, sono nominati con decreto del Presidente del Consiglio dei Ministri. Il Comitato dura in carica tre anni e l'incarico non e' rinnovabile.

2. Il Comitato dei garanti e' composto da un consigliere della Corte dei conti, designato dal suo Presidente, e da quattro componenti designati rispettivamente, uno dal Presidente della Commissione di cui all'articolo 13 del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico, e di efficienza e trasparenza delle pubbliche amministrazioni, uno dal Ministro per la pubblica amministrazione e l'innovazione, scelto tra un esperto scelto tra soggetti con specifica qualificazione ed esperienza nei settori dell'organizzazione amministrativa e del lavoro pubblico, e due scelti tra dirigenti di uffici dirigenziali generali di cui almeno uno appartenente agli Organismi indipendenti di valutazione, estratti a sorte fra coloro che hanno presentato la propria candidatura. I componenti sono collocati fuori ruolo e il posto corrispondente nella dotazione organica dell'amministrazione di appartenenza e' reso indisponibile per tutta la durata del mandato. Per la partecipazione al Comitato non e' prevista la corresponsione di emolumenti o rimborsi spese.

3. Il parere del Comitato dei garanti viene reso entro il termine di quarantacinque giorni dalla richiesta; decorso inutilmente tale termine si prescinde dal parere.

))

#### Art. 23. - (Ruolo dei dirigenti)

1. In ogni amministrazione dello Stato, anche ad ordinamento autonomo, e' istituito il ruolo dei dirigenti, che si articola nella prima e nella seconda fascia, nel cui ambito sono definite apposite sezioni in modo da garantire la eventuale specificita' tecnica. I dirigenti della seconda fascia sono reclutati attraverso i meccanismi di accesso di cui all'articolo 28. I dirigenti della seconda fascia transitano nella prima qualora abbiano ricoperto incarichi di direzione di uffici dirigenziali generali o equivalenti, in base ai particolari ordinamenti di cui all'articolo 19, comma 11, per un periodo pari almeno a cinque anni senza essere incorsi nelle misure previste dall'articolo 21 per le ipotesi di responsabilita' dirigenziale, ((nei limiti dei posti complessivamente disponibili, al netto dei posti previsti dall'articolo 28-bis, comma 1)), ovvero nel momento in cui si verifica la prima disponibilita' di posto utile, tenuto conto, quale criterio di precedenza ai fini del transito, della data di maturazione del requisito dei cinque anni e, a parita' di data di maturazione, della maggiore anzianita' nella qualifica dirigenziale. (33)

2. E' assicurata la mobilita' dei dirigenti, nei limiti dei posti disponibili, in base all' articolo 30 del presente decreto. I contratti o accordi collettivi nazionali disciplinano, secondo il criterio della continuita' dei rapporti e privilegiando la libera scelta del dirigente, gli effetti connessi ai trasferimenti e alla mobilita' in generale in ordine al mantenimento del rapporto assicurativo con l'ente di previdenza, al trattamento di fine rapporto e allo stato giuridico legato all'anzianita' di servizio e al fondo di previdenza complementare. La Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica cura una banca dati informatica contenente i dati relativi ai ruoli delle amministrazioni dello Stato.

--------------- AGGIORNAMENTO (33) Il D.Lgs. 27 ottobre 2009, n. 150, ha disposto (con l'art. 43, comma 2) che "Per i dirigenti ai quali sia stato conferito l'incarico di direzione di uffici dirigenziali generali o equivalenti prima della data di entrata in vigore del presente decreto, il termine di cui all'articolo 23, comma 1, terzo periodo, del decreto legislativo n. 165 del 2001, rimane fissato in tre anni."

#### Art. 23-bis. - (Disposizioni in materia di mobilita' tra pubblico e privato).

1. In deroga all'articolo 60 del testo unico delle disposizioni concernenti lo statuto degli impiegati civili dello Stato, di cui al decreto del Presidente della Repubblica 10 gennaio 1957, n. 3, ((i dipendenti delle pubbliche amministrazioni, ivi compresi gli appartenenti alle carriere diplomatica e prefettizia,)) e, limitamente agli incarichi pubblici, i magistrati ordinari, amministrativi e contabili e gli avvocati e procuratori dello Stato sono collocati, salvo motivato diniego dell'amministrazione di appartenenza in ordine alle proprie preminenti esigenze organizzative, in aspettativa senza assegni per lo svolgimento di attivita' presso soggetti e organismi, pubblici o privati, anche operanti in sede internazionale, i quali provvedono al relativo trattamento previdenziale. Resta ferma la disciplina vigente in materia di collocamento fuori ruolo nei casi consentiti. Il periodo di aspettativa comporta il mantenimento della qualifica posseduta. E' sempre ammessa la ricongiunzione dei periodi contributivi a domanda dell'interessato, ai sensi della legge 7 febbraio 1979, n. 29, presso una qualsiasi delle forme assicurative nelle quali abbia maturato gli anni di contribuzione. Quando l'incarico e' espletato presso organismi operanti in sede internazionale, la ricongiunzione dei periodi contributivi e' a carico dell'interessato, salvo che l'ordinamento dell'amministrazione di destinazione non disponga altrimenti. (25)

2. I dirigenti di cui all'articolo 19, comma 10, sono collocati a domanda in aspettativa senza assegni per lo svolgimento dei medesimi incarichi di cui al comma 1 del presente articolo, salvo motivato diniego dell'amministrazione di appartenenza in ordine alle proprie preminenti esigenze organizzative.

3. Per i magistrati ordinari, amministrativi e contabili, e per gli avvocati e procuratori dello Stato, gli organi competenti deliberano il collocamento in aspettativa, fatta salva per i medesimi la facolta' di valutare ragioni ostative all'accoglimento della domanda.

4. Nel caso di svolgimento di attivita' presso soggetti diversi dalle amministrazioni pubbliche, il periodo di collocamento in aspettativa di cui al comma 1 non puo' superare i cinque anni ((, e' rinnovabile per una sola volta)) e non e' computabile ai fini del trattamento di quiescenza e previdenza.

5. L'aspettativa per lo svolgimento di attivita' o incarichi presso soggetti privati o pubblici da parte del personale di cui al comma 1 non puo' comunque essere disposta se:

- a) il personale, nei due anni precedenti, e' stato addetto a funzioni di vigilanza, di controllo ovvero, nel medesimo periodo di tempo, ha stipulato contratti o formulato pareri o avvisi su contratti o concesso autorizzazioni a favore di soggetti presso i quali intende svolgere l'attivita'. Ove l'attivita' che si intende svolgere sia presso una impresa, il divieto si estende anche al caso in cui le predette attivita' istituzionali abbiano interessato imprese che, anche indirettamente, la controllano o ne sono controllate, ai sensi dell'articolo 2359 del codice civile;
- b) il personale intende svolgere attivita' in organismi e imprese private che, per la loro natura o la loro attivita', in relazione alle funzioni precedentemente esercitate, possa cagionare nocumento all'immagine dell'amministrazione o comprometterne il normale funzionamento o l'imparzialita'.

((6. Il personale di cui al comma 1, nei successivi due anni, non puo' essere destinatario di incarichi ne' essere impiegato nello svolgimento di attivita' che comportino l'esercizio delle funzioni individuate alla lettera a) del comma 5))

7. Sulla base di appositi protocolli di intesa tra le parti, le amministrazioni di cui all'articolo 1, comma 2, possono disporre, per singoli progetti di interesse specifico dell'amministrazione e con il consenso dell'interessato, l'assegnazione temporanea di personale presso altre pubbliche amministrazioni o imprese private. I protocolli disciplinano le funzioni, le modalita' di inserimento, l'onere per la corresponsione del trattamento economico da porre a carico delle imprese destinatarie. Nel caso di assegnazione temporanea presso imprese private i predetti protocolli possono prevedere l'eventuale attribuzione di un compenso aggiuntivo, con oneri a carico delle imprese medesime.

8. Il servizio prestato dai dipendenti durante il periodo di assegnazione temporanea di cui al comma 7 costituisce titolo valutabile ai fini della progressione di carriera.

9. Le disposizioni del presente articolo non trovano comunque applicazione nei confronti del personale militare e delle Forze di polizia, nonche' del Corpo nazionale dei vigili del fuoco.

10. COMMA ABROGATO DAL D.L. 31 AGOSTO 2013, N. 101, CONVERTITO CON MODIFICAZIONI DALLA L. 30 OTTOBRE 2013, N. 125.

--------------- AGGIORNAMENTO (25) La L. 27 dicembre 2006, n. 296 ha disposto (con l'art. 1, comma 578) che "L'articolo 23-bis, comma 1, del decreto legislativo 30 marzo 2001, n. 165, si interpreta nel senso che ai dirigenti delle pubbliche amministrazioni, agli appartenenti alla carriera diplomatica e prefettizia nonche' ai magistrati ordinari, amministrativi e contabili, agli avvocati e procuratori dello Stato, collocati in aspettativa senza assegni presso soggetti e organismi pubblici, e' riconosciuta l'anzianita' di servizio. E' fatta salva l'esecuzione dei giudicati formatisi alla data di entrata in vigore della presente legge".

#### Art. 24. - Trattamento economico (Art. 24 del d.lgs. n. 29 del 1993, come sostituito prima dall'art. 13 del d.lgs. n. 546 del 1993 e poi dall'art. 16 del d.lgs. n. 80 del 1998 e successivamente modificato prima dall'art. 9 del d.lgs n. 387 del 1998 e poi dall'art. 26, comma 6 della legge n. 448 del 1998)

1. La retribuzione del personale con qualifica di dirigente e' determinata dai contratti collettivi per le aree dirigenziali, prevedendo che il trattamento economico accessorio sia correlato alle funzioni attribuite, alle connesse responsabilita' e ai risultati conseguiti. La graduazione delle funzioni e responsabilita' ai fini del trattamento accessorio e' definita, ai sensi dell'articolo 4, con decreto ministeriale per le amministrazioni dello Stato e con provvedimenti dei rispettivi organi di governo per le altre amministrazioni o enti, ferma restando comunque l'osservanza dei criteri e dei limiti delle compatibilita' finanziarie fissate dal Presidente del Consiglio dei ministri, di concerto con il Ministro ((dell'economia e delle finanze)).

1-bis. Il trattamento accessorio collegato ai risultati deve costituire almeno il 30 per cento della retribuzione complessiva del dirigente considerata al netto della retribuzione individuale di anzianita' e degli incarichi aggiuntivi soggetti al regime dell'onnicomprensivita'.

1-ter. I contratti collettivi nazionali incrementano progressivamente la componente legata al risultato, in modo da adeguarsi a quanto disposto dal comma 1-bis, entro la tornata contrattuale successiva a quella decorrente dal 1° gennaio 2010, destinando comunque a tale componente tutti gli incrementi previsti per la parte accessoria della retribuzione. La disposizione di cui al comma 1-bis non si applica alla dirigenza del Servizio sanitario nazionale e dall'attuazione del medesimo comma non devono derivare nuovi o maggiori oneri per la finanza pubblica.

1-quater. La parte della retribuzione collegata al raggiungimento dei risultati della prestazione non puo' essere corrisposta al dirigente responsabile qualora l'amministrazione di appartenenza, decorso il periodo transitorio di sei mesi dalla data di entrata in vigore del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni, non abbia predisposto il sistema di valutazione di cui al Titolo II del citato decreto legislativo.

2. Per gli incarichi di uffici dirigenziali di livello generale ai sensi dell'articolo 19, commi 3 e 4, con contratto individuale e' stabilito il trattamento economico fondamentale, assumendo come parametri di base i valori economici massimi contemplati dai contratti collettivi per le aree dirigenziali, e sono determinati gli istituti del trattamento economico accessorio, collegato al livello di responsabilita' attribuito con l'incarico di funzione ed ai risultati conseguiti nell'attivita' amministrativa e di gestione, ed i relativi importi. Con decreto del Presidente del Consiglio dei Ministri, di concerto con il Ministro dell'economia e delle finanze sono stabiliti i criteri per l'individuazione dei trattamenti accessori massimi, secondo principi di contenimento della spesa e di uniformita' e perequazione.

3. Il trattamento economico determinato ai sensi dei commi 1 e 2 remunera tutte le funzioni ed i compiti attribuiti ai dirigenti in base a quanto previsto dal presente decreto, nonche' qualsiasi incarico ad essi conferito in ragione del loro ufficio o comunque conferito dall'amministrazione presso cui prestano servizio o su designazione della stessa; i compensi dovuti dai terzi sono corrisposti direttamente alla medesima amministrazione e confluiscono nelle risorse destinate al trattamento economico accessorio della dirigenza.

4. Per il restante personale con qualifica dirigenziale indicato dall'articolo 3, comma 1, la retribuzione e' determinata ai sensi dell'articolo 2, commi 5 e 7, della legge 6 marzo 1992, n. 216, nonche' dalle successive modifiche ed integrazioni della relativa disciplina.

5. Il bilancio triennale e le relative leggi finanziarie, nell'ambito delle risorse da destinare ai miglioramenti economici delle categorie di personale di cui all'articolo 3, indicano te somme da destinare, in caso di perequazione, al riequilibrio del trattamento economico del restante personali dirigente civile e militare non contrattualizzato con il trattamento previsto dai contratti collettivi nazionali per i dirigenti del comparto ministeri, tenendo conto dei rispettivi trattamenti economici complessivi e degli incrementi comunque determinatisi a partire dal febbraio 1993, e secondo i criteri indicati nell'articolo 1, comma 2, della legge 2 ottobre 1997, n. 334.

6. I fondi per la perequazione di cui all'articolo 2 della legge 2 ottobre 1997, n. 334, destinati al personale di cui all'articolo 3, comma 2, sono assegnati alle universita' e da queste utilizzati per l'incentivazione dell'impegno didattico dei professori e ricercatori universitari, con particolare riferimento al sostegno dell'innovazione didattica, delle attivita' di orientamento e tutorato, della diversificazione dell'offerta formativa. Le universita' possono destinare allo stesso scopo propri fondi, utilizzando anche le somme attualmente stanziate per il pagamento delle supplenze e degli affidamenti. Le universita' possono erogare, a valere sul proprio bilancio, appositi compensi incentivanti ai professori e ricercatori universitari che svolgono attivita' di ricerca nell'ambito dei progetti e dei programmi dell'Unione europea e internazionali. L'incentivazione, a valere sui fondi di cui all'articolo 2 della predetta legge n. 334 del 1997, e' erogata come assegno aggiuntivo pensionabile.

7. I compensi spettanti in base a norme speciali ai dirigenti dei ruoli di cui all'articolo 23 o equiparati sono assorbiti nel trattamento economico attribuito ai sensi dei commi precedenti.

8. Ai fini della determinazione del trattamento economico accessorio le risorse che si rendono disponibili ai sensi del comma 7 confluiscono in appositi fondi istituiti presso ciascuna amministrazione, unitamente agli altri compensi previsti dal presente articolo.

9. COMMA ABROGATO DAL D.L. 28 MAGGIO 2004, N. 136, CONVERTITO CON MODIFICAZIONI DALLA L. 27 LUGLIO 2004, N. 186.

#### Articolo 25 - Dirigenti delle istituzioni scolastiche (Art.25-bis del d.lgs n.29 del 1993, aggiunto dall'art.1 del d.lgs n.59 del 1998; Art. 25-ter del d.lgs n.29 del 1993, aggiunto dall'art.1 del d.lgs n.59 del 1998)

1. Nell'ambito dell'amministrazione scolastica periferica e' istituita la qualifica dirigenziale per i capi di istituto preposti alle istituzioni scolastiche ed educative alle quali e' stata attribuita personalita' giuridica ed autonomia a norma dell'articolo 21 della legge 15 marzo 1997, n. 59, e successive modificazioni ed integrazioni. I dirigenti scolastici sono inquadrati in ruoli di dimensione regionale e rispondono, agli effetti dell'articolo 21, in ordine ai risultati, che sono valutati tenuto conto della specificita' delle funzioni e sulla base ((degli strumenti e dei dati a disposizione del sistema informativo del Ministero dell'istruzione e del merito nonche')) del Sistema nazionale di valutazione dei risultati dei dirigenti scolastici, adottato con decreto del Ministro dell'istruzione e del merito, che stabilisce gli indirizzi per la definizione degli obiettivi strategici volti ad assicurare il buon andamento dell'azione dirigenziale e individua i soggetti che intervengono nella procedura di valutazione, in coerenza con la direttiva generale del Ministro dell'istruzione e del merito, di cui all'articolo 15, comma 2, lettera a), del decreto legislativo 27 ottobre 2009, n. 150. ((131))

2. Il dirigente scolastico assicura la gestione unitaria dell'istituzione, ne ha la legale rappresentanza, e' responsabile della gestione delle risorse finanziarie e strumentali e dei risultati deI servizio. Nel rispetto delle competenze degli organi collegiali scolastici, spettano al dirigente scolastico autonomi poteri di direzione, di coordinamento e di valorizzazione delle risorse umane. In particolare, il dirigente scolastico organizza l'attivita' scolastica secondo criteri di efficienza e di efficacia formative ed e' titolare delle relazioni sindacali.

3. Nell'esercizio delle competenze di cui al comma 2, il dirigente scolastico promuove gli interventi per assicurare la qualita' dei processi formativi e la collaborazione delle risorse culturali, professionali, sociali ed economiche del territorio, per l'esercizio della liberta' di insegnamento, intesa anche come liberta' di ricerca e innovazione metodologica e didattica, per l'esercizio della liberta' di scelta educativa delle famiglie e per l'attuazione del diritto all'apprendimento da parte degli alunni.

4. Nell'ambito delle funzioni attribuite alle istituzioni scolastiche, spetta al dirigente l'adozione dei provvedimenti di gestione delle risorse e del personale.

5. Nello svolgimento delle proprie funzioni organizzative e amministrative il dirigente puo' avvalersi di docenti da lui individuati, ai quali possono essere delegati specifici compiti, ed e' coadiuvato dal responsabile amministrativo, che sovrintende, con autonomia operativa, nell'ambito delle direttive di massima impartite e degli obiettivi assegnati, ai servizi amministrativi ed ai servizi generali dell'istituzione scolastica, coordinando il relativo personale. (48)

6. Il dirigente presenta periodicamente al consiglio di circolo o al consiglio di istituto motivata relazione sulla direzione e il coordinamento dell'attivita' formativa, organizzativa e amministrativa al fine di garantire la piu' ampia informazione e un efficace raccordo per l'esercizio delle competenze degli organi della istituzione scolastica.

7. I capi di istituto con rapporto di lavoro a tempo indeterminato, ivi compresi i rettori e vicerettori dei convitti nazionali, le direttrici e vice direttrici degli educandati, assumono la qualifica di dirigente, previa frequenza di appositi corsi di formazione, all'atto della preposizione alle istituzioni scolastiche dotate di autonomia e della personalita' giuridica a norma dell'articolo 21 della legge 15 marzo 1997, n. 59, e successive modificazioni ed integrazioni, salvaguardando. per quanto possibile, la titolarita' della sede di servizio.

8. Il Ministro della pubblica istruzione, con proprio decreto, definisce gli obiettivi, i contenuti e la durata della formazione; determina le modalita' di partecipazione ai diversi moduli formativi e delle connesse verifiche; definisce i criteri di valutazione e di certificazione della qualita' di ciascun corso; individua gli organi dell'amministrazione scolastica responsabili dell'articolazione e del coordinamento dei corsi sul territorio, definendone i criteri; stabilisce le modalita' di svolgimento dei corsi con il loro affidamento ad universita', agenzie specializzate ed enti pubblici e privati anche tra loro associati o consorziati.

9. La direzione dei conservatori di musica, delle accademie di belle arti, degli istituti superiori per le industrie artistiche e delle accademie nazionali di arte drammatica e di danza, e' equiparata alla dirigenza dei capi d'istituto. Con decreto del Ministro della pubblica istruzione sono disciplinate le modalita' di designazione e di conferimento e la durata dell'incarico, facendo salve le posizioni degli attuali direttori di ruolo.

10. Contestualmente all'attribuzione della qualifica dirigenziale, ai vicerettori dei convitti nazionali e alle vicedirettrici degli educandati sono soppressi i corrispondenti posti. Alla conclusione delle operazioni sono soppressi i relativi ruoli.

11. I capi d'istituto che rivestano l'incarico di Ministro o Sottosegretario di Stato, ovvero siano in aspettativa per mandato parlamentare o amministrativo o siano in esonero sindacale, distaccati, comandati, utilizzati o collocati fuori ruolo possono assolvere all'obbligo di formazione mediante la frequenza di appositi moduli nell'ambito della formazione prevista dal presente articolo, ovvero della formazione di cui all'articolo 29. In tale ultimo caso l'inquadramento decorre ai fini giuridici dalla prima applicazione degli inquadramenti di cui al comma 7 ed ai fini economici dalla data di assegnazione ad una istituzione scolastica autonoma.

--------------- AGGIORNAMENTO (48) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 14, comma 22) che "Il comma 5 dell'articolo 25 del decreto legislativo 30 marzo 2001, n. 165, si interpreta nel senso che la delega ai docenti di compiti non costituisce affidamento di mansioni superiori o di funzioni vicarie, anche nel caso in cui detti docenti godano dell'esonero o semiesonero ai sensi dell'articolo 459 del decreto legislativo n. 297 del 1994. Il docente delegato puo' essere retribuito esclusivamente a carico dei fondi disponibili per la remunerazione accessoria presso la specifica istituzione scolastica od educativa ai sensi dell'articolo 88, comma 2, lettera f), del ccnl relativo al personale scolastico". --------------- AGGIORNAMENTO (131) Il D.L. 31 maggio 2024, n. 71, convertito con modificazioni dalla L. 29 luglio 2024, n. 106, ha disposto (con l'art. 13, comma 3) che la presente modifica si applica a decorrere dall'anno scolastico 2024/2025.

#### Articolo 26 - Norme per la dirigenza del Servizio sanitario nazionale (Art.26, commi 1, 2-quinquies e 3 del d.lgs n.29 del 1993, modificati prima dall'art.14 del d.lgs n.546 del 1993 e poi dall'art.45, comma 15 del d.lgs n.80 del 1998)

1. Alla qualifica di dirigente dei ruoli professionale, tecnico ed amministrativo del Servizio sanitario nazionale si accede mediante concorso pubblico per titoli ed esami, al quale sono ammessi candidati in possesso del relativo diploma di laurea, con cinque anni di servizio effettivo corrispondente alla medesima professionalita' prestato in enti del Servizio sanitario nazionale nella posizione funzionale di settimo e ottavo livello, ovvero in qualifiche funzionali di settimo, ottavo e nono livello di altre pubbliche amministrazioni. Relativamente al personale del ruolo tecnico e professionale, l'ammissione e' altresi' consentita ai candidati in possesso di esperienze lavorative con rapporto di lavoro libero-professionale o di attivita' coordinata e continuata presso enti o pubbliche amministrazioni, ovvero di attivita' documentate presso studi professionali privati, societa' o istituti di ricerca, aventi contenuto analogo a quello previsto per corrispondenti profili del molo medesimo.

2. Nell'attribuzione degli incarichi dirigenziali determinati in relazione alla struttura organizzativa derivante dalle leggi regionali di cui all'articolo 3 del decreto legislativo 30 dicembre 1992, n. 502, si deve tenere conto della posizione funzionale posseduta dal relativo personale all'atto dell'inquadramento nella qualifica di dirigente. E' assicurata la corrispondenza di funzioni, a parita' di struttura organizzativa, dei dirigenti di piu' elevato livello dei ruoli di cui al comma 1 con i dirigenti di secondo livello del ruolo sanitario.

3. Fino alla ridefinizione delle piante organiche non puo' essere disposto alcun incremento delle dotazioni organiche per ciascuna delle attuali posizioni funzionali dirigenziali del ruolo sanitario, professionale, tecnico ed amministrativo.

#### Articolo 27 - Criteri di adeguamento per le pubbliche amministrazioni non statali (Art.27-bis del d.lgs n.29 del 1993, aggiunto dall'art.17 del d.lgs n.80 del 1998)

1. Le regioni a statuto ordinario, nell'esercizio della propria potesta' statutaria, legislativa e regolamentare, e le altre pubbliche amministrazioni, nell'esercizio della propria potesta' statutaria e regolamentare, adeguano ai principi dell'articolo 4 e del presente capo i propri ordinamenti, tenendo conto delle relative peculiarita'. Gli enti pubblici non economici nazionali si adeguano, anche in deroga alle speciali disposizioni di legge che li disciplinano, adottando appositi regolamenti di organizzazione.

2. Le pubbliche amministrazioni di cui al comma 1 trasmettono, entro due mesi dalla adozione, le deliberazioni, le disposizioni ed i provvedimenti adottati in attuazione del medesimo comma alla Presidenza del Consiglio dei ministri, che ne cura la raccolta e la pubblicazione.

## Accesso alla dirigenza e riordino della ((Scuola nazionale dell'amministrazione))

### Art. 28. - Accesso alla qualifica di dirigente della seconda fascia

1. ((L'accesso alla qualifica di dirigente di seconda fascia nelle amministrazioni statali, anche ad ordinamento autonomo, e negli enti pubblici non economici avviene per corso-concorso selettivo di formazione bandito dalla Scuola nazionale dell'amministrazione, per concorso indetto dalle singole amministrazioni ovvero per concorso unico ai sensi dell'articolo 35, comma 4-ter.))

1-bis. Nelle procedure concorsuali per l'accesso alla dirigenza in aggiunta all'accertamento delle conoscenze delle materie disciplinate dal decreto del Presidente della Repubblica 9 maggio 1994, n. 487, i bandi definiscono gli ambiti di competenza da valutare e prevedono la valutazione delle capacita', attitudini e motivazioni individuali, anche attraverso prove, scritte e orali, finalizzate alla loro osservazione e valutazione comparativa, definite secondo metodologie e standard riconosciuti.

1-ter. Fatta salva la percentuale non inferiore al 50 per cento dei posti da ricoprire, destinata al corso-concorso selettivo di formazione bandito dalla Scuola nazionale dell'amministrazione, ai fini di cui al comma 1, una quota non superiore al 30 per cento dei posti residui disponibili sulla base delle facolta' assunzionali autorizzate e' riservata da ciascuna pubblica amministrazione al personale in servizio a tempo indeterminato, in possesso dei titoli di studio previsti a legislazione vigente e che abbia maturato almeno cinque anni di servizio nell'area o categoria apicale. Il personale di cui al presente comma e' selezionato attraverso procedure comparative bandite dalla Scuola nazionale dell'amministrazione, che tengono conto della valutazione conseguita nell'attivita' svolta, dei titoli professionali, di studio o di specializzazione ulteriori rispetto a quelli previsti per l'accesso alla qualifica dirigenziale, e in particolar modo del possesso del dottorato di ricerca, nonche' della tipologia degli incarichi rivestiti con particolare riguardo a quelli inerenti agli incarichi da conferire e sono volte ad assicurare la valutazione delle capacita', attitudini e motivazioni individuali. Una quota non superiore al 15 per cento e' altresi' riservata al personale di cui al periodo precedente, in servizio a tempo indeterminato, che abbia ricoperto o ricopra l'incarico di livello dirigenziale di cui all'articolo 19, comma 6, del decreto legislativo 30 marzo 2001, n. 165. A tal fine, i bandi, che possono essere adottati anche dalle singole amministrazioni, definiscono gli ambiti di competenza da valutare e prevedono prove scritte e orali di esclusivo carattere esperienziale, finalizzate alla valutazione comparativa e definite secondo metodologie e standard riconosciuti. A questo scopo, sono nominati membri di commissione professionisti esperti nella valutazione dei suddetti ambiti di competenza, senza nuovi o maggiori oneri a carico della finanza pubblica. Le disposizioni di cui al presente comma non si applicano agli enti di cui ai commi 2 e 2-bis dell'articolo 2 del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125.

2. COMMA ABROGATO DAL D.P.R. 16 APRILE 2013, N. 70.

3. COMMA ABROGATO DAL D.P.R. 16 APRILE 2013, N. 70.

4. COMMA ABROGATO DAL D.P.R. 16 APRILE 2013, N. 70.

5. Con regolamento emanato ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, su proposta del Ministro per la funzione pubblica sentita, per la parte relativa al corso-concorso, la ((Scuola nazionale dell'amministrazione)), sono definiti:

- a) le percentuali, sul complesso dei posti di dirigente disponibili, riservate al concorso per esami, al corso-concorso;
- b) la percentuale di posti che possono essere riservati al personale di ciascuna amministrazione che indice i concorsi pubblici per esami;
- c) i criteri per la composizione e la nomina delle commissioni esaminatrici;
- d) le modalita' di svolgimento delle selezioni, prevedendo anche la valutazione delle esperienze di servizio professionali maturate nonche', nella fase di prima applicazione del concorso di cui al comma 2, una riserva di posti non superiore al 30 per cento per il personale appartenente da almeno quindici anni alla qualifica apicale, comunque denominata, della carriera direttiva;
- e) l'ammontare delle borse di studio per i partecipanti al corso-concorso.

6. I vincitori dei concorsi di cui al comma 2, anteriormente al conferimento del primo incarico dirigenziale, frequentano un ciclo di attivita' formative organizzato dalla ((Scuola nazionale dell'amministrazione)) e disciplinato ai sensi del decreto legislativo 30 luglio 1999, n. 287. Tale ciclo puo' comprendere anche l'applicazione presso amministrazioni italiane e straniere, enti o organismi internazionali, istituti o aziende pubbliche o private. Il medesimo ciclo formativo, di durata non superiore a dodici mesi, puo' svolgersi anche in collaborazione con istituti universitari italiani o stranieri, ovvero primarie istituzioni formative pubbliche o private.

7. COMMA ABROGATO DAL D.P.R. 16 APRILE 2013, N. 70.

7-bis. COMMA ABROGATO DAL D.P.R. 16 APRILE 2013, N. 70.

8. Restano ferme le vigenti disposizioni in materia di accesso alle qualifiche dirigenziali delle carriere diplomatica e prefettizia, delle Forze di polizia, delle Forze armate e del Corpo nazionale dei vigili del fuoco.

9. Per le finalita' di cui al presente articolo, e' attribuito alla ((Scuola nazionale dell'amministrazione)) un ulteriore contributo di 1.500 migliaia di euro a decorrere dall'anno 2002.

10. All'onere derivante dall'attuazione del comma 9, pari a 1.500 migliaia di euro a decorrere dall'anno 2002, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero.

### Art. 28-bis. - (Accesso alla qualifica di dirigente della prima fascia)

1. Fermo restando quanto previsto dall'articolo 19, comma 4, e dall'articolo 23, comma 1, secondo periodo, l'accesso alla qualifica di dirigente di prima fascia nelle amministrazioni statali, anche ad ordinamento autonomo, e negli enti pubblici non economici avviene, per il 50 per cento dei posti, calcolati con riferimento a quelli che si rendono disponibili ogni anno per la cessazione dal servizio dei soggetti incaricati, con le modalita' di cui al comma 3-bis. A tal fine, entro il 31 dicembre di ogni anno, le amministrazioni indicano, per il triennio successivo, il numero dei posti che si rendono vacanti per il collocamento in quiescenza del personale dirigenziale di ruolo di prima fascia e la programmazione relativa a quelli da coprire mediante concorso.

2. Nei casi in cui le amministrazioni valutino che la posizione da ricoprire richieda specifica esperienza, peculiare professionalita' e attitudini manageriali e qualora le ordinarie procedure di interpello non abbiano dato esito soddisfacente, l'attribuzione dell'incarico puo' avvenire attraverso il coinvolgimento di primarie societa' di selezione di personale dirigenziale e la successiva valutazione delle candidature proposte da parte di una commissione indipendente composta anche da membri esterni, senza maggiori oneri per la finanza pubblica. Nei casi di cui al presente comma non si applicano i limiti percentuali di cui all'articolo 19, comma 6. Gli incarichi sono conferiti con contratti di diritto privato a tempo determinato e stipulati per un periodo non superiore a tre anni. L'applicazione della disposizione di cui al presente comma non deve determinare posizioni sovrannumerarie.

3. Al concorso per titoli ed esami di cui al comma 1 possono essere ammessi i dirigenti di ruolo delle pubbliche amministrazioni, che abbiano maturato almeno cinque anni di servizio nei ruoli dirigenziali e gli altri soggetti in possesso di titoli di studio e professionali individuati nei bandi di concorso, con riferimento alle specifiche esigenze dell'Amministrazione e sulla base di criteri generali di equivalenza stabiliti con decreto del Presidente del Consiglio dei Ministri, previo parere della ((Scuola nazionale dell'amministrazione)), sentito il Ministro dell'istruzione, dell'universita' e della ricerca. A tale fine le amministrazioni che bandiscono il concorso tengono in particolare conto del personale di ruolo che ha esercitato per almeno cinque anni funzioni di livello dirigenziale generale all'interno delle stesse ovvero del personale appartenente all'organico dell'Unione europea in virtu' di un pubblico concorso organizzato da dette istituzioni.

3-bis. Al fine di assicurare la valutazione delle capacita', attitudini e motivazioni individuali, i concorsi di cui al comma 3 definiscono gli ambiti di competenza da valutare e prevedono prove scritte e orali, finalizzate alla valutazione comparativa, definite secondo metodologie e standard riconosciuti. A questo scopo, sono nominati membri di commissione professionisti esperti nella valutazione dei suddetti ambiti di competenza, senza maggiori oneri a carico della finanza pubblica.

4. I vincitori del concorso di cui al comma 1 sono assunti dall'amministrazione e, anteriormente al conferimento dell'incarico, sono tenuti all'espletamento di un periodo di formazione presso uffici amministrativi di uno Stato dell'Unione europea o di un organismo comunitario o internazionale secondo moduli definiti dalla Scuola nazionale dell'amministrazione. In ogni caso il periodo di formazione e' completato entro tre anni dalla conclusione del concorso.

5. COMMA ABROGATO DAL D.L. 9 GIUGNO 2021, N. 80, CONVERTITO, CON MODIFICAZIONI DALLA L. 6 AGOSTO 2021, N. 113.

6. Con regolamento emanato ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, su proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze, e sentita la ((Scuola nazionale dell'amministrazione)), sono disciplinate le modalita' di compimento del periodo di formazione, tenuto anche conto di quanto previsto nell'articolo 32.

7. Al termine del periodo di formazione e' prevista, da parte degli uffici di cui al comma 4, una valutazione del livello di professionalita' acquisito che equivale al superamento del periodo di prova necessario per l'immissione in ruolo di cui all'articolo 70, comma 13.

8. Le spese sostenute per l'espletamento del periodo di formazione svolto presso le sedi estere di cui al comma 4 sono a carico delle singole amministrazioni nell'ambito delle risorse finanziarie disponibili a legislazione vigente. (48) (65) (69) (76) (89) (104) (106)

--------------- AGGIORNAMENTO (48) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 2, comma 15) che "Fino alla conclusione dei processi di riorganizzazione di cui al presente articolo e comunque non oltre il 31 dicembre 2015 sono sospese le modalita' di reclutamento previste dall'articolo 28-bis del decreto legislativo 30 marzo 2001, n. 165." --------------- AGGIORNAMENTO (65) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, come modificato dal D.L. 30 dicembre 2015, n. 210, convertito con modificazioni dalla L. 25 febbraio 2016, n. 21, ha disposto (con l'art. 2, comma 15) che "Fino alla conclusione dei processi di riorganizzazione di cui al presente articolo e comunque non oltre il 31 dicembre 2016 sono sospese le modalita' di reclutamento previste dall'articolo 28-bis del decreto legislativo 30 marzo 2001, n. 165." ------------- AGGIORNAMENTO (69) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, come modificato dal D.L. 30 dicembre 2016, n. 244, convertito con modificazioni dalla L. 27 febbraio 2017, n. 19, ha disposto (con l'art. 2, comma 15) che "Fino alla conclusione dei processi di riorganizzazione di cui al presente articolo e comunque non oltre il 31 dicembre 2017 sono sospese le modalita' di reclutamento previste dall'articolo 28-bis del decreto legislativo 30 marzo 2001, n. 165". ----------- AGGIORNAMENTO (76) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, come modificato dalla L. 27 dicembre 2017, n. 205, ha disposto (con l'art. 2, comma 15) che "Fino alla conclusione dei processi di riorganizzazione di cui al presente articolo e comunque non oltre il 31 dicembre 2018 sono sospese le modalita' di reclutamento previste dall'articolo 28-bis del decreto legislativo 30 marzo 2001, n. 165". -------------- AGGIORNAMENTO (89) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, come modificato dal D.L. 30 dicembre 2019 n. 162, ha disposto (con l'art. 2, comma 15) che "Fino alla conclusione dei processi di riorganizzazione di cui al presente articolo e comunque non oltre il 31 dicembre 2020 sono sospese le modalita' di reclutamento previste dall'articolo 28-bis del decreto legislativo 30 marzo 2001, n. 165". -------------- AGGIORNAMENTO (104) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, come modificato dal D.L. 30 dicembre 2020 n. 183, ha disposto (con l'art. 2, comma 15) che "Fino alla conclusione dei processi di riorganizzazione di cui al presente articolo e comunque non oltre il 31 dicembre 2021 sono sospese le modalita' di reclutamento previste dall'articolo 28-bis del decreto legislativo 30 marzo 2001, n. 165". -------------- AGGIORNAMENTO (106) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, come modificato dal D.L. 9 giugno 2021, n. 80, convertito con modificazioni dalla L. 6 agosto 2021, n. 113, ha disposto (con l'art. 2, comma 15) che "Fino alla conclusione dei processi di riorganizzazione di cui al presente articolo e comunque non oltre il 31 ottobre 2021 sono sospese le modalita' di reclutamento previste dall'articolo 28-bis del decreto legislativo 30 marzo 2001, n. 165".

### Art. 29. - Reclutamento dei dirigenti scolastici

1. Il reclutamento dei dirigenti scolastici si realizza mediante concorso selettivo per titoli ed esami, organizzato su base regionale, bandito dal Ministero dell'istruzione ((e del merito)), per tutti i posti vacanti nel triennio, fermo restando il regime autorizzatorio in materia di assunzioni di cui all'articolo 39, comma 3-bis, della legge 27 dicembre 1997, n. 449, e successive modificazioni. PERIODO SOPPRESSO DAL D.L. 29 OTTOBRE 2019, N. 126. Al concorso puo' partecipare il personale docente ed educativo delle istituzioni scolastiche ed educative statali in possesso del relativo diploma di laurea magistrale ovvero di laurea conseguita in base al previgente ordinamento, che abbia maturato un'anzianita' complessiva nel ruolo di appartenenza di almeno cinque anni. E' previsto il pagamento di un contributo, da parte dei candidati, per le spese della procedura concorsuale. Il concorso puo' comprendere una prova preselettiva e comprende una o piu' prove scritte, cui sono ammessi tutti coloro che superano l'eventuale preselezione, e una prova orale, a cui segue la valutazione dei titoli. Le prove scritte e la prova orale sono superate dai candidati che conseguano, in ciascuna prova, il punteggio minimo di sette decimi o equivalente. PERIODO SOPPRESSO DAL D.L. 29 OTTOBRE 2019, N. 126. PERIODO SOPPRESSO DAL D.L. 29 OTTOBRE 2019, N. 126. Con uno o piu' decreti del Ministro dell'istruzione, dell'universita' e della ricerca, di concerto con il Ministro per la pubblica amministrazione e con il Ministro dell'economia e delle finanze, sono definiti le modalita' di svolgimento del concorso e dell'eventuale preselezione, le prove e i programmi concorsuali, la valutazione della preselezione, delle prove e dei titoli, la disciplina del periodo di formazione e prova e i contenuti dei moduli formativi relativi ai due anni successivi alla conferma in ruolo.

------------- AGGIORNAMENTO (29) Il D.P.R. 10 luglio 2008, n. 140 ha disposto (con l'art. 12, comma 1) che "Con effetto dalla data di entrata in vigore del presente regolamento sono abrogate le disposizioni dell'articolo 29 del decreto legislativo 30 marzo 2001, n. 165, che prevedono, ai fini del reclutamento e della mobilita' professionale, la distinzione in settori formativi dei dirigenti scolastici, nonche' ogni altra disposizione dello stesso articolo incompatibile con il presente regolamento". ------------- AGGIORNAMENTO (58) Il D.L. 12 settembre 2013, n. 104, convertito con modificazioni dalla L. 8 novembre 2013, n. 128 ha disposto (con l'art. 17, comma 2) che "Il decreto di cui all'articolo 29, comma 1, del decreto legislativo 30 marzo 2001, n. 165, come modificato dal precedente comma 1, e' adottato entro quattro mesi dalla data di entrata in vigore della legge di conversione del presente decreto.".

## Uffici, piante organiche, mobilita' e accessi

### Art. 29-bis. - (Mobilita' intercompartimentale).

1. Al fine di favorire i processi di mobilita' fra i comparti di contrattazione del personale delle pubbliche amministrazioni, con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze, previo parere della Conferenza unificata di cui all'articolo 8 del decreto legislativo n. 281 del 1997, sentite le Organizzazioni sindacali e' definita, senza nuovi o maggiori oneri per la finanza pubblica, una tabella di equiparazione fra i livelli di inquadramento previsti dai contratti collettivi relativi ai diversi comparti di contrattazione. ((61))

------------ AGGIORNAMENTO (61) Il D.L. 24 giugno 2014, n. 90, convertito con modificazioni dalla L. 11 agosto 2014, n. 114 ha disposto (con l'art. 4, comma 3) che "Il decreto di cui all'articolo 29-bis del decreto legislativo 30 marzo 2001, n. 165 e' adottato, secondo la procedura ivi indicata, entro sessanta giorni dalla data di entrata in vigore della legge di conversione del presente decreto. Decorso il suddetto termine, la tabella di equiparazione ivi prevista e' adottata con decreto del Ministro delegato per la semplificazione e la pubblica amministrazione, di concerto con il Ministro dell'economia e delle finanze. Le successive modifiche sono operate secondo la procedura di cui al citato articolo 29-bis".

### Art. 30. - Passaggio diretto di personale tra amministrazioni diverse (Art. 33 del d. lgs n. 29 del 1993, come sostituito prima dall'art. 13 del d.lgs n. 470 del 1993 e poi dall'art. 18 del d.lgs n. 80 del 1998 e successivamente modificato dall'art.20, comma 2 della Legge n.488 del 1999)

1. Le amministrazioni possono ricoprire posti vacanti in organico mediante passaggio diretto di dipendenti di cui all'articolo 2, comma 2, appartenenti a una qualifica corrispondente e in servizio presso altre amministrazioni, che facciano domanda di trasferimento. E' richiesto il previo assenso dell'amministrazione di appartenenza nel caso in cui si tratti di posizioni dichiarate motivatamente infungibili dall'amministrazione cedente o di personale assunto da meno di tre anni o qualora la mobilita' determini una carenza di organico superiore al 20 per cento nella qualifica corrispondente a quella del richiedente. E' fatta salva la possibilita' di differire, per motivate esigenze organizzative, il passaggio diretto del dipendente fino ad un massimo di sessanta giorni dalla ricezione dell'istanza di passaggio diretto ad altra amministrazione. Le disposizioni di cui ai periodi secondo e terzo non si applicano al personale delle aziende e degli enti del servizio sanitario nazionale e degli enti locali con un numero di dipendenti a tempo indeterminato non superiore a 100, per i quali e' comunque richiesto il previo assenso dell'amministrazione di appartenenza. Al personale della scuola continuano ad applicarsi le disposizioni vigenti in materia. Le amministrazioni, fissando preventivamente i requisiti e le competenze professionali richieste, pubblicano sul proprio sito istituzionale, per un periodo pari almeno a trenta giorni, un bando in cui sono indicati i posti che intendono ricoprire attraverso passaggio diretto di personale di altre amministrazioni, con indicazione dei requisiti da possedere. In via sperimentale e fino all'introduzione di nuove procedure per la determinazione dei fabbisogni standard di personale delle amministrazioni pubbliche, per il trasferimento tra le sedi centrali di differenti ministeri, agenzie ed enti pubblici non economici nazionali non e' richiesto l'assenso dell'amministrazione di appartenenza, la quale dispone il trasferimento entro due mesi dalla richiesta dell'amministrazione di destinazione, fatti salvi i termini per il preavviso e a condizione che l'amministrazione di destinazione abbia una percentuale di posti vacanti superiore all'amministrazione di appartenenza. PERIODO SOPPRESSO DAL D.L. 30 APRILE 2022, N. 36. (65) (76) 1.1. PERIODO SOPPRESSO DAL D.L. 21 OTTOBRE 2021, N. 146. Per gli enti locali con un numero di dipendenti compreso tra 101 e 250, la percentuale di cui al comma 1 e' stabilita al 5 per cento; per gli enti locali con un numero di dipendenti non superiore a 500, la predetta percentuale e' fissata al 10 per cento. La percentuale di cui al comma 1 e' da considerare all'esito della mobilita' e riferita alla dotazione organica dell'ente.

1-bis. L'amministrazione di destinazione provvede alla riqualificazione dei dipendenti la cui domanda di trasferimento e' accolta, eventualmente avvalendosi, ove sia necessario predisporre percorsi specifici o settoriali di formazione, della Scuola nazionale dell'amministrazione. All'attuazione del presente comma si provvede utilizzando le risorse umane, strumentali e finanziarie disponibili a legislazione vigente e, comunque, senza nuovi o maggiori oneri per la finanza pubblica.

1-ter. La dipendente vittima di violenza di genere inserita in specifici percorsi di protezione, debitamente certificati dai servizi sociali del comune di residenza, puo' presentare domanda di trasferimento ad altra amministrazione pubblica ubicata in un comune diverso da quello di residenza, previa comunicazione all'amministrazione di appartenenza. Entro quindici giorni dalla suddetta comunicazione l'amministrazione di appartenenza dispone il trasferimento presso l'amministrazione indicata dalla dipendente, ove vi siano posti vacanti corrispondenti alla sua qualifica professionale.

1-quater. A decorrere dal 1° luglio 2022, ai fini di cui al comma 1 e in ogni caso di avvio di procedure di mobilita', le amministrazioni provvedono a pubblicare il relativo avviso in una apposita sezione del Portale unico del reclutamento di cui all'articolo 35-ter. Il personale interessato a partecipare alle predette procedure invia la propria candidatura, per qualsiasi posizione disponibile, previa registrazione nel Portale corredata del proprio curriculum vitae esclusivamente in formato digitale. Dalla presente disposizione non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

1-quinquies. Per il personale non dirigenziale delle amministrazioni di cui all'articolo 1, comma 2, delle autorita' amministrative indipendenti e dei soggetti di cui all'articolo 70, comma 4, i comandi o distacchi sono consentiti esclusivamente nel limite del 25 per cento dei posti non coperti all'esito delle procedure di mobilita' di cui al presente articolo. La disposizione di cui al primo periodo non si applica ai comandi o distacchi obbligatori, previsti da disposizioni di legge, ivi inclusi quelli relativi agli uffici di diretta collaborazione, nonche' a quelli relativi alla partecipazione ad organi, comunque denominati, istituiti da disposizioni legislative o regolamentari che prevedono la partecipazione di personale di amministrazioni diverse, nonche' ai comandi presso le sedi territoriali dei ministeri, o presso le Unioni di comuni per i Comuni che ne fanno parte. (114)

2. Nell'ambito dei rapporti di lavoro di cui all'articolo 2, comma 2, i dipendenti possono essere trasferiti all'interno della stessa amministrazione o, previo accordo tra le amministrazioni interessate, in altra amministrazione, in sedi collocate nel territorio dello stesso comune ovvero a distanza non superiore a cinquanta chilometri dalla sede cui sono adibiti. Ai fini del presente comma non si applica il terzo periodo del primo comma dell'articolo 2103 del codice civile. Con decreto del Ministro per la semplificazione e la pubblica amministrazione, previa consultazione con le confederazioni sindacali rappresentative e previa intesa, ove necessario, in sede di conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, possono essere fissati criteri per realizzare i processi di cui al presente comma, anche con passaggi diretti di personale tra amministrazioni senza preventivo accordo, per garantire l'esercizio delle funzioni istituzionali da parte delle amministrazioni che presentano carenze di organico. Le disposizioni di cui al presente comma si applicano ai dipendenti con figli di eta' inferiore a tre anni, che hanno diritto al congedo parentale, e ai soggetti di cui all'articolo 33, comma 3, della legge 5 febbraio 1992, n. 104, e successive modificazioni, con il consenso degli stessi alla prestazione della propria attivita' lavorativa in un'altra sede. 2.1. Nei casi di cui ai commi 1 e 2 per i quali sia necessario un trasferimento di risorse, si applica il comma 2.3. 2.2. I contratti collettivi nazionali possono integrare le procedure e i criteri generali per l'attuazione di quanto previsto dai commi 1 e 2. Sono nulli gli accordi, gli atti o le clausole dei contratti collettivi in contrasto con le disposizioni di cui ai commi 1 e 2. 2.3. Al fine di favorire i processi di cui ai commi 1 e 2, e' istituito, nello stato di previsione del Ministero dell'economia e delle finanze, un fondo destinato al miglioramento dell'allocazione del personale presso le pubbliche amministrazioni, con una dotazione di 15 milioni di euro per l'anno 2014 e di 30 milioni di euro a decorrere dall'anno 2015, da attribuire alle amministrazioni destinatarie dei predetti processi. Al fondo confluiscono, altresi', le risorse corrispondenti al cinquanta per cento del trattamento economico spettante al personale trasferito mediante versamento all'entrata dello Stato da parte dell'amministrazione cedente e corrispondente riassegnazione al fondo ovvero mediante contestuale riduzione dei trasferimenti statali all'amministrazione cedente. I criteri di utilizzo e le modalita' di gestione-delle risorse del fondo sono stabiliti con decreto del Presidente del Consiglio dei Ministri, di concerto con il Ministro dell'economia e delle finanze. In sede di prima applicazione, nell'assegnazione delle risorse vengono prioritariamente valutate le richieste finalizzate all'ottimale funzionamento degli uffici giudiziari che presentino rilevanti carenze di personale e conseguentemente alla piena applicazione della riforma delle province di cui alla legge 7 aprile 2014, n. 56. Le risorse sono assegnate alle amministrazioni di destinazione sino al momento di effettiva permanenza in servizio del personale oggetto delle procedure di cui ai commi 1 e 2. 2.4. Agli oneri derivanti dall'attuazione del comma 2.3, pari a 15 milioni di euro per l'anno 2014 e a 30 milioni di euro a decorrere dall'anno 2015, si provvede, quanto a 6 milioni di euro per l'anno 2014 e a 9 milioni di euro a decorrere dal 2015 mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 3, comma 97, della legge 24 dicembre 2007, n. 244, quanto a 9 milioni di euro a decorrere dal 2014 mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 1, comma 14, del decreto-legge del 3 ottobre 2006, n. 262 convertito con modificazioni, dalla legge 24 novembre 2006, n. 286 e quanto a 12 milioni di euro a decorrere dal 2015 mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 1, comma 527, della legge 27 dicembre 2006, n. 296. A decorrere dall'anno 2015, il fondo di cui al comma 2.3 puo' essere rideterminato ai sensi dell'articolo 11, comma 3, lettera d), della legge 31 dicembre 2009, n. 196. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare con propri decreti le occorrenti variazioni di bilancio per l'attuazione del presente articolo.

2-bis. ((A decorrere dall'anno 2026,)) Le amministrazioni, ad eccezione della Presidenza del Consiglio dei ministri ((, degli enti locali con un numero di dipendenti a tempo indeterminato non superiore a 50, dell'Agenzia per la rappresentanza negoziale delle pubbliche amministrazioni (ARAN) e delle aziende e degli enti del Servizio sanitario nazionale)), destinano alle procedure di mobilita' di cui al ((presente articolo)) una percentuale non inferiore al 15 per cento delle facolta' assunzionali ((impegnate in ciascun esercizio finanziario, nel caso in cui il piano assunzionale preveda un numero di assunzioni pari o superiore a 10 unita' di personale,)) provvedendo, in via prioritaria, all'immissione in ruolo dei dipendenti provenienti da altre amministrazioni, in posizione di comando, appartenenti alla stessa area funzionale e con esclusione del personale comandato presso gli uffici di diretta collaborazione o equiparati, ((ovvero presso gli assessorati regionali alla sanita' e gli uffici a essi afferenti)) che facciano domanda di trasferimento nei ruoli delle amministrazioni in cui prestano servizio da almeno dodici mesi e che ((abbiano conseguito)) una valutazione della performance pienamente favorevole. Le posizioni eventualmente non coperte all'esito delle predette procedure sono destinate ai concorsi. In caso di mancata attivazione delle procedure di mobilita' entro l'anno di riferimento, le facolta' assunzionali autorizzate per l'anno successivo sono ridotte del 15 per cento, con conseguente adeguamento della dotazione organica, e i comandi in essere presso l'amministrazione cessano allo scadere del termine di sei mesi dall'avvio delle procedure concorsuali e non possono essere riattivati per diciotto mesi, nemmeno per il personale diverso da quello cessato. In caso di mancata presentazione della domanda di inquadramento, il personale cessa dal comando alla naturale scadenza e non puo' essere ulteriormente comandato anche presso una amministrazione diversa nei successivi diciotto mesi. ((Le disposizioni del quarto periodo si applicano al personale, escluso quello delle Forze di polizia ad ordinamento civile e militare con qualifica non dirigenziale, in posizione di comando ai sensi dell'articolo 113-bis, commi 3 e 4-ter, del codice delle leggi antimafia e delle misure di prevenzione, di cui al decreto legislativo 6 settembre 2011, n. 159, a decorrere dall'esercizio finanziario successivo al raggiungimento di una forza effettiva di ruolo pari almeno al 90 per cento della dotazione di cui al comma 1 del citato articolo 113-bis)). Gli inquadramenti di cui al presente comma avvengono, nei limiti dei posti vacanti, nell'area funzionale e posizione economica corrispondente a quella posseduta presso le amministrazioni di provenienza e possono essere disposti anche se la vacanza sia presente in area diversa da quella di inquadramento ((,)) assicurando la necessaria neutralita' finanziaria, previa rimodulazione della dotazione organica da inserire nella sezione del ((Piano integrato di attivita' e organizzazione)) relativa alla programmazione triennale dei fabbisogni di personale.

2-ter. L'immissione in ruolo di cui al comma 2-bis, limitatamente ((...)) al Ministero degli affari esteri, in ragione della specifica professionalita' richiesta ai propri dipendenti, avviene previa valutazione comparativa dei titoli di servizio e di studio, posseduti dai dipendenti comandati o fuori ruolo al momento della presentazione della domanda di trasferimento, nei limiti dei posti effettivamente disponibili.

2-quater. La Presidenza del Consiglio dei Ministri, per fronteggiare le situazioni di emergenza in atto, in ragione della specifica professionalita' richiesta ai propri dipendenti puo' procedere alla riserva di posti da destinare al personale assunto con ordinanza per le esigenze della Protezione civile e del servizio civile, nell'ambito delle procedure concorsuali di cui all'articolo 3, comma 59, della legge 24 dicembre 2003, n. 350, e all'articolo 1, comma 95, della legge 30 dicembre 2004, n. 311.

2-quinquies. Salvo diversa previsione, a seguito dell'iscrizione nel ruolo dell'amministrazione di destinazione, al dipendente trasferito per mobilita' si applica esclusivamente il trattamento giuridico ed economico, compreso quello accessorio, previsto nei contratti collettivi vigenti nel comparto della stessa amministrazione .

2-sexies. Le pubbliche amministrazioni, per motivate esigenze organizzative, risultanti dai documenti di programmazione previsti all'articolo 6, possono utilizzare in assegnazione temporanea, con le modalita' previste dai rispettivi ordinamenti, personale di altre amministrazioni per un periodo non superiore a tre anni, fermo restando quanto gia' previsto da norme speciali sulla materia, nonche' il regime di spesa eventualmente previsto da tali norme e dal presente decreto.(52) (60) (74) (76) (78) (103)

------------ AGGIORNAMENTO (52) La L. 24 dicembre 2012, n. 228, ha disposto (con l'art. 1, comma 413) che " A decorrere dal 1° gennaio 2013, i provvedimenti con i quali sono disposte le assegnazioni temporanee. del personale tra amministrazioni pubbliche, di cui all'articolo 30, comma 2-sexies, del decreto legislativo 30 marzo 2001, n. 165, sono adottati d'intesa tra le amministrazioni interessate, con l'assenso dell'interessato." Il D.Lgs. 6 settembre 2011, n. 159, come modificato dalla L. 24 dicembre 2012, n. 228, ha disposto (con l'art. 113-bis, comma 4) che "Fino al 31 dicembre 2013, le assegnazioni temporanee di personale all'Agenzia possono avvenire in deroga al limite temporale stabilito dall'articolo 30, comma 2-sexies, del citato decreto legislativo n. 165 del 2001". --------------- AGGIORNAMENTO (60) Il D.L. 31 maggio 2014, n. 83 convertito con modificazioni dalla L. 29 luglio 2014, n. 106 ha disposto (con l'art. 15, comma 1) che "Al fine di assicurare l'espletamento delle funzioni di tutela, fruizione e valorizzazione del patrimonio culturale statale, nelle more della definizione delle procedure di mobilita', le assegnazioni temporanee del personale non dirigenziale del comparto Scuola presso il Ministero dei beni e delle attivita' culturali e del turismo possono essere prorogate fino al 31 agosto 2015, in deroga al limite temporale di cui all'articolo 30, comma 2-sexies, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, ai fini della predisposizione di un piano di revisione dell'utilizzo del personale comandato, nel rispetto della normativa vigente in materia di assunzioni in caso di inquadramento nei ruoli del personale comandato". --------------- AGGIORNAMENTO (65) La L. 28 dicembre 2015, n. 221 ha disposto (con l'art. 29, comma 3) che "Al fine di accelerare lo svolgimento delle procedure e la realizzazione degli interventi di cui al presente articolo, il personale assunto a tempo indeterminato, sulla base di procedure concorsuali, presso le amministrazioni pubbliche di cui agli articoli 1, comma 2, e 3 del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, in posizione di distacco o di comando presso il Ministero dell'ambiente e della tutela del territorio e del mare alla data di entrata in vigore della presente legge, in deroga all'articolo 30, comma 1, del decreto legislativo n. 165 del 2001, e successive modificazioni, puo' richiedere, entro il 31 dicembre 2016, di essere inquadrato nei ruoli del medesimo Ministero dell'ambiente e della tutela del territorio e del mare nell'ambito dei posti vacanti nella dotazione organica, fino a un massimo di quindici unita' e a condizione che il transito non comporti un aumento del trattamento economico, previo parere favorevole dei dirigenti responsabili dei servizi e degli uffici in cui il predetto personale opera". ------------ AGGIORNAMENTO (74) Il D.L. 16 ottobre 2017, n. 148, convertito con modificazioni dalla L. 4 dicembre 2017, n. 172, ha disposto (con l'art. 15-ter, comma 3) che "Per le finalita' di cui ai commi 1 e 2, a decorrere dal 2018 l'ANSF e' autorizzata all'assunzione di 11 funzionari e 9 collaboratori, tenuto conto di quanto previsto all'articolo 4, comma 3, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, in deroga a quanto previsto dall'articolo 30 del decreto legislativo 30 marzo 2001, n. 165, e dall'articolo 4, comma 3-quinquies, del citato decreto-legge n. 101 del 2013, in relazione alle specifiche professionalita' necessarie per garantire il presidio della sicurezza ferroviaria". ------------ AGGIORNAMENTO (76) La L. 27 dicembre 2017, n. 205, ha disposto: - (con l'art. 1, comma 445) che "Per il biennio 2018-2019, nel rispetto della programmazione triennale del fabbisogno di personale l'AGENAS puo' bandire, in deroga alle procedure di mobilita' di cui all'articolo 30, comma 1, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, nonche' ad ogni altra procedura per l'assorbimento del personale in esubero dalle amministrazioni pubbliche e nel limite dei posti disponibili nella propria dotazione organica, procedure concorsuali, per esami, per assunzioni a tempo indeterminato di 100 unita' di personale, di cui 10 dirigenti di area III, 80 di categoria D a posizione economica di base, 7 di categoria C a posizione economica di base e 3 di categoria B a posizione economica di base, con una riserva di posti non superiore al 50 per cento per il personale non di ruolo, di qualifica non dirigenziale, che, alla data di entrata in vigore della presente legge, presti servizio, con contratto a tempo determinato ovvero con contratto di lavoro flessibile, ivi compresi i contratti di collaborazione coordinata e continuativa da almeno tre anni, presso l'AGENAS"; - (con l'art. 1, comma 567) che "In attuazione dei commi 565 e 566 il Ministero delle infrastrutture e dei trasporti e' autorizzato ad avviare appositi concorsi pubblici, tenuto conto di quanto previsto all'articolo 4, comma 3, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, in deroga a quanto previsto all'articolo 30 del decreto legislativo 30 marzo 2001, n. 165, e all'articolo 4, comma 3-quinquies, del citato decreto-legge 31 agosto 2013, n. 101"; - (con l'art. 1, comma 572) che "In attuazione dei commi 570 e 571, il Ministero delle infrastrutture e dei trasporti e' autorizzato ad avviare appositi concorsi pubblici, tenuto conto di quanto previsto dall'articolo 4, comma 3, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, in deroga a quanto previsto dall'articolo 30 del decreto legislativo 30 marzo 2001, n. 165, e dall'articolo 4, comma 3-quinquies, del citato decreto-legge n. 101 del 2013"; - (con l'art. 1, comma 576) che "Al fine di garantire il rispetto, da parte di tutti gli operatori del sistema dell'aviazione civile, degli standard di sicurezza stabiliti dalla normativa internazionale, l'ENAC, in aggiunta alle vigenti facolta' assunzionali, e' autorizzato, nei limiti dell'attuale dotazione organica, in considerazione dei significativi incrementi degli investimenti in opere aeroportuali, del numero dei passeggeri e delle merci trasportate, a procedere, previo svolgimento di procedure selettive pubbliche, all'assunzione di 93 unita' di personale appartenenti alle categorie professionali e operative, tenuto conto di quanto previsto dall'articolo 4, comma 3, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, in deroga a quanto previsto dall'articolo 30 del decreto legislativo 30 marzo 2001, n. 165, e dall'articolo 4, comma 3-quinquies, del citato decreto-legge n. 101 del 2013, in relazione alle specifiche professionalita' necessarie per lo svolgimento, in particolare, di attivita' di certificazione, ispezione, vigilanza e controllo sugli operatori aerei e sulle organizzazioni aeronautiche". --------------- AGGIORNAMENTO (78) Il D.L. 28 settembre 2018, n. 109, convertito con modificazioni dalla L. 16 novembre 2018, n. 130, ha disposto (con l'art. 15, comma 3) che "In attuazione dei commi 1 e 2, il Ministero delle infrastrutture e dei trasporti e' autorizzato ad avviare appositi concorsi pubblici, tenuto conto di quanto previsto dall'articolo 4, comma 3, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, in deroga a quanto previsto dall'articolo 30 del decreto legislativo 30 marzo 2001, n. 165, e dall'articolo 4, comma 3-quinquies, del citato decreto-legge n. 101 del 2013. Resta ferma la facolta' di avvalersi della previsione di cui all'articolo 3, comma 61, terzo periodo, della legge 24 dicembre 2003, n. 350". Ha inoltre disposto (con l'art. 15-bis, comma 1) che "Per far fronte alla necessita' di coprire le gravi scoperture organiche degli uffici giudiziari del distretto della corte di appello di Genova nonche' per garantire il regolare andamento dell'attivita' giudiziaria in ragione dell'incremento dei procedimenti civili e penali presso i medesimi uffici, il Ministero della giustizia e' autorizzato ad assumere in via straordinaria, nell'ambito dell'attuale dotazione organica, nel biennio 2018-2019, con contratto di lavoro a tempo indeterminato un contingente massimo di 50 unita' di personale amministrativo non dirigenziale da inquadrare nei ruoli dell'amministrazione giudiziaria. Il personale di cui al periodo precedente e' assunto, in deroga a quanto previsto dagli articoli 30 e 35, comma 4, del decreto legislativo 30 marzo 2001, n. 165, e ferme restando le previsioni di cui all'articolo 4, commi 3, 3-bis e 3-ter, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, mediante lo scorrimento di graduatorie delle pubbliche amministrazioni in corso di validita' alla data di entrata in vigore della legge di conversione del presente decreto ovvero mediante selezioni pubbliche svolte su base nazionale, anche con modalita' semplificate definite con decreto del Ministro per la pubblica amministrazione, di concerto con il Ministro della giustizia, da adottare entro trenta giorni dalla data di entrata in vigore della legge di conversione del presente decreto, anche in deroga alla disciplina prevista dal regolamento di cui al decreto del Presidente della Repubblica 9 maggio 1994, n. 487, per quanto concerne, in particolare, la tipologia e le modalita' di svolgimento delle prove di esame e la nomina delle commissioni e delle sottocommissioni". --------------- AGGIORNAMENTO (103) La L. 30 dicembre 2020, n. 178, ha disposto (con l'art. 1, comma 435) che "Al fine di potenziare l'attivita' di prevenzione e assistenza socio-sanitaria in favore di quanti versano in condizioni di elevata fragilita' e marginalita' anche a seguito dell'epidemia di COVID-19, l'Istituto nazionale per la promozione della salute delle popolazioni migranti e per il contrasto delle malattie della poverta' (INMP), ente del Servizio sanitario nazionale, e' autorizzato, a decorrere dall'anno 2021, in aggiunta alle ordinarie facolta' assunzionali previste dalla normativa vigente, nel rispetto della programmazione triennale del fabbisogno di personale, a bandire, in deroga alle procedure di mobilita' di cui all'articolo 30, comma 2-bis, del decreto legislativo 30 marzo 2001, n. 165, nonche' a ogni altra procedura per l'assorbimento del personale in esubero dalle amministrazioni pubbliche, nel limite dei posti disponibili nella propria vigente dotazione organica, procedure concorsuali pubbliche, per titoli ed esami, al fine di assumere, con contratto di lavoro subordinato a tempo indeterminato, un contingente complessivo di 9 unita' di personale, di cui 2 dirigenti medici, 1 dirigente sanitario non medico, 1 dirigente amministrativo, 2 unita' di categoria D posizione economica base e 3 unita' di categoria C posizione economica base". Ha inoltre disposto (con l'art. 1, comma 1004) che "Al fine di garantire il rispetto, da parte di tutti gli operatori del sistema dell'aviazione civile, degli standard di sicurezza stabiliti dalla normativa internazionale, nonche' di rafforzare le attivita' ispettiva, di certificazione e di vigilanza e controllo, l'Ente nazionale per l'aviazione civile (ENAC) e' autorizzato, in aggiunta alle vigenti facolta' assunzionali e in deroga a quanto previsto dall'articolo 30 del decreto legislativo 30 marzo 2001, n. 165, e dall'articolo 4, comma 3-quinquies, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, per il biennio 2021-2022, a bandire procedure concorsuali pubbliche e ad assumere con contratto di lavoro a tempo indeterminato, con conseguente incremento delle relative dotazioni organiche vigenti, 10 unita' di personale di livello dirigenziale non generale, 151 unita' di personale appartenente alla prima qualifica professionale, 145 unita' di personale appartenente al ruolo tecnico-ispettivo e 72 ispettori di volo". --------------- AGGIORNAMENTO (114) Il D.L. 30 aprile 2022, n. 36, convertito con modificazioni dalla L. 29 giugno 2022, n. 79, ha disposto (con l'art. 6, comma 2) che "I comandi o distacchi, in corso alla data di entrata in vigore del presente decreto, esclusi quelli di cui all'articolo 30, comma 1-quinquies, del decreto legislativo 30 marzo 2001, n. 165, come introdotto dal comma 1 del presente articolo, cessano alla data del 31 dicembre 2022 o alla naturale scadenza, se successiva alla predetta data, qualora le amministrazioni non abbiano gia' attivato procedure straordinarie di inquadramento di cui al comma 3".

### Articolo 31 - Passaggio di dipendenti per effetto di trasferimento di attivita' (Art.34 del d.lgs n.29 del 1993, come sostituito dall'art.19 del d.lgs n.80 del 1998)

1. Fatte salve le disposizioni speciali, nel caso di trasferimento o conferimento di attivita', svolte da pubbliche amministrazioni, enti pubblici o loro aziende o strutture, ad altri soggetti, pubblici o privati, al personale che passa alle dipendenze ditali soggetti si applicano l'articolo 2112 del codice civile e si osservano le procedure di informazione e di consultazione di cui all'articolo 47, commi da 1 a 4, della legge 29 dicembre 1990, n. 428.

### Art. 32. - Collegamento con le istituzioni internazionali, dell'Unione europea e di altri Stati. Esperti nazionali distaccati).

1. Le amministrazioni pubbliche favoriscono e incentivano le esperienze del proprio personale presso le istituzioni europee, le organizzazioni internazionali nonche' gli Stati membri dell'Unione europea, gli Stati candidati all'adesione all'Unione e gli altri Stati con i quali l'Italia intrattiene rapporti di collaborazione, ai sensi della lettera c), al fine di favorire lo scambio internazionale di esperienze amministrative e di rafforzare il collegamento tra le amministrazioni di provenienza e quelle di destinazione. I dipendenti delle amministrazioni pubbliche possono essere destinati a prestare temporaneamente servizio presso:

- a) il Parlamento europeo, il Consiglio dell'Unione europea, la Commissione europea, le altre istituzioni e gli altri organi dell'Unione europea, incluse le agenzie, prioritariamente in qualita' di esperti nazionali distaccati;
- b) le organizzazioni e gli enti internazionali ai quali l'Italia aderisce;
- c) le amministrazioni pubbliche degli Stati membri dell'Unione europea, degli Stati candidati all'adesione all'Unione e di altri Stati con i quali l'Italia intrattiene rapporti di collaborazione, a seguito di appositi accordi di reciprocita' stipulati tra le amministrazioni interessate, d'intesa con il Ministero degli affari esteri e con la Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica.

2. Ai fini di cui al comma 1, la Presidenza del Consiglio dei Ministri - Dipartimenti della funzione pubblica e per le politiche europee e il Ministero degli affari esteri, d'intesa tra loro:

- a) coordinano la costituzione di una banca dati di potenziali candidati qualificati dal punto di vista delle competenze in materia europea o internazionale e delle conoscenze linguistiche;
- b) definiscono, d'intesa con le amministrazioni interessate, le aree di impiego prioritarie del personale da distaccare, con specifico riguardo agli esperti nazionali presso le istituzioni dell'Unione europea;
- c) promuovono la sensibilizzazione dei centri decisionali, le informazioni relative ai posti vacanti nelle istituzioni internazionali e dell'Unione europea e la formazione del personale, con specifico riguardo agli esperti nazionali presso le istituzioni dell'Unione.

3. Il trattamento economico degli esperti nazionali distaccati puo' essere a carico delle amministrazioni di provenienza, di quelle di destinazione o essere suddiviso tra esse, ovvero essere rimborsato in tutto o in parte allo Stato italiano dall'Unione europea o da un'organizzazione o ente internazionale.

3-bis. Le pubbliche amministrazioni, nei casi in cui alle proprie unita' di personale impiegate come esperti nazionali distaccati presso l'Unione europea non sono corrisposte dalle istituzioni, organi o agenzie europei interessati, sulla base di intese con gli stessi, le indennita' di soggiorno, comunque denominate, previste dalla disciplina dell'Unione europea, possono corrispondere al predetto personale, per il periodo di effettiva assegnazione come esperti nazionali distaccati, una indennita' forfettaria e omnicomprensiva, non pensionabile, destinata a sostenere le spese di soggiorno, di entita' non superiore a quelle corrisposte dall'Unione europea per le medesime posizioni. A tal fine e' autorizzata la spesa di 400.000 euro per l'anno 2022 e di 1.000.000 di euro a decorrere dall'anno 2023 che costituisce il limite di spesa per l'erogazione della indennita' di cui al presente comma.

4. Il personale che presta servizio temporaneo all'estero resta a tutti gli effetti dipendente dell'amministrazione di appartenenza. L'esperienza maturata all'estero costituisce titolo preferenziale per l'accesso a posizioni economiche superiori o a progressioni orizzontali e verticali di carriera all'interno dell'amministrazione pubblica ((ed e' adeguatamente valorizzata, se di durata almeno biennale, nei bandi di concorso per l'accesso alla dirigenza, nonche' nelle procedure di conferimento di incarichi dirigenziali qualora attinenti all'esperienza stessa)).

### Articolo 33 - (Eccedenze di personale e mobilita' collettiva)

1. Le pubbliche amministrazioni che hanno situazioni di soprannumero o rilevino comunque eccedenze di personale, in relazione alle esigenze funzionali o alla situazione finanziaria, anche in sede di ricognizione annuale prevista dall'articolo 6, comma 1, terzo e quarto periodo, sono tenute ad osservare le procedure previste dal presente articolo dandone immediata comunicazione al Dipartimento della funzione pubblica.

2. Le amministrazioni pubbliche che non adempiono alla ricognizione annuale di cui al comma 1 non possono effettuare assunzioni o instaurare rapporti di lavoro con qualunque tipologia di contratto pena la nullita' degli atti posti in essere.

3. La mancata attivazione delle procedure di cui al presente articolo da parte del dirigente responsabile e' valutabile ai fini della responsabilita' disciplinare.

4. Nei casi previsti dal comma 1 del presente articolo il dirigente responsabile deve dare un'informativa preventiva alle rappresentanze unitarie del personale e alle organizzazioni sindacali firmatarie del contratto collettivo nazionale del comparto o area.

5. Trascorsi dieci giorni dalla comunicazione di cui al comma 4, l'amministrazione applica l'articolo 72, comma 11, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, in subordine, verifica la ricollocazione totale o parziale del personale in situazione di soprannumero o di eccedenza nell'ambito della stessa amministrazione, anche mediante il ricorso a forme flessibili di gestione del tempo di lavoro o a contratti di solidarieta', ovvero presso altre amministrazioni, previo accordo con le stesse, comprese nell'ambito della regione tenuto anche conto di quanto previsto dall'articolo 1, comma 29, del decreto-legge 13 agosto 2011, n. 138, convertito, con modificazioni, dalla legge 14 settembre 2011, n. 148, nonche' del comma 6.

6. I contratti collettivi nazionali possono stabilire criteri generali e procedure per consentire, tenuto conto delle caratteristiche del comparto, la gestione delle eccedenze di personale attraverso il passaggio diretto ad altre amministrazioni al di fuori del territorio regionale che, in relazione alla distribuzione territoriale delle amministrazioni o alla situazione del mercato del lavoro, sia stabilito dai contratti collettivi nazionali. Si applicano le disposizioni dell'articolo 30.

7. Trascorsi novanta giorni dalla comunicazione di cui al comma 4 l'amministrazione colloca in disponibilita' il personale che non sia possibile impiegare diversamente nell'ambito della medesima amministrazione e che non possa essere ricollocato presso altre amministrazioni nell'ambito regionale, ovvero che non abbia preso servizio presso la diversa amministrazione secondo gli accordi di mobilita'.

8. Dalla data di collocamento in disponibilita' restano sospese tutte le obbligazioni inerenti al rapporto di lavoro e il lavoratore ha diritto ad un'indennita' pari all'80 per cento dello stipendio e dell'indennita' integrativa speciale, con esclusione di qualsiasi altro emolumento retributivo comunque denominato, per la durata massima di ventiquattro mesi. I periodi di godimento dell'indennita' sono riconosciuti ai fini della determinazione dei requisiti di accesso alla pensione e della misura della stessa. E' riconosciuto altresi' il diritto all'assegno per il nucleo familiare di cui all'articolo 2 del decreto-legge 13 marzo 1988, n. 69, convertito, con modificazioni, dalla legge 13 maggio 1988, n. 153. (43) ((48))

------------- AGGIORNAMENTO (35) Il D.L. 31 maggio 2010, n. 78, convertito con modificazioni dalla L. 30 luglio 2010, n. 122, ha disposto (con l'art. 9, comma 25) che " In deroga a quanto previsto dall'articolo 33 del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni e integrazioni, le unita' di personale eventualmente risultanti in soprannumero all'esito delle riduzioni previste dall'articolo 2, comma 8-bis, del decreto-legge 30 dicembre 2009, n. 194, convertito, con modificazioni, dalla legge 26 febbraio 2010, n. 25, non costituiscono eccedenze ai sensi del citato articolo 33 e restano temporaneamente in posizione soprannumeraria, nell'ambito dei contingenti di ciascuna area o qualifica dirigenziale." ------------- AGGIORNAMENTO (43) La L. 12 novembre 2011, n. 183 ha disposto (con l'art. 16, commi 2 e 3) che "2. Le procedure di cui all'articolo 33 del decreto legislativo 31 marzo 2001, n. 165, come modificato dal comma 1 del presente articolo, si applicano anche nei casi previsti dall'articolo 15 del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111. 3. Le disposizioni di cui ai commi precedenti non si applicano ai concorsi gia' banditi e alle assunzioni gia' autorizzate alla data di entrata in vigore della presente legge." ------------------ AGGIORNAMENTO (48) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 2, comma 12) che "Il periodo di 24 mesi di cui al comma 8 dell'articolo 33 del decreto legislativo n. 165 del 2001 puo' essere aumentato fino a 48 mesi laddove il personale collocato in disponibilita' maturi entro il predetto arco temporale i requisiti per il trattamento pensionistico".

### Art. 34. - Gestione del personale in disponibilita' (Art.35-bis del d.lgs n.29 del 1993, aggiunto dall'art.21 del d.lgs n.80 del 1998)

1. Il personale in disponibilita' e' iscritto in appositi elenchi secondo l'ordine cronologico di sospensione del relativo rapporto di lavoro.

2. Per le amministrazioni dello Stato, anche ad ordinamento autonomo e per gli enti pubblici non economici nazionali, il Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri forma e gestisce l'elenco, avvalendosi anche, ai fini della riqualificazione professionale del personale e della sua ricollocazione in altre amministrazioni, della collaborazione delle strutture regionali e provinciali di cui al decreto legislativo 23 dicembre 1997, n. 469, e realizzando opportune forme di coordinamento con l'elenco di cui al comma 3.

3. Per le altre amministrazioni, l'elenco e' tenuto dalle strutture regionali e provinciali di cui al decreto legislativo 23 dicembre 1997, n. 469, e successive modificazioni ed integrazioni, alle quali sono affidati i compiti di riqualificazione professionale e ricollocazione presso altre amministrazioni del personale. Le leggi regionali previste dal decreto legislativo 23 dicembre 1997, n. 469, nel provvedere all'organizzazione del sistema regionale per l'impiego, si adeguano ai principi di cui al comma 2.

3-bis. Gli elenchi di cui ai commi 2 e 3 sono pubblicati sul sito istituzionale delle amministrazioni competenti.

4. Il personale in disponibilita' iscritto negli appositi elenchi ha diritto all'indennita' di cui all'articoLo 33, comma 8, per la durata massima ivi prevista. La spesa relativa grava sul bilancio dell'amministrazione di appartenenza sino al trasferimento ad altra amministrazione, ovvero al raggiungimento del periodo massimo di fruizione dell'indennita' di cui al medesimo comma 8. ((Fermo restando quanto previsto dall'articolo 33, il rapporto di lavoro si intende definitivamente risolto alla data del raggiungimento del periodo massimo di fruizione dell'indennita' di cui al comma 8 del medesimo articolo 33, ovvero, prima del raggiungimento di detto periodo massimo, qualora il dipendente in disponibilita' rinunci o non accetti per due volte l'assegnazione disposta ai sensi dell'articolo 34-bis nell'ambito della provincia dallo stesso indicata)). Gli oneri sociali relativi alla retribuzione goduta al momento del collocamento in disponibilita' sono corrisposti dall'amministrazione di appartenenza all'ente previdenziale di riferimento per tutto il periodo della disponibilita'. Nei sei mesi anteriori alla data di scadenza del termine di cui all'articolo 33, comma 8, il personale in disponibilita' puo' presentare, alle amministrazioni di cui ai commi 2 e 3, istanza di ricollocazione, in deroga all'articolo 2103 del codice civile, nell'ambito dei posti vacanti in organico, anche in una qualifica inferiore o in posizione economica inferiore della stessa o di inferiore area o categoria di un solo livello per ciascuna delle suddette fattispecie, al fine di ampliare le occasioni di ricollocazione. In tal caso la ricollocazione non puo' avvenire prima dei trenta giorni anteriori alla data di scadenza del termine di cui all'articolo 33, comma 8. Il personale ricollocato ai sensi del periodo precedente non ha diritto all'indennita' di cui all'articolo 33, comma 8, e mantiene il diritto di essere successivamente ricollocato nella propria originaria qualifica e categoria di inquadramento, anche attraverso le procedure di mobilita' volontaria di cui all'articolo 30. In sede di contrattazione collettiva con le organizzazioni sindacali maggiormente rappresentative possono essere stabiliti criteri generali per l'applicazione delle disposizioni di cui al quinto e al sesto periodo.

5. I contratti collettivi nazionali possono riservare appositi fondi per la riqualificazione professionale del personale trasferito ai sensi dell'articolo 33 o collocato in disponibilita' e per favorire forme di incentivazione alla ricollocazione del personale. in particolare mediante mobilita' volontaria.

6. Nell'ambito della programmazione triennale del personale di cui all'articolo 39 della legge 27 dicembre 1997, n. 449, e successive modificazioni, l'avvio di procedure concorsuali e le nuove assunzioni a tempo indeterminato o determinato per un periodo superiore a dodici mesi, ((ad esclusione di quelle relative al conferimento di incarichi dirigenziali ai sensi dell'articolo 19, comma 6, nonche' al conferimento degli incarichi di cui all'articolo 110 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, e all'articolo 15-septies del decreto legislativo 30 dicembre 1992, n. 502,)) sono subordinate alla verificata impossibilita' di ricollocare il personale in disponibilita' iscritto nell'apposito elenco ((e in possesso della qualifica e della categoria di inquadramento occorrenti)). I dipendenti iscritti negli elenchi di cui al presente articolo possono essere assegnati, nell'ambito dei posti vacanti in organico, in posizione di comando presso amministrazioni che ne facciano richiesta o presso quelle individuate ai sensi dell'articolo 34-bis, comma 5-bis. Gli stessi dipendenti possono, altresi', avvalersi della disposizione di cui all'articolo 23-bis. Durante il periodo in cui i dipendenti sono utilizzati con rapporto di lavoro a tempo determinato o in posizione di comando presso altre amministrazioni pubbliche o si avvalgono dell'articolo 23-bis il termine di cui all'articolo 33 comma 8 resta sospeso e l'onere retributivo e' a carico dall'amministrazione o dell'ente che utilizza il dipendente.

7. Per gli enti pubblici territoriali le economie derivanti dalla minore spesa per effetto del collocamento in disponibilita' restano a disposizione del loro bilancio e possono essere utilizzate per la formazione e la riqualificazione del personale nell'esercizio successivo.

8. Sono fatte salve le procedure di cui al decreto legislativo 18 agosto 2000, n. 267, relative al collocamento in disponibilita' presso gli enti locali che hanno dichiarato il dissesto.

### Art. 34-bis. - Disposizioni in materia di mobilita' del personale

1. Le amministrazioni pubbliche di cui all'articolo 1, comma 2,con esclusione delle amministrazioni previste dall'articolo 3, comma 1, ivi compreso il Corpo nazionale dei vigili del fuoco, prima di avviare le procedure di assunzione di personale, sono tenute a comunicare ai soggetti di cui all'articolo 34, commi 2 e 3, l'area, il livello e la sede di destinazione per i quali si intende bandire il concorso nonche', se necessario, le funzioni e le eventuali specifiche idoneita' richieste.

2. La Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica, di concerto con il Ministero dell'economia e delle finanze e le strutture regionali e provinciali di cui all'articolo 34, comma 3, provvedono, entro ((otto giorni)) dalla comunicazione, ad assegnare secondo l'anzianita' di iscrizione nel relativo elenco il personale collocato in disponibilita' ai sensi degli articoli 33 e 34. Le predette strutture regionali e provinciali, accertata l'assenza negli appositi elenchi di personale da assegnare alle amministrazioni che intendono bandire il concorso, comunicano tempestivamente alla Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica le informazioni inviate dalle stesse amministrazioni. Entro ((otto giorni)) dal ricevimento della predetta comunicazione, la Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica, di concerto con il Ministero dell'economia e delle finanze, provvede ad assegnare alle amministrazioni che intendono bandire il concorso il personale inserito nell'elenco previsto dall'articolo 34, comma 2. A seguito dell'assegnazione, l'amministrazione destinataria iscrive il dipendente in disponibilita' nel proprio ruolo e il rapporto di lavoro prosegue con l'amministrazione che ha comunicato l'intenzione di bandire il concorso. L'amministrazione destinataria comunica tempestivamente alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica e alle strutture regionali e provinciali di cui all'articolo 34, comma 3, la rinuncia o la mancata accettazione dell'assegnazione da parte del dipendente in disponibilita'. (100)

3. Le amministrazioni possono provvedere a organizzare percorsi di qualificazione del personale assegnato ai sensi del comma 2.

4. Le amministrazioni, decorsi quarantacinque giorni dalla ricezione della comunicazione di cui al comma 1 da parte del Dipartimento della funzione pubblica direttamente per le amministrazioni dello Stato e per gli enti pubblici non economici nazionali, comprese le universita', e per conoscenza per le altre amministrazioni, possono procedere all'avvio della procedura concorsuale per le posizioni per le quali non sia intervenuta l'assegnazione di personale ai sensi del comma 2. (100) ((114))

5. Le assunzioni effettuate in violazione del presente articolo sono nulle di diritto. Restano ferme le disposizioni previste dall'articolo 39 della legge 27 dicembre 1997, n. 449, e successive modificazioni.

5-bis. Ove se ne ravvisi l'esigenza per una piu' tempestiva ricollocazione del personale in disponibilita' iscritto nell'elenco di cui all'articolo 34, comma 2, il Dipartimento della funzione pubblica effettua ricognizioni presso le amministrazioni pubbliche per verificare l'interesse all'acquisizione in mobilita' dei medesimi dipendenti. Si applica l'articolo 4, comma 2, del decreto-legge 12 maggio 1995, n. 163, convertito, con modificazioni, dalla legge 11 luglio 1995, n. 273. (89)

-------------- AGGIORNAMENTO (89) La L. 27 dicembre 2019, n. 160 ha disposto (con l'art. 1, comma 328) che "Al fine di rafforzare lo svolgimento dell'attivita' a completamento dell'avvio del Centro di valutazione e certificazione nazionale (CVCN) delle funzioni aggiuntive attribuite al Ministero dello sviluppo economico in materia di laboratorio di certificazione, di normativa tecnica e vigilanza sulla sicurezza dei prodotti e dei processi produttivi, di crisi di impresa, di amministrazioni straordinarie, di contenzioso e arbitrati internazionali in materia di energia, di vigilanza e controllo del corretto uso delle frequenze, il Ministero dello sviluppo economico e' autorizzato a bandire concorsi pubblici e, conseguentemente, ad assumere a tempo indeterminato, in aggiunta alle settantasette unita' gia' autorizzate ai sensi dell'articolo 2, comma 1, del decreto-legge 21 settembre 2019, n. 105, convertito, con modificazioni, dalla legge 18 novembre 2019, n. 133, e in deroga all'articolo 6, commi 1, 2, 3, 4 e 6, e all'articolo 34-bis del decreto legislativo 30 marzo 2001, n. 165, all'articolo 4, comma 3, del decreto-legge 31 agosto 2013 n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, nonche' ai limiti di cui all'articolo 66 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, con conseguente incremento della vigente dotazione organica nel limite delle unita' eccedenti, in aggiunta alle ordinarie facolta' assunzionali, trecentonove unita' di personale da inquadrare nella III area del personale non dirigenziale, posizione economica F1, e trecentodiciotto unita' di personale da inquadrare nella II area del personale non dirigenziale, posizione economica F1, con professionalita' pertinenti alle funzioni di cui al presente comma". -------------- AGGIORNAMENTO (100) Il D.L. 19 maggio 2020, n. 34, ha disposto (con l'art. 247, comma 12) che "Per le procedure di cui al presente articolo, i termini previsti dall'articolo 34-bis, commi 2 e 4, del decreto legislativo 30 marzo 2001, n. 165, sono stabiliti, rispettivamente, in sette e quindici giorni". -------------- AGGIORNAMENTO (114) Il D.L. 30 aprile 2022, n. 36, convertito con modificazioni dalla L. 29 giugno 2022, n. 79, ha disposto (con l'art. 3, comma 3-quater) che "al comma 4, le parole: "entro quarantacinque giorni" sono sostituite dalle seguenti: "entro venti giorni"".

### Art. 34-ter. - (Anagrafe dei dipendenti della pubblica amministrazione)

1. Per il completo raggiungimento dei traguardi e degli obiettivi relativi alla missione M1C1: "Digitalizzazione, innovazione e sicurezza nella PA", del Piano nazionale di ripresa e resilienza, e per il completamento del fascicolo elettronico del dipendente e' avviato, presso il Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, il censimento anagrafico permanente dei dipendenti pubblici, avvalendosi della base di dati del personale della pubblica amministrazione del ((Ministero dell'economia e delle finanze)), strumentale all'erogazione dei servizi di cui all'articolo 11, comma 9, del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111, ed ampliata in attuazione del Piano Triennale per l'informatica nella pubblica amministrazione 2017-2019, nel rispetto delle norme del regolamento (UE) 2016/679 del Parlamento europeo e del Consiglio, del 27 aprile 2016, ((e del codice di cui al decreto legislativo)) 30 giugno 2003, n. 196. Con decreto del Ministro per la pubblica amministrazione e del Ministro dell'economia e delle finanze, di concerto con il Ministro per l'innovazione tecnologica e la transizione digitale, da adottare entro trenta giorni dalla data di entrata in vigore della presente disposizione, previa intesa ((in sede di Conferenza unificata)) di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, sono disciplinate le modalita' di funzionamento e di comunicazione dei dati da parte delle amministrazioni pubbliche di cui all'articolo 1, comma 2, ((del presente decreto)) e degli enti pubblici economici. Alle attivita' derivanti dal presente articolo il Dipartimento della funzione pubblica provvede con le risorse umane, strumentali e finanziarie disponibili a legislazione vigente.

### Art. 35. - Reclutamento del personale (Art. 36, commi da 1 a 6 del d.lgs n. 29 del 1993, come sostituiti prima dall'art. 17 del d.lgs n. 546 del 1993 e poi dall'art. 22 del d.lgs. n. 80 del 1998, successivamente modificati dall'art. 2, comma 2-ter del decreto legge 17 giugno 1999, n. 180 convertito con modificazioni dalla legge n. 269 del 1999; Art. 36-bis del d.lgs. n. 29 del 1993, aggiunto dall'art. 23 del d.lgs n. 80 del 1998 e successivamente modificato dall'art. 274, comma 1, lett. aa) del d.lgs n. 267 del 2000)

1. L'assunzione nelle amministrazioni pubbliche avviene con contratto individuale di lavoro:

- a) tramite procedure selettive, conformi ai principi del comma 3, volte all'accertamento della professionalita' richiesta, che garantiscano in misura adeguata l'accesso dall'esterno;
- b) mediante avviamento degli iscritti nelle liste di collocamento ai sensi della legislazione vigente per le qualifiche e profili per i quali e' richiesto il solo requisito della scuola dell'obbligo, facendo salvi gli eventuali ulteriori requisiti per specifiche professionalita'.

2. Le assunzioni obbligatorie da parte delle amministrazioni pubbliche, aziende ed enti pubblici dei soggetti di cui alla legge 12 marzo 1999, n.68, avvengono per chiamata numerica degli iscritti nelle liste di collocamento ai sensi della vigente normativa, previa verifica della compatibilita' della invalidita' con le mansioni da svolgere. Per il coniuge superstite e per i figli del personale delle Forze armate, delle Forze dell'ordine, del Corpo nazionale dei vigili del fuoco e del personale della Polizia municipale deceduto nell'espletamento del servizio, nonche' delle vittime del terrorismo e della criminalita' organizzata di cui alla legge 13 agosto 1980, n. 466, e successive modificazioni ed integrazioni, tali assunzioni avvengono per chiamata diretta nominativa.

3. Le procedure di reclutamento nelle pubbliche amministrazioni si conformano ai seguenti principi:

- a) adeguata pubblicita' della selezione e modalita' di svolgimento che garantiscano l'imparzialita' e assicurino economicita' e celerita' di espletamento, ricorrendo, ove e' opportuno, all'ausilio di sistemi automatizzati, diretti anche a realizzare forme di preselezione;
- b) adozione di meccanismi oggettivi e trasparenti, idonei a verificare il possesso dei requisiti attitudinali e professionali richiesti in relazione alla posizione da ricoprire;
- c) rispetto delle pari opportunita' tra lavoratrici e lavoratori;
- d) decentramento delle procedure di reclutamento;
- e) composizione delle commissioni esclusivamente con esperti di provata competenza nelle materie di concorso, scelti tra funzionari delle amministrazioni, docenti ed estranei alle medesime, che non siano componenti dell'organo di direzione politica dell'amministrazione, che non ricoprano cariche politiche e che non siano rappresentanti sindacali o designati dalle confederazioni ed organizzazioni sindacali o dalle associazioni professionali;
- e-bis) LETTERA ABROGATA DALLA L. 30 DICEMBRE 2018, N. 145; (81) (80) (84)
- e-ter) possibilita' di richiedere, tra i requisiti previsti per specifici profili o livelli di inquadramento di alta specializzazione, il possesso del titolo di dottore di ricerca o del master universitario di secondo livello o l'essere stati titolari per almeno due anni di contratti di ricerca di cui all'articolo 22 della legge 30 dicembre 2010, n. 240. In tali casi, nelle procedure sono individuate, tra le aree dei settori scientifico-disciplinari definite ai sensi dell'articolo 17, comma 99, della legge 15 maggio 1997, n. 127, afferenti al titolo di dottore di ricerca o al master universitario di secondo livello o al contratto di ricerca, quelle pertinenti alla tipologia del profilo o livello di inquadramento.

3-bis. Le amministrazioni pubbliche, nel rispetto della programmazione triennale del fabbisogno, nonche' del limite massimo complessivo del 50 per cento delle risorse finanziarie disponibili ai sensi della normativa vigente in materia di assunzioni ovvero di contenimento della spesa di personale, secondo i rispettivi regimi limitativi fissati dai documenti di finanza pubblica e, per le amministrazioni interessate, previo espletamento della procedura di cui al comma 4, possono avviare procedure di reclutamento mediante concorso pubblico:

- a) con riserva dei posti, nel limite massimo del 40 per cento di quelli banditi, a favore dei titolari di rapporto di lavoro subordinato a tempo determinato che, alla data di pubblicazione dei bandi, hanno maturato almeno tre anni di servizio alle dipendenze dell'amministrazione che emana il bando ((nonche' con una riserva pari al 10 per cento dei posti messi a concorso in favore delle persone con disabilita' di cui alla legge 12 marzo 1999, n. 68. Restano ferme le tutele gia' stabilite dalla citata legge n. 68 del 1999 in materia di assunzioni obbligatorie e relative riserve));
- b) per titoli ed esami, finalizzati a valorizzare, con apposito punteggio, l'esperienza professionale maturata dal personale di cui alla lettera a) e di coloro che, alla data di emanazione del bando, hanno maturato almeno tre anni di contratto di lavoro flessibile nell'amministrazione che emana il bando.

3-ter. Con decreto del Presidente del Consiglio dei Ministri di concerto con il Ministro dell'economia e delle finanze, da adottare ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, entro il 31 gennaio 2013, sono dettati modalita' e criteri applicativi del comma 3-bis e la disciplina della riserva dei posti di cui alla lettera a) del medesimo comma in rapporto ad altre categorie riservatarie. Le disposizioni normative del comma 3-bis costituiscono principi generali a cui devono conformarsi tutte le amministrazioni pubbliche.

3-quater. COMMA ABROGATO DAL D.L. 9 GIUGNO 2021, N. 80, CONVERTITO, CON MODIFICAZIONI DALLA L. 6 AGOSTO 2021, N. 113.

4. Le determinazioni relative all'avvio di procedure di reclutamento sono adottate da ciascuna amministrazione o ente sulla base del piano triennale dei fabbisogni approvato ai sensi dell'articolo 6, comma 4. Con decreto del Presidente del Consiglio dei ministri di concerto con il Ministro dell'economia e delle finanze, sono autorizzati l'avvio delle procedure concorsuali e le relative assunzioni del personale delle amministrazioni dello Stato, anche ad ordinamento autonomo, delle agenzie e degli enti pubblici non economici. PERIODO SOPPRESSO DAL D.LGS. 25 NOVEMBRE 2016, N. 218. PERIODO SOPPRESSO DAL D.LGS. 25 NOVEMBRE 2016, N. 218. A decorrere dall'anno 2025, le facolta' assunzionali autorizzate con il decreto di cui al secondo periodo hanno una validita' non superiore a tre anni. Tali facolta' assunzionali, ivi incluse quelle derivanti da speciali disposizioni di legge, alla scadenza non possono essere prorogate. In via transitoria, le facolta' assunzionali non ancora esercitate relative ad annualita' pregresse all'anno 2025, gia' autorizzate o da autorizzare con il suddetto decreto, ivi comprese quelle previste da speciali disposizioni di legge, che giungono a scadenza alla data del 31 dicembre 2024, sono esercitate entro e non oltre il 31 dicembre 2025 e non possono essere prorogate. (68) (78) (82) (84) (129)((136))

4-bis. L'avvio delle procedure concorsuali mediante l'emanazione di apposito decreto del Presidente del Consiglio dei Ministri, di concerto con il Ministro dell'economia e delle finanze, di cui al comma 4 si applica anche alle procedure di reclutamento a tempo determinato per contingenti superiori alle cinque unita', inclusi i contratti di formazione e lavoro, e tiene conto degli aspetti finanziari, nonche' dei criteri previsti dall'articolo 36.

4-ter. ((Fatte salve)) la percentuale non inferiore al 50 per cento dei posti da ricoprire, destinata al corso-concorso selettivo di formazione bandito dalla Scuola nazionale dell'amministrazione di cui all'articolo 28, nonche' le riserve previste all'articolo 28, comma 1-ter, e le altre stabilite a legislazione vigente, il reclutamento dei dirigenti delle amministrazioni dello Stato, delle agenzie e degli enti pubblici ((non economici)) si svolge mediante concorsi pubblici unici organizzati dal Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, senza nuovi o maggiori oneri per la finanza pubblica, avvalendosi della Commissione per l'attuazione del progetto di riqualificazione delle pubbliche amministrazioni (RIPAM) di cui al comma 5, previa ricognizione del fabbisogno presso le amministrazioni interessate, nel rispetto dei vincoli finanziari e del regime autorizzatorio in materia di assunzioni a tempo indeterminato. Ove richiesto, il Dipartimento della funzione pubblica autorizza le amministrazioni a procedere autonomamente per il reclutamento di specifiche professionalita'. ((136))

4-quater. Con le medesime modalita' di cui al comma 4-ter si svolge il reclutamento delle figure professionali comuni e delle elevate professionalita' delle amministrazioni dello Stato, anche ad ordinamento autonomo, delle agenzie e degli enti pubblici non economici ((, che, ove richiesto, possono essere autorizzati dal Dipartimento della funzione pubblica a svolgere autonomamente i concorsi pubblici per il reclutamento del personale non dirigenziale in possesso di specifiche professionalita')). ((136))

4-quinquies. Le amministrazioni pubbliche diverse da quelle di cui al comma 4-ter e la Presidenza del Consiglio dei ministri, per lo svolgimento delle proprie procedure concorsuali, ivi comprese quelle relative al reclutamento delle figure professionali di cui al comma 4-quater, possono rivolgersi al Dipartimento della funzione pubblica e avvalersi della Commissione RIPAM. ((136))

4-sexies. Il Dipartimento della funzione pubblica ((,)) mediante la Commissione RIPAM, organizza i concorsi anche per il reclutamento di un'unica figura professionale e per una singola amministrazione. ((136))

4-septies. Al fine di rafforzare l'attrattivita' della pubblica amministrazione e i processi di reclutamento del personale, la Commissione RIPAM, per le amministrazioni di cui al comma 4-ter:

- a) organizza i concorsi di cui ai commi da 4-ter a 4-sexies;
- b) ((organizza i concorsi unici applicando una riserva del 10 per cento dei posti messi a concorso in favore delle persone con disabilita' di cui alla legge 12 marzo 1999, n. 68. Restano ferme le tutele previste dalla legge n. 68 del 1999 in materia di assunzioni obbligatorie e relative riserve));
- c) organizza concorsi unici per il reclutamento di personale per la transizione digitale e la sicurezza informatica delle pubbliche amministrazioni di cui all'articolo 6, comma 2, lettera c-bis), del decreto-legge 9 giugno 2021, n. 80, convertito, con modificazioni, dalla legge 6 agosto 2021, n. 113;
- d) pubblica, attraverso il Portale unico del reclutamento di cui all'articolo 35-ter, avvisi per l'individuazione di ((valutatori)), specialisti in psicologia del lavoro e risorse umane ed esperti in valutazione delle competenze e selezione del personale per lo svolgimento dei concorsi unici nel rispetto di quanto previsto dall'articolo 35-quater. ((136))

4-octies. Il Dipartimento della funzione pubblica, anche tramite la Commissione RIPAM, trasmette al ((Parlamento)) e al Governo una relazione annuale sullo stato del reclutamento mediante concorsi unici entro il 31 maggio dell'anno successivo a ((quello di riferimento)). ((136))

5. PERIODO SOPPRESSO DAL D.L. 14 MARZO 2025, N. 25, CONVERTITO, CON MODIFICAZIONI, DALLA L. 9 MAGGIO 2025, N. 69. La Commissione RIPAM e' nominata con decreto del Ministro per la pubblica amministrazione ed e' composta dal Capo del Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, che la presiede, dall'Ispettore generale capo dell'Ispettorato generale per gli ordinamenti del personale e l'analisi dei costi del lavoro pubblico del Dipartimento della Ragioneria generale dello Stato del Ministero dell'economia e delle finanze e dal Capo del Dipartimento per le politiche del personale dell'amministrazione civile e per le risorse strumentali e finanziarie del Ministero dell'interno, o loro delegati. La Commissione:

- a) approva i bandi di concorso per il reclutamento di personale a tempo indeterminato;
- b) indice i bandi di concorso e nomina le commissioni esaminatrici;
- c) valida le graduatorie finali di merito delle procedure concorsuali trasmesse dalle commissioni esaminatrici;
- d) assegna i vincitori e gli idonei delle procedure concorsuali alle amministrazioni pubbliche interessate;
- e) adotta ogni ulteriore eventuale atto connesso alle procedure concorsuali, fatte salve le competenze proprie delle commissioni esaminatrici. A tali fini, la Commissione RIPAM si avvale di personale messo a disposizione dall'Associazione Formez PA, che puo' essere utilizzato anche per la costituzione dei comitati di vigilanza dei concorsi di cui al presente comma. 5.1. Nell'ipotesi di cui al comma 5, il bando di concorso puo' fissare un contributo di ammissione, ai sensi dell'articolo 4, comma 3-septies del decreto-legge 31 agosto 2013, n. 101, convertito con modificazioni nella legge 31 ottobre 2013, n. 125. 5.2. Il Dipartimento della funzione pubblica, anche avvalendosi dell'Associazione Formez PA e della Commissione RIPAM, elabora, previo accordo in sede di Conferenza Unificata ai sensi dell'articolo 4 del decreto legislativo n. 281 del 1997, linee guida di indirizzo amministrativo sullo svolgimento delle prove concorsuali e sulla valutazione dei titoli, ispirate alle migliori pratiche a livello nazionale e internazionale in materia di reclutamento del personale, nel rispetto della normativa, anche regolamentare, vigente in materia. Le linee guida per le prove concorsuali e la valutazione dei titoli del personale sanitario, tecnico e professionale, anche dirigente, del Servizio sanitario nazionale sono adottate di concerto con il Ministero della salute.

5-bis. I vincitori dei concorsi devono permanere nella sede di prima destinazione per un periodo non inferiore a cinque anni, ad eccezione dei direttori dei servizi generali e amministrativi delle istituzioni scolastiche ed educative che permangono nella sede di prima destinazione per un periodo non inferiore a tre anni. La presente disposizione costituisce norma non derogabile dai contratti collettivi. (60) (68)

5-ter. Le graduatorie dei concorsi per il reclutamento del personale presso le amministrazioni pubbliche rimangono vigenti per un termine di due anni dalla data di approvazione. Sono fatti salvi i periodi di vigenza inferiori previsti da leggi regionali e quelli stabiliti per gli enti locali dall'articolo 91 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267. Il principio della parita' di condizioni per l'accesso ai pubblici uffici e' garantito, mediante specifiche disposizioni del bando, con riferimento al luogo di residenza dei concorrenti, quando tale requisito sia strumentale all'assolvimento di servizi altrimenti non attuabili o almeno non attuabili con identico risultato. Nei concorsi pubblici, a esclusione di quelli banditi per il reclutamento del personale sanitario e socio-sanitario, educativo e scolastico, compreso quello impiegato nei servizi educativo-scolastici gestiti direttamente dai comuni e dalle unioni di comuni, e dei ricercatori, nonche' del personale di cui all'articolo 3, sono considerati idonei i candidati collocati nella graduatoria finale dopo l'ultimo candidato vincitore, in numero non superiore al 20 per cento dei posti messi a concorso. Entro il termine di validita' delle graduatorie e nei limiti delle facolta' assunzionali gia' autorizzate, le amministrazioni possono procedere allo scorrimento delle graduatorie nei limiti di cui al quarto periodo. La disposizione del quarto periodo non si applica alle procedure concorsuali bandite dalle regioni, dalle province, ((dalle camere di commercio, industria, artigianato e agricoltura,)) dagli enti locali o da enti o agenzie da questi controllati o partecipati che prevedano un numero di posti messi a concorso non superiore a venti unita' e per i comuni con popolazione inferiore a 3.000 abitanti e per l'effettuazione di assunzioni a tempo determinato. Con decreto del Ministro della pubblica amministrazione, adottato previa intesa in sede di Conferenza unificata ai sensi dell'articolo 8, comma 6, della legge 5 giugno 2003, n. 131, possono essere stabilite ulteriori modalita' applicative delle disposizioni del presente comma. Espletata la verifica di cui all'articolo 4, comma 3, lettera a), del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni ((,)) dalla legge 30 ottobre 2013, n. 125, le amministrazioni, per ragioni di carattere organizzativo, purche' in presenza di profili professionali sovrapponibili a quelli individuati nei propri atti di programmazione, possono reclutare il proprio personale, a tempo determinato ((o a tempo indeterminato)), mediante utilizzo di proprie graduatorie vigenti ovvero, previo accordo, di quelle di altra amministrazione, ai sensi dell'articolo 1, comma 4, lettera ((b-bis) )), del decreto-legge 22 aprile 2023, n. 44, convertito, con modificazioni, dalla legge 21 giugno 2023, n. 74. (27) (124)

5-quater. Ai fini di cui al comma 5-ter, le commissioni di concorso, al termine dello svolgimento delle prove d'esame elaborano una graduatoria di merito sulla base dei soli risultati delle predette prove. Su tale graduatoria sono applicati i punteggi relativi ai titoli previsti dal bando e, successivamente, sono applicate le precedenze e le preferenze. Su tale ultima elaborazione le commissioni applicano il limite di cui al comma 5-ter. Sulla graduatoria risultante si applicano, entro il limite del 20 per cento degli idonei, le riserve di posti previste dal bando. Al fine di assicurare la trasparenza della procedura concorsuale, la graduatoria di merito, quella risultante dall'applicazione dei titoli sulla graduatoria di merito e quella finale sulla quale si applicano le riserve previste ((dal bando sono pubblicate contestualmente, anche in un unico documento,)) sul Portale unico del reclutamento di cui all'articolo 35-ter e sul sito dell'amministrazione procedente ((, anche tramite apposito collegamento ipertestuale,)) in un'area ad accesso riservato ai partecipanti, utilizzando le specifiche funzionalita' previste dal predetto Portale. ((E' assicurata)) la minimizzazione dei dati personali. ((Resta fermo quanto previsto dall'articolo 19 del decreto legislativo 14 marzo 2013, n. 33)).

5-quinquies. Le graduatorie per il reclutamento del personale educativo e scolastico danno evidenza ((, in un'area ad accesso riservato ai partecipanti,)) delle riserve, delle precedenze e delle preferenze applicate, ((assicurando comunque)) la minimizzazione dei dati personali.

5-sexies. La graduatoria si intende utilmente scorsa quando, entro il limite temporale di validita', l'amministrazione titolare individua, o cede ad amministrazioni terze, candidati idonei individuati ((numericamente o)) nominativamente, in ordine di graduatoria, per la successiva convocazione da parte dell'amministrazione procedente, a nulla rilevando il momento della ((stipulazione)) del contratto di assunzione.

6. Ai fini delle assunzioni di personale presso la Presidenza del Consiglio dei ministri, il Ministero degli affari esteri e della cooperazione internazionale e le amministrazioni che esercitano competenze istituzionali in materia di difesa e sicurezza dello Stato, di polizia, di giustizia ordinaria, amministrativa, contabile e di difesa in giudizio dello Stato, si applica il disposto di cui all'articolo 26 della legge 1° febbraio 1989, n. 53, e successive modificazioni ed integrazioni.

7. Il regolamento sull'ordinamento degli uffici e dei servizi degli enti locali disciplina le dotazioni organiche, le modalita' di assunzione agli impieghi, i requisiti di accesso e le procedure concorsuali, nel rispetto dei principi fissati dai commi precedenti.

--------------- AGGIORNAMENTO (27) Il D.L. 31 dicembre 2007, n.248 convertito con modificazioni dalla L. 28 febbraio 2008, n. 31 ha disposto (con l'art. 24-quater, comma 1) che "In deroga alla disposizione di cui all'articolo 35, comma 5-ter, del decreto legislativo 30 marzo 2001, n. 165, per far fronte alle esigenze relative alla prevenzione degli infortuni e delle morti sul lavoro, il Ministero del lavoro e della previdenza sociale e' autorizzato ad utilizzare la graduatoria formata in seguito allo svolgimento dei concorsi pubblici per esami a complessivi 795 posti di ispettore del lavoro, indetti con decreto direttoriale 15 novembre 2004, pubblicato nella Gazzetta Ufficiale - 4ª serie speciale - n. 93 del 23 novembre 2004, fino al 10 dicembre 2010." --------------- AGGIORNAMENTO (60) Il D.L. 31 maggio 2014, n. 83, convertito con modificazioni dalla L. 29 luglio 2014, n. 106, ha disposto (con l'art. 15, comma 2-ter) che "Per le medesime finalita' di cui al comma 2-bis nonche' al fine di assicurare la piena funzionalita' degli istituti del Ministero dei beni e delle attivita' culturali e del turismo, la durata temporale dell'obbligo di permanenza nella sede di prima destinazione, di cui all'articolo 35, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, per il personale in servizio di ruolo nel medesimo Ministero, e' di tre anni. La presente disposizione costituisce norma non derogabile dai contratti collettivi". --------------- AGGIORNAMENTO (68) Il D.Lgs. 25 novembre 2016, n. 218 ha disposto (con l'art. 11, comma 2) che "In deroga all'articolo 35, comma 5-bis, del decreto legislativo 30 marzo 2001, n. 165, la durata temporale dell'obbligo di permanenza nella sede di prima destinazione, per il personale in servizio di ruolo e' di tre anni". Ha inoltre disposto (con l'art. 12, comma 2) che "Le disposizioni di cui al secondo periodo del comma 4 dell'articolo 35 del decreto legislativo 30 marzo 2001, n. 165 non si applicano agli Enti". --------------- AGGIORNAMENTO (78) Il D.L. 28 settembre 2018, n. 109, convertito con modificazioni dalla L. 16 novembre 2018, n. 130, ha disposto (con l'art. 15-bis, comma 1) che "Per far fronte alla necessita' di coprire le gravi scoperture organiche degli uffici giudiziari del distretto della corte di appello di Genova nonche' per garantire il regolare andamento dell'attivita' giudiziaria in ragione dell'incremento dei procedimenti civili e penali presso i medesimi uffici, il Ministero della giustizia e' autorizzato ad assumere in via straordinaria, nell'ambito dell'attuale dotazione organica, nel biennio 2018-2019, con contratto di lavoro a tempo indeterminato un contingente massimo di 50 unita' di personale amministrativo non dirigenziale da inquadrare nei ruoli dell'amministrazione giudiziaria. Il personale di cui al periodo precedente e' assunto, in deroga a quanto previsto dagli articoli 30 e 35, comma 4, del decreto legislativo 30 marzo 2001, n. 165, e ferme restando le previsioni di cui all'articolo 4, commi 3, 3-bis e 3-ter, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, mediante lo scorrimento di graduatorie delle pubbliche amministrazioni in corso di validita' alla data di entrata in vigore della legge di conversione del presente decreto ovvero mediante selezioni pubbliche svolte su base nazionale, anche con modalita' semplificate definite con decreto del Ministro per la pubblica amministrazione, di concerto con il Ministro della giustizia, da adottare entro trenta giorni dalla data di entrata in vigore della legge di conversione del presente decreto, anche in deroga alla disciplina prevista dal regolamento di cui al decreto del Presidente della Repubblica 9 maggio 1994, n. 487, per quanto concerne, in particolare, la tipologia e le modalita' di svolgimento delle prove di esame e la nomina delle commissioni e delle sottocommissioni". -------------- AGGIORNAMENTO (81) La L. 30 dicembre 2018, n. 145 ha disposto (con l'art. 1, comma 364) che "All'articolo 35 del decreto legislativo 30 marzo 2001, n. 165, la lettera e-bis) del comma 3 e' abrogata, fermo restando quanto previsto dall'articolo 400, comma 15, del testo unico di cui al decreto legislativo 16 aprile 1994, n. 297, e dal decreto legislativo 13 aprile 2017, n. 59". Ha inoltre disposto (con l'art. 1, comma 366) che "I commi da 360 a 364 non si applicano alle assunzioni del personale scolastico, inclusi i dirigenti, e del personale delle istituzioni di alta formazione artistica, musicale e coreutica". -------------- AGGIORNAMENTO (80) La L. 30 dicembre 2018, n. 145, come modificata dal D.L. 14 dicembre 2018, n. 135, convertito con modificazioni dalla L. 11 febbraio 2019, n. 12, ha disposto (con l'art. 1, comma 365) che "Le previsioni di cui ai commi 361, 363 e 364 si applicano alle procedure concorsuali per l'assunzione di personale medico, tecnico-professionale e infermieristico, bandite dalle aziende e dagli enti del Servizio sanitario nazionale a decorrere dal 1° gennaio 2020". -------------- AGGIORNAMENTO (82) Il D.Lgs. 20 febbraio 2019, n. 15 ha disposto (con l'art. 36, comma 2) che "Le assunzioni di cui al comma 1 sono effettuate in deroga agli articoli 30, comma 2-bis e 35, comma 4, del decreto legislativo 30 marzo 2001, n. 165, e all'articolo 4, commi 3 e 3-quinquies, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125". --------------- AGGIORNAMENTO (84) Il D.L. 30 aprile 2019, n. 34, convertito con modificazioni dalla L. 28 giugno 2019, n. 58, ha disposto (con l'art. 31, comma 3) che "Al fine dello svolgimento dei nuovi incrementali adempimenti, il Ministero dello sviluppo economico e' autorizzato, nei limiti della vigente dotazione organica, ad assumere a tempo indeterminato dieci unita' da inquadrare nell'area III, posizione economica F1, selezionate attraverso apposito concorso pubblico, in possesso degli specifici requisiti professionali necessari all'espletamento dei nuovi compiti operativi. Le assunzioni sono effettuate in deroga agli articoli 30, comma 2-bis e 35, comma 4, del decreto legislativo 30 marzo 2001, n. 165, e all'articolo 4, commi 3 e 3-quinquies, del decreto-legge 31 agosto 2013, n. 101, convertito con modificazioni, dalla legge 30 ottobre 2013, n. 125". La L. 30 dicembre 2018, n. 145, come modificata dal D.L. 30 aprile 2019, n. 34, convertito con modificazioni dalla L. 28 giugno 2019, n. 58, ha disposto (con l'art. 1, comma 366) che "I commi da 360 a 364 non si applicano alle assunzioni del personale scolastico, inclusi i dirigenti, e del personale delle istituzioni di alta formazione artistica, musicale e coreutica. I commi 360, 361, 363 e 364 non si applicano alle assunzioni del personale educativo degli enti locali". -------------- AGGIORNAMENTO (124) Il D.L. 22 giugno 2023, n. 75, convertito con modificazioni dalla L. 10 agosto 2023, n. 112 ha disposto (con l'art. 28-ter, comma 2) che "Le disposizioni dell'articolo 35, comma 5-ter, quarto e quinto periodo, del decreto legislativo 30 marzo 2001, n. 165, si applicano ai concorsi pubblici banditi successivamente alla data di entrata in vigore della legge di conversione del presente decreto". -------------- AGGIORNAMENTO (129) Il D.L. 2 marzo 2024, n. 19 ha disposto (con l'art. 10, comma 3, lettera b)) che " in aggiunta alle facolta' assunzionali previste a legislazione vigente e in deroga a quanto previsto dall'articolo 35, comma 4, del decreto legislativo n. 165 del 2001, il Consiglio nazionale dell'economia e del lavoro e' autorizzato ad assumere con contratto di lavoro subordinato a tempo indeterminato nel triennio 2024-2026, nei limiti della dotazione organica vigente, una unita' dirigenziale di livello non generale, otto unita' da inquadrare nel livello iniziale dell'area dei funzionari e sette unita' da inquadrare nel livello iniziale dell'area degli assistenti. Le predette unita' sono reclutate mediante nuove procedure concorsuali, scorrimento di vigenti graduatorie di concorsi pubblici o attivazione di procedure di mobilita' volontaria, ai sensi dell'articolo 30 del decreto legislativo n. 165 del 2001". -------------- AGGIORNAMENTO (136) Il D.L. 14 marzo 2025, n. 25, convertito con modificazioni dalla L. 9 maggio 2025, n. 69, ha disposto (con l'art. 3, comma 3) che "Le disposizioni di cui al comma 1, lettera d), numero 1), non si applicano ai concorsi inseriti nel Piano integrato di attivita' e organizzazione relativo all'anno 2025, che puo' essere presentato entro il 31 marzo 2025, e banditi nell'anno 2025". Inoltre nel modificare l'art. 1, comma 1 del D.L. 27 dicembre 2024, n. 202, convertito con modificazioni dalla L. 21 febbraio 2025, n. 15, ha conseguentemente disposto (con l'art. 17-quater, comma 3) che "In deroga a quanto previsto dall'articolo 1, comma 1, del decreto-legge 27 dicembre 2024, n. 202, convertito, con modificazioni, dalla legge 21 febbraio 2025, n. 15, le facolta' assunzionali dell'amministrazione giudiziaria, ivi comprese quelle relative alle procedure di reclutamento straordinarie di cui all'articolo 1, comma 858, della legge 30 dicembre 2020, n. 178, all'articolo 1, comma 27, della legge 27 settembre 2021, n. 134, all'articolo 1, comma 867, della legge 29 dicembre 2022, n. 197, e all'articolo 13, comma 2, del decreto-legge 22 giugno 2023, n. 75, convertito, con modificazioni, dalla legge 10 agosto 2023, n. 112, sono esercitabili fino al 31 dicembre 2026".

### Art. 35.1. - (( (Concorsi su base territoriale). ))

((

1. I concorsi unici possono essere organizzati su base territoriale. In tali casi i bandi di concorso prevedono che ciascun candidato possa presentare domanda di partecipazione per non piu' di uno dei profili oggetto del bando e, rispetto a tale profilo, per non piu' di un ambito territoriale.

2. L'amministrazione puo' coprire i posti di ciascun profilo non assegnati in ciascun ambito territoriale, mediante scorrimento delle graduatorie degli idonei non vincitori, per il medesimo profilo, in ambiti territoriali confinanti che presentano il maggior numero di idonei))

### Art. 35-bis. - (( (Prevenzione del fenomeno della corruzione nella formazione di commissioni e nelle assegnazioni agli uffici) ))

((

1. Coloro che sono stati condannati, anche con sentenza non passata in giudicato, per i reati previsti nel capo I del titolo II del libro secondo del codice penale:

- a) non possono fare parte, anche con compiti di segreteria, di commissioni per l'accesso o la selezione a pubblici impieghi;
- b) non possono essere assegnati, anche con funzioni direttive, agli uffici preposti alla gestione delle risorse finanziarie, all'acquisizione di beni, servizi e forniture, nonche' alla concessione o all'erogazione di sovvenzioni, contributi, sussidi, ausili finanziari o attribuzioni di vantaggi economici a soggetti pubblici e privati;
- c) non possono fare parte delle commissioni per la scelta del contraente per l'affidamento di lavori, forniture e servizi, per la concessione o l'erogazione di sovvenzioni, contributi, sussidi, ausili finanziari, nonche' per l'attribuzione di vantaggi economici di qualunque genere.

2. La disposizione prevista al comma 1 integra le leggi e regolamenti che disciplinano la formazione di commissioni e la nomina dei relativi segretari))

### Art. 35-ter. - (Portale unico del reclutamento)

1. L'assunzione a tempo determinato e indeterminato nelle amministrazioni pubbliche centrali di cui all'articolo 1, comma 2, e nelle autorita' amministrative indipendenti avviene mediante concorsi pubblici orientati alla massima partecipazione ai quali si accede mediante registrazione nel Portale unico del reclutamento, di cui all'articolo 3, comma 7, della legge 19 giugno 2019, n. 56, di seguito denominato "Portale", disponibile all'indirizzo www.InPA.gov.it, sviluppato dal Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, che ne cura la gestione.

2. All'atto della registrazione al Portale l'interessato compila il proprio curriculum vitae, completo di tutte le generalita' anagrafiche ivi richieste, con valore di dichiarazione sostitutiva di certificazione ai sensi dell'articolo 46 del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, indicando un indirizzo di posta elettronica certificata o un domicilio digitale a lui intestato al quale intende ricevere ogni comunicazione relativa alla procedura cui intende partecipare, ivi inclusa quella relativa all'eventuale assunzione in servizio, unitamente ad un recapito telefonico. All'atto della registrazione l'interessato puo' chiedere l'invio, da parte del Portale, di notifiche relative alla pubblicazione di bandi o avvisi corrispondenti ai propri requisiti di registrazione. ((Il diario delle prove, il punteggio conseguito, l'eventuale convocazione alle prove e l'elenco dei candidati che hanno superato la prova, con i relativi punteggi, sono pubblicati e messi a disposizione dei partecipanti in un'area ad accesso riservato, utilizzando le specifiche funzionalita' del Portale unico del reclutamento di cui all'articolo 35-ter. Gli esiti delle prove orali, con l'elenco dei candidati esaminati, sono altresi' affissi al termine di ogni sessione giornaliera d'esame nei luoghi fisici in cui si e' svolta la prova e rimangono pubblicati fino al termine di ciascuna giornata)). La registrazione al Portale e' gratuita e puo' essere effettuata esclusivamente mediante i sistemi di identificazione di cui all'articolo 64, commi 2-quater e 2-nonies, del codice dell'amministrazione digitale, di cui al decreto legislativo 7 marzo 2005, n. 82. Con decreto del Ministro per la pubblica amministrazione, da adottare entro sessanta giorni dalla data di entrata in vigore della legge di conversione del decreto-legge 24 febbraio 2023, n. 13, previa acquisizione del parere del Garante per la protezione dei dati personali e dell'intesa in sede di Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, sono individuate le caratteristiche e le modalita' di funzionamento del Portale, le informazioni necessarie per la registrazione al medesimo da parte degli utenti, le modalita' di accesso e di utilizzo dello stesso da parte delle amministrazioni di cui ai commi 1 e 4 e quelle per la pubblicazione dei bandi di concorso, degli avvisi di mobilita' e degli avvisi di selezione di professionisti ed esperti, ivi compresi le comunicazioni ai candidati e la pubblicazione delle graduatorie, i tempi di conservazione dei dati raccolti o comunque trattati e le misure per assicurare l'integrita' e la riservatezza dei dati personali, nonche' le modalita' per l'adeguamento e l'evoluzione delle caratteristiche tecniche del Portale. In relazione alle procedure per il reclutamento delle amministrazioni di cui all'articolo 3, il decreto di cui al quarto periodo tiene conto delle specificita' dei rispettivi ordinamenti. Entro il medesimo termine di cui al ((quarto periodo)), per le amministrazioni di cui all'articolo 19 della legge 4 novembre 2010, n. 183, e' adottato apposito decreto del Ministro per la pubblica amministrazione, di concerto con i Ministri dell'interno, della difesa, dell'economia e delle finanze e della giustizia, previa acquisizione del parere del Garante per la protezione dei dati personali. La veridicita' delle dichiarazioni rese dagli interessati ai sensi dell'articolo 46 del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, e' verificata dalle amministrazioni che indicono le selezioni e utilizzano il Portale in quanto amministrazioni procedenti ai sensi dell'articolo 71 del medesimo testo unico di cui al decreto del Presidente della Repubblica n. 445 del 2000. Non si tiene conto delle iscrizioni che non contengono tutte le indicazioni circa il possesso dei requisiti richiesti per la registrazione nel Portale o richieste dai bandi di concorso.

2-bis. A decorrere dall'anno 2023 la pubblicazione delle procedure di reclutamento nei siti istituzionali e sul Portale unico del reclutamento esonera le amministrazioni pubbliche, inclusi gli enti locali, dall'obbligo di pubblicazione delle selezioni pubbliche nella Gazzetta Ufficiale.

3. COMMA ABROGATO DAL D.L. 24 FEBBRAIO 2023, N. 13, CONVERTITO CON MODIFICAZIONI DALLA L. 21 APRILE 2023, N. 41. (119)

4. L'utilizzo del Portale e' esteso a Regioni ed enti locali per le rispettive selezioni di personale. Le modalita' di utilizzo da parte di Regioni ed enti locali sono definite con il decreto del Ministro per la pubblica amministrazione di cui al comma 2.

5. I bandi per il reclutamento e per la mobilita' del personale pubblico sono pubblicati sul Portale secondo lo schema predisposto dal Dipartimento della funzione pubblica. Il Portale garantisce l'acquisizione della documentazione relativa a tali procedure da parte delle amministrazioni pubbliche in formato aperto e organizza la pubblicazione in modo accessibile e ricercabile secondo parametri utili ai cittadini che intendono partecipare a tali procedure.

6. All'attuazione delle disposizioni del presente articolo si provvede nell'ambito delle risorse umane, finanziarie e strumentali disponibili a legislazione vigente e, comunque, senza nuovi o maggiori oneri per la finanza pubblica. (114)

------------- AGGIORNAMENTO (114) Il D.L. 30 aprile 2022, n. 36, convertito con modificazioni dalla L. 29 giugno 2022, n. 79, ha disposto (con l'art. 2, comma 2) che "Il Portale unico del reclutamento di cui all'articolo 35-ter del decreto legislativo n. 165 del 2001, introdotto dal comma 1 del presente articolo, e' operativo dal 1° luglio 2022 e, a decorrere dalla medesima data, puo' essere utilizzato dalle amministrazioni pubbliche centrali di cui all'articolo 1, comma 2, del medesimo decreto legislativo n. 165 del 2001 e dalle autorita' amministrative indipendenti. Dal 1° novembre 2022 le medesime amministrazioni utilizzano il Portale per tutte le procedure di assunzione a tempo determinato e indeterminato. Resta fermo quanto previsto dall'articolo 1, comma 4, ultimo periodo, del decreto-legge 9 giugno 2021, n. 80, convertito, con modificazioni, dalla legge 6 agosto 2021, n. 113". ------------- AGGIORNAMENTO (119) Il D.L. 24 febbraio 2023, n. 13, convertito con modificazioni dalla L. 21 aprile 2023, n. 41, ha disposto (con l'art. 12, comma 2) che "Fino alla data di entrata in vigore del decreto del Ministro per la pubblica amministrazione previsto dall'articolo 35-ter, comma 2, del decreto legislativo 30 marzo 2001, n. 165, come modificato dal comma 1, continua ad applicarsi la disciplina contenuta nei protocolli adottati d'intesa tra il Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri e ciascuna amministrazione ai sensi dell'articolo 35-ter, comma 3, del decreto legislativo n. 165 del 2001 nel testo vigente prima della data di entrata in vigore del presente decreto.".

### Art. 35-quater. - (Procedimento per l'assunzione del personale non dirigenziale)

1. I concorsi per l'assunzione del personale non dirigenziale delle amministrazioni di cui all'articolo 1, comma 2, ivi inclusi quelli indetti dalla Commissione per l'attuazione del progetto di riqualificazione delle pubbliche amministrazioni (RIPAM) di cui all'articolo 35, comma 5, ed esclusi quelli relativi al personale di cui all'articolo 3, prevedono:

- a) l'espletamento di almeno una prova scritta, anche a contenuto teorico-pratico, e di una prova orale, comprendente l'accertamento della conoscenza di almeno una lingua straniera ai sensi dell'articolo 37. Le prove di esame sono finalizzate ad accertare il possesso delle competenze, intese come insieme delle conoscenze e delle capacita' logico-tecniche, comportamentali nonche' manageriali, per i profili che svolgono tali compiti, che devono essere specificate nel bando e definite in maniera coerente con la natura dell'impiego, ovvero delle abilita' residue nel caso dei soggetti di cui all'articolo 1, comma 1, della legge 12 marzo 1999, n. 68. Per profili iniziali e non specializzati, le prove di esame danno particolare rilievo all'accertamento delle capacita' comportamentali, incluse quelle relazionali, e delle attitudini. Il numero delle prove d'esame e le relative modalita' di svolgimento e correzione devono contemperare l'ampiezza e la profondita' della valutazione delle competenze definite nel bando con l'esigenza di assicurare tempi rapidi e certi di svolgimento del concorso orientati ai principi espressi nel comma 2;
- b) l'utilizzo di strumenti informatici e digitali e, facoltativamente, lo svolgimento in videoconferenza della prova orale, garantendo comunque l'adozione di soluzioni tecniche che ne assicurino la pubblicita', l'identificazione dei partecipanti, la sicurezza delle comunicazioni e la loro tracciabilita', nel rispetto della normativa in materia di protezione dei dati personali e nel limite delle pertinenti risorse disponibili a legislazione vigente;
- c) che le prove di esame possano essere precedute da forme di preselezione con test predisposti anche da imprese e soggetti specializzati in selezione di personale, nei limiti delle risorse disponibili a legislazione vigente, e possano riguardare l'accertamento delle conoscenze o il possesso delle competenze di cui alla lettera a), indicate nel bando;
- d) che i contenuti di ciascuna prova siano disciplinati dalle singole amministrazioni responsabili dello svolgimento delle procedure di cui al presente articolo, le quali adottano la tipologia selettiva piu' conferente con la tipologia dei posti messi a concorso, prevedendo che per l'assunzione di profili specializzati, oltre alle competenze, siano valutate le esperienze lavorative pregresse e pertinenti, anche presso la stessa amministrazione, ovvero le abilita' residue nel caso dei soggetti di cui all'articolo 1, comma 1, della legge 12 marzo 1999, n. 68. Le predette amministrazioni possono prevedere che nella predisposizione delle prove le commissioni siano integrate da esperti in valutazione delle competenze e selezione del personale, senza nuovi o maggiori oneri a carico della finanza pubblica;
- e) per i profili qualificati dalle amministrazioni, in sede di bando, ad elevata specializzazione tecnica, una fase di valutazione dei titoli legalmente riconosciuti e strettamente correlati alla natura e alle caratteristiche delle posizioni bandite, ai fini dell'ammissione a successive fasi concorsuali;
- f) che i titoli e l'eventuale esperienza professionale, inclusi i titoli di servizio, possano concorrere, in misura non superiore a un terzo, alla formazione del punteggio finale.

2. Le procedure di reclutamento di cui al comma 1 si svolgono con modalita' che ne garantiscano l'imparzialita', l'efficienza, l'efficacia e la celerita' di espletamento, che assicurino l'integrita' delle prove, la sicurezza e la tracciabilita' delle comunicazioni, ricorrendo all'utilizzo di sistemi digitali diretti anche a realizzare forme di preselezione ed a selezioni decentrate, anche non contestuali, in relazione a specifiche esigenze o per scelta organizzativa dell'amministrazione procedente, nel rispetto dell'eventuale adozione di misure compensative per lo svolgimento delle prove da parte dei candidati con disabilita' accertata ai sensi dell'articolo 4, comma 1, della legge 5 febbraio 1992, n. 104, o con disturbi specifici di apprendimento accertati ai sensi della legge 8 ottobre 2010, n. 170. Nelle selezioni non contestuali le amministrazioni assicurano comunque la trasparenza e l'omogeneita' delle prove somministrate in modo da garantire il medesimo grado di selettivita' tra tutti i partecipanti.

3. Le commissioni esaminatrici dei concorsi possono essere suddivise in sottocommissioni, con l'integrazione di un numero di componenti pari a quello delle commissioni originarie e di un segretario aggiunto. Per ciascuna sottocommissione e' nominato un presidente. La commissione definisce in una seduta plenaria preparatoria procedure e criteri di valutazione omogenei e vincolanti per tutte le sottocommissioni. Tali procedure e criteri di valutazione sono pubblicati nel sito internet dell'amministrazione procedente contestualmente alla graduatoria finale. All'attuazione del presente comma le amministrazioni provvedono nei limiti delle risorse disponibili a legislazione vigente.

((3-bis. Fino al 31 dicembre 2026, in deroga al comma 1, lettera a), i bandi di concorso per i profili non apicali possono prevedere lo svolgimento della sola prova scritta))

### Art. 36. - Personale a tempo determinato o assunto con forme di lavoro flessibile

1. Per le esigenze connesse con il proprio fabbisogno ordinario le pubbliche amministrazioni assumono esclusivamente con contratti di lavoro subordinato a tempo indeterminato seguendo le procedure di reclutamento previste dall'articolo 35.

2. Le amministrazioni pubbliche possono stipulare contratti di lavoro subordinato a tempo determinato, contratti di formazione e lavoro e contratti di somministrazione di lavoro a tempo determinato, nonche' avvalersi delle forme contrattuali flessibili previste dal codice civile e dalle altre leggi sui rapporti di lavoro nell'impresa, esclusivamente nei limiti e con le modalita' in cui se ne preveda l'applicazione nelle amministrazioni pubbliche. Le amministrazioni pubbliche possono stipulare i contratti di cui al primo periodo del presente comma soltanto per comprovate esigenze di carattere esclusivamente temporaneo o eccezionale e nel rispetto delle condizioni e modalita' di reclutamento stabilite dall'articolo 35. I contratti di lavoro subordinato a tempo determinato possono essere stipulati nel rispetto degli articoli 19 e seguenti del decreto legislativo 15 giugno 2015, n. 81, escluso il diritto di precedenza che si applica al solo personale reclutato secondo le procedure di cui all'articolo 35, comma 1, lettera b), del presente decreto. I contratti di somministrazione di lavoro a tempo determinato sono disciplinati dagli articoli 30 e seguenti del decreto legislativo 15 giugno 2015, n. 81, fatta salva la disciplina ulteriore eventualmente prevista dai contratti collettivi nazionali di lavoro. Non e' possibile ricorrere alla somministrazione di lavoro per l'esercizio di funzioni direttive e dirigenziali. Per prevenire fenomeni di precariato, le amministrazioni pubbliche, nel rispetto delle disposizioni del presente articolo, sottoscrivono contratti a tempo determinato con i vincitori e gli idonei delle proprie graduatorie vigenti per concorsi pubblici a tempo indeterminato. E' consentita l'applicazione dell'articolo 3, comma 61, terzo periodo, della legge 24 dicembre 2003, n. 350, ferma restando la salvaguardia della posizione occupata nella graduatoria dai vincitori e dagli idonei per le assunzioni a tempo indeterminato. 2.1. ((Nei casi in cui il personale dipendente delle amministrazioni di cui all'articolo 1, comma 2, fruisca dell'aspettativa non retribuita, le amministrazioni stesse, senza nuovi o maggiori oneri a carico della finanza pubblica, previo svolgimento di procedure selettive conformi a quanto previsto dall'articolo 35, possono coprire le vacanze di organico conseguenti al collocamento in aspettativa mediante il ricorso a contratti a tempo determinato della durata massima di trentasei mesi, comunque non superiore all'effettiva durata dell'aspettativa. I contratti di cui al primo periodo si intendono risolti alla data di rientro in servizio del personale collocato in aspettativa di cui al presente comma. Nel periodo di aspettativa non retribuita, il personale dipendente delle amministrazioni di cui al primo periodo non riveste la qualifica di pubblico ufficiale o di incaricato di pubblico servizio. Il servizio prestato ai sensi del presente comma e' valorizzato nei concorsi per l'accesso ai ruoli della pubblica amministrazione, anche attraverso la previsione di riserve di posti in misura non superiore al 10 per cento di quelli messi a concorso)).

2-bis. I rinvii operati dal decreto legislativo 15 giugno 2015, n. 81, ai contratti collettivi devono intendersi riferiti, per quanto riguarda le amministrazioni pubbliche, ai contratti collettivi nazionali stipulati dall'ARAN.

3. Al fine di combattere gli abusi nell'utilizzo del lavoro flessibile, sulla base di apposite istruzioni fornite con direttiva del Ministro per la semplificazione e la pubblica amministrazione, le amministrazioni redigono, dandone informazione alle organizzazioni sindacali tramite invio all'Osservatorio paritetico presso l'Aran, senza nuovi o maggiori oneri per la finanza pubblica, un analitico rapporto informativo sulle tipologie di lavoro flessibile utilizzate, con l'indicazione dei dati identificativi dei titolari del rapporto nel rispetto della normativa vigente in tema di protezione dei dati personali, da trasmettere, entro il 31 gennaio di ciascun anno, ai nuclei di valutazione e agli organismi indipendenti di valutazione di cui all'articolo 14 del decreto legislativo 27 ottobre 2009, n. 150, nonche' alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica che redige una relazione annuale al Parlamento.

4. Le amministrazioni pubbliche comunicano, nell'ambito del rapporto di cui al precedente comma 3, anche le informazioni concernenti l'utilizzo dei lavoratori socialmente utili.

5. In ogni caso, la violazione di disposizioni imperative riguardanti l'assunzione o l'impiego di lavoratori, da parte delle pubbliche amministrazioni, non puo' comportare la costituzione di rapporti di lavoro a tempo indeterminato con le medesime pubbliche amministrazioni, ferma restando ogni responsabilita' e sanzione. Il lavoratore interessato ha diritto al risarcimento del danno derivante dalla prestazione di lavoro in violazione di disposizioni imperative. Nella specifica ipotesi di danno conseguente all'abuso nell'utilizzo di una successione di contratti o rapporti di lavoro a tempo determinato, fatta salva la facolta' per il lavoratore di provare il maggior danno, il giudice stabilisce un'indennita' nella misura compresa tra un minimo di quattro e un massimo di ventiquattro mensilita' dell'ultima retribuzione di riferimento per il calcolo del trattamento di fine rapporto, avuto riguardo alla gravita' della violazione anche in rapporto al numero dei contratti in successione intervenuti tra le parti e alla durata complessiva del rapporto.

5-bis. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75.

5-ter. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75.

5-quater. I contratti di lavoro posti in essere in violazione del presente articolo sono nulli e determinano responsabilita' erariale. I dirigenti che operano in violazione delle disposizioni del presente articolo sono, altresi', responsabili ai sensi dell'articolo 21. Al dirigente responsabile di irregolarita' nell'utilizzo del lavoro flessibile non puo' essere erogata la retribuzione di risultato.

5-quinquies. Il presente articolo, fatto salvo il comma 5, non si applica al reclutamento del personale docente, educativo e amministrativo, tecnico e ausiliario (ATA), a tempo determinato presso le istituzioni scolastiche ed educative statali e degli enti locali, le istituzioni di alta formazione artistica, musicale e coreutica. Per gli enti di ricerca pubblici di cui agli articoli 1, comma 1, e 19, comma 4, del decreto legislativo 25 novembre 2016, n. 218, rimane fermo quanto stabilito dal medesimo decreto.

### Articolo 37 - Accertamento delle conoscenze informatiche e di lingue straniere nei concorsi pubblici (Art.36-ter del d.lgs n.29 del 1993, aggiunto dall'art.13 del d.lgs n.387 del 1998)

1. A decorrere dal 1 gennaio 2000 i bandi di concorso per l'accesso alle pubbliche amministrazioni di cui all'articolo 1, comma 2, prevedono l'accertamento della conoscenza dell'usa delle apparecchiature e delle applicazioni informatiche piu' diffuse ((e della lingua inglese, nonche', ove opportuno in relazione al profilo professionale richiesto, di altre lingue straniere)).

2. Per i dirigenti il regolamento di cui all'articolo 28 definisce il livello di conoscenza richiesto e le modalita' per il relativo accertamento.

3. Per gli altri dipendenti delle amministrazioni dello Stato, con regolamento emanato ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, e successive modificazioni ed integrazioni. su proposta del Presidente del Consiglio dei ministri, sono stabiliti i livelli di conoscenza, anche in relazione alla professionalita' cui si riferisce il bando, e le modalita' per l'accertamento della conoscenza medesima. Il regolamento stabilisce altresi' i casi nei quali il comma 1 non si applica.

### Articolo 38 - Accesso dei cittadini degli Stati membri della Unione europea (Art.37 d.lgs n.29 del 1993, come modificato dall'art.24 del d.lgs n.80 del 1998)

1. I cittadini degli Stati membri dell'Unione europea e i loro familiari non aventi la cittadinanza di uno Stato membro che siano titolari del diritto di soggiorno o del diritto di soggiorno permanente possono accedere ai posti di lavoro presso te amministrazioni pubbliche che non implicano esercizio diretto o indiretto di pubblici poteri, ovvero non attengono alla tutela dell'interesse nazionale.

2. Con decreto del Presidente del Consiglio dei ministri, ai sensi dell'articolo 17 della legge 23 agosto 1988, n.400, e successive modificazioni ed integrazioni, sono individuati i posti e le funzioni per i quali non puo' prescindersi dal possesso della cittadinanza italiana, nonche' i requisiti indispensabili all'accesso dei cittadini di cui al comma 1.

3. Sino all'adozione di una regolamentazione della materia da parte dell'Unione europea, al riconoscimento dei titoli di studio esteri, aventi valore ufficiale nello Stato in cui sono stati conseguiti, ai fini della partecipazione ai concorsi pubblici destinati al reclutamento di personale dipendente, con esclusione dei concorsi per il personale docente delle scuole di ogni ordine e grado, provvede il Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, previo parere conforme del Ministero dell'istruzione e del merito ovvero del Ministero dell'universita' e della ricerca. I candidati che sono in possesso del titolo di ammissione conseguito all'estero ((sono ammessi con riserva a partecipare ai concorsi di cui al primo periodo)). Il Dipartimento della funzione pubblica conclude il procedimento di riconoscimento di cui al presente comma solo nei confronti dei vincitori del concorso, che hanno l'onere, a pena di decadenza, di presentare istanza di riconoscimento ((,)) entro quindici giorni dalla pubblicazione della graduatoria finale, al Ministero dell'universita' e della ricerca ovvero al Ministero dell'istruzione e del merito. 3.1. Per i fini previsti dagli articoli 3 e 4 del regolamento di cui al decreto del Presidente della Repubblica 30 luglio 2009, n. 189, e per le selezioni pubbliche di personale non dipendente, al riconoscimento del titolo di studio provvede, con le medesime modalita' di cui al comma 3 del presente articolo, il Ministero dell'universita' e della ricerca, indipendentemente dalla cittadinanza posseduta, anche per i titoli conseguiti in Paesi diversi da quelli firmatari della Convenzione sul riconoscimento dei titoli di studio relativi all'insegnamento superiore nella Regione europea, fatta a Lisbona l'11 aprile 1997, ratificata ai sensi della legge 11 luglio 2002, n. 148. 3.2. Al riconoscimento accademico e al conferimento del valore legale ai titoli di formazione superiore esteri, ai dottorati di ricerca esteri e ai titoli accademici esteri conseguiti nel settore artistico, musicale e coreutico, indipendentemente dalla cittadinanza posseduta, provvedono le istituzioni di formazione superiore italiane ai sensi dell'articolo 2 della legge 11 luglio 2002, n. 148, anche per i titoli conseguiti in Paesi diversi da quelli firmatari della Convenzione sul riconoscimento dei titoli di studio relativi all'insegnamento superiore nella Regione europea, fatta a Lisbona l'11 aprile 1997, ratificata ai sensi della citata legge n. 148 del 2002. Il riconoscimento accademico produce gli effetti legali del corrispondente titolo italiano, anche ai fini dei concorsi pubblici per l'accesso al pubblico impiego.

3-bis. Le disposizioni di cui ai commi 1, 2 e 3 si applicano ai cittadini di Paesi terzi che siano titolari del permesso di soggiorno CE per soggiornanti di lungo periodo o che siano titolari dello status di rifugiato ovvero dello status di protezione sussidiaria.

3-ter. Sono fatte salve, in ogni caso, le disposizioni di cui all'articolo 1 del decreto del Presidente della Repubblica 26 luglio 1976, n. 752, in materia di conoscenza della lingua italiana e di quella tedesca per le assunzioni al pubblico impiego nella provincia autonoma di Bolzano.

### Articolo 39 - ((Assunzioni obbligatorie e tirocinio delle categorie protette))

1. ((Le amministrazioni pubbliche promuovono o propongono, anche per profili professionali delle aree o categorie previste dai contratti collettivi di comparto per i quali non e' previsto il solo requisito della scuola dell'obbligo e nel rispetto dei principi di cui all'articolo 35, comma 3, del presente decreto, programmi di assunzioni ai sensi dell'articolo 11 della legge 12 marzo 1999, n. 68, destinati ai soggetti titolari del diritto al collocamento obbligatorio previsto dagli articoli 3 e 18 della medesima legge n. 68 del 1999 e dall'articolo 1, comma 2, della legge 23 novembre 1998, n. 407,)) sulla base delle direttive impartite dalla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica e dal Ministero del lavoro, della salute e delle politiche sociali, cui confluisce il Dipartimento degli affari sociali della Presidenza del Consiglio dei ministri ai sensi dell'articolo 45, comma 3 del decreto legislativo 30 luglio 1999, n.300 con le decorrenze previste dall'articolo 10, commi 3 e 4, del decreto legislativo 30 luglio 1999, n.303.

### Articolo 39-bis - (Consulta nazionale per l'integrazione in ambiente di lavoro delle persone con disabilita')

1. Presso il Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri e' istituita, senza nuovi o maggiori oneri per la finanza pubblica, la Consulta nazionale per l'integrazione in ambiente di lavoro delle persone con disabilita', di seguito Consulta.

2. La Consulta e' composta da un rappresentante del Dipartimento della funzione pubblica, ((un rappresentante del Presidente del Consiglio dei ministri ovvero del Ministro delegato per la famiglia e le disabilita',)) un rappresentante del Dipartimento per le pari opportunita', un rappresentante del Ministero del lavoro e delle politiche sociali, un rappresentante del Ministero della salute, un rappresentante dell'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro (INAIL), un rappresentante dell'Agenzia nazionale politiche attive del lavoro (ANPAL), due rappresentanti designati dalla Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, due rappresentanti delle organizzazioni sindacali maggiormente rappresentative sul piano nazionale e due rappresentanti delle associazioni del mondo della disabilita' indicati dall'osservatorio nazionale di cui all'articolo 3 della legge 3 marzo 2009, n. 18. Ai componenti della Consulta non spettano gettoni di presenza, compensi, indennita' ed emolumenti comunque denominati, ad eccezione del rimborso delle spese effettivamente sostenute previsto dalla normativa vigente.

3. La Consulta svolge le seguenti funzioni:

- a) elabora piani, programmi e linee di indirizzo per ottemperare agli obblighi di cui alla legge 12 marzo 1999, n. 68;
- b) effettua il monitoraggio sul rispetto degli obblighi di comunicazione di cui all'articolo 39-quater;
- c) propone alle amministrazioni pubbliche iniziative e misure innovative finalizzate al miglioramento dei livelli di occupazione e alla valorizzazione delle capacita' e delle competenze dei lavoratori disabili nelle pubbliche amministrazioni;
- d) prevede interventi straordinari per l'adozione degli accomodamenti ragionevoli nei luoghi di lavoro previsti dall'articolo 3, comma 3-bis, del decreto legislativo 9 luglio 2003, n. 216;
- e) verifica lo stato di attuazione e la corretta applicazione delle disposizioni in materia di tutela e sostegno della disabilita' da parte delle amministrazioni, con particolare riferimento alle forme di agevolazione previste dalla legge e alla complessiva disciplina delle quote di riserva.

### Articolo 39-ter - (Responsabile dei processi di inserimento delle persone con disabilita')

1. ((Al fine di dare attuazione all'articolo 7, comma 1, e garantire)) un'efficace integrazione nell'ambiente di lavoro delle persone con disabilita', le amministrazioni pubbliche ((...)), senza nuovi o maggiori oneri per la finanza pubblica e nell'ambito delle risorse umane, finanziarie e strumentali disponibili a legislazione vigente, nominano un responsabile dei processi di inserimento ((in ambiente di lavoro delle persone con disabilita' individuato nell'ambito del personale in servizio)).

((

1-bis. Il responsabile di cui al comma 1 e' individuato tra i dirigenti di ruolo ovvero tra gli altri dipendenti ed e' scelto prioritariamente tra coloro i quali abbiano esperienza sui temi dell'inclusione sociale e dell'accessibilita' delle persone con disabilita' anche comprovata da specifica formazione.

))

2. Il responsabile dei processi di inserimento svolge le seguenti funzioni:

- a) cura i rapporti con il centro per l'impiego territorialmente competente per l'inserimento lavorativo dei disabili, nonche' con i servizi territoriali per l'inserimento mirato;
- b) predispone, sentito il medico competente della propria amministrazione ed eventualmente il comitato tecnico di cui alla legge 12 marzo 1999, n. 68, gli accorgimenti organizzativi e propone, ove necessario, le soluzioni tecnologiche per facilitare l'integrazione al lavoro anche ai fini dei necessari accomodamenti ragionevoli di cui all'articolo 3, comma 3-bis, del decreto legislativo 9 luglio 2003, n. 216;
- c) verifica l'attuazione del processo di inserimento, recependo e segnalando ai servizi competenti eventuali situazioni di disagio e di difficolta' di integrazione.

### Articolo 39-quater - (( (Monitoraggio sull'applicazione della legge 12 marzo 1999, n. 68). ))

((

1. Al fine di verificare la corretta e uniforme applicazione della legge 12 marzo 1999, n. 68, le amministrazioni pubbliche, tenute a dare attuazione alle disposizioni in materia di collocamento obbligatorio, inviano il prospetto informativo di cui all'articolo 9, comma 6, della legge n. 68 del 1999, al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, al Ministero del lavoro e delle politiche sociali e al Centro per l'impiego territorialmente competente.

2. Entro i successivi sessanta giorni le amministrazioni pubbliche di cui al comma 1 trasmettono, in via telematica, al servizio inserimento lavorativo disabili territorialmente competente, al Dipartimento della funzione pubblica e al Ministero del lavoro e delle politiche sociali una comunicazione contenente tempi e modalita' di copertura della quota di riserva. In tale comunicazione sono indicati anche eventuali bandi di concorso per specifici profili professionali per i quali non e' previsto il solo requisito della scuola dell'obbligo, riservati ai soggetti di cui all'articolo 8 della legge 12 marzo 1999, n. 68, o, in alternativa, le convenzioni di cui all'articolo 11 della citata legge. Tali informazioni sono trasmesse anche al fine di consentire una opportuna verifica della disciplina delle quote di riserva, in rapporto anche a quanto previsto per le vittime del terrorismo, della criminalita' organizzata e del dovere. Le informazioni sono altresi' trasmesse alla Consulta nazionale per l'integrazione in ambiente di lavoro delle persone con disabilita', ai fini di cui all'articolo 39-bis, comma 3, lettera e).

3. Le informazioni di cui al presente articolo sono raccolte nell'ambito della banca dati di cui all'articolo 8 del decreto-legge 28 giugno 2013, n. 76, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 99.

4. In caso di mancata osservanza delle disposizioni del presente articolo o di mancato rispetto dei tempi concordati, i centri per l'impiego avviano numericamente i lavoratori disabili attingendo alla graduatoria vigente con profilo professionale generico, dando comunicazione delle inadempienze al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri.

))

## CONTRATTAZIONE COLLETTIVA E RAPPRESENTATIVITA' SINDACALE

### Art. 40. - Contratti collettivi nazionali e integrativi (Art. 45 del d.lgs. n. 29 del 1993, come sostituito prima dall'art. 15 del d.lgs. n. 470 del 1993 e dall'art. 1 del d.lgs. n. 396 del 1997 e successivamente modificato dall'art. 43, comma 1 del d.lgs. n. 80 del 1998)

1. ((La contrattazione collettiva disciplina il rapporto di lavoro e le relazioni sindacali e si svolge con le modalita' previste dal presente decreto. Nelle materie relative alle sanzioni disciplinari, alla valutazione delle prestazioni ai fini della corresponsione del trattamento accessorio, della mobilita', la contrattazione collettiva e' consentita nei limiti previsti dalle norme di legge. Sono escluse dalla contrattazione collettiva le materie attinenti all'organizzazione degli uffici, quelle oggetto di partecipazione sindacale ai sensi dell'articolo 9, quelle afferenti alle prerogative dirigenziali ai sensi degli articoli 5, comma 2, 16 e 17, la materia del conferimento e della revoca degli incarichi dirigenziali, nonche' quelle di cui all'articolo 2, comma 1, lettera c), della legge 23 ottobre 1992, n. 421.))

2. Tramite appositi accordi tra l'ARAN e le Confederazioni rappresentative, secondo le procedure di cui agli articoli 41, comma 5, e 47, senza nuovi o maggiori oneri per la finanza pubblica, sono definiti fino a un massimo di quattro comparti di contrattazione collettiva nazionale, cui corrispondono non piu' di quattro separate aree per la dirigenza. Una apposita ((area o)) sezione contrattuale di un'area dirigenziale riguarda la dirigenza del ruolo sanitario del Servizio sanitario nazionale, per gli effetti di cui all'articolo 15 del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni. Nell'ambito dei comparti di contrattazione possono essere costituite apposite sezioni contrattuali per specifiche professionalita'.

3. La contrattazione collettiva disciplina, in coerenza con il settore privato, la struttura contrattuale, i rapporti tra i diversi livelli e la durata dei contratti collettivi nazionali e integrativi. La durata viene stabilita in modo che vi sia coincidenza fra la vigenza della disciplina giuridica e di quella economica.

3-bis. Le pubbliche amministrazioni attivano autonomi livelli di contrattazione collettiva integrativa, nel rispetto dell'articolo 7, comma 5, e dei vincoli di bilancio risultanti dagli strumenti di programmazione annuale e pluriennale di ciascuna amministrazione. La contrattazione collettiva integrativa assicura adeguati livelli di efficienza e produttivita' dei servizi pubblici, incentivando l'impegno e la qualita' della performance ((, destinandovi, per l'ottimale perseguimento degli obiettivi organizzativi ed individuali, una quota prevalente delle risorse finalizzate ai trattamenti economici accessori comunque denominati)) ai sensi dell'articolo 45, comma 3. ((La predetta quota e' collegata alle risorse variabili determinate per l'anno di riferimento.)) ((La contrattazione collettiva integrativa)) si svolge sulle materie, con i vincoli e nei limiti stabiliti dai contratti collettivi nazionali, tra i soggetti e con le procedure negoziali che questi ultimi prevedono; essa puo' avere ambito territoriale e riguardare piu' amministrazioni. I contratti collettivi nazionali definiscono il termine delle sessioni negoziali in sede decentrata. Alla scadenza del termine le parti riassumono le rispettive prerogative e liberta' di iniziativa e decisione.

((

3-ter. Nel caso in cui non si raggiunga l'accordo per la stipulazione di un contratto collettivo integrativo, qualora il protrarsi delle trattative determini un pregiudizio alla funzionalita' dell'azione amministrativa, nel rispetto dei principi di correttezza e buona fede fra le parti, l'amministrazione interessata puo' provvedere, in via provvisoria, sulle materie oggetto del mancato accordo fino alla successiva sottoscrizione e prosegue le trattative al fine di pervenire in tempi celeri alla conclusione dell'accordo. Agli atti adottati unilateralmente si applicano le procedure di controllo di compatibilita' economico-finanziaria previste dall'articolo 40-bis. I contratti collettivi nazionali possono individuare un termine minimo di durata delle sessioni negoziali in sede decentrata, decorso il quale l'amministrazione interessata puo' in ogni caso provvedere, in via provvisoria, sulle materie oggetto del mancato accordo. E' istituito presso l'ARAN, senza nuovi o maggiori oneri a carico della finanza pubblica, un osservatorio a composizione paritetica con il compito di monitorare i casi e le modalita' con cui ciascuna amministrazione adotta gli atti di cui al primo periodo. L'osservatorio verifica altresi' che tali atti siano adeguatamente motivati in ordine alla sussistenza del pregiudizio alla funzionalita' dell'azione amministrativa. Ai componenti non spettano compensi, gettoni, emolumenti, indennita' o rimborsi di spese comunque denominati.

))

3-quater. ((COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75)).

3-quinquies. La contrattazione collettiva nazionale dispone, per le amministrazioni di cui al comma 3 dell'articolo 41, le modalita' di utilizzo delle risorse indicate all'articolo 45, comma 3-bis, individuando i criteri e i limiti finanziari entro i quali si deve svolgere la contrattazione integrativa. Le regioni, per quanto concerne le proprie amministrazioni, e gli enti locali possono destinare risorse aggiuntive alla contrattazione integrativa nei limiti stabiliti dalla contrattazione nazionale e nei limiti dei parametri di virtuosita' fissati per la spesa di personale dalle vigenti disposizioni, in ogni caso nel rispetto ((degli obiettivi di finanza pubblica)) e di analoghi strumenti del contenimento della spesa. Lo stanziamento delle risorse aggiuntive per la contrattazione integrativa e' correlato all'affettivo rispetto dei principi in materia di misurazione, valutazione e trasparenza della performance e in materia di merito e premi applicabili alle regioni e agli enti locali secondo quanto previsto dagli articoli 16 e 31 del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni. Le pubbliche amministrazioni non possono in ogni caso sottoscrivere in sede decentrata contratti collettivi integrativi in contrasto con i vincoli e con i limiti risultanti dai contratti collettivi nazionali o che disciplinano materie non espressamente delegate a tale livello negoziale ovvero che comportano oneri non previsti negli strumenti di programmazione annuale e pluriennale di ciascuna amministrazione. Nei casi di violazione dei vincoli e dei limiti di competenza imposti dalla contrattazione nazionale o dalle norme di legge, le clausole sono nulle, non possono essere applicate e sono sostituite ai sensi degli articoli 1339 e 1419, secondo comma, del codice civile. ((In caso di superamento di vincoli finanziari accertato da parte delle sezioni regionali di controllo della Corte dei conti, del Dipartimento della funzione pubblica o del Ministero dell'economia e delle finanze e' fatto altresi' obbligo di recupero nell'ambito della sessione negoziale successiva, con quote annuali e per un numero massimo di annualita' corrispondente a quelle in cui si e' verificato il superamento di tali vincoli. Al fine di non pregiudicare l'ordinata prosecuzione dell'attivita' amministrativa delle amministrazioni interessate, la quota del recupero non puo' eccedere il 25 per cento delle risorse destinate alla contrattazione integrativa ed il numero di annualita' di cui al periodo precedente, previa certificazione degli organi di controllo di cui all'articolo 40-bis, comma 1, e' corrispondentemente incrementato. In alternativa a quanto disposto dal periodo precedente, le regioni e gli enti locali possono prorogare il termine per procedere al recupero delle somme indebitamente erogate, per un periodo non superiore a cinque anni, a condizione che adottino o abbiano adottato le misure di contenimento della spesa di cui all'articolo 4, comma 1, del decreto-legge 6 marzo 2014, n. 16, dimostrino l'effettivo conseguimento delle riduzioni di spesa previste dalle predette misure, nonche' il conseguimento di ulteriori riduzioni di spesa derivanti dall'adozione di misure di razionalizzazione relative ad altri settori anche con riferimento a processi di soppressione e fusione di societa', enti o agenzie strumentali. Le regioni e gli enti locali forniscono la dimostrazione di cui al periodo precedente con apposita relazione, corredata del parere dell'organo di revisione economico-finanziaria, allegata al conto consuntivo di ciascun anno in cui e' effettuato il recupero.)) Le disposizioni del presente comma trovano applicazione a decorrere dai contratti sottoscritti successivamente alla data di entrata in vigore del decreto legislativo di attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni.

3-sexies. A corredo di ogni contratto integrativo le pubbliche amministrazioni, redigono una relazione tecnico-finanziaria ed una relazione illustrativa, utilizzando gli schemi appositamente predisposti e resi disponibili tramite i rispettivi siti istituzionalidal Ministero dell'economia e delle finanze di intesa con il Dipartimento della funzione pubblica. Tali relazioni vengono certificate dagli organi di controllo di cui all'articolo 40-bis, comma 1.

4. Le pubbliche amministrazioni adempiono agli obblighi assunti con i contratti collettivi nazionali o integrativi dalla data della sottoscrizione definitiva e ne assicurano l'osservanza nelle forme previste dai rispettivi ordinamenti.

((

4-bis. I contratti collettivi nazionali di lavoro devono prevedere apposite clausole che impediscono incrementi della consistenza complessiva delle risorse destinate ai trattamenti economici accessori, nei casi in cui i dati sulle assenze, a livello di amministrazione o di sede di contrattazione integrativa, rilevati a consuntivo, evidenzino, anche con riferimento alla concentrazione in determinati periodi in cui e' necessario assicurare continuita' nell'erogazione dei servizi all'utenza o, comunque, in continuita' con le giornate festive e di riposo settimanale, significativi scostamenti rispetto a dati medi annuali nazionali o di settore.

4-ter. Al fine di semplificare la gestione amministrativa dei fondi destinati alla contrattazione integrativa e di consentirne un utilizzo piu' funzionale ad obiettivi di valorizzazione degli apporti del personale, nonche' di miglioramento della produttivita' e della qualita' dei servizi, la contrattazione collettiva nazionale provvede al riordino, alla razionalizzazione ed alla semplificazione delle discipline in materia di dotazione ed utilizzo dei fondi destinati alla contrattazione integrativa.

))

### Art. 40-bis. - (Controlli in materia di contrattazione integrativa).

1. Il controllo sulla compatibilita' dei costi della contrattazione collettiva integrativa con i vincoli di bilancio e quelli derivanti dall'applicazione delle norme di legge, con particolare riferimento alle disposizioni inderogabili che incidono sulla misura e sulla corresponsione dei trattamenti accessori e' effettuato dal collegio dei revisori dei conti, dal collegio sindacale, dagli uffici centrali di bilancio o dagli analoghi organi previsti dai rispettivi ordinamenti. Qualora dai contratti integrativi derivino costi non compatibili con i rispettivi vincoli di bilancio delle amministrazioni, si applicano le disposizioni di cui all'articolo 40, comma 3-quinquies, sesto periodo.

2. Per le amministrazioni statali, anche ad ordinamento autonomo, nonche' per gli enti pubblici non economici e per gli enti e le istituzioni di ricerca con organico superiore a duecento unita', i contratti integrativi sottoscritti, corredati da una apposita relazione tecnico-finanziaria ed una relazione illustrativa certificate dai competenti organi di controllo previsti dal comma 1, sono trasmessi alla Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica e al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, che, entro trenta giorni dalla data di ricevimento, ne accertano, congiuntamente, la compatibilita' economico-finanziaria, ai sensi del presente articolo e dell'articolo 40, comma 3-quinquies. Decorso tale termine, che puo' essere sospeso in caso di richiesta di elementi istruttori, la delegazione di parte pubblica puo' procedere alla stipula del contratto integrativo. Nel caso in cui il riscontro abbia esito negativo, le parti riprendono le trattative.

3. Le amministrazioni pubbliche di cui all'articolo 1, comma 2, inviano entro il 31 maggio di ogni anno, specifiche informazioni sui costi della contrattazione integrativa, certificate dagli organi di controllo interno, al Ministero dell'economia e delle finanze, che predispone, allo scopo, uno specifico modello di rilevazione, d'intesa con la Corte dei conti e con la Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica. Tali informazioni sono volte ad accertare, oltre il rispetto dei vincoli finanziari in ordine sia alla consistenza delle risorse assegnate ai fondi per la contrattazione integrativa sia all'evoluzione della consistenza dei fondi e della spesa derivante dai contratti integrativi applicati, anche la concreta definizione ed applicazione di criteri improntati alla premialita', al riconoscimento del merito ed alla valorizzazione dell'impegno e della qualita' della performanceindividuale, con riguardo ai diversi istituti finanziati dalla contrattazione integrativa, nonche' a parametri di selettivita', con particolare riferimento alle progressioni economiche. Le informazioni sono trasmesse alla Corte dei conti che, ferme restando le ipotesi di responsabilita' eventualmente ravvisabili le utilizza, unitamente a quelle trasmesse ai sensi del Titolo V, anche ai fini del referto sul costo del lavoro.

4. ((COMMA ABROGATO DAL D.LGS. 14 MARZO 2013, N. 33)).

5. Ai fini dell'articolo 46, comma 4, le pubbliche amministrazioni sono tenute a trasmettere all'ARAN, per via telematica, entro cinque giorni dalla sottoscrizione, il testo contrattuale con l'allegata relazione tecnico-finanziaria ed illustrativa e con l'indicazione delle modalita' di copertura dei relativi oneri con riferimento agli strumenti annuali e pluriennali di bilancio. I predetti testi contrattuali sono altresi' trasmessi al CNEL.

6. Il Dipartimento della funzione pubblica, il Dipartimento della Ragioneria generale dello Stato presso il Ministero dell'economia e delle finanze e la Corte dei conti possono avvalersi ai sensi dell'articolo 17, comma 14, della legge 15 maggio 1997, n. 127, di personale in posizione di fuori ruolo o di comando per l'esercizio delle funzioni di controllo sulla contrattazione integrativa.

7. In caso di mancato adempimento delle prescrizioni del presente articolo, oltre alle sanzioni previste dall'articolo 60, comma 2, e' fatto divieto alle amministrazioni di procedere a qualsiasi adeguamento delle risorse destinate alla contrattazione integrativa. Gli organi di controllo previsti dal comma 1 vigilano sulla corretta applicazione delle disposizioni del presente articolo.

### Art. 41. - (Poteri di indirizzo nei confronti dell'ARAN).

1. Il potere di indirizzo nei confronti dell'ARAN e le altre competenze relative alle procedure di contrattazione collettiva nazionale sono esercitati dalle pubbliche amministrazioni attraverso le proprie istanze associative o rappresentative, le quali costituiscono comitati di settore che regolano autonomamente le proprie modalita' di funzionamento e di deliberazione. In ogni caso, le deliberazioni assunte in materia di indirizzo all'ARAN o di parere sull'ipotesi di accordo nell'ambito della procedura di contrattazione collettiva di cui all'articolo 47, si considerano definitive e non richiedono ratifica da parte delle istanze associative o rappresentative delle pubbliche amministrazioni del comparto.

2. E' costituito un comitato di settore nell'ambito della Conferenza delle Regioni, che esercita ((...)) le competenze di cui al comma 1, per le regioni, i relativi enti dipendenti, e le amministrazioni del Servizio sanitario nazionale; a tale comitato partecipa un rappresentante del Governo, designato dal Ministro del lavoro, della salute e delle politiche sociali per le competenze delle amministrazioni del Servizio sanitario nazionale. E' costituito un comitato di settore nell'ambito dell'Associazione nazionale dei Comuni italiani (ANCI), dell'Unione delle province d'Italia (UPI) e dell'Unioncamere che esercita ((...)) le competenze di cui al comma 1, per i dipendenti degli enti locali, delle Camere di commercio e dei segretari comunali e provinciali.

3. Per tutte le altre amministrazioni opera come comitato di settore il Presidente del Consiglio dei Ministri tramite il Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e finanze. Al fine di assicurare la salvaguardia delle specificita' delle diverse amministrazioni e delle categorie di personale ivi comprese, gli indirizzi sono emanati per il sistema scolastico, sentito il Ministro dell'istruzione, dell'universita' e della ricerca, nonche', per i rispettivi ambiti di competenza, sentiti i direttori delle Agenzie fiscali, la Conferenza dei rettori delle universita' italiane; le istanze rappresentative promosse dai presidenti degli enti di ricerca e degli enti pubblici non economici ed il presidente del Consiglio nazionale dell'economia e del lavoro.

4. Rappresentati designati dai Comitati di settore possono assistere l'ARAN nello svolgimento delle trattative. I comitati di settore possono stipulare con l'ARAN specifici accordi per i reciproci rapporti in materia di contrattazione e per eventuali attivita' in comune. Nell'ambito del regolamento di organizzazione dell'ARAN per assicurare il miglior raccordo tra i Comitati di settore delle Regioni e degli enti locali e l'ARAN, a ciascun comitato corrisponde una specifica struttura, senza nuovi o maggiori oneri per la finanza pubblica.

5. Per la stipulazione degli accordi che definiscono o modificano i comparti o le aree di contrattazione collettiva di cui all'articolo 40, comma 2, o che regolano istituti comuni a piu' comparti ((o che si applicano a un comparto per il quale operano piu' comitati di settore)) le funzioni di indirizzo e le altre competenze inerenti alla contrattazione collettiva sono esercitate collegialmente dai comitati di settore.

------------- AGGIORNAMENTO (7) Il D.Lgs. 3 luglio 2003, n. 173 ha disposto (con l'art. 3, comma 3) che "All'articolo 41, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, dopo le parole: "Ministero dell'istruzione, dell'universita' e della ricerca", sono aggiunte le seguenti: "e, per il comparto delle Agenzie fiscali, sentiti i direttori delle medesime"".

### Articolo 42 - Diritti e prerogative sindacali nei luoghi di lavoro (Art.47 del d.lgs n.29 del 1993, come sostituito dall'art.6 del d.lgs n.396 del 1997)

1. Nelle pubbliche amministrazioni la liberta' e l'attivita' sindacale sono tutelate nelle forme previste dalle disposizioni della legge 20 maggio 1970, n. 300, e successive modificazioni ed integrazioni. Fino a quando non vengano emanate norme di carattere generale sulla rappresentativita' sindacale che sostituiscano o modifichino tali disposizioni, le pubbliche amministrazioni, in attuazione dei criteri di cui all'articolo 2, comma 1, lettera b) della legge 23 ottobre 1992, n. 421, osservano le disposizioni seguenti in materia di rappresentativita' delle organizzazioni sindacali ai fini dell'attribuzione dei diritti e delle prerogative sindacali nei luoghi di lavoro e dell'esercizio della contrattazione collettiva.

2. In ciascuna amministrazione, ente o struttura amministrativa di cui al comma 8, le organizzazioni sindacali che, in base ai criteri dell'articolo 43, siano ammesse alle trattative per la sottoscrizione dei contratti collettivi, possono costituire rappresentanze sindacali aziendali ai sensi dell'articolo 19 e seguenti della legge 20 maggio 1970, n. 300, e successive modificazioni ed integrazioni. Ad esse spettano, in proporzione alla rappresentativita', le garanzie previste dagli articoli 23, 24 e 30 della medesima legge n.300 del 1970, e le migliori condizioni derivanti dal contratti collettivi.

3. In ciascuna amministrazione, ente o struttura amministrativa di cui al comma 8, ad iniziativa anche disgiunta delle organizzazioni sindacali di cui al comma 2, viene altresi' costituito, con le modalita' di cui ai commi seguenti, un organismo di rappresentanza unitaria del personale mediante elezioni alle quali e' garantita la partecipazione di tutti i lavoratori.

((3-bis. Ai fini della costituzione degli organismi di cui al comma 3, e' garantita la partecipazione del personale in servizio presso le rappresentanze diplomatiche e consolari nonche' presso gli istituti italiani di cultura all'estero, ancorche' assunto con contratto regolato dalla legge locale. Di quanto previsto dal presente comma si tiene conto ai fini del calcolo della rappresentativita' sindacale ai sensi dell'articolo 43))

4. Con appositi accordi o contratti collettivi nazionali, tra l'ARAN e le confederazioni o organizzazioni sindacali rappresentative ai sensi dell'articolo 43, sono definite la composizione dell'organismo di rappresentanza unitaria del personale e le specifiche modalita' delle elezioni, prevedendo in ogni caso il voto segreto, il metodo proporzionale e il periodico rinnovo, con esclusione della prorogabilita'. Deve essere garantita la facolta' di presentare liste, oltre alle organizzazioni che, in base ai criteri dell'articolo 43, siano ammesse alle trattative per la sottoscrizione dei contratti collettivi, anche ad altre organizzazioni sindacali, purche' siano costituite in associazione con un proprio statuto e purche' abbiano aderito agli accordi o contratti collettivi che disciplinano l'elezione e il funzionamento dell'organismo. Per la presentazione delle liste, puo' essere richiesto a tutte le organizzazioni sindacali promotrici un numero di firme di dipendenti con diritto al voto non superiore al 3 per cento del totale dei dipendenti nelle amministrazioni, enti o strutture amministrative fino a duemila dipendenti, e del 2 per cento in quelle di dimensioni superiori. (33) (34)

5. I medesimi accordi o contratti collettivi possono prevedere che, alle condizioni di cui al comma 8, siano costituite rappresentanze unitarie del personale comuni a piu' amministrazioni di enti di modeste dimensioni ubicati nel medesimo territorio. Essi possono altresi' prevedere che siano costituiti organismi di coordinamento tra le rappresentanze unitarie del personale nelle amministrazioni e enti con pluralita' di sedi o strutture di cui al comma 8.

6. I componenti della rappresentanza unitaria del personale sono equiparati ai dirigenti delle rappresentanze sindacali aziendali ai fini della legge 20 maggio 1970, n.300, e successive modificazioni ed integrazioni, e del presente decreto. Gli accordi o contratti collettivi che regolano l'elezione e il funzionamento dell'organismo, stabiliscono i criteri e le modalita' con cui sono trasferite ai componenti eletti della rappresentanza unitaria del personale le garanzie spettanti alle rappresentanze sindacali aziendali delle organizzazioni sindacali di cui al comma 2 che li abbiano sottoscritti o vi aderiscano.

7. I medesimi accordi possono disciplinare le modalita' con le quali la rappresentanza unitaria del personale esercita in via esclusiva i diritti di informazione e di partecipazione riconosciuti alle rappresentanze sindacali aziendali dall'articolo 9 o da altre disposizioni della legge e della contrattazione collettiva. Essi possono altresi' prevedere che, ai fini dell'esercizio della contrattazione collettiva integrativa, la rappresentanza unitaria del personale sia integrata da rappresentanti delle organizzazioni sindacali firmatarie del contratto collettivo nazionale del compatto.

8. Salvo che i contratti collettivi non prevedano, in relazione alle caratteristiche del comparto, diversi criteri dimensionali, gli organismi di cui ai commi 2 e 3 del presente articolo possono essere costituiti, alle condizioni previste dai commi precedenti, in ciascuna amministrazione o ente che occupi oltre quindici dipendenti. Nel caso di amministrazioni o enti con pluralita' di sedi o strutture periferiche, possono essere costituiti anche presso le sedi o struttura periferiche che siano considerate livelli decentrati di contrattazione collettiva dai contratti collettivi nazionali.

9. Fermo restando quanto previsto dal comma 2, per la costituzione di rappresentanze sindacali aziendali ai sensi dell'articolo 19 della legge 20 maggio 1970, n. 300, e successive modificazioni ed integrazioni, la rappresentanza dei dirigenti nelle amministrazioni, enti o strutture amministrative e' disciplinata, in coerenza con la natura delle loro funzioni, agli accordi o contratti collettivi riguardanti la relativa area contrattuale.

10. Alle figure professionali per le quali nel contratto collettivo del comparto sia prevista una disciplina distinta ai sensi dell'articolo 40, comma 2, deve essere garantita una adeguata presenza negli organismi di rappresentanza unitaria del personale, anche mediante l'istituzione, tenuto conto della loro incidenza quantitativa e del numero dei componenti dell'organismo, di specifici collegi elettorali.

11. Per quanto riguarda i diritti e le prerogative sindacali delle organizzazioni sindacali delle minoranze linguistiche, nell'ambito della provincia di Bolzano e della regione Valle d'Aosta, si applica quanto previsto dall'articolo 9 del decreto del Presidente della Repubblica 6 gennaio 1978, n. 58, e dal decreto legislativo 28 dicembre 1989 n. 430.

------------- AGGIORNAMENTO (33) Il D.Lgs. 27 ottobre 2009, n. 150, ha disposto (con l'art. 65, comma 3)che "In via transitoria, con riferimento al periodo contrattuale immediatamente successivo a quello in corso, definiti i comparti e le aree di contrattazione ai sensi degli articoli 40, comma 2, e 41, comma 4, del decreto legislativo 30 marzo 2001, n. 165, come sostituiti, rispettivamente, dagli articoli 54 e 56 del presente decreto legislativo, l'ARAN avvia le trattative contrattuali con le organizzazioni sindacali e le confederazioni rappresentative, ai sensi dell'articolo 43, commi 1 e 2, del decreto legislativo n. 165 del 2001, nei nuovi comparti ed aree di contrattazione collettiva, sulla base dei dati associativi ed elettorali rilevati per il biennio contrattuale 2008-2009. Conseguentemente, in deroga all'articolo 42, comma 4, del predetto decreto legislativo n. 165 del 2001, sono prorogati gli organismi di rappresentanza del personale anche se le relative elezioni siano state gia' indette. Le elezioni relative al rinnovo dei predetti organismi di rappresentanza si svolgeranno, con riferimento ai nuovi comparti di contrattazione, entro il 30 novembre 2010." ------------- AGGIORNAMENTO (34) Il D.Lgs. 27 ottobre 2009, n. 150, come modificato dal D.L. 30 dicembre 2009, n. 194, convertito con modificazioni dalla L. 26 febbraio 2010, n. 25 ha disposto (con l'art. 65, comma 3) che "In via transitoria, con riferimento al periodo contrattuale immediatamente successivo a quello in corso, definiti i comparti e le aree di contrattazione ai sensi degli articoli 40, comma 2, e 41, comma 4, del decreto legislativo 30 marzo 2001, n. 165, come sostituiti, rispettivamente, dagli articoli 54 e 56 del presente decreto legislativo, l'ARAN avvia le trattative contrattuali con le organizzazioni sindacali e le confederazioni rappresentative. in deroga all'articolo 42, comma 4, del predetto decreto legislativo n. 165 del 2001, sono prorogati gli organismi di rappresentanza del personale anche se le relative elezioni siano state gia' indette. Le elezioni relative al rinnovo dei predetti organismi di rappresentanza si svolgeranno, con riferimento ai nuovi comparti di contrattazione, entro il 30 novembre 2010."

### Articolo 43 - Rappresentativita' sindacale ai fini della contrattazione collettiva (Art.47-bis del d.lgs n.29 del 1993, aggiunto dall'art.7 del d.lgs n.396 del 1997, modificato dall'art.44, comma 4 del d.lgs n.80 del 1998; Art.44 comma 7 del d.lgs n.80 del 1998, come modificato dall'art.22, comma 4 del d.lgs n.387 del 1998)

1. L'ARAN ammette alla contrattazione collettiva nazionale le organizzazioni sindacali che abbiano nel comparto o nell'area una rappresentativita' non inferiore al 5 per cento, considerando a tal fine la media tra il dato associativo e il dato elettorale. Il dato associativo e' espresso dalla percentuale delle deleghe per il versamento dei contributi sindacali rispetto al totale delle deleghe rilasciate nell'ambito considerato. Il dato elettorale e' espresso dalla percentuale dei voti ottenuti nelle elezioni delle rappresentanze unitarie del personale, rispetto al totale dei voti espressi nell'ambito considerato.

2. Alla contrattazione collettiva nazionale per il relativo comparto o area partecipano altresi' le confederazioni alle quali le organizzazioni sindacali ammesse alla contrattazione collettiva ai sensi del comma 1 siano affiliate.

3. L'ARAN sottoscrive i contratti collettivi verificando previamente, sulla base della rappresentativita' accertata per l'ammissione alle trattative ai sensi del comma 1, che le organizzazioni sindacali che aderiscono all'ipotesi di accordo rappresentino nel loro complesso almeno il 51 per cento come media tra dato associativo e dato elettorale neI comparto o nell'area contrattuale, o almeno il 60 per cento del dato elettorale nel medesimo ambito.

4. L'ARAN ammette alla contrattazione collettiva per la stipulazione degli accordi o contratti collettivi che definiscono o modificano i compatti o le aree o che regolano istituti comuni a tutte le pubbliche amministrazioni o riguardanti piu' comparti, le confederazioni sindacali alle quali, in almeno due comparti o due aree contrattuali; siano affiliate organizzazioni sindacali rappresentative ai sensi del comma 1.

5. I soggetti e le procedure della contrattazione collettiva integrativa sono disciplinati, in conformita' all'articolo ((40, commi 3-bis e seguenti)), dai contratti collettivi nazionali, fermo restando quanto previsto dall'articolo 42, comma 7, per gli organismi di rappresentanza unitaria del personale.

6. Agli effetti dell'accordo tra l'ARAN e le confederazioni sindacali rappresentative, previsto dall'articolo 50, comma 1, e dei contratti collettivi che regolano la materia, le confederazioni e le organizzazioni sindacali ammesse alla contrattazione collettiva nazionale ai sensi dei commi precedenti, hanno titolo ai permessi, aspettative e distacchi sindacali, in quota proporzionale alla loro rappresentativita' ai sensi del comma 1, tenendo conto anche della diffusione territoriale e della consistenza delle strutture organizzative nel comparto o nell'area.

7. La raccolta dei dati sui voti e sulle deleghe e' assicurata dall'ARAN. I dati relativi alle deleghe rilasciate a ciascuna amministrazione nell'anno considerato sono rilevati e trasmessi all'ARAN non oltre il 31 marzo dell'anno successivo dalle pubbliche amministrazioni, controfirmati da un rappresentante dell'organizzazione sindacale interessata, con modalita' che garantiscano la riservatezza delle informazioni. Le pubbliche amministrazioni hanno l'obbligo di indicare il funzionario responsabile della rilevazione e della trasmissione dei dati. Per il controllo sulle procedure elettorali e per la raccolta dei dati relativi alle deleghe l'ARAN si avvale, sulla base di apposite convenzioni, della collaborazione del Dipartimento della funzione pubblica, del Ministero del lavoro, delle istanze rappresentative o associative delle pubbliche amministrazioni.

8. Per garantire modalita' di rilevazione certe ed obiettive, per la certificazione dei dati e per la risoluzione delle eventuali controversie e' istituito presso l'ARAN un comitato paritetico, che puo' essere articolato per comparti, al quale partecipano le organizzazioni sindacali ammesse alla contrattazione collettiva nazionale.

9. Il comitato procede alla verifica dei dati relativi ai voti ed alle deleghe. Puo' deliberare che non siano prese in considerazione, ai fini della misurazione del dato associativo, le deleghe a favore di organizzazioni sindacali che richiedano ai lavoratori un contributo economico inferiore di piu' della meta' rispetto a quello mediamente richiesto dalle organizzazioni sindacali del comparto o dell'area.

10. Il comitato delibera sulle contestazioni relative alla rilevazione dei voti e delle deleghe. Qualora vi sia dissenso, e in ogni caso quando la contestazione sia avanzata da un soggetto sindacale non rappresentato nel comitato, la deliberazione e' adottata su conforme parere del Consiglio nazionale dell'economia e del lavoro - CNEL, che lo emana entro quindici giorni dalla richiesta. La richiesta di parere e' trasmessa dal comitato al Ministro per la funzione pubblica, che provvede a presentarla al CNEL entro cinque giorni dalla ricezione.

11. Ai fini delle deliberazioni, l'ARAN e le organizzazioni sindacali rappresentate nel comitato votano separatamente e il voto delle seconde e' espresso dalla maggioranza dei rappresentanti presenti.

12. A tutte le organizzazioni sindacali vengono garantite adeguate forme di informazione e di accesso ai dati, nel rispetto della legislazione sulla riservatezza delle informazioni di cui alla legge 31 dicembre 1996, n. 675, e successive disposizioni correttive ed integrative.

13. Ai sindacati delle minoranze linguistiche della Provincia di Bolzano e delle regioni Valle D'Aosta e Friuli Venezia-Giulia, riconosciuti rappresentativi agli effetti di speciali disposizioni di legge regionale e provinciale o di attuazione degli Statuti, spettano, eventualmente anche con forme di rappresentanza in comune, i medesimi diritti, poteri e prerogative, previsti per le organizzazioni sindacali considerate rappresentative in base al presente decreto. Per le organizzazioni sindacali che organizzano anche lavoratori delle minoranze linguistiche della provincia di Bolzano e della regione della Val d'Aosta, i criteri per la determinazione della rappresentativita' si riferiscono esclusivamente ai rispettivi ambiti territoriali e ai dipendenti ivi impiegati.

### Articolo 44 - Nuove forme di partecipazione alla organizzazione del lavoro (Art.48 del d.lgs n.29 del 1993, come sostituito dall'art.l6 del d.lgs n.470 del 1993)

1. In attuazione dell'articolo 2, comma 1 lettera a), della legge 23 ottobre 1992, n. 421, la contrattazione collettiva nazionale definisce nuove forme di partecipazione delle rappresentanze del personale ai fini dell'organizzazione del lavoro nelle amministrazioni pubbliche di cui all'articolo 1, comma 2. Sono abrogate le norme che prevedono ogni forma di rappresentanza, anche elettiva, del personale nei consigli di amministrazione delle predette amministrazioni pubbliche, nonche' nelle commissioni di concorso. La contrattazione collettiva nazionale indichera' forme e procedure di partecipazione che sostituiranno commissioni del personale e organismi di gestione, comunque denominati.

### Articolo 45 - Trattamento economico (Art.49 del d.lgs n.29 del 1993, come sostituito dall'art.23 del d.lgs n.546 del 1993)

1. Il trattamento economico fondamentale ed accessorio ((fatto salvo quanto previsto all'articolo 40, commi 3-ter e 3-quater, e all'articolo 47-bis, comma 1,)) e' definito dai contratti collettivi.

2. Le amministrazioni pubbliche garantiscono ai propri dipendenti di cui all'articolo 2, comma 2, parita' di trattamento contrattuale e comunque trattamenti non inferiori a quelli previsti dai rispettivi contratti collettivi.

((

3. I contratti collettivi definiscono, in coerenza con le disposizioni legislative vigenti, trattamenti economici accessori collegati:

- a) alla performance individuale;
- b) alla performance organizzativa con riferimento all'amministrazione nel suo complesso e alle unita' organizzative o aree di responsabilita' in cui si articola l'amministrazione;
- c) all'effettivo svolgimento di attivita' particolarmente disagiate ovvero pericolose o dannose per la salute.

))

((

3-bis. Per premiare il merito e il miglioramento della performance dei dipendenti, ai sensi delle vigenti disposizioni di legge, sono destinate, compatibilmente con i vincoli di finanza pubblica, apposite risorse nell'ambito di quelle previste per il rinnovo del contratto collettivo nazionale di lavoro.

))

4. I dirigenti sono responsabili dell'attribuzione dei trattamenti economici accessori.

5. Le funzioni ed i relativi trattamenti economici accessori del personale non diplomatico del Ministero degli affari esteri, per i servizi che si prestano all'estero presso le rappresentanze diplomatiche, gli uffici consolari e le istituzioni culturali e scolastiche, sono disciplinati, limitatamente al periodo di servizio ivi prestato, dalle disposizioni del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18, e successive modificazioni ed integrazioni, nonche' dalle altre pertinenti normative di settore del Ministero degli affari esteri.

### Articolo 46 - Agenzia per la rappresentanza negoziale delle pubbliche amministrazioni (Art.50,commi da 1 a 12 e 16 del d.lgs n.29 del 1993,come sostituiti prima dall'art.17 del d.lgs n.470 del 1993 e poi dall'art.2 del d.lgs n.396 del 1997)

1. Le pubbliche amministrazioni sono legalmente rappresentate dall'Agenzia per la rappresentanza negoziale delle pubbliche amministrazioni - ARAN, agli effetti della contrattazione collettiva nazionale. L'ARAN esercita a livello nazionale, in base agli indirizzi ricevuti ai sensi degli articoli 41 e 47, ogni attivita' relativa alle relazioni sindacali, alla negoziazione dei contratti collettivi e alla assistenza delle pubbliche amministrazioni ai fini dell'uniforme applicazione dei contratti collettivi. Sottopone alla valutazione della commissione di garanzia dell'attuazione della legge 12 giugno 1990, n. 146, e successive modificazioni e integrazioni, gli accordi nazionali sulle prestazioni indispensabili ai sensi dell'articolo 2 della legge citata.

2. Le pubbliche amministrazioni possono avvalersi dell'assistenza dell'ARAN ai fini della contrattazione integrativa. Sulla base di apposite intese, l'assistenza puo' essere assicurata anche collettivamente ad amministrazioni dello stesso tipo o ubicate nello stesso ambito territoriale. Su richiesta dei comitati di settore, in relazione all'articolazione della contrattazione collettiva integrativa nel comparto ed alle specifiche esigenze delle pubbliche amministrazioni interessate, possono essere costituite, anche per periodi determinati, delegazioni dell'ARAN su base regionale o pluriregionale.

3. L'ARAN cura le attivita' di studio, monitoraggio e documentazione necessarie all'esercizio della contrattazione collettiva. Predispone a cadenza semestrale, ed invia al Governo, ai comitati di settore dei comparti regioni e autonomie locali e sanita' e alle commissioni parlamentari competenti, un rapporto sull'evoluzione delle retribuzioni di fatto dei pubblici dipendenti. A tale fine l'ARAN si avvale della collaborazione dell'ISTAT per l'acquisizione di informazioni statistiche e per la formulazione di modelli statistici di rilevazione. L'ARAN si avvale, altresi', della collaborazione del Ministero dell'economia e delle finanze che garantisce l'accesso ai dati raccolti in sede di predisposizione del bilancio dello Stato, del conto annuale del personale e del monitoraggio dei flussi di cassa e relativi agli aspetti riguardanti il costo del lavoro pubblico.

4. L'ARAN effettua il monitoraggio sull'applicazione dei contratti collettivi nazionali e sulla contrattazione collettiva integrativa e presenta annualmente al Dipartimento della funzione pubblica, al Ministero dell'economia e delle finanze nonche' ai comitati di settore, un rapporto in cui verifica l'effettivita' e la congruenza della ripartizione fra le materie regolate dalla legge, quelle di competenza della contrattazione nazionale e quelle di competenza dei contratti integrativi nonche' le principali criticita' emerse in sede di contrattazione collettiva nazionale ed integrativa.

5. Sono organi dell'ARAN:

- a) il Presidente;
- b) il Collegio di indirizzo e controllo. (33)

6. Il Presidente dell'ARAN e' nominato con decreto del Presidente della Repubblica, su proposta del Ministro per la pubblica amministrazione e l'innovazione previo parere della Conferenza unificata. Il Presidente rappresenta l'agenzia ed e' scelto fra esperti in materia di economia del lavoro, diritto del lavoro, politiche del personale e strategia aziendale, anche estranei alla pubblica amministrazione, nel rispetto delle disposizioni riguardanti le incompatibilita' di cui al comma 7-bis. Il Presidente dura in carica quattro anni e puo' essere riconfermato per una sola volta. La carica di Presidente e' incompatibile con qualsiasi altra attivita' professionale a carattere continuativo, se dipendente pubblico, e' collocato in aspettativa o in posizione di fuori ruolo secondo l'ordinamento dell'amministrazione di appartenenza.

7. Il collegio di indirizzo e controllo e' costituito da quattro componenti scelti tra esperti di riconosciuta competenza in materia di relazioni sindacali e di gestione del personale, anche estranei alla pubblica amministrazione e dal presidente dell'Agenzia che lo presiede; due di essi sono designati con decreto del Presidente del Consiglio dei Ministri, su proposta, rispettivamente, del Ministro per la pubblica amministrazione e l'innovazione e del Ministro dell'economia e delle finanze e gli altri due, rispettivamente, dall'ANCI e dall'UPI e dalla Conferenza delle Regioni e delle province autonome. Il collegio coordina la strategia negoziale e ne assicura l'omogeneita', assumendo la responsabilita' per la contrattazione collettiva e verificando che le trattative si svolgano in coerenza con le direttive contenute negli atti di indirizzo. Nell'esercizio delle sue funzioni il collegio delibera a maggioranza, su proposta del presidente. Il collegio dura in carica quattro anni e i suoi componenti possono essere riconfermati per una sola volta.

7-bis. Non possono far parte del collegio di indirizzo e controllo ne' ricoprire funzioni di presidente, persone che rivestano incarichi pubblici elettivi o cariche in partiti politici ovvero che ricoprano o abbiano ricoperto nei cinque anni precedenti alla nomina cariche in organizzazioni sindacali. L'incompatibilita' si intende estesa a qualsiasi rapporto di carattere professionale o di consulenza con le predette organizzazioni sindacali o politiche. L'assenza delle predette cause di incompatibilita' costituisce presupposto necessario per l'affidamento degli incarichi dirigenziali nell'agenzia.

8. Per la sua attivita', l'ARAN si avvale:

- a) delle risorse derivanti da contributi posti a carico delle singole amministrazioni dei vari comparti, corrisposti in misura fissa per dipendente in servizio. La misura annua del contributo individuale e' definita, sentita l'ARAN, con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro della pubblica amministrazione e l'innovazione, d'intesa con la Conferenza unificata ed e' riferita a ciascun triennio contrattuale;))
- b) di quote per l'assistenza alla contrattazione integrativa e per le altre prestazioni eventualmente richieste, poste a carico dei soggetti che se ne avvalgano.

9. La riscossione dei contributi di cui al comma 8 e' effettuata:

- a) per le amministrazioni dello Stato mediante l'assegnazione di risorse pari all'ammontare dei contributi che si prevedono dovuti nell'esercizio di riferimento. L'assegnazione e' effettuata annualmente sulla base della quota definita al comma 8, lettera a), con la legge annuale di bilancio, con imputazione alla pertinente unita' previsionale di base dello stato di previsione del ministero dell'economia e finanze;
- b) per le amministrazioni diverse dal]o Stato, mediante un sistema di trasferimenti da definirsi tramite decreti del Ministro per la funzione pubblica di concerto con il Ministro ((dell'economia e delle finanze)) e, a seconda del comparto, dei Ministri competenti, nonche', per gli aspetti di interesse regionale e locale, previa intesa espressa dalla Conferenza unificata Stato-regioni e Stato-citta'.

10. L'ARAN ha personalita' giuridica di diritto pubblico. Ha autonomia organizzativa e contabile nei limiti del proprio bilancio. Affluiscono direttamente al bilancio dell'ARAN i contributi di cui al comma 8. L'ARAN definisce con propri regolamenti le norme concernenti l'organizzazione interna, il funzionamento e la gestione finanziaria. I regolamenti sono soggetti al controllo del Dipartimento della funzione pubblica e del Ministero dell'economia e delle finanze, adottati d'intesa con la Conferenza unificata, da esercitarsi entro quarantacinque giorni dal ricevimento degli stessi. La gestione finanziaria e' soggetta al controllo consuntivo della Corte dei conti.

11. Il ruolo del personale dipendente dell'ARAN e' definito in base ai regolamenti di cui al comma 10. Alla copertura dei relativi posti si provvede nell'ambito delle disponibilita' di bilancio tramite concorsi pubblici, ovvero mediante assunzioni con contratto di lavoro a tempo determinato, regolati dalle norme di diritto privato.

12. L'ARAN puo' altresi' avvalersi di un contingente di personale, anche di qualifica dirigenziale, proveniente dalle pubbliche amministrazioni rappresentate, in posizione di comando o fuori ruolo in base ai regolamenti di cui al comma 10. I dipendenti comandati o collocati fuori ruolo conservano lo stato giuridico ed il trattamento economico delle amministrazioni di provenienza. Ad essi sono attribuite dall'ARAN, secondo le disposizioni contrattuali vigenti, le voci retributive accessorie, ivi compresa la produttivita' per il personale non dirigente e per i dirigenti la retribuzione di posizione e di risultato. Il collocamento in posizione di comando o di fuori ruolo e' disposto secondo le disposizioni vigenti nonche' ai sensi dell'articolo 17, comma 14, della legge 15 maggio 1997, n.127. L'ARAN puo' utilizzare, sulla base di apposite intese, anche personale direttamente messo a disposizione dalle amministrazioni e dagli enti rappresentati, con oneri a carico di questi. L'ARAN puo' avvalersi di esperti e collaboratori esterni con modalita' di rapporto stabilite con i regolamenti adottati ai sensi del comma 10, nel rispetto dell'articolo 7, commi 6 e seguenti.

13. Le regioni a statuto speciale e le province autonome possono avvalersi, per la contrattazione collettiva di loro competenza, di agenzie tecniche istituite con legge regionale o provinciale ovvero dell'assistenza dell'ARAN ai sensi del comma 2.

--------------- AGGIORNAMENTO (33) Il D.Lgs. 27 ottobre 2009, n. 150, ha disposto (con l'art. 58, comma 2) che "Entro trenta giorni dalla data di entrata in vigore del presente decreto si provvede alla nomina dei nuovi organi dell'ARAN di cui all'articolo 46, comma 5, del decreto legislativo 30 marzo 2001, n. 165, come modificato dal comma 1. Fino alla nomina dei nuovi organi, e comunque non oltre il termine di cui al precedente periodo, continuano ad operare gli organi in carica alla data di entrata in vigore del presente decreto."

### Art. 47. - (( (Procedimento di contrattazione collettiva). ))

((

1. Gli indirizzi per la contrattazione collettiva nazionale sono emanati dai Comitati di settore prima di ogni rinnovo contrattuale.

2. Gli atti di indirizzo delle amministrazioni di cui all'articolo 41, comma 2, emanati dai rispettivi comitati di settore, sono sottoposti al Governo che, nei successivi venti giorni, puo' esprimere le sue valutazioni per quanto attiene agli aspetti riguardanti la compatibilita' con le linee di politica economica e finanziaria nazionale. Trascorso inutilmente tale termine l'atto di indirizzo puo' essere inviato all'ARAN.

3. Sono altresi' inviati appositi atti di indirizzo all'ARAN in tutti gli altri casi in cui e' richiesta una attivita' negoziale. L'ARAN informa costantemente i comitati di settore e il Governo sullo svolgimento delle trattative.

4. L'ipotesi di accordo e' trasmessa dall'ARAN, corredata dalla prescritta relazione tecnica, ai comitati di settore ed al Governo entro 10 giorni dalla data di sottoscrizione. Per le amministrazioni di cui all'articolo 41, comma 2, il comitato di settore esprime il parere sul testo contrattuale e sugli oneri finanziari diretti e indiretti a carico dei bilanci delle amministrazioni interessate.Fino alla data di entrata in vigore dei decreti di attuazione della legge 5 maggio 2009, n. 42, il Consiglio dei Ministri puo' esprimere osservazioni entro 20 giorni dall'invio del contratto da parte dell'ARAN. Per le amministrazioni di cui al comma 3 del medesimo articolo 41, il parere e' espresso dal Presidente del Consiglio dei Ministri, tramite il Ministro per la pubblica amministrazione e l'innovazione, previa deliberazione del Consiglio dei Ministri.

5. Acquisito il parere favorevole sull'ipotesi di accordo, nonche' la verifica da parte delle amministrazioni interessate sulla copertura degli oneri contrattuali, il giorno successivo l'ARAN trasmette la quantificazione dei costi contrattuali alla Corte dei conti ai fini della certificazione di compatibilita' con gli strumenti di programmazione e di bilancio di cui all'articolo 1-bis della legge 5 agosto 1978, n. 468, e successive modificazioni. La Corte dei conti certifica l'attendibilita' dei costi quantificati e la loro compatibilita' con gli strumenti di programmazione e di bilancio. La Corte dei conti delibera entro quindici giorni dalla trasmissione della quantificazione dei costi contrattuali, decorsi i quali la certificazione si intende effettuata positivamente. L'esito della certificazione viene comunicato dalla Corte all'ARAN, al comitato di settore e al Governo. Se la certificazione e' positiva, il presidente dell'ARAN sottoscrive definitivamente il contratto collettivo.

6. La Corte dei conti puo' acquisire elementi istruttori e valutazioni sul contratto collettivo da parte di tre esperti in materia di relazioni sindacali e costo del lavoro individuati dal Ministro per la pubblica amministrazione e l'innovazione, tramite il Capo del Dipartimento della funzione pubblica di intesa con il Capo del Dipartimento della Ragioneria generale dello Stato, nell'ambito di un elenco definito di concerto con il Ministro dell'economia e delle finanze. Nel caso delle amministrazioni di cui all'articolo 41, comma 2, la designazione di due esperti viene effettuata dall'ANCI, dall' UPI e dalla Conferenza delle Regioni e delle province autonome.

7. In caso di certificazione non positiva della Corte dei conti le parti contraenti non possono procedere alla sottoscrizione definitiva dell'ipotesi di accordo. Nella predetta ipotesi, il Presidente dell'ARAN, d'intesa con il competente comitato di settore, che puo' dettare indirizzi aggiuntivi, provvede alla riapertura delle trattative ed alla sottoscrizione di una nuova ipotesi di accordo adeguando i costi contrattuali ai fini delle certificazioni. In seguito alla sottoscrizione della nuova ipotesi di accordo si riapre la procedura di certificazione prevista dai commi precedenti. Nel caso in cui la certificazione non positiva sia limitata a singole clausole contrattuali l'ipotesi puo' essere sottoscritta definitivamente ferma restando l'inefficacia delle clausole contrattuali non positivamente certificate.

8. I contratti e accordi collettivi nazionali, nonche' le eventuali interpretazioni autentiche sono pubblicati nella Gazzetta Ufficiale della Repubblica italiana oltre che sul sito dell'ARAN e delle amministrazioni interessate.

9. Dal computo dei termini previsti dal presente articolo sono esclusi i giorni considerati festivi per legge, nonche' il sabato.

))

### Art. 47-bis. - (Tutela retributiva per i dipendenti pubblici.)

1. Decorsi sessanta giorni dalla data di entrata in vigore della legge finanziaria che dispone in materia di rinnovi dei contratti collettivi per il periodo di riferimento, gli incrementi previsti per il trattamento stipendiale possono essere erogati in via provvisoria previa deliberazione dei rispettivi comitati di settore, sentite le organizzazioni sindacali rappresentative. salvo conguaglio all'atto della stipulazione dei contratti collettivi nazionali di lavoro.

2. In ogni caso a decorrere dal mese di aprile dell'anno successivo alla scadenza del contratto collettivo nazionale di lavoro, qualora lo stesso non sia ancora stato rinnovato e non sia stata disposta l'erogazione di cui al comma 1, e' riconosciuta ai dipendenti dei rispettivi comparti di contrattazione, nella misura e con le modalita' stabilite dai contratti nazionali, e comunque entro i limiti previsti dalla legge finanziaria in sede di definizione delle risorse contrattuali,una copertura economica che costituisce un'anticipazione dei benefici complessivi che saranno attribuiti all'atto del rinnovo contrattuale. (58) ((59))

--------------- AGGIORNAMENTO (58) Il D.P.R. 4 settembre 2013, n. 122 ha disposto (con l'art. 1, comma 1, lettera d)) che "in deroga alle previsioni di cui all'articolo 47-bis, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, ed all'articolo 2, comma 35, della legge 22 dicembre 2008, n. 303, per gli anni 2013 e 2014 non si da' luogo, senza possibilita' di recupero, al riconoscimento di incrementi a titolo di indennita' di vacanza contrattuale che continua ad essere corrisposta, nei predetti anni, nelle misure di cui all'articolo 9, comma 17, secondo periodo, del decreto-legge 31 maggio 2010, n. 78. L'indennita' di vacanza contrattuale relativa al triennio contrattuale 2015-2017 e' calcolata secondo le modalita' ed i parametri individuati dai protocolli e dalla normativa vigenti in materia e si aggiunge a quella corrisposta ai sensi del precedente periodo." --------------- AGGIORNAMENTO (59) La L. 4 27 dicembre 2013, n. 147 ha disposto (con l'art. 1, comma 452) che "Per gli anni 2015-2017, l'indennita' di vacanza contrattuale da computare quale anticipazione dei benefici complessivi che saranno attribuiti all'atto del rinnovo contrattuale ai sensi dell'articolo 47-bis, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e' quella in godimento al 31 dicembre 2013 ai sensi dell'articolo 9, comma 17, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e successive modificazioni". Ha inoltre disposto (con l'art. 1, comma 454) che "Le disposizioni di cui ai commi 452 e 453 si applicano anche al personale convenzionato con il Servizio sanitario nazionale".

### Articolo 48 - Disponibilita' destinate alla contrattazione collettiva nelle amministrazioni pubbliche e verifica (Art.52 del d.lgs n.29 del 1993, come sostituto prima dall'art.19 del d.lgs n.470 del 1993 e poi dall'art.5 del d.lgs n.396 del 1997 e successivamente modificato dall'art.14, commi da 2 a 4 del d.lgs n.387 del 1998)

1. Il Ministero ((dell'economia e delle finanze)), quantifica, in coerenza con i parametri previsti dagli strumenti di programmazione e di bilancio di cui all'articolo 1-bis della legge 5 agosto 1978, n. 468 e successive modificazioni e integrazioni. l'onere derivante dalla contrattazione collettiva nazionale a carico del bilancio dello Stato con apposita norma da inserire nella legge finanziaria ai sensi dell'articolo 11 della legge 5 agosto 1978, n. 468, e successive modificazioni ed integrazioni. Allo stesso modo sono determinati gli eventuali oneri aggiuntivi a carico del bilancio dello Stato per la contrattazione integrativa delle amministrazioni dello Stato di cui all'articolo 40, comma 3-bis.

2. Per le amministrazioni di cui all'articolo 41, comma 2, nonche' per le universita' italiane, gli enti pubblici non economici e gli enti e le istituzioni di ricerca, ivi compresi gli enti e le amministrazioni di cui all'articolo 70, comma 4, gli oneri derivanti dalla contrattazione collettiva nazionale sono determinati a carico dei rispettivi bilanci nel rispetto dell'articolo 40, comma 3-quinquies. Le risorse per gli incrementi retributivi per il rinnovo dei contratti collettivi nazionali delle amministrazioni regionali, locali e degli enti del Servizio sanitario nazionale sono definite dal Governo, nel rispetto dei vincoli di bilancio, del patto di stabilita' e di analoghi strumenti di contenimento della spesa, previa consultazione con le rispettive rappresentanze istituzionali del sistema delle autonomie.

3. I contratti collettivi sono corredati da prospetti contenenti la quantificazione degli oneri nonche' l'indicazione della copertura complessiva per l'intero periodo di validita' contrattuale, prevedendo con apposite clausole la possibilita' di prorogare l'efficacia temporale del contratto ovvero di sospenderne l'esecuzione parziale o totale in caso di' accertata esorbitanza dai limiti di spesa.

4. La spesa posta a carico del bilancio dello Stato e' iscritta in apposito fondo dello stato di previsione del Ministero ((dell'economia e delle finanze)) in ragione dell'ammontare complessivo. In esito alla sottoscrizione dei singoli contratti di comparto, il Ministero ((dell'economia e delle finanze)) e' autorizzato a ripartire, con propri decreti, le somme destinate a ciascun compatto mediante assegnazione diretta a favore dei competenti capitoli di bilancio, anche di nuova istituzione, per il personale dell'amministrazione statale, ovvero mediante trasferimento ai bilanci delle amministrazioni autonome e degli enti in favore dei quali sia previsto l'apporto finanziario dello Stato a copertura dei relativi oneri. Per le amministrazioni diverse dalle amministrazioni dello Stato e per gli altri enti cui si applica il presente decreto, l'autorizzazione di spesa relativa al rinnovo dei contratti collettivi e' disposta nelle stesse forme con cui vengono approvati i bilanci, con distinta indicazione dei mezzi di copertura.

5. Le somme provenienti dai trasferimenti di cui al comma 4 devono trovare specifica allocazione nelle entrate dei bilanci delle amministrazioni ed enti beneficiari, per essere assegnate ai pertinenti capitoli di spesa dei medesimi bilanci. I relativi stanziamenti sia in entrata che in uscita non possono essere incrementati se non con apposita autorizzazione legislativa.

6. COMMA ABROGATO DAL D.LGS. 27 OTTOBRE 2009, N. 150.

7. Ferme restando le disposizioni di cui al titolo V del presente decreto, la Corte dei conti, anche nelle sue articolazioni regionali di controllo, verifica periodicamente gli andamenti della spesa per il personale delle pubbliche amministrazioni, utilizzando, per ciascun comparto, insiemi significativi di amministrazioni. A tal fine, la Corte dei conti puo' avvalersi, oltre che dei servizi di controllo interno o nuclei di valutazione, di esperti designati a sua richiesta da amministrazioni ed enti pubblici.

### Articolo 49 - (( (Interpretazione autentica dei contratti collettivi). ))

((

1. Quando insorgano controversie sull'interpretazione dei contratti collettivi, le parti che li hanno sottoscritti si incontrano per definire consensualmente il significato delle clausole controverse.

2. L'eventuale accordo di interpretazione autentica, stipulato con le procedure di cui all'articolo 47, sostituisce la clausola in questione sin dall'inizio della vigenza del contratto. Qualora tale accordo non comporti oneri aggiuntivi e non vi sia divergenza sulla valutazione degli stessi, il parere del Presidente del Consiglio dei Ministri e' espresso tramite il Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze.

))

### Articolo 50 - Aspettative e permessi sindacali (Art.54, commi da 1 a 3 e 5 del d.lgs n.29 del 1993, come modificati prima dall'art.20 del d.lgs n.470 del 1993 poi dall'art.2 del decreto legge n.254 del 1996, convertito con modificazioni dalla legge n.365 del 1996, e, infine, dall'art.44, comma 5 del d.lgs n.80 del 1998)

1. Al fine del contenimento, della trasparenza e della razionalizzazione delle aspettative e dei permessi sindacali nel settore pubblico, la contrattazione collettiva ne determina i limiti massimi in un apposito accordo, tra l'ARAN e le confederazioni sindacali rappresentative ai sensi dell'articolo 43.

2. La gestione dell'accordo di cui al comma 1, ivi comprese le modalita' di utilizzo e distribuzione delle aspettative e dei permessi sindacali tra le confederazioni e le organizzazioni sindacali aventi titolo sulla base della loro rappresentativita' e con riferimento a ciascun comparto e area separata di contrattazione, e' demandata alla contrattazione collettiva, garantendo a decorrere dal 1 agosto 1996 in ogni caso l'applicazione della legge 20 maggio 1970, n.300, e successive modificazioni ed integrazioni. Per la provincia autonoma di Bolzano si terra' conto di quanto previsto dall'articolo 9 del decreto del Presidente della Repubblica 6 gennaio 1978, n.58.

3. Le amministrazioni pubbliche sono tenute a fornire alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica - il numero complessivo ed i nominativi dei beneficiari dei permessi sindacali.

4. Oltre ai dati relativi ai permessi sindacali, le pubbliche amministrazioni sono tenute a fornire alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica gli elenchi nominativi, suddivisi per qualifica, del personale dipendente collocato in aspettativa, in quanto chiamato a ricoprire una funzione pubblica elettiva, ovvero per motivi sindacali. I dati riepilogativi dei predetti elenchi sono pubblicati in allegato alla relazione annuale da presentare al Parlamento ai sensi dell'articolo 16 della legge 29marzo 1983, n. 93.

### Art. 50-bis. - (( (Personale delle rappresentanze diplomatiche e consolari e degli istituti italiani di cultura all'estero). 1. In considerazione di quanto disposto dall'articolo 42, comma 3-bis, le disposizioni di cui all'articolo 50 si applicano anche al personale in servizio presso le rappresentanze diplomatiche e consolari nonche' presso gli istituti italiani di cultura all'estero, ancorche' assunto con contratto regolato dalla legge locale))

## RAPPORTO Dl LAVORO

### Articolo 51 - Disciplina del rapporto di lavoro (Art.55 del d.lgs n.29 del 1993)

1. Il rapporto di lavoro dei dipendenti delle amministrazioni pubbliche e' disciplinato secondo le disposizioni degli articoli 2, commi 2 e 3, e 3, comma 1.

2. La legge 20 maggio 1970, n.300, e successive modificazioni ed integrazioni, si applica alle pubbliche amministrazioni a prescindere dal numero dei dipendenti.

### Articolo 52 - Disciplina delle mansioni (Art.56 del d.lgs n.29 del 1993, come sostituito dall'art.25 del d.lgs n.80 del 1998 e successivamente modificato dall'art. 15 del d.lgs n.387 del 1998)

1. Il prestatore di lavoro deve essere adibito alle mansioni per le quali e' stato assunto o alle mansioni equivalenti nell'ambito dell'area di inquadramentoovvero a quelle corrispondenti alla qualifica superiore che abbia successivamente acquisito per effetto delle procedure selettive di cui all'articolo 35, comma 1, lettera a). L'esercizio di fatto di mansioni non corrispondenti alla qualifica di appartenenza non ha effetto ai fini dell'inquadramento del lavoratore o dell'assegnazione di incarichi di direzione.

1-bis. I dipendenti pubblici, con esclusione dei dirigenti e del personale docente della scuola, delle accademie, dei conservatori e degli istituti assimilati, sono inquadrati in almeno tre distinte aree funzionali. La contrattazione collettiva individua un'ulteriore area per l'inquadramento del personale di elevata qualificazione. Le progressioni all'interno della stessa area avvengono, con modalita' stabilite dalla contrattazione collettiva, in funzione delle capacita' culturali e professionali e dell'esperienza maturata e secondo principi di selettivita', in funzione della qualita' dell'attivita' svolta e dei risultati conseguiti, attraverso l'attribuzione di fasce di merito. Fatta salva una riserva di almeno il 50 per cento delle posizioni disponibili destinata all'accesso dall'esterno, le progressioni fra le aree e, negli enti locali, anche fra qualifiche diverse, avvengono tramite procedura comparativa basata sulla valutazione positiva conseguita dal dipendente negli ultimi tre anni in servizio, sull'assenza di provvedimenti disciplinari, sul possesso di titoli o competenze professionali ovvero di studio ulteriori rispetto a quelli previsti per l'accesso all'area dall'esterno, nonche' sul numero e sulla tipologia de gli incarichi rivestiti. In sede di revisione degli ordinamenti professionali, i contratti collettivi nazionali di lavoro di comparto per il periodo 2019-2021 possono definire tabelle di corrispondenza tra vecchi e nuovi inquadramenti, ad esclusione dell'area di cui al secondo periodo, sulla base di requisiti di esperienza e professionalita' maturate ed effettivamente utilizzate ((dalle amministrazioni)) per almeno cinque anni, anche in deroga al possesso del titolo di studio richiesto per l'accesso all'area dall'esterno. All'attuazione del presente comma si provvede nei limiti delle risorse destinate ad assunzioni di personale a tempo indeterminato disponibili a legislazione vigente.

1-ter. COMMA ABROGATO DAL D.P.R. 16 APRILE 2013, N. 70.

2. Per obiettive esigenze di servizio il prestatore di lavoro puo' essere adibito a mansioni proprie della qualifica immediatamente superiore:

- a) nel caso di vacanza di posto in organico. per non piu' di sei mesi, prorogabili fino a dodici qualora siano state avviate le procedure per la copertura dei posti vacanti come previsto al comma 4;
- b) nel caso di sostituzione di altro dipendente assente con diritto alla conservazione del posto, con esclusione dell'assenza per ferie, per la durata dell'assenza.

3. Si considera svolgimento di mansioni sUperiori, ai fini del presente articolo, soltanto l'attribuzione in modo prevalente, sotto il profilo qualitativo, quantitativo e temporale, dei compiti propri di dette mansioni.

4. Nei casi di cui al comma 2, per il periodo di effettiva prestazione, il lavoratore ha diritto al trattamento previsto per la qualifica superiore. Qualora l'utilizzazione del dipendente sia disposta per sopperire a vacanze dei posti in organico, immediatamente, e comunque nel termine massimo di novanta giorni dalla data in cui il dipendente e' assegnato alle predette mansioni, devono essere avviate le procedure per la copertura dei posti vacanti.

5. Al di fuori delle ipotesi di cui al comma 2, e' nulla l'assegnazione del lavoratore a mansioni proprie di una qualifica superiore, ma al lavoratore e' corrisposta la differenza di trattamento economico con la qualifica superiore. Il dirigente che ha disposto l'assegnazione risponde personalmente del maggior onere conseguente, se ha agito con dolo o colpa grave.

6. Le disposizioni del presente articolo si applicano in sede di attuazione della nuova disciplina degli ordinamenti professionali prevista dai contratti collettivi e con la decorrenza da questi stabilita. I medesimi contratti collettivi possono regolare diversamente gli effetti di cui ai commi 2, 3 e 4. Fino a tale data, in nessun caso lo svolgimento di mansioni superiori rispetto alla qualifica di appartenenza, puo' comportare il diritto ad avanzamenti automatici nell'inquadramento professionale del lavoratore.

### Art. 53. - Incompatibilita', cumulo di impieghi e incarichi (Art. 58 del d.lgs. n. 29 del 1993, come modificato prima dall'art. 2 del decreto legge n. 358 del 1993, convertito dalla legge n. 448 del 1993, poi dall'art. 1 del decreto legge n. 361 del 1995, convertito con modificazioni dalla legge n. 437 del 1995, e, infine, dall'art. 26 del d.lgs n. 80 del 1998 nonche' dall'art. 16 del d.lgs n. 387 del 1998)

1. Resta ferma per tutti i dipendenti pubblici la disciplina delle incompatibilita' dettata dagli articoli 60 e seguenti del testo unico approvato con decreto del Presidente della Repubblica 10 gennaio 1957, n. 3, salva la deroga prevista dall'articolo 23-bis del presente decreto, nonche', per i rapporti di lavoro a tempo parziale, dall'articolo 6, comma 2, del decreto del Presidente del Consiglio dei ministri 17 marzo 1989, n. 117 e dall'articolo 1, commi 57 e seguenti della legge 23 dicembre 1996, n. 662. Restano ferme altresi' le disposizioni di cui agli articoli 267, comma 1, 273, 274, 508 nonche' 676 del decreto legislativo 16 aprile 1994, n. 297, all'articolo 9, commi 1 e 2, della legge 23 dicembre 1992, n. 498, all'articolo 4, comma 7, della legge 30 dicembre 1991, n. 412, ed ogni altra successiva modificazione ed integrazione della relativa disciplina.

1-bis. Non possono essere conferiti incarichi di direzione di strutture deputate alla gestione del personale a soggetti che rivestano o abbiano rivestito negli ultimi due anni cariche in partiti politici o in organizzazioni sindacali o che abbiano avuto negli ultimi due anni rapporti continuativi di collaborazione o di consulenza con le predette organizzazioni.

2. Le pubbliche amministrazioni non possono conferire ai dipendenti incarichi, non compresi nei compiti e doveri di ufficio, che non siano espressamente previsti o disciplinati da legge o altre fonti normative, o che non siano espressamente autorizzati.

3. Ai fini previsti dal comma 2, con appositi regolamenti, da emanarsi ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, sono individuati gli incarichi consentiti e quelli vietati ai magistrati ordinari, amministrativi, contabili e militari, nonche' agli avvocati e procuratori dello Stato, sentiti, per le diverse magistrature, i rispettivi istituti.

3-bis. Ai fini previsti dal comma 2, con appositi regolamenti emanati su proposta del Ministro per la pubblica amministrazione e la semplificazione, di concerto con i Ministri interessati, ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, e successive modificazioni, sono individuati, secondo criteri differenziati in rapporto alle diverse qualifiche e ruoli professionali, gli incarichi vietati ai dipendenti delle amministrazioni pubbliche di cui all'articolo 1, comma 2.

4. Nel caso in cui i regolamenti di cui al comma 3 non siano emanati, l'attribuzione degli incarichi e' consentita nei soli casi espressamente previsti dalla legge o da altre fonti normative.

5. In ogni caso, il conferimento operato direttamente dall'amministrazione, nonche' l'autorizzazione all'esercizio di incarichi che provengano da amministrazione pubblica diversa da quella di appartenenza, ovvero da societa' o persone fisiche, che svolgano attivita' d'impresa o commerciale, sono disposti dai rispettivi organi competenti secondo criteri oggettivi e predeterminati, che tengano conto della specifica professionalita', tali da escludere casi di incompatibilita', sia di diritto che di fatto, nell'interesse del buon andamento della pubblica amministrazione o situazioni di conflitto, anche potenziale, di interessi, che pregiudichino l'esercizio imparziale delle funzioni attribuite al dipendente.

6. I commi da 7 a 13 del presente articolo si applicano ai dipendenti delle amministrazioni pubbliche di cui all'articolo 1, comma 2, compresi quelli di cui all'articolo 3, con esclusione dei dipendenti con rapporto di lavoro a tempo parziale con prestazione lavorativa non superiore al cinquanta per cento di quella a tempo pieno, dei docenti universitari a tempo definito e delle altre categorie di dipendenti pubblici ai quali e' consentito da disposizioni speciali lo svolgimento di attivita' libero-professionali. Sono nulli tutti gli atti e provvedimenti comunque denominati, regolamentari e amministrativi, adottati dalle amministrazioni di appartenenza in contrasto con il presente comma. Gli incarichi retribuiti, di cui ai commi seguenti, sono tutti gli incarichi, anche occasionali, non compresi nei compiti e doveri di ufficio, per i quali e' previsto, sotto qualsiasi forma, un compenso. Sono esclusi i compensi e le prestazioni derivanti:

- a) dalla collaborazione a giornali, riviste, enciclopedie e simili;
- b) dalla utilizzazione economica da parte dell'autore o inventore di opere dell'ingegno e di invenzioni industriali;
- c) dalla partecipazione a convegni e seminari;
- d) da incarichi per i quali e' corrisposto solo il rimborso delle spese documentate;
- e) da incarichi per lo svolgimento dei quali il dipendente e' posto in posizione di aspettativa, di comando o di fuori ruolo;
- f) da incarichi conferiti dalle organizzazioni sindacali a dipendenti presso le stesse distaccati o in aspettativa non retribuita.
- f-bis) da attivita' di formazione diretta ai dipendenti della pubblica amministrazione nonche' di docenza e di ricerca scientifica.
- f-ter) dalle prestazioni di lavoro sportivo, fino ((all'importo complessivo)) di 5.000 euro annui, per le quali e' sufficiente la comunicazione preventiva.

7. I dipendenti pubblici non possono svolgere incarichi retribuiti che non siano stati conferiti o previamente autorizzati dall'amministrazione di appartenenza. Ai fini dell'autorizzazione, l'amministrazione verifica l'insussistenza di situazioni, anche potenziali, di conflitto di interessi. Con riferimento ai professori universitari a tempo pieno, gli statuti o i regolamenti degli atenei disciplinano i criteri e le procedure per il rilascio dell'autorizzazione nei casi previsti dal presente decreto. In caso di inosservanza del divieto, salve le piu' gravi sanzioni e ferma restando la responsabilita' disciplinare, il compenso dovuto per le prestazioni eventualmente svolte deve essere versato, a cura dell'erogante o, in difetto, del percettore, nel conto dell'entrata del bilancio dell'amministrazione di appartenenza del dipendente per essere destinato ad incremento del fondo di produttivita' o di fondi equivalenti.

7-bis. L'omissione del versamento del compenso da parte del dipendente pubblico indebito percettore costituisce ipotesi di responsabilita' erariale soggetta alla giurisdizione della Corte dei conti.

8. Le pubbliche amministrazioni non possono conferire incarichi retribuiti a dipendenti di altre amministrazioni pubbliche senza la previa autorizzazione dell'amministrazione di appartenenza dei dipendenti stessi. Salve le piu' gravi sanzioni, il conferimento dei predetti incarichi, senza la previa autorizzazione, costituisce in ogni caso infrazione disciplinare per il funzionario responsabile del procedimento; il relativo provvedimento e' nullo di diritto. In tal caso l'importo previsto come corrispettivo dell'incarico, ove gravi su fondi in disponibilita' dell'amministrazione conferente, e' trasferito all'amministrazione di appartenenza del dipendente ad incremento del fondo di produttivita' o di fondi equivalenti.

9. Gli enti pubblici economici e i soggetti privati non possono conferire incarichi retribuiti a dipendenti pubblici senza la previa autorizzazione dell'amministrazione di appartenenza dei dipendenti stessi. Ai fini dell'autorizzazione, l'amministrazione verifica l'insussistenza di situazioni, anche potenziali, di conflitto di interessi. In caso di inosservanza si applica la disposizione dell'articolo 6, comma 1, del decreto legge 28 marzo 1997, n. 79, convertito, con modificazioni, dalla legge 28 maggio 1997, n. 140, e successive modificazioni ed integrazioni. All'accertamento delle violazioni e all'irrogazione delle sanzioni provvede il Ministero delle finanze, avvalendosi della Guardia di finanza, secondo le disposizioni della legge 24 novembre 1981, n. 689, e successive modificazioni ed integrazioni. Le somme riscosse sono acquisite alle entrate del Ministero delle finanze.

10. L'autorizzazione, di cui ai commi precedenti, deve essere richiesta all'amministrazione di appartenenza del dipendente dai soggetti pubblici o privati, che intendono conferire l'incarico; puo', altresi, essere richiesta dal dipendente interessato. L'amministrazione di appartenenza deve pronunciarsi sulla richiesta di autorizzazione entro trenta giorni dalla ricezione della richiesta stessa. Per il personale che presta comunque servizio presso amministrazioni pubbliche diverse da quelle di appartenenza, l'autorizzazione e' subordinata all'intesa tra le due amministrazioni. In tal caso il termine per provvedere e' per l'amministrazione di appartenenza di 45 giorni e si' prescinde dall'intesa se l'amministrazione presso la quale il dipendente presta servizio non si pronunzia entro 10 giorni dalla ricezione della richiesta di intesa da parte dell'amministrazione di appartenenza. Decorso il termine per provvedere, l'autorizzazione, se richiesta per incarichi da conferirsi da amministrazioni pubbliche, si intende accordata; in ogni altro caso, si intende definitivamente negata. (100)

11. Entro quindici giorni dall'erogazione del compenso per gli incarichi di cui al comma 6, i soggetti pubblici o privati comunicano all'amministrazione di appartenenza l'ammontare dei compensi erogati ai dipendenti pubblici. Per le prestazioni di lavoro sportivo, le comunicazioni di cui al primo periodo sono effettuate entro i trenta giorni successivi alla fine di ciascun anno di riferimento, in un'unica soluzione, ovvero alla cessazione del relativo rapporto di lavoro se intervenuta precedentemente.

12. Le amministrazioni pubbliche che conferiscono o autorizzano incarichi, anche a titolo gratuito, ai propri dipendenti comunicano in via telematica, nel termine di quindici giorni, al Dipartimento della funzione pubblica gli incarichi conferiti o autorizzati ai dipendenti stessi, con l'indicazione dell'oggetto dell'incarico e del compenso lordo, ove previsto. PERIODO SOPPRESSO DAL D.LGS. 25 MAGGIO 2017, N. 75. PERIODO SOPPRESSO DAL D.LGS. 25 MAGGIO 2017, N. 75. (71)

13. Le amministrazioni di appartenenza sono tenute a comunicare tempestivamente al Dipartimento della funzione pubblica, in via telematica, per ciascuno dei propri dipendenti e distintamente per ogni incarico conferito o autorizzato, i compensi da esse erogati o della cui erogazione abbiano avuto comunicazione dai soggetti di cui al comma 11. (71)

14. Al fine della verifica dell'applicazione delle norme di cui all'articolo 1, commi 123 e 127, della legge 23 dicembre 1996, n. 662, e successive modificazioni e integrazioni, le amministrazioni pubbliche sono tenute a comunicare al Dipartimento della funzione pubblica, in via telematica, tempestivamente e comunque nei termini previsti dal decreto legislativo 14 marzo 2013, n. 33, i dati di cui agli articoli 15 e 18 del medesimo decreto legislativo n. 33 del 2013, relativi a tutti gli incarichi conferiti o autorizzati a qualsiasi titolo. Le amministrazioni rendono noti, mediante inserimento nelle proprie banche dati accessibili al pubblico per via telematica, gli elenchi dei propri consulenti indicando l'oggetto, la durata e il compenso dell'incarico nonche' l'attestazione dell'avvenuta verifica dell'insussistenza di situazioni, anche potenziali, di conflitto di interessi. Le informazioni relative a consulenze e incarichi comunicate dalle amministrazioni al Dipartimento della funzione pubblica, nonche' le informazioni pubblicate dalle stesse nelle proprie banche dati accessibili al pubblico per via telematica ai sensi del presente articolo, sono trasmesse e pubblicate in tabelle riassuntive rese liberamente scaricabili in un formato digitale standard aperto che consenta di analizzare e rielaborare, anche a fini statistici, i dati informatici. Entro il 31 dicembre di ciascun anno il Dipartimento della funzione pubblica trasmette alla Corte dei conti l'elenco delle amministrazioni che hanno omesso di trasmettere e pubblicare, in tutto o in parte, le informazioni di cui al terzo periodo del presente comma in formato digitale standard aperto. Entro il 31 dicembre di ciascun anno il Dipartimento della funzione pubblica trasmette alla Corte dei conti l'elenco delle amministrazioni che hanno omesso di effettuare la comunicazione, avente ad oggetto l'elenco dei collaboratori esterni e dei soggetti cui sono stati affidati incarichi di consulenza.(71)

15. Le amministrazioni che omettono gli adempimenti di cui ai commi da 11 a 14 non possono conferire nuovi incarichi fino a quando non adempiono. I soggetti di cui al comma 9 che omettono le comunicazioni di cui al comma 11 incorrono nella sanzione di cui allo stesso comma 9. (62)

16. Il Dipartimento della funzione pubblica, entro il 31 dicembre di ciascun anno, riferisce al Parlamento sui dati raccolti, adotta le relative misure di pubblicita' e trasparenza e formula proposte per il contenimento della spesa per gli incarichi e per la razionalizzazione dei criteri di attribuzione degli incarichi stessi.

16-bis. La Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica puo' disporre verifiche del rispetto delle disposizioni del presente articolo e dell' articolo 1, commi 56 e seguenti, della legge 23 dicembre 1996, n. 662, per il tramite dell'Ispettorato per la funzione pubblica. A tale fine quest'ultimo opera d'intesa con i Servizi ispettivi di finanza pubblica del Dipartimento della Ragioneria generale dello Stato.

16-ter. I dipendenti che, negli ultimi tre anni di servizio, hanno esercitato poteri autoritativi o negoziali per conto delle pubbliche amministrazioni di cui all'articolo 1, comma 2, non possono svolgere, nei tre anni successivi alla cessazione del rapporto di pubblico impiego, attivita' lavorativa o professionale presso i soggetti privati destinatari dell'attivita' della pubblica amministrazione svolta attraverso i medesimi poteri. I contratti conclusi e gli incarichi conferiti in violazione di quanto previsto dal presente comma sono nulli ed e' fatto divieto ai soggetti privati che li hanno conclusi o conferiti di contrattare con le pubbliche amministrazioni per i successivi tre anni con obbligo di restituzione dei compensi eventualmente percepiti e accertati ad essi riferiti. (48)

------------- AGGIORNAMENTO (48) La L. 6 novembre 2012, n. 190 ha disposto (con l'art. 1, comma 43) che "Le disposizioni di cui all'articolo 53, comma 16-ter, secondo periodo, del decreto legislativo 30 marzo 2001, n.165, introdotto dal comma 42, lettera l), non si applicano ai contratti gia' sottoscritti alla data di entrata in vigore della presente legge". ------------- AGGIORNAMENTO (62) La Corte Costituzionale, con sentenza 29 aprile - 5 giugno 2015, n. 98 (in G.U. 1ª s.s. 10/6/2015, n. 23), ha dichiarato "l'illegittimita' costituzionale dell'art. 53, comma 15, del decreto legislativo 30 marzo 2001, n. 165 (Norme generali sull'ordinamento del lavoro alle dipendenze delle amministrazioni pubbliche), nella parte in cui prevede che «I soggetti di cui al comma 9 che omettono le comunicazioni di cui al comma 11 incorrono nella sanzione di cui allo stesso comma 9»". ----------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 22, comma 12) che le presenti modifiche si applicano agli incarichi conferiti successivamente al 1° gennaio 2018. ----------- AGGIORNAMENTO (100) Il D.L. 19 maggio 2020, n. 34, ha disposto (con l'art. 247, comma 9) che "Nelle more dell'adozione del decreto di cui all'articolo 3, comma 15, della legge 19 giugno 2019, n. 56, il Dipartimento della funzione pubblica della Presidenza del Consiglio dei Ministri individua i componenti delle commissioni esaminatrici sulla base di manifestazioni di interesse pervenute a seguito di apposito avviso pubblico. A tal fine e per le procedure concorsuali di cui al presente articolo, i termini di cui all'articolo 53, comma 10, del decreto legislativo 30 marzo 2001, n. 165, relativi all'autorizzazione a rivestire l'incarico di commissario nelle procedure concorsuali di cui al presente articolo, sono rideterminati, rispettivamente, in dieci e quindici giorni".

### Art. 54. - (Codice di comportamento).

1. Il Governo definisce un codice di comportamento dei dipendenti delle pubbliche amministrazioni al fine di assicurare la qualita' dei servizi, la prevenzione dei fenomeni di corruzione, il rispetto dei doveri costituzionali di diligenza, lealta', imparzialita' e servizio esclusivo alla cura dell'interesse pubblico. Il codice contiene una specifica sezione dedicata ai doveri dei dirigenti, articolati in relazione alle funzioni attribuite, e comunque prevede per tutti i dipendenti pubblici il divieto di chiedere o di accettare, a qualsiasi titolo, compensi, regali o altre utilita', in connessione con l'espletamento delle proprie funzioni o dei compiti affidati, fatti salvi i regali d'uso, purche' di modico valore e nei limiti delle normali relazioni di cortesia. (48)

1-bis. Il codice contiene, altresi', una sezione dedicata al corretto utilizzo delle tecnologie informatiche e dei mezzi di informazione e social media da parte dei dipendenti pubblici, anche al fine di tutelare l'immagine della pubblica amministrazione.

2. Il codice, approvato con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro per la pubblica amministrazione e la semplificazione, previa intesa in sede di Conferenza unificata, e' pubblicato nella Gazzetta Ufficiale e consegnato al dipendente, che lo sottoscrive all'atto dell'assunzione.

3. La violazione dei doveri contenuti nel codice di comportamento, compresi quelli relativi all'attuazione del Piano di prevenzione della corruzione, e' fonte di responsabilita' disciplinare. La violazione dei doveri e' altresi' rilevante ai fini della responsabilita' civile, amministrativa e contabile ogniqualvolta le stesse responsabilita' siano collegate alla violazione di doveri, obblighi, leggi o regolamenti. Violazioni gravi o reiterate del codice comportano l'applicazione della sanzione di cui all'articolo 55-quater, comma 1.

4. Per ciascuna magistratura e per l'Avvocatura dello Stato, gli organi delle associazioni di categoria adottano un codice etico a cui devono aderire gli appartenenti alla magistratura interessata. In caso di inerzia, il codice e' adottato dall'organo di autogoverno. (48)

5. Ciascuna pubblica amministrazione definisce, con procedura aperta alla partecipazione e previo parere obbligatorio del proprio organismo indipendente di valutazione, un proprio codice di comportamento che integra e specifica il codice di comportamento di cui al comma 1. Al codice di comportamento di cui al presente comma si applicano le disposizioni del comma 3. A tali fini, la Commissione per la valutazione, la trasparenza e l'integrita' delle amministrazioni pubbliche (CIVIT) definisce criteri, linee guida e modelli uniformi per singoli settori o tipologie di amministrazione.

6. Sull'applicazione dei codici di cui al presente articolo vigilano i dirigenti responsabili di ciascuna struttura, le strutture di controllo interno e gli uffici di disciplina.

7. Le pubbliche amministrazioni verificano annualmente lo stato di applicazione dei codici e organizzano attivita' di formazione del personale per la conoscenza e la corretta applicazione degli stessi. ((Le pubbliche amministrazioni prevedono lo svolgimento di un ciclo formativo obbligatorio, sia a seguito di assunzione, sia in ogni caso di passaggio a ruoli o a funzioni superiori, nonche' di trasferimento del personale, le cui durata e intensita' sono proporzionate al grado di responsabilita', nei limiti delle risorse finanziarie disponibili a legislazione vigente, sui temi dell'etica pubblica e sul comportamento etico)).

------------- AGGIORNAMENTO (48) La L. 6 novembre 2012, n. 190 ha disposto (con l'art. 1, comma 45) che "I codici di cui all'articolo 54, commi 1 e 4, del decreto legislativo 30 marzo 2001, n. 165, come sostituito dal comma 44, sono approvati entro sei mesi dalla data di entrata in vigore della presente legge".

### Art. 54-bis.

((ARTICOLO ABROGATO DAL D.LGS. 10 MARZO 2023, N. 24))

### Articolo 55 - (Responsabilita', infrazioni e sanzioni, procedure conciliative).

1. Le disposizioni del presente articolo e di quelli seguenti, fino all'articolo 55-octies, costituiscono norme imperative, ai sensi e per gli effetti degli articoli 1339 e 1419, secondo comma, del codice civile, e si applicano ai rapporti di lavoro di cui all'articolo 2, comma 2, alle dipendenze delle amministrazioni pubbliche di cui all'articolo 1, comma 2. ((La violazione dolosa o colposa delle suddette disposizioni costituisce illecito disciplinare in capo ai dipendenti preposti alla loro applicazione.)) ((71))

2. Ferma la disciplina in materia di responsabilita' civile, amministrativa, penale e contabile, ai rapporti di lavoro di cui al comma 1 si applica l'articolo 2106 del codice civile. Salvo quanto previsto dalle disposizioni del presente Capo, la tipologia delle infrazioni e delle relative sanzioni e' definita dai contratti collettivi. La pubblicazione sul sito istituzionale dell'amministrazione del codice disciplinare, recante l'indicazione delle predette infrazioni e relative sanzioni, equivale a tutti gli effetti alla sua affissione all'ingresso della sede di lavoro.

3. La contrattazione collettiva non puo' istituire procedure di impugnazione dei provvedimenti disciplinari. Resta salva la facolta' di disciplinare mediante i contratti collettivi procedure di conciliazione non obbligatoria, fuori dei casi per i quali e' prevista la sanzione disciplinare del licenziamento, da instaurarsi e concludersi entro un termine non superiore a trenta giorni dalla contestazione dell'addebito e comunque prima dell'irrogazione della sanzione. La sanzione concordemente determinata all'esito di tali procedure non puo' essere di specie diversa da quella prevista, dalla legge o dal contratto collettivo, per l'infrazione per la quale si procede e non e' soggetta ad impugnazione. I termini del procedimento disciplinare restano sospesi dalla data di apertura della procedura conciliativa e riprendono a decorrere nel caso di conclusione con esito negativo. Il contratto collettivo definisce gli atti della procedura conciliativa che ne determinano l'inizio e la conclusione.

4. Fermo quanto previsto nell'articolo 21, per le infrazioni disciplinari ascrivibili al dirigente ai sensi degli articoli 55-bis, comma 7, e 55-sexies, comma 3, si applicano, ove non diversamente stabilito dal contratto collettivo, le disposizioni di cui al comma 4 del predetto articolo 55-bis, ma le determinazioni conclusive del procedimento sono adottate dal dirigente generale o titolare di incarico conferito ai sensi dell'articolo 19, comma 3.

--------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 22, comma 13) che "Le disposizioni di cui al Capo VII si applicano agli illeciti disciplinari commessi successivamente alla data di entrata in vigore del presente decreto".

### Art. 55-bis. - (Forme e termini del procedimento disciplinare).

((1. Per le infrazioni di minore gravita', per le quali e' prevista l'irrogazione della sanzione del rimprovero verbale, il procedimento disciplinare e' di competenza del responsabile della struttura presso cui presta servizio il dipendente. Alle infrazioni per le quali e' previsto il rimprovero verbale si applica la disciplina stabilita dal contratto collettivo.)) ((71)) ((2. Ciascuna amministrazione, secondo il proprio ordinamento e nell'ambito della propria organizzazione, individua l'ufficio per i procedimenti disciplinari competente per le infrazioni punibili con sanzione superiore al rimprovero verbale e ne attribuisce la titolarita' e responsabilita'.)) ((71)) ((3. Le amministrazioni, previa convenzione, possono prevedere la gestione unificata delle funzioni dell'ufficio competente per i procedimenti disciplinari, senza maggiori oneri per la finanza pubblica.)) ((71)) ((4. Fermo restando quanto previsto dall'articolo 55-quater, commi 3-bis e 3-ter, per le infrazioni per le quali e' prevista l'irrogazione di sanzioni superiori al rimprovero verbale, il responsabile della struttura presso cui presta servizio il dipendente, segnala immediatamente, e comunque entro dieci giorni, all'ufficio competente per i procedimenti disciplinari i fatti ritenuti di rilevanza disciplinare di cui abbia avuto conoscenza. L'Ufficio competente per i procedimenti disciplinari, con immediatezza e comunque non oltre trenta giorni decorrenti dal ricevimento della predetta segnalazione, ovvero dal momento in cui abbia altrimenti avuto piena conoscenza dei fatti ritenuti di rilevanza disciplinare, provvede alla contestazione scritta dell'addebito e convoca l'interessato, con un preavviso di almeno venti giorni, per l'audizione in contraddittorio a sua difesa. Il dipendente puo' farsi assistere da un procuratore ovvero da un rappresentante dell'associazione sindacale cui aderisce o conferisce mandato. In caso di grave ed oggettivo impedimento, ferma la possibilita' di depositare memorie scritte, il dipendente puo' richiedere che l'audizione a sua difesa sia differita, per una sola volta, con proroga del termine per la conclusione del procedimento in misura corrispondente. Salvo quanto previsto dall'articolo 54-bis, comma 4, il dipendente ha diritto di accesso agli atti istruttori del procedimento. L'ufficio competente per i procedimenti disciplinari conclude il procedimento, con l'atto di archiviazione o di irrogazione della sanzione, entro centoventi giorni dalla contestazione dell'addebito. Gli atti di avvio e conclusione del procedimento disciplinare, nonche' l'eventuale provvedimento di sospensione cautelare del dipendente, sono comunicati dall'ufficio competente di ogni amministrazione, per via telematica, all'Ispettorato per la funzione pubblica, entro venti giorni dalla loro adozione. Al fine di tutelare la riservatezza del dipendente, il nominativo dello stesso e' sostituito da un codice identificativo.)) ((71)) ((5. La comunicazione di contestazione dell'addebito al dipendente, nell'ambito del procedimento disciplinare, e' effettuata tramite posta elettronica certificata, nel caso in cui il dipendente dispone di idonea casella di posta, ovvero tramite consegna a mano. In alternativa all'uso della posta elettronica certificata o della consegna a mano, le comunicazioni sono effettuate tramite raccomandata postale con ricevuta di ritorno. Per le comunicazioni successive alla contestazione dell'addebito, e' consentita la comunicazione tra l'amministrazione ed i propri dipendenti tramite posta elettronica o altri strumenti informatici di comunicazione, ai sensi dell'articolo 47, comma 3, secondo periodo, del decreto legislativo 7 marzo 2005, n. 82, ovvero anche al numero di fax o altro indirizzo di posta elettronica, previamente comunicati dal dipendente o dal suo procuratore.)) ((71))

6. Nel corso dell'istruttoria, ((l'Ufficio per i procedimenti disciplinari puo' acquisire da altre amministrazioni pubbliche)) informazioni o documenti rilevanti per la definizione del procedimento. La predetta attivita' istruttoria non determina la sospensione del procedimento, ne' il differimento dei relativi termini. ((71))

7. Il ((...)) dipendente o il dirigente, appartenente alla stessa ((o a una diversa)) amministrazione pubblica dell'incolpato ((...)), che, essendo a conoscenza per ragioni di ufficio o di servizio di informazioni rilevanti per un procedimento disciplinare in corso, rifiuta, senza giustificato motivo, la collaborazione richiesta ((dall'Ufficio disciplinare)) procedente ovvero rende dichiarazioni false o reticenti, e' soggetto all'applicazione, da parte dell'amministrazione di appartenenza, della sanzione disciplinare della sospensione dal servizio con privazione della retribuzione, commisurata alla gravita' dell'illecito contestato al dipendente, fino ad un massimo di quindici giorni. ((71))

8. In caso di trasferimento del dipendente, a qualunque titolo, in un'altra amministrazione pubblica, il procedimento disciplinare e' avviato o ((concluso e)) la sanzione e' applicata presso quest'ultima. ((In caso di trasferimento del dipendente in pendenza di procedimento disciplinare, l'ufficio per i procedimenti disciplinari che abbia in carico gli atti provvede alla loro tempestiva trasmissione al competente ufficio disciplinare dell'amministrazione presso cui il dipendente e' trasferito. In tali casi il procedimento disciplinare e' interrotto e dalla data di ricezione degli atti da parte dell'ufficio disciplinare dell'amministrazione presso cui il dipendente e' trasferito decorrono nuovi termini per la contestazione dell'addebito o per la conclusione del procedimento. Nel caso in cui l'amministrazione di provenienza venga a conoscenza dell'illecito disciplinare successivamente al trasferimento del dipendente, la stessa Amministrazione provvede a segnalare immediatamente e comunque entro venti giorni i fatti ritenuti di rilevanza disciplinare all'Ufficio per i procedimenti disciplinari dell'amministrazione presso cui il dipendente e' stato trasferito e dalla data di ricezione della predetta segnalazione decorrono i termini per la contestazione dell'addebito e per la conclusione del procedimento. Gli esiti del procedimento disciplinare vengono in ogni caso comunicati anche all'amministrazione di provenienza del dipendente.)) ((71))

9. ((La cessazione del rapporto di lavoro estingue il procedimento disciplinare salvo che per l'infrazione commessa sia prevista la sanzione del licenziamento o comunque sia stata disposta la sospensione cautelare dal servizio. In tal caso le determinazioni conclusive sono assunte ai fini degli effetti giuridici ed economici non preclusi dalla cessazione del rapporto di lavoro.)) ((71))

((9-bis. Sono nulle le disposizioni di regolamento, le clausole contrattuali o le disposizioni interne, comunque qualificate, che prevedano per l'irrogazione di sanzioni disciplinari requisiti formali o procedurali ulteriori rispetto a quelli indicati nel presente articolo o che comunque aggravino il procedimento disciplinare.))

((71))

((9-ter. La violazione dei termini e delle disposizioni sul procedimento disciplinare previste dagli articoli da 55 a 55-quater, fatta salva l'eventuale responsabilita' del dipendente cui essa sia imputabile, non determina la decadenza dall'azione disciplinare ne' l'invalidita' degli atti e della sanzione irrogata, purche' non risulti irrimediabilmente compromesso il diritto di difesa del dipendente, e le modalita' di esercizio dell'azione disciplinare, anche in ragione della natura degli accertamenti svolti nel caso concreto, risultino comunque compatibili con il principio di tempestivita'. Fatto salvo quanto previsto dall'articolo 55-quater, commi 3-bis e 3-ter, sono da considerarsi perentori il termine per la contestazione dell'addebito e il termine per la conclusione del procedimento.))

((71))

((9-quater. Per il personale docente, educativo e amministrativo, tecnico e ausiliario (ATA) presso le istituzioni scolastiche ed educative statali, il procedimento disciplinare per le infrazioni per le quali e' prevista l'irrogazione di sanzioni fino alla sospensione dal servizio con privazione della retribuzione per dieci giorni e' di competenza del responsabile della struttura in possesso di qualifica dirigenziale e si svolge secondo le disposizioni del presente articolo. Quando il responsabile della struttura non ha qualifica dirigenziale o comunque per le infrazioni punibili con sanzioni piu' gravi di quelle indicate nel primo periodo, il procedimento disciplinare si svolge dinanzi all'Ufficio competente per i procedimenti disciplinari.))

((71))

--------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 22, comma 13) che "Le disposizioni di cui al Capo VII si applicano agli illeciti disciplinari commessi successivamente alla data di entrata in vigore del presente decreto".

### Art. 55-ter. - (Rapporti fra procedimento disciplinare e procedimento penale).

1. Il procedimento disciplinare, che abbia ad oggetto, in tutto o in parte, fatti in relazione ai quali procede l'autorita' giudiziaria, e' proseguito e concluso anche in pendenza del procedimento penale. PERIODO SOPPRESSO DAL D.LGS. 30 MARZO 2001, N. 165. Per le infrazioni per le quali e' applicabile una sanzione superiore alla sospensione dal servizio con privazione della retribuzione fino a dieci giorni, l'ufficio competente per i procedimenti disciplinari, nei casi di particolare complessita' dell'accertamento del fatto addebitato al dipendente e quando all'esito dell'istruttoria non dispone di elementi sufficienti a motivare l'irrogazione della sanzione, puo' sospendere il procedimento disciplinare fino al termine di quello penale. Fatto salvo quanto previsto al comma 3, il procedimento disciplinare sospeso puo' essere riattivato qualora l'amministrazione giunga in possesso di elementi nuovi, sufficienti per concludere il procedimento, ivi incluso un provvedimento giurisdizionale non definitivo. Resta in ogni caso salva la possibilita' di adottare la sospensione o altri provvedimenti cautelari nei confronti del dipendente. ((, fermo restando il rispetto del termine di cui all'articolo 9, comma 2, secondo e terzo periodo, della legge 7 febbraio 1990, n. 19)). (71)

2. Se il procedimento disciplinare, non sospeso, si conclude con l'irrogazione di una sanzione e, successivamente, il procedimento penale viene definito con una sentenza irrevocabile di assoluzione che riconosce che il fatto addebitato al dipendente non sussiste o non costituisce illecito penale o che il dipendente medesimo non lo ha commesso, ((ovvero con declaratoria di estinzione del reato per intervenuta prescrizione,)) l'ufficio competente per i procedimenti disciplinari, ad istanza di parte da proporsi entro il termine di decadenza di sei mesi dall'irrevocabilita' della pronuncia penale, riapre il procedimento disciplinare per modificarne o confermarne l'atto conclusivo in relazione all'esito del giudizio penale. (71)

3. Se il procedimento disciplinare si conclude con l'archiviazione ed il processo penale con una sentenza irrevocabile di condanna, l'ufficio competente per i procedimenti disciplinari riapre il procedimento disciplinare per adeguare le determinazioni conclusive all'esito del giudizio penale. Il procedimento disciplinare e' riaperto, altresi', se dalla sentenza irrevocabile di condanna risulta che il fatto addebitabile al dipendente in sede disciplinare comporta la sanzione del licenziamento, mentre ne e' stata applicata una diversa. (71)

4. Nei casi di cui ai commi 1, 2 e 3, il procedimento disciplinare e', rispettivamente, ripreso o riaperto, mediante rinnovo della contestazione dell'addebito, entro sessanta giorni dalla comunicazione della sentenza, da parte della cancelleria del giudice, all'amministrazione di appartenenza del dipendente, ovvero dal ricevimento dell'istanza di riapertura. Il procedimento si svolge secondo quanto previsto nell'articolo 55-bis con integrale nuova decorrenza dei termini ivi previsti per la conclusione dello stesso. Ai fini delle determinazioni conclusive, l'ufficio procedente, nel procedimento disciplinare ripreso o riaperto, applica le disposizioni dell'articolo 653, commi 1 e 1-bis, del codice di procedura penale. (71)

--------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 22, comma 13) che "Le disposizioni di cui al Capo VII si applicano agli illeciti disciplinari commessi successivamente alla data di entrata in vigore del presente decreto".

### Art. 55-quater. - (Licenziamento disciplinare).

1. Ferma la disciplina in tema di licenziamento per giusta causa o per giustificato motivo e salve ulteriori ipotesi previste dal contratto collettivo, si applica comunque la sanzione disciplinare del licenziamento nei seguenti casi:

- a) falsa attestazione della presenza in servizio, mediante l'alterazione dei sistemi di rilevamento della presenza o con altre modalita' fraudolente, ovvero giustificazione dell'assenza dal servizio mediante una certificazione medica falsa o che attesta falsamente uno stato di malattia;
- b) assenza priva di valida giustificazione per un numero di giorni, anche non continuativi, superiore a tre nell'arco di un biennio o comunque per piu' di sette giorni nel corso degli ultimi dieci anni ovvero mancata ripresa del servizio, in caso di assenza ingiustificata, entro il termine fissato dall'amministrazione;
- c) ingiustificato rifiuto del trasferimento disposto dall'amministrazione per motivate esigenze di servizio;
- d) falsita' documentali o dichiarative commesse ai fini o in occasione dell'instaurazione del rapporto di lavoro ovvero di progressioni di carriera;
- e) reiterazione nell'ambiente di lavoro di gravi condotte aggressive o moleste o minacciose o ingiuriose o comunque lesive dell'onore e della dignita' personale altrui;
- f) condanna penale definitiva, in relazione alla quale e' prevista l'interdizione perpetua dai pubblici uffici ovvero l'estinzione, comunque denominata, del rapporto di lavoro.
- f-bis) gravi o reiterate violazioni dei codici di comportamento, ai sensi dell'articolo 54, comma 3; (71)
- f-ter) commissione dolosa, o gravemente colposa, dell'infrazione di cui all'articolo 55-sexies, comma 3; (71)
- f-quater) la reiterata violazione di obblighi concernenti la prestazione lavorativa, che abbia determinato l'applicazione, in sede disciplinare, della sospensione dal servizio per un periodo complessivo superiore a un anno nell'arco di un biennio; (71)
- f-quinquies) insufficiente rendimento, dovuto alla reiterata violazione degli obblighi concernenti la prestazione lavorativa, stabiliti da norme legislative o regolamentari, dal contratto collettivo o individuale, da atti e provvedimenti dell'amministrazione di appartenenza, e rilevato dalla costante valutazione negativa della performance del dipendente per ciascun anno dell'ultimo triennio, resa a tali specifici fini ai sensi dell'articolo 3, comma 5-bis, del decreto legislativo n. 150 del 2009. (71)

1-bis. Costituisce falsa attestazione della presenza in servizio qualunque modalita' fraudolenta posta in essere, anche avvalendosi di terzi, per far risultare il dipendente in servizio o trarre in inganno l'amministrazione presso la quale il dipendente presta attivita' lavorativa circa il rispetto dell'orario di lavoro dello stesso. Della violazione risponde anche chi abbia agevolato con la propria condotta attiva o omissiva la condotta fraudolenta. (67)

2. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75. (71)

3. Nei casi di cui al comma 1, lettere a), d), e) ed f), il licenziamento e' senza preavviso. Nei casi in cui le condotte punibili con il licenziamento sono accertate in flagranza, si applicano le previsioni dei commi da 3-bis a 3-quinquies. (71)

3-bis. Nel caso di cui al comma 1, lettera a), la falsa attestazione della presenza in servizio, accertata in flagranza ovvero mediante strumenti di sorveglianza o di registrazione degli accessi o delle presenze, determina l'immediata sospensione cautelare senza stipendio del dipendente, fatto salvo il diritto all'assegno alimentare nella misura stabilita dalle disposizioni normative e contrattuali vigenti, senza obbligo di preventiva audizione dell'interessato. La sospensione e' disposta dal responsabile della struttura in cui il dipendente lavora o, ove ne venga a conoscenza per primo, dall'ufficio di cui all'articolo 55-bis, comma 4, con provvedimento motivato, in via immediata e comunque entro quarantotto ore dal momento in cui i suddetti soggetti ne sono venuti a conoscenza. La violazione di tale termine non determina la decadenza dall'azione disciplinare ne' l'inefficacia della sospensione cautelare, fatta salva l'eventuale responsabilita' del dipendente cui essa sia imputabile. (67)

3-ter. Con il medesimo provvedimento di sospensione cautelare di cui al comma 3-bis si procede anche alla contestuale contestazione per iscritto dell'addebito e alla convocazione del dipendente dinanzi all'Ufficio di cui all'articolo 55-bis, comma 4. Il dipendente e' convocato, per il contraddittorio a sua difesa, con un preavviso di almeno quindici giorni e puo' farsi assistere da un procuratore ovvero da un rappresentante dell'associazione sindacale cui il lavoratore aderisce o conferisce mandato. Fino alla data dell'audizione, il dipendente convocato puo' inviare una memoria scritta o, in caso di grave, oggettivo e assoluto impedimento, formulare motivata istanza di rinvio del termine per l'esercizio della sua difesa per un periodo non superiore a cinque giorni. Il differimento del termine a difesa del dipendente puo' essere disposto solo una volta nel corso del procedimento. L'Ufficio conclude il procedimento entro trenta giorni dalla ricezione, da parte del dipendente, della contestazione dell'addebito. La violazione dei suddetti termini, fatta salva l'eventuale responsabilita' del dipendente cui essa sia imputabile, non determina la decadenza dall'azione disciplinare ne' l'invalidita' della sanzione irrogata, purche' non risulti irrimediabilmente compromesso il diritto di difesa del dipendente e non sia superato il termine per la conclusione del procedimento di cui all'articolo 55-bis, comma 4. (67)

3-quater. Nei casi di cui al comma 3-bis, la denuncia al pubblico ministero e la segnalazione alla competente procura regionale della Corte dei conti avvengono entro venti giorni dall'avvio del procedimento disciplinare. La Procura della Corte dei conti, quando ne ricorrono i presupposti, emette invito a dedurre per danno d'immagine entro tre mesi dalla conclusione della procedura di licenziamento. L'azione di responsabilita' e' esercitata, con le modalita' e nei termini di cui all'articolo 5 del decreto-legge 15 novembre 1993, n. 453, convertito, con modificazioni, dalla legge 14 gennaio 1994, n. 19, entro i centocinquanta giorni successivi alla denuncia, senza possibilita' di proroga. L'ammontare del danno risarcibile e' rimesso alla valutazione equitativa del giudice anche in relazione alla rilevanza del fatto per i mezzi di informazione e comunque l'eventuale condanna non puo' essere inferiore a sei mensilita' dell'ultimo stipendio in godimento, oltre interessi e spese di giustizia. (67) (73) ((98))

3-quinquies. Nei casi di cui al comma 3-bis, per i dirigenti che abbiano acquisito conoscenza del fatto, ovvero, negli enti privi di qualifica dirigenziale, per i responsabili di servizio competenti, l'omessa attivazione del procedimento disciplinare e l'omessa adozione del provvedimento di sospensione cautelare, senza giustificato motivo, costituiscono illecito disciplinare punibile con il licenziamento e di esse e' data notizia, da parte dell'ufficio competente per il procedimento disciplinare, all'Autorita' giudiziaria ai fini dell'accertamento della sussistenza di eventuali reati. (67)

3-sexies. I provvedimenti di cui ai commi 3-bis e 3-ter e quelli conclusivi dei procedimenti di cui al presente articolo sono comunicati all'Ispettorato per la funzione pubblica ai sensi di quanto previsto dall'articolo 55-bis, comma 4. (73)

--------------- AGGIORNAMENTO (67) Il D.Lgs. 20 giugno 2016, n. 116 ha disposto (con l'art. 3, comma 1) le modifiche si applicano agli illeciti disciplinari commessi successivamente alla data di entrata in vigore del presente decreto. --------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 22, comma 13) che "Le disposizioni di cui al Capo VII si applicano agli illeciti disciplinari commessi successivamente alla data di entrata in vigore del presente decreto". --------------- AGGIORNAMENTO (73) Il D.Lgs. 20 luglio 2017, n. 118, nel modificare l'art. 1 del D.Lgs. 20 giugno 2016, n. 116, ha conseguentemente disposto (con l'art. 5, comma 1) che "Sono fatti salvi gli effetti gia' prodotti dal decreto legislativo n. 116 del 2016". --------------- AGGIORNAMENTO (98) La Corte Costituzionale, con sentenza 9 gennaio - 10 aprile 2020, n. 61 (in G.U. 1ª s.s. 15/04/2020, n. 16), ha dichiarato "l'illegittimita' costituzionale del secondo, terzo e quarto periodo del comma 3-quater dell'art. 55-quater del d.lgs. n. 165 del 2001, come introdotto dall'art. 1, comma 1, lettera b), del d.lgs. n. 116 del 2016".

### Art. 55-quinquies. - (False attestazioni o certificazioni).

1. Fermo quanto previsto dal codice penale, il lavoratore dipendente di una pubblica amministrazione che attesta falsamente la propria presenza in servizio, mediante l'alterazione dei sistemi di rilevamento della presenza o con altre modalita' fraudolente, ovvero giustifica l'assenza dal servizio mediante una certificazione medica falsa o falsamente attestante uno stato di malattia e' punito con la reclusione da uno a cinque anni e con la multa da euro 400 ad euro 1.600. La medesima pena si applica al medico e a chiunque altro concorre nella commissione del delitto.

2. Nei casi di cui al comma 1, il lavoratore, ferme la responsabilita' penale e disciplinare e le relative sanzioni, e' obbligato a risarcire il danno patrimoniale, pari al compenso corrisposto a titolo di retribuzione nei periodi per i quali sia accertata la mancata prestazione, nonche' ((il danno d'immagine di cui all'articolo 55-quater, comma 3-quater.)) ((71))

3. La sentenza definitiva di condanna o di applicazione della pena per il delitto di cui al comma 1 comporta, per il medico, la sanzione disciplinare della radiazione dall'albo ed altresi', se dipendente di una struttura sanitaria pubblica o se convenzionato con il servizio sanitario nazionale, il licenziamento per giusta causa o la decadenza dalla convenzione. Le medesime sanzioni disciplinari si applicano se il medico, in relazione all'assenza dal servizio, rilascia certificazioni che attestano dati clinici non direttamente constatati ne' oggettivamente documentati.

((3-bis. Fermo restando quanto previsto dall'articolo 55-quater, comma 1, lettere a) e b), i contratti collettivi nazionali individuano le condotte e fissano le corrispondenti sanzioni disciplinari con riferimento alle ipotesi di ripetute e ingiustificate assenze dal servizio in continuita' con le giornate festive e di riposo settimanale, nonche' con riferimento ai casi di ingiustificate assenze collettive in determinati periodi nei quali e' necessario assicurare continuita' nell'erogazione dei servizi all'utenza.))

((71))

--------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 22, comma 13) che "Le disposizioni di cui al Capo VII si applicano agli illeciti disciplinari commessi successivamente alla data di entrata in vigore del presente decreto".

### Art. 55-sexies. - Responsabilita' disciplinare per condotte pregiudizievoli per l'amministrazione e limitazione della responsabilita' per l'esercizio dell'azione disciplinare).

((1. La violazione di obblighi concernenti la prestazione lavorativa, che abbia determinato la condanna dell'amministrazione al risarcimento del danno, comporta comunque, nei confronti del dipendente responsabile, l'applicazione della sospensione dal servizio con privazione della retribuzione da un minimo di tre giorni fino ad un massimo di tre mesi, in proporzione all'entita' del risarcimento, salvo che ricorrano i presupposti per l'applicazione di una piu' grave sanzione disciplinare.)) ((71))

2. Fuori dei casi previsti nel comma 1, il lavoratore, quando cagiona grave danno al normale funzionamento dell'ufficio di appartenenza, per inefficienza o incompetenza professionale accertate dall'amministrazione ai sensi delle disposizioni legislative e contrattuali concernenti la valutazione del personale delle amministrazioni pubbliche, e' collocato in disponibilita', all'esito del procedimento disciplinare che accerta tale responsabilita', e si applicano nei suoi confronti le disposizioni di cui all'articolo 33, comma 8, e all'articolo 34, commi 1, 2, 3 e 4. Il provvedimento che definisce il giudizio disciplinare stabilisce le mansioni e la qualifica per le quali puo' avvenire l'eventuale ricollocamento. Durante il periodo nel quale e' collocato in disponibilita', il lavoratore non ha diritto di percepire aumenti retributivi sopravvenuti.

((3. Il mancato esercizio o la decadenza dall'azione disciplinare, dovuti all'omissione o al ritardo, senza giustificato motivo, degli atti del procedimento disciplinare, inclusa la segnalazione di cui all'articolo 55-bis, comma 4, ovvero a valutazioni manifestamente irragionevoli di insussistenza dell'illecito in relazione a condotte aventi oggettiva e palese rilevanza disciplinare, comporta, per i soggetti responsabili, l'applicazione della sospensione dal servizio fino a un massimo di tre mesi, salva la maggiore sanzione del licenziamento prevista nei casi di cui all'articolo 55-quater, comma 1, lettera f-ter), e comma 3-quinquies. Tale condotta, per il personale con qualifica dirigenziale o titolare di funzioni o incarichi dirigenziali, e' valutata anche ai fini della responsabilita' di cui all'articolo 21 del presente decreto. Ogni amministrazione individua preventivamente il titolare dell'azione disciplinare per le infrazioni di cui al presente comma commesse da soggetti responsabili dell'ufficio di cui all'articolo 55-bis, comma 4.))

((71))

4. La responsabilita' civile eventualmente configurabile a carico del dirigente in relazione a profili di illiceita' nelle determinazioni concernenti lo svolgimento del procedimento disciplinare e' limitata, in conformita' ai principi generali, ai casi di dolo o colpa grave.

--------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 22, comma 13) che "Le disposizioni di cui al Capo VII si applicano agli illeciti disciplinari commessi successivamente alla data di entrata in vigore del presente decreto".

### Art. 55-septies. - (Controlli sulle assenze).

1. Nell'ipotesi di assenza per malattia protratta per un periodo superiore a dieci giorni, e, in ogni caso, dopo il secondo evento di malattia nell'anno solare l'assenza viene giustificata esclusivamente mediante certificazione medica rilasciata da una struttura sanitaria pubblica o da un medico convenzionato con il Servizio sanitario nazionale. ((I controlli sulla validita' delle suddette certificazioni restano in capo alle singole amministrazioni pubbliche interessate.))

2. In tutti i casi di assenza per malattia la certificazione medica e' inviata per via telematica, direttamente dal medico o dalla struttura sanitaria che la rilascia, all'Istituto nazionale della previdenza sociale, secondo le modalita' stabilite per la trasmissione telematica dei certificati medici nel settore privato dalla normativa vigente, e in particolare dal decreto del Presidente del Consiglio dei Ministri previsto dall'articolo 50, comma 5-bis, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, introdotto dall'articolo 1, comma 810, della legge 27 dicembre 2006, n. 296, e dal predetto Istituto e' immediatamente ((resa disponibile)), con le medesime modalita', all'amministrazione interessata. ((L'Istituto nazionale della previdenza sociale utilizza la medesima certificazione per lo svolgimento delle attivita' di cui al successivo comma 3 anche mediante la trattazione dei dati riferiti alla diagnosi. I relativi certificati devono contenere anche il codice nosologico.)) Il medico o la struttura sanitaria invia telematicamente la medesima certificazione all'indirizzo di posta elettronica personale del lavoratore qualora il medesimo ne faccia espressa richiesta fornendo un valido indirizzo.

((2-bis. Gli accertamenti medico-legali sui dipendenti assenti dal servizio per malattia sono effettuati, sul territorio nazionale, in via esclusiva dall'Inps d'ufficio o su richiesta con oneri a carico dell'Inps che provvede nei limiti delle risorse trasferite delle Amministrazioni interessate. Il rapporto tra l'Inps e i medici di medicina fiscale e' disciplinato da apposite convenzioni, stipulate dall'Inps con le organizzazioni sindacali di categoria maggiormente rappresentative in campo nazionale. L'atto di indirizzo per la stipula delle convenzioni e' adottato con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro per la semplificazione e la pubblica amministrazione e con il Ministro della salute, sentito l'Inps per gli aspetti organizzativo-gestionali e sentite la Federazione nazionale degli Ordini dei medici chirurghi e degli odontoiatri e le organizzazioni sindacali di categoria maggiormente rappresentative. Le convenzioni garantiscono il prioritario ricorso ai medici iscritti nelle liste di cui all'articolo 4, comma 10-bis, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, per tutte le funzioni di accertamento medico-legali sulle assenze dal servizio per malattia dei pubblici dipendenti, ivi comprese le attivita' ambulatoriali inerenti alle medesime funzioni. Il predetto atto di indirizzo stabilisce, altresi', la durata delle convenzioni, demandando a queste ultime, anche in funzione della relativa durata, la disciplina delle incompatibilita' in relazione alle funzioni di certificazione delle malattie.))

((71))

3. L'Istituto nazionale della previdenza sociale, gli enti del servizio sanitario nazionale e le altre amministrazioni interessate svolgono le attivita' di cui al comma 2 con le risorse finanziarie, strumentali e umane disponibili a legislazione vigente, senza nuovi o maggiori oneri a carico della finanza pubblica.

4. L'inosservanza degli obblighi di trasmissione per via telematica della certificazione medica concernente assenze di lavoratori per malattia di cui al comma 2 costituisce illecito disciplinare e, in caso di reiterazione, comporta l'applicazione della sanzione del licenziamento ovvero, per i medici in rapporto convenzionale con le aziende sanitarie locali, della decadenza dalla convenzione, in modo inderogabile dai contratti o accordi collettivi. Affinche' si configuri l'ipotesi di illecito disciplinare devono ricorrere sia l'elemento oggettivo dell'inosservanza all'obbligo di trasmissione, sia l'elemento soggettivo del dolo o della colpa. Le sanzioni sono applicate secondo criteri di gradualita' e proporzionalita', secondo le previsioni degli accordi e dei contratti collettivi di riferimento.

5. Le pubbliche amministrazioni dispongono per il controllo sulle assenze per malattia dei dipendenti valutando la condotta complessiva del dipendente e gli oneri connessi all'effettuazione della visita, tenendo conto dell'esigenza di contrastare e prevenire l'assenteismo. Il controllo e' in ogni caso richiesto sin dal primo giorno quando l'assenza si verifica nelle giornate precedenti o successive a quelle non lavorative.

((

5-bis. Al fine di armonizzare la disciplina dei settori pubblico e privato, con decreto del Ministro per la semplificazione e la pubblica amministrazione, di concerto con il Ministro del lavoro e delle politiche sociali, sono stabilite le fasce orarie di reperibilita' entro le quali devono essere effettuate le visite di controllo e sono definite le modalita' per lo svolgimento delle visite medesime e per l'accertamento, anche con cadenza sistematica e ripetitiva, delle assenze dal servizio per malattia. Qualora il dipendente debba allontanarsi dall'indirizzo comunicato durante le fasce di reperibilita' per effettuare visite mediche, prestazioni o accertamenti specialistici o per altri giustificati motivi, che devono essere, a richiesta, documentati, e' tenuto a darne preventiva comunicazione all'amministrazione che, a sua volta, ne da' comunicazione all'Inps.

))

5-ter. Nel caso in cui l'assenza per malattia abbia luogo per l'espletamento di visite, terapie, prestazioni specialistiche od esami diagnostici il permesso e' giustificato mediante la presentazione di attestazione, anche in ordine all'orario, rilasciata dal medico o dalla struttura, anche privati, che hanno svolto la visita o la prestazione o trasmessa da questi ultimi mediante posta elettronica. (38)

6. Il responsabile della struttura in cui il dipendente lavora nonche' il dirigente eventualmente preposto all'amministrazione generale del personale, secondo le rispettive competenze, curano l'osservanza delle disposizioni del presente articolo, in particolare al fine di prevenire o contrastare, nell'interesse della funzionalita' dell'ufficio, le condotte assenteistiche. Si applicano, al riguardo, le disposizioni degli articoli 21 e 55-sexies, comma 3.

------------- AGGIORNAMENTO (38) Il D.L. 6 luglio 2011, n. 98, convertito con modificazioni dalla L. 15 luglio 2011, n. 111, ha disposto (con l'art. 16, comma 10) che "Le disposizioni dei commi 5, 5-bis e 5-ter, dell'articolo 55-septies, del decreto legislativo 30 marzo 2001, n. 165, si applicano anche ai dipendenti di cui all'articolo 3 del medesimo decreto." --------------- AGGIORNAMENTO (71) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 22, comma 2) che "La disposizione di cui all'articolo 55-septies, comma 2-bis, primo periodo, del decreto legislativo 30 marzo 2001, n. 165, che attribuisce all'Inps la competenza esclusiva ad effettuare gli accertamenti medico legali sui dipendenti assenti dal servizio per malattia, si applica a decorrere dal 1° settembre 2017 e, nei confronti del personale delle istituzioni scolastiche ed educative statali, a decorrere dall'anno scolastico 2017/2018".

### Art. 55-octies. - (( (Permanente inidoneita' psicofisica). ))

((

1. Nel caso di accertata permanente inidoneita' psicofisica al servizio dei dipendenti delle amministrazioni pubbliche, di cui all'articolo 2, comma 2, l'amministrazione puo' risolvere il rapporto di lavoro. Con regolamento da emanarsi, ai sensi dell'articolo 17, comma 1, lettera b), della legge 23 agosto 1988, n. 400, sono disciplinati, per il personale delle amministrazioni statali, anche ad ordinamento autonomo, nonche' degli enti pubblici non economici:

- a) la procedura da adottare per la verifica dell'idoneita' al servizio, anche ad iniziativa dell'Amministrazione;
- b) la possibilita' per l'amministrazione, nei casi di pericolo per l'incolumita' del dipendente interessato nonche' per la sicurezza degli altri dipendenti e degli utenti, di adottare provvedimenti di sospensione cautelare dal servizio, in attesa dell'effettuazione della visita di idoneita', nonche' nel caso di mancata presentazione del dipendente alla visita di idoneita', in assenza di giustificato motivo;
- c) gli effetti sul trattamento giuridico ed economico della sospensione di cui alla lettera b), nonche' il contenuto e gli effetti dei provvedimenti definitivi adottati dall'amministrazione in seguito all'effettuazione della visita di idoneita';
- d) la possibilita', per l'amministrazione, di risolvere il rapporto di lavoro nel caso di reiterato rifiuto, da parte del dipendente, di sottoporsi alla visita di idoneita'.

))

### Art. 55-novies. - (( (Identificazione del personale a contatto con il pubblico). ))

((

1. I dipendenti delle amministrazioni pubbliche che svolgono attivita' a contatto con il pubblico sono tenuti a rendere conoscibile il proprio nominativo mediante l'uso di cartellini identificativi o di targhe da apporre presso la postazione di lavoro.

2. Dall'obbligo di cui al comma 1 e' escluso il personale individuato da ciascuna amministrazione sulla base di categorie determinate, in relazione ai compiti ad esse attribuiti, mediante uno o piu' decreti del Presidente del Consiglio dei Ministri o del Ministro per la pubblica amministrazione e l'innovazione, su proposta del Ministro competente ovvero, in relazione al personale delle amministrazioni pubbliche non statali, previa intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano o di Conferenza Stato-citta' ed autonomie locali. ))

--------------- AGGIORNAMENTO (33) Il D.lgs. 27 ottobre 2009, n. 150, ha disposto (con l'art. 73, comma 2) che l'obbligo di esposizione di cartellini o targhe identificativi, previsto dal presente articolo decorre dal novantesimo giorno successivo all'entrata in vigore del medesimo decreto.

### Articolo 56

((ARTICOLO ABROGATO DAL D.LGS. 27 OTTOBRE 2009, N. 150))

### Articolo 57 - (Art.61 del d.lgs n.29 del 1993, come sostituito dall'art.29 del d.lgs n.546 del 1993, successivamente modificato prima dall'art.43, comma 8 del d.lgs n.80 del 1998 e poi dall'art.l7 del d.lgs n.387 del 1998)

01. Le pubbliche amministrazioni costituiscono al proprio interno, entro centoventi giorni dalla data di entrata in vigore della presente disposizione e senza nuovi o maggiori oneri per la finanza pubblica, il "Comitato unico di garanzia per le pari opportunita', la valorizzazione del benessere di chi lavora e contro le discriminazioni" che sostituisce, unificando le competenze in un solo organismo, i comitati per le pari opportunita' e i comitati paritetici sul fenomeno del mobbing, costituiti in applicazione della contrattazione collettiva, dei quali assume tutte le funzioni previste dalla legge, dai contratti collettivi relativi al personale delle amministrazioni pubbliche o da altre disposizioni.

02. Il Comitato unico di garanzia per le pari opportunita', la valorizzazione del benessere di chi lavora e contro le discriminazioni ha composizione paritetica ed e' formato da un componente designato da ciascuna delle organizzazioni sindacali maggiormente rappresentative a livello di amministrazione e da un pari numero di rappresentanti dell'amministrazione in modo da assicurare nel complesso la presenza paritaria di entrambi i generi. Il presidente del Comitato unico di garanzia e' designato dall'amministrazione.

03. Il Comitato unico di garanzia, all'interno dell'amministrazione pubblica, ha compiti propositivi, consultivi e di verifica e opera in collaborazione con la consigliera o il consigliere nazionale di parita'. Contribuisce all'ottimizzazione della produttivita' del lavoro pubblico, migliorando l'efficienza delle prestazioni collegata alla garanzia di un ambiente di lavoro caratterizzato dal rispetto dei principi di pari opportunita', di benessere organizzativo e dal contrasto di qualsiasi forma di discriminazione e di violenza morale o psichica per i lavoratori.

04. Le modalita' di funzionamento dei Comitati unici di garanzia sono disciplinate da linee guida contenute in una direttiva emanata di concerto dal Dipartimento della funzione pubblica e dal Dipartimento per le pari opportunita' della Presidenza del Consiglio dei ministri entro novanta giorni dalla data di entrata in vigore della presente disposizione.

05. La mancata costituzione del Comitato unico di garanzia comporta responsabilita' dei dirigenti incaricati della gestione del personale, da valutare anche al fine del raggiungimento degli obiettivi.

1. Le pubbliche amministrazioni, al fine di garantire pari opportunita' tra uomini e donne per l'accesso al lavoro ed il trattamento sul lavoro:

- a) riservano alle donne, salva motivata impossibilita', almeno un terzo dei posti di componente delle commissioni di concorso, fermo restando il principio di cui all'articolo 35, comma 3, lettera e) ((; in caso di quoziente frazionario si procede all'arrotondamento all'unita' superiore qualora la cifra decimale sia pari o superiore a 0,5 e all'unita' inferiore qualora la cifra decimale sia inferiore a 0,5));
- b) adottano propri atti regolamentari per assicurare pari opportunita' fra uomini e donne sul lavoro, conformemente alle direttive impartite dalla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica;
- c) garantiscono la partecipazione delle proprie dipendenti ai corsi di formazione e di aggiornamento professionale in rapporto proporzionale alla loro presenza nelle amministrazioni interessate ai corsi medesimi, adottando modalita' organizzative atte a favorirne la partecipazione, consentendo la conciliazione fra vita professionale e vita familiare;
- d) possono finanziare programmi di azioni positive e l'attivita' dei Comitati unici di garanzia per le pari opportunita', per la valorizzazione del benessere di chi lavora e contro le discriminazioni, nell'ambito delle proprie disponibilita' di bilancio.

((1-bis. L'atto di nomina della commissione di concorso e' inviato, entro tre giorni, alla consigliera o al consigliere di parita' nazionale ovvero regionale, in base all'ambito territoriale dell'amministrazione che ha bandito il concorso, che, qualora ravvisi la violazione delle disposizioni contenute nel comma 1, lettera a), diffida l'amministrazione a rimuoverla entro il termine massimo di trenta giorni. In caso di inottemperanza alla diffida, la consigliera o il consigliere di parita' procedente propone, entro i successivi quindici giorni, ricorso ai sensi dell'articolo 37, comma 4, del codice delle pari opportunita' tra uomo e donna, di cui al decreto legislativo 11 aprile 2006, n. 198, e successive modificazioni; si applica il comma 5 del citato articolo 37 del codice di cui al decreto legislativo n. 198 del 2006, e successive modificazioni. Il mancato invio dell'atto di nomina della commissione di concorso alla consigliera o al consigliere di parita' comporta responsabilita' del dirigente responsabile del procedimento, da valutare anche al fine del raggiungimento degli obiettivi))

2. Le pubbliche amministrazioni, secondo le modalita' di cui all'articolo 9, adottano tutte le misure per attuare le direttive dell'Unione europea in materia di pari opportunita', contrasto alle discriminazioni ed alla violenza morale o psichica, sulla base di quanto disposto dalla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica.

## CONTROLLO DELLA SPESA

### Articolo 58 - Finalita' (Art.63 del d.lgs n.29 del 1993, come sostituito dall'art.30 del d.lgs n.546 del 1993)

((

1. Al fine di realizzare il piu' efficace controllo del costo del lavoro, il Ministero dell'economia e delle finanze, d'intesa con la Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, provvede all'acquisizione delle informazioni relative al personale di tutte le amministrazioni pubbliche e al relativo costo.

))

2. ((COMMA ABROGATO DAL D.LGS 25 maggio 2017, n. 75)).

3. ((Per le finalita' di cui al comma 1,)) il Ministero ((dell'economia e delle finanze)) d'intesa con la Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, ((cura il)) processo di integrazione dei sistemi informativi delle amministrazioni pubbliche che rilevano i trattamenti economici e le spese del personale, facilitando la razionalizzazione delle modalita' di pagamento delle retribuzioni. Le informazioni acquisite dal sistema informativo del Dipartimento della ragioneria generale dello Stato sono disponibili per tutte le amministrazioni e gli enti interessati.

### Articolo 59

((ARTICOLO ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75))

### Art. 60. - Controllo del costo del lavoro (Art. 65 del d.lgs. n. 29 del 1993, come sostituito dall'art. 32 del d.lgs. n. 546 del 1993)

1. Il Ministero ((dell'economia e delle finanze)) ((- Dipartimento della Ragioneria generale dello Stato)), d'intesa con la Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, definisce ((le modalita' di acquisizione)) della consistenza del personale, in servizio e in quiescenza ((presso le amministrazioni pubbliche)), e delle relative spese, ivi compresi gli oneri previdenziali e le entrate derivanti dalle contribuzioni, anche per la loro evidenziazione ((, limitatamente al personale dipendente dei ministeri,)) a preventivo e a consuntivo, mediante allegati ((al bilancio dello Stato)). Il Ministero ((dell'economia e delle finanze)) ((- Dipartimento della Ragioneria generale dello Stato)) elabora, ((altresi', il)) conto annuale che evidenzi anche il rapporto tra contribuzioni e prestazioni previdenziali relative al personale delle amministrazioni statali.

2. Le amministrazioni pubbliche presentano, entro il mese di maggio di ogni anno, alla Corte dei conti e alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, per il tramite del Dipartimento della ragioneria generale dello Stato, il conto annuale delle spese sostenute per il personale, ((rilevate secondo le modalita')) di cui al comma 1. Il conto e' accompagnato da una relazione, con cui le amministrazioni pubbliche espongono i risultati della gestione del personale, con riferimento agli obiettivi che, per ciascuna amministrazione, sono stabiliti dalle leggi, dai regolamenti e dagli atti di programmazione. ((PERIODO SOPPRESSO DAL D.LGS. 25 MAGGIO 2017, N. 75)). Le comunicazioni previste dal presente comma sono trasmesse, a cura del Ministero dell'economia e delle finanze, anche all'Unione delle province d'Italia (UPI), all'Associazione nazionale dei comuni italiani (ANCI) e all'Unione nazionale comuni, comunita', enti montani (UNCEM), per via telematica.

3. Gli enti pubblici economici, le aziende ((e gli enti)) che producono servizi di pubblica utilita', le societa' non quotate partecipate direttamente o indirettamente, a qualunque titolo, dalle pubbliche amministrazioni di cui all'articolo 1, comma 3, della legge 31 dicembre 2009, n. 196, diverse da quelle emittenti strumenti finanziari quotati in mercati regolamentati e dalle societa' dalle stesse controllate, nonche' gli enti e le aziende di cui all'articolo 70, comma 4, e la societa' concessionaria del servizio pubblico generale radiotelevisivo, relativamente ai singoli rapporti di lavoro dipendente o autonomo, sono tenuti a comunicare alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica e al Ministero dell'economia e delle finanze, il costo annuo del personale comunque utilizzato, in conformita' alle procedure definite dal Ministero dell'economia e delle finanze, d'intesa con il predetto Dipartimento della funzione pubblica. (57)

4. La Corte dei conti riferisce annualmente al Parlamento sulla gestione delle risorse finanziarie destinate al personale del settore pubblico, avvalendosi di tutti i dati e delle informazioni disponibili presso le amministrazioni pubbliche. Con apposite relazioni in corso d'anno, anche a richiesta del Parlamento, la Corte riferisce altresi' in ordine a specifiche materie, settori ed interventi.

5. Il Ministero ((dell'economia e delle finanze)), anche su espressa richiesta del ((Ministro per la semplificazione e la pubblica amministrazione)), dispone visite ispettive, a cura dei servizi ispettivi di finanza del Dipartimento della ragioneria generale dello Stato, coordinate anche con altri analoghi servizi, per la valutazione e la verifica delle spese, con particolare riferimento agli oneri dei contratti collettivi nazionali e decentrati, denunciando alla Corte dei conti le irregolarita' riscontrate. Tali verifiche vengono eseguite presso le amministrazioni pubbliche, nonche' presso gli enti e le aziende di cui al comma 3. Ai fini dello svolgimento integrato delle verifiche ispettive, i servizi ispettivi di finanza del Dipartimento della ragioneria generale dello Stato esercitano presso le predette amministrazioni, enti e aziende sia le funzioni di cui all'articolo 3, comma 1, del decreto del Presidente della Repubblica 20 febbraio 1998, n. 38 e all'articolo 2, comma 1, lettera b) del decreto del Presidente della Repubblica 28 aprile 1998, n. 154, sia i compiti di cui all'articolo 27, comma quarto, della legge 29 marzo 1983, n. 93.

6. Presso la Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica e' istituito l'Ispettorato per la funzione pubblica, che opera alle dirette dipendenze del Ministro delegato. L'Ispettorato vigila e svolge verifiche sulla conformita' dell'azione amministrativa ai principi di imparzialita' e buon andamento, sull'efficacia della sua attivita' con particolare riferimento alle riforme volte alla semplificazione delle procedure, sul corretto conferimento degli incarichi, sull'esercizio dei poteri disciplinari, sull'osservanza delle disposizioni vigenti in materia di controllo dei costi ((...)). Collabora alle verifiche ispettive di cui al comma 5. Nell'ambito delle proprie verifiche, l'Ispettorato puo' avvalersi della Guardia di Finanza che opera nell'esercizio dei poteri ad essa attribuiti dalle leggi vigenti. Per le predette finalita' l'Ispettorato si avvale altresi' di un numero complessivo di dieci funzionari scelti tra esperti del Ministero dell'economia e delle finanze, del Ministero dell'interno, o comunque tra il personale di altre amministrazioni pubbliche, in posizione di comando o fuori ruolo, per il quale si applicano l'articolo 17, comma 14, della legge 15 maggio 1997, n. 127, e l'articolo 56, comma 7, del Testo unico delle disposizioni concernenti lo statuto degli impiegati civili dello Stato di cui al decreto del Presidente della Repubblica 10 gennaio 1957, n. 3, e successive modificazioni. Per l'esercizio delle funzioni ispettive connesse, in particolare, al corretto conferimento degli incarichi e ai rapporti di collaborazione, svolte anche d'intesa con il Ministero dell'economia e delle finanze, l'Ispettorato si avvale dei dati comunicati dalle amministrazioni al Dipartimento della funzione pubblica ai sensi dell'articolo 53. L'Ispettorato, inoltre, al fine di corrispondere a segnalazioni da parte di cittadini o pubblici dipendenti circa presunte irregolarita', ritardi o inadempienze delle amministrazioni di cui all'articolo 1, comma 2, puo' richiedere chiarimenti e riscontri in relazione ai quali l'amministrazione interessata ha l'obbligo di rispondere, anche per via telematica, entro quindici giorni. A conclusione degli accertamenti, gli esiti delle verifiche svolte dall'ispettorato costituiscono obbligo di valutazione, ai fini dell'individuazione delle responsabilita' e delle eventuali sanzioni disciplinari di cui all'articolo 55, per l'amministrazione medesima. Gli ispettori, nell'esercizio delle loro funzioni, hanno piena autonomia funzionale ed hanno l'obbligo, ove ne ricorrano le condizioni, di denunciare alla Procura generale della Corte dei conti le irregolarita' riscontrate.

------------- AGGIORNAMENTO (57) Il D.L. 31 agosto 2013, n. 101, convertito con modificazioni dalla L. 30 ottobre 2013, n. 125, ha disposto (con l'art. 2, comma 11) che la modifica del comma 3 del presente articolo decorre dal 1° gennaio 2014.

### Art. 60-bis. - (Istituzione e attivita' del Nucleo della Concretezza)

1. Ferme le competenze dell'Ispettorato di cui all'articolo 60, comma 6, e dell'Unita' per la semplificazione e la qualita' della regolazione di cui all'articolo 1, comma 22-bis, del decreto-legge 18 maggio 2006, n. 181, convertito, con modificazioni, dalla legge 17 luglio 2006, n. 233, e' istituito, presso il Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri, il Nucleo delle azioni concrete di miglioramento dell'efficienza amministrativa, denominato "Nucleo della Concretezza".

2. Con decreto del Ministro per la pubblica amministrazione, di concerto con il Ministro dell'interno, previa intesa in sede di Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, per la parte relativa alle azioni da effettuare nelle regioni, negli enti strumentali regionali, negli enti del Servizio sanitario regionale e negli enti locali, e' approvato il Piano triennale delle azioni concrete per l'efficienza delle pubbliche amministrazioni, predisposto annualmente dal Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri. Il Piano contiene:

- a) le azioni dirette a garantire la corretta applicazione delle disposizioni in materia di organizzazione, funzionamento, trasparenza e digitalizzazione delle pubbliche amministrazioni e la conformita' dell'attivita' amministrativa ai principi di imparzialita' e buon andamento;
- b) le tipologie di azioni dirette a incrementare l'efficienza delle pubbliche amministrazioni, anche con riferimento all'impiego delle risorse dei fondi strutturali e di investimento europei;
- c) l'indicazione delle modalita' di svolgimento delle attivita' del Nucleo della Concretezza nei confronti delle regioni, degli enti strumentali regionali, degli enti del Servizio sanitario regionale e degli enti locali.

3. Il Nucleo della Concretezza assicura la concreta realizzazione delle misure indicate nel Piano di cui al comma 2. A tal fine, in collaborazione con l'Ispettorato di cui all'articolo 60, comma 6, effettua sopralluoghi e visite finalizzati a rilevare lo stato di attuazione delle disposizioni da parte delle pubbliche amministrazioni, nonche' le modalita' di organizzazione e di gestione dell'attivita' amministrativa alla luce dei criteri di efficienza, efficacia ed economicita', proponendo eventuali misure correttive. Le amministrazioni dello Stato, anche ad ordinamento autonomo, le agenzie e gli enti pubblici non economici nazionali realizzano le misure correttive entro tempi definiti e comunque nei limiti di quelli indicati nel Piano di cui al comma 2.

4. Di ogni sopralluogo e visita e' redatto processo verbale, sottoscritto dal rappresentante dell'amministrazione o da un suo delegato, da cui risultano le visite e le rilevazioni eseguite, le richieste avanzate, la documentazione visionata o acquisita, nonche' le risposte e i chiarimenti ricevuti. Il verbale contiene anche l'indicazione delle eventuali misure correttive e, per le amministrazioni di cui al terzo periodo del comma 3, del termine entro il quale le stesse devono essere attuate. L'amministrazione, nei tre giorni successivi, puo' formulare osservazioni e fornire ulteriori documenti.

5. I verbali redatti in occasione di sopralluoghi e visite effettuati in comuni o in altri enti locali sono trasmessi anche al prefetto territorialmente competente.

6. Le pubbliche amministrazioni provvedono alla comunicazione al Nucleo della Concretezza dell'avvenuta attuazione delle misure correttive entro quindici giorni dall'attuazione medesima, fermo restando, per le pubbliche amministrazioni di cui al terzo periodo del comma 3, il rispetto del termine assegnato dal Nucleo medesimo.

7. L'inosservanza del termine assegnato, ai sensi del comma 3, per l'attuazione delle misure correttive rileva ai fini della responsabilita' dirigenziale e disciplinare e determina l'iscrizione della pubblica amministrazione inadempiente in un elenco pubblicato nel sito del Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri. Entro il 30 giugno di ogni anno, il Dipartimento della funzione pubblica trasmette una relazione sugli esiti dei sopralluoghi e delle visite, con l'evidenziazione dei casi di mancato adeguamento, al Ministro per la pubblica amministrazione, al Ministro dell'interno e alla Corte dei conti. Il Ministro per la pubblica amministrazione trasmette tale relazione alle Camere, ai fini del deferimento alle competenti Commissioni parlamentari. ((116))

-------------- AGGIORNAMENTO (116) Il D.P.R. 24 giugno 2022, n. 81, ha disposto (con l'art. 1, comma 1, lettera a)) che "Ai sensi di quanto previsto dall'articolo 6, comma 1, del decreto-legge 9 giugno 2021, n. 80, convertito, con modificazioni, dalla legge 6 agosto 2021, n. 113, per le amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, con piu' di cinquanta dipendenti, sono soppressi, in quanto assorbiti nelle apposite sezioni del Piano integrato di attivita' e organizzazione (PIAO), gli adempimenti inerenti ai piani di cui alle seguenti disposizioni: a) [...] articoli 60-bis (Piano delle azioni concrete) [...] del decreto legislativo 30 marzo 2001, n. 165".

### Art. 60-ter. - (Collaborazione tra il prefetto e il Nucleo della Concretezza)

1. Il prefetto puo' segnalare al Nucleo della Concretezza di cui all'articolo 60-bis, comma 1, eventuali irregolarita' dell'azione amministrativa degli enti locali e chiederne l'intervento. In tal caso puo' partecipare ai sopralluoghi e alle visite anche personale della prefettura-ufficio territoriale del Governo richiedente. ((116))

-------------- AGGIORNAMENTO (116) Il D.P.R. 24 giugno 2022, n. 81, ha disposto (con l'art. 1, comma 1, lettera a)) che "Ai sensi di quanto previsto dall'articolo 6, comma 1, del decreto-legge 9 giugno 2021, n. 80, convertito, con modificazioni, dalla legge 6 agosto 2021, n. 113, per le amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, con piu' di cinquanta dipendenti, sono soppressi, in quanto assorbiti nelle apposite sezioni del Piano integrato di attivita' e organizzazione (PIAO), gli adempimenti inerenti ai piani di cui alle seguenti disposizioni: a)[...] articoli 60-ter, [...] del decreto legislativo 30 marzo 2001, n. 165".

### Art. 60-quater. - (( (Personale del Nucleo della Concretezza) ))

((

.

1. Per lo svolgimento delle attivita' di cui agli articoli 60-bis e 60-ter, il Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri si avvale di cinquantatre' unita' di personale, di cui una con qualifica dirigenziale di livello generale e due con qualifica dirigenziale di livello non generale, reclutate come segue:

- a) ventitre' unita', ivi comprese quelle di livello dirigenziale in deroga alle percentuali di cui all'articolo 19, comma 5-bis, individuate anche tra il personale delle altre amministrazioni pubbliche di cui all'articolo 1, comma 2, che e' collocato in posizione di comando o fuori ruolo o altro analogo istituto previsto dai rispettivi ordinamenti, per il quale si applicano l'articolo 17, comma 14, della legge 15 maggio 1997, n. 127, e l'articolo 56, settimo comma, del testo unico delle disposizioni concernenti lo statuto degli impiegati civili dello Stato, di cui al decreto del Presidente della Repubblica 10 gennaio 1957, n. 3. Il trattamento economico e' corrisposto secondo le modalita' previste dall'articolo 9, comma 5-ter, del decreto legislativo 30 luglio 1999, n. 303;
- b) trenta unita', di cui venti da inquadrare nel livello iniziale della categoria A e dieci da inquadrare nel livello iniziale della categoria B, reclutate a seguito di concorso pubblico per titoli ed esami, espletato ai sensi dell'articolo 35, comma 5.

2. Agli oneri derivanti dall'attuazione delle disposizioni di cui al comma 1, pari a euro 4.153.160 annui a decorrere dal 2019, si provvede mediante corrispondente riduzione dello stanziamento del fondo speciale di parte corrente iscritto, ai fini del bilancio triennale 2019-2021, nell'ambito del programma "Fondi di riserva e speciali" della missione "Fondi da ripartire" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2019, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

))

### Art. 60-quinquies. - (( (Applicazione alle istituzioni scolastiche ed educative) ))

((

.

1. Fermo restando quanto previsto dall'articolo 60-quater, le disposizioni degli articoli 60-bis e 60-ter si applicano, nell'ambito delle risorse umane, finanziarie e strumentali disponibili a legislazione vigente e, comunque, senza nuovi o maggiori oneri per la finanza pubblica, agli istituti e scuole di ogni ordine e grado e alle istituzioni educative tenendo conto delle loro specificita' organizzative e funzionali e nel rispetto dell'autonomia organizzativa, didattica, di ricerca e di sviluppo ad essi riconosciuta dalle vigenti disposizioni.

))

### Art. 61. - interventi correttivi del costo del personale (Art.66 del d.lgs n.29 del 1993)

1. Fermo restando il disposto dell'articolo ((17, comma 12-bis, della legge 31 dicembre 2009, n. 196,)) e successive modificazioni ed integrazioni, e salvi i casi di cui ai commi successivi, qualora si verifichino o siano prevedibili, per qualunque causa, scostamenti rispetto agli stanziamenti previsti per le spese destinate al personale, il Ministro ((dell'economia e delle finanze)), informato dall'amministrazione competente, ne riferisce al Parlamento, proponendo l'adozione di misure correttive idonee a ripristinare l'equilibrio del bilancio. ((PERIODO SOPPRESSO DAL D.LGS. 25 MAGGIO 2017, N. 75)).

1-bis. Le pubbliche amministrazioni comunicano alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica e al Ministero dell'economia e delle finanze l'esistenza di controversie relative al rapporti di lavoro dalla cui soccombenza potrebbero derivare oneri aggiuntivi significativamente rilevanti per il numero dei soggetti direttamente o indirettamente interessati o comunque per gli effetti sulla finanza pubblica. La Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, d'intesa con il Ministero dell'economia e delle finanze, puo' intervenire nel processo ai sensi dell'articolo 105 del codice di procedura civile.

2. Le pubbliche amministrazioni che vengono, in qualunque modo, a conoscenza di decisioni giurisdizionali che comportino oneri a carico del bilancio, ne danno immediata comunicazione alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, al Ministero ((dell'economia e delle finanze)). Ove tali decisioni producano nuovi o maggiori oneri rispetto alle spese autorizzate, il Ministro ((dell'economia e delle finanze)) presenta, entro trenta giorni dalla data di pubblicazione delle sentenze della Corte costituzionale o dalla conoscenza delle decisioni esecutive di altre autorita' giurisdizionali, una relazione al Parlamento, impegnando Governo e Parlamento a definire con procedura d'urgenza una nuova disciplina legislativa idonea a ripristinare i limiti della spesa globale.

3. Il Ministro ((dell'economia e delle finanze)) provvede, con la stessa procedura di cui al comma 2, a seguito di richieste pervenute alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica per la estensione generalizzata di decisioni giurisdizionali divenute esecutive, atte a produrre gli effetti indicati nel medesimo comma 2 sulla entita' della spesa autorizzata.

### Articolo 62 - Commissario del Governo (Art. 67 del d.lgs n. 29 del 1993)

1. Il Commissario del Governo, fino all'entrata in vigore del regolamento di cui all'articolo 11, comma 4, del decreto legislativo 30 luglio 1999, n. 300, rappresenta lo Stato nel territorio regionale. Egli e' responsabile, nei confronti del Governo, del flusso di informazioni degli enti pubblici operanti nel territorio, in particolare di quelli attivati attraverso gli allegati ai bilanci e il conto annuale di cui all'articolo 60, comma 1. Ogni comunicazione del Governo alla regione avviene tramite il Commissario del Governo.

## GIURISDIZIONE

### Art. 63. - Controversie relative ai rapporti di lavoro (Art.68 del d.lgs n.29 del 1993, come sostituito prima dall'art.33 del d.lgs n.546 del 1993 e poi dall'art.29 del d.lgs n.80 del 1998 e successivamente modificato dall'art.18 del d.lgs n.387 del 1998)

1. Sono devolute al giudice ordinario, in funzione di giudice del lavoro, tutte le controversie relative ai rapporti di lavoro alle dipendenze delle pubbliche amministrazioni di cui all'articolo 1, comma 2, ad eccezione di quelle relative ai rapporti di lavoro di cui al comma 4, incluse le controversie concernenti l'assunzione al lavoro, il conferimento e la revoca degli incarichi dirigenziali e la responsabilita' dirigenziale, nonche' quelle concernenti le indennita' di fine rapporto, comunque denominate e corrisposte, ancorche' vengano in questione atti amministrativi presupposti. Quando questi ultimi siano rilevanti ai fini della decisione, il giudice li disapplica, se illegittimi. L'impugnazione davanti al giudice amministrativo dell'atto amministrativo rilevante nella controversia non e' causa di sospensione del processo.

2. Il giudice adotta, nei confronti delle pubbliche amministrazioni, tutti i provvedimenti, di accertamento, costitutivi o di condanna, richiesti dalla natura dei diritti tutelati. Le sentenze con le quali riconosce il diritto all'assunzione, ovvero accerta che l'assunzione e' avvenuta in violazione di norme sostanziali o procedurali, hanno anche effetto rispettivamente costitutivo o estintivo del rapporto di lavoro. ((Il giudice, con la sentenza con la quale annulla o dichiara nullo il licenziamento, condanna l'amministrazione alla reintegrazione del lavoratore nel posto di lavoro e al pagamento di un'indennita' risarcitoria commisurata all'ultima retribuzione di riferimento per il calcolo del trattamento di fine rapporto corrispondente al periodo dal giorno del licenziamento fino a quello dell'effettiva reintegrazione, e comunque in misura non superiore alle ventiquattro mensilita', dedotto quanto il lavoratore abbia percepito per lo svolgimento di altre attivita' lavorative. Il datore di lavoro e' condannato, altresi', per il medesimo periodo, al versamento dei contributi previdenziali e assistenziali.))

((

2-bis. Nel caso di annullamento della sanzione disciplinare per difetto di proporzionalita', il giudice puo' rideterminare la sanzione, in applicazione delle disposizioni normative e contrattuali vigenti, tenendo conto della gravita' del comportamento e dello specifico interesse pubblico violato.

))

3. Sono devolute al giudice ordinario, in funzione di giudice del lavoro, le controversie relative a comportamenti antisindacali delle pubbliche amministrazioni ai sensi dell'articolo 28 della legge 20 maggio 1970, n. 300, e successive modificazioni ed integrazioni, e le controversie, promosse da organizzazioni sindacali, dall'ARAN o dalle pubbliche amministrazioni, relative alle procedure di contrattazione collettiva di cui all'articolo 40 e seguenti del presente decreto.

4. Restano devolute alla giurisdizione del giudice amministrativo le controversie in materia di procedure concorsuali per l'assunzione dei dipendenti delle pubbliche amministrazioni, nonche', in sede di giurisdizione esclusiva, le controversie relative ai rapporti di lavoro di cui all'articolo 3, ivi comprese quelle attinenti ai diritti patrimoniali connessi.

5. Nelle controversie di cui ai commi 1 e 3 e nel caso di cui all'articolo 64, comma 3, il ricorso per cassazione puo' essere proposto anche per violazione o falsa applicazione dei contratti e accordi collettivi nazionali di cui all'articolo 40.

### Art. 63-bis. - (( (Intervento dell'ARAN nelle controversie relative ai rapporti di lavoro). ))

((

1. L'ARAN puo' intervenire nei giudizi innanzi al giudice ordinario, in funzione di giudice del lavoro, aventi ad oggetto le controversie relative ai rapporti di lavoro alle dipendenze delle pubbliche amministrazioni di cui agli articoli 1, comma 2, e 70, comma 4, al fine di garantire la corretta interpretazione e l'uniforme applicazione dei contratti collettivi. Per le controversie relative al personale di cui all'articolo 3, derivanti dalle specifiche discipline ordinamentali e retributive, l'intervento in giudizio puo' essere assicurato attraverso la Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, d'intesa con il Ministero dell'economia e delle finanze.

))

### Articolo 64 - Accertamento pregiudiziale sull'efficacia, validita' ed interpretazione dei contratto collettivi (Art. 68-bis del d.lgs n.29 del 1993, aggiunto dall'art.30 del d.lgs n.80 del 1998 e successivamente modificato dall'art.19, commi 1 e 2 del d.lgs n.387 del 1998)

1. Quando per la definizione di una controversia individuale di cui all'articolo 63, e' necessario risolvere in via pregiudiziale una questione concernente l'efficacia, la validita' o l'interpretazione delle clausole di un contratto o accordo collettivo nazionale, sottoscritto dall'ARAN ai sensi dell'articolo 40 e seguenti, il giudice, con ordinanza non impugnabile, nella quale indica la questione da risolvere, fissa una nuova udienza di discussione non prima di centoventi giorni e dispone la comunicazione, a cura della cancelleria, dell'ordinanza, del ricorso introduttivo e della memoria difensiva all'ARAN.

2. Entro trenta giorni dalla comunicazione di cui al comma 1, l'ARAN convoca le organizzazioni sindacali firmatarie per verificare la possibilita' di un accordo sull'interpretazione autentica del contratto o accordo collettivo, ovvero sulla modifica della clausola controversa. All'accordo sull'interpretazione autentica o sulla modifica della clausola si applicano le disposizioni dell'articolo 49. Il testo dell'accordo e' trasmesso, a cura dell'ARAN, alla cancelleria del giudice procedente, la quale provvede a darne avviso alle parti almeno dieci giorni prima dell'udienza. Decorsi novanta giorni dalla comunicazione di cui al comma 1, in mancanza di accordo, la procedura si intende conclusa.

3. Se non interviene l'accordo sull'interpretazione autentica o sulla modifica della clausola controversa, il giudice decide con sentenza sulla sola questione di cui al comma 1, impartendo distinti provvedimenti per l'ulteriore istruzione o, comunque, per la prosecuzione della causa. La sentenza e' impugnabile soltanto con ricorso immediato per Cassazione, proposto nel termine di sessanta giorni dalla comunicazione dell'avviso di deposito della sentenza. Il deposito nella cancelleria del giudice davanti a cui pende la causa di una copia del ricorso per cassazione, dopo la notificazione alle altre parti, determina la sospensione del processo.

4. La Corte di cassazione, quando accoglie il ricorso a norma dell'articolo 383 del codice di procedura civile, rinvia la causa allo stesso giudice che ha pronunciato la sentenza cassata. La riassunzione della causa puo' essere fatta da ciascuna delle parti entro il termine perentorio di sessanta giorni dalla comunicazione della sentenza di cassazione. In caso di estinzione del processo, per qualsiasi causa, la sentenza della Corte di cassazione conserva i suoi effetti.

5. L'ARAN e le organizzazioni sindacali firmatarie possono intervenire nel processo anche oltre i] termine previsto dall'articolo 419 del codice di procedura civile e sono legittimate, a seguito dell'intervento alla proposizione dei mezzi di' impugnazione delle sentenze che decidono una questione di cui al comma 1. Possono, anche se non intervenute, presentare memorie nel giudizio di merito ed in quello per cassazione. Della presentazione di memorie e' dato avviso alle parti, a cura della cancelleria.

6. In pendenza del giudizio davanti alla Corte di cassazione, possono essere sospesi i processi la cui definizione dipende dalla risoluzione della medesima questione sulla quale la Corte e' chiamata a pronunciarsi. Intervenuta la decisione della Corte di cassazione, il giudice fissa, anche d'ufficio, l'udienza per la prosecuzione del processo.

7. Quando per la definizione di altri processi e' necessario risolvere una questione di cui al comma 1 sulla quale e' gia' intervenuta una pronuncia della Corte di cassazione e il giudice non ritiene di uniformarsi alla pronuncia della Corte, si applica il disposto del comma 3.

8. La Corte di cassazione, nelle controversie di cui e' investita ai sensi del comma 3, puo' condannare la parte soccombente, a norma dell'articolo 96 del codice di procedura civile, anche in assenza di istanza di parte.

### Articolo 65

((ARTICOLO ABROGATO DALLA L. 4 NOVEMBRE 2010, N. 183))

### Articolo 66

((ARTICOLO ABROGATO DALLA L. 4 NOVEMBRE 2010, N. 183))

## DISPOSIZIONI DIVERSE E NORME TRANSITORIE FINALI Capo I Disposizioni diverse

### Articolo 67 - Integrazione funzionale del Dipartimento della funzione pubblica con la Ragioneria generale dello Stato (Art.70 del d.lgs n.29 del 1993, come sostituito dall'art.35 del d.lgs n.546 del 1993)

1. Il piu' efficace perseguimento degli obiettivi di cui all'articolo 48, commi da 1 a 3, ed agli articoli da 58 a 60 e' realizzato attraverso l'integrazione funzionale della Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica con il Ministero ((dell'economia e delle finanze)) - Dipartimento della Ragioneria generale dello Stato, da conseguirsi mediante apposite conferenze di servizi presiedute dal Ministro per la funzione pubblica o da un suo delegato.

2. L'applicazione dei contratti collettivi di lavoro, nazionali e decentrati, per i dipendenti delle amministrazioni pubbliche, e' oggetto di verifica del Ministero ((dell'economia e delle finanze)) e della Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, con riguardo, rispettivamente, al rispetto dei costi prestabiliti ed agli effetti degli istituti contrattuali sull'efficiente organizzazione delle amministrazioni pubbliche e sulla efficacia della loro azione.

3. Gli schemi di provvedimenti legislativi e i progetti di' legge, comunque sottoposti alla valutazione del Governo, contenenti disposizioni relative alle amministrazioni pubbliche richiedono il necessario concerto del Ministero ((dell'economia e delle finanze)) e del Dipartimento della funzione pubblica. I provvedimenti delle singole amministrazioni dello Stato incidenti nella medesima materia sono adottati d'intesa con il Ministero ((dell'economia e delle finanze)) e con la Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica in apposite conferenze di servizi da indire ai sensi e con le modalita' di cui all'articolo 14 della legge 7 agosto 1990, n. 241, e successive modificazioni ed integrazioni.

### Articolo 68 - Aspettativa per mandato parlamentare (Art.71, commi da 1 a 3 e 5 del d.lgs n.29 del 1993)

1. I dipendenti delle pubbliche amministrazioni eletti al Parlamento nazionale, al Parlamento europeo e nei Consigli regionali sono collocati in aspettativa senza assegni per la durata del mandato. Essi possono optare per la conservazione, in luogo dell'indennita' parlamentare e dell'analoga indennita' corrisposta ai consiglieri regionali, del trattamento economico in godimento presso l'amministrazione di appartenenza, che resta a carico della medesima.

2. Il periodo di aspettativa e' utile ai fini dell'anzianita' di servizio e del trattamento di quiescenza e di previdenza.

3. Il collocamento in aspettativa ha luogo all'atto della proclamazione degli eletti; di questa le Camere ed i Consigli regionali danno comunicazione alle amministrazioni di appartenenza degli eletti per i conseguenti provvedimenti.

4. Le regioni adeguano i propri ordinamenti ai principi di cui ai commi 1, 2 e 3.

## Norme transitorie e finali

### Art. 69. - Norme transitorie (Art. 25, comma 4 del d.lgs. n. 29 del 1993; art. 50, comma 14 del d.lgs. n. 29 del 1993, come sostituito prima dall'art. 17 del d.lgs. n. 470 del 1993 e poi dall'art. 2 del d.lgs. n. 396 del 1997; art. 72, commi 1 e 4 del d.lgs. n. 29 del 1993, come sostituiti dall'art. 36 del d.lgs. n. 546 del 1993; art. 73, comma 2 del d.lgs. n. 29 del 1993, come sostituito dall'art. 37 del d.lgs. n. 546 del 1993; art. 28, comma 2 del d.lgs. n. 80 del 1998; art. 45, commi 5, 9, 17 e 25 del d.lgs. n. 80 del 1998, come modificati dall'art. 22, comma 6 del d.lgs. n. 387 del 1998; art. 24, comma 3 del d.lgs. n. 387 del 1998)

1. Salvo che per le materie di cui all'articolo 2, comma 1, lettera c), della legge 23 ottobre 1992, n. 421, gli accordi sindacali recepiti in decreti deI Presidente della Repubblica in base alla legge 29 marzo 1983, n. 93, e le norme generali e speciali del pubblico impiego, vigenti alla data del 13 gennaio 1994 e non abrogate, costituiscono, limitatamente agli istituti del rapporto di lavoro, la disciplina di cui all'articolo 2, comma 2. Tali disposizioni sono inapplicabili a seguito della stipulazione dei contratti collettivi del quadriennio 1994-1997, in relazione ai soggetti e alle materie dagli stessi contemplati. Tali disposizioni cessano in ogni caso di produrre effetti dal momento della sottoscrizione, per ciascun ambito di riferimento, dei contratti collettivi del quadriennio 1998-2001.

2. In attesa di una nuova regolamentazione contrattuale della materia, resta ferma per i dipendenti di cui all'articolo 2, comma 2, la disciplina vigente in materia di trattamento di fine rapporto.

3. Il personale delle qualifiche ad esaurimento di cui agli articoli 60 e 61 del decreto del Presidente della Repubblica 30 giugno 1972. n. 748, e successive modificazioni ed integrazioni, e quello di cui all'articolo 15 della legge 9 marzo 1989, n. 88, i cui ruoli sono contestualmente soppressi dalla data del 21 febbraio 1993, conserva le qualifiche ad personam. A tale personale sono attribuite funzioni vicarie del dirigente e funzioni di direzione di uffici di particolare rilevanza non riservati al dirigente, nonche' compiti di studio, ricerca, ispezione e vigilanza ad esse delegati dal dirigente. Il trattamento economico e' definito tramite il relativo contratto collettivo. ((3))

4. La disposizione di cui all'articolo 56, comma 1, si applica, per ciascun ambito di riferimento, a far data dalla entrata in vigore dei contratti collettivi del quadriennio contrattuale 1998-2001.

5. Le disposizioni di cui all'articolo 22, commi 17 e 18, della legge 29 dicembre 1994, n. 724, continuano ad applicarsi alle amministrazioni che non hanno ancora provveduto alla determinazione delle dotazioni organiche previa rilevazione dei carichi di lavoro.

6. Con riferimento ai rapporti di lavoro di cui all'articolo 2, comma 3, del presente decreto, non si applica l'articolo 199 del decreto del Presidente della Repubblica 10 gennaio 1957, n. 3.

7. Sono attribuite al giudice ordinario, in funzione di giudice del lavoro, le controversie di cui all'articolo 63 del presente decreto, relative a questioni attinenti al periodo del rapporto di lavoro successivo al 30 giugno 1998. Le controversie relative a questioni attinenti al periodo del rapporto di lavoro anteriore a tale data restano attribuite alla giurisdizione esclusiva del giudice amministrativo solo qualora siano state proposte, a pena di decadenza, entro il 15 settembre 2000.

8. Fino all'entrata in vigore della nuova disciplina derivante dal contratto collettivo per il comparto scuola, relativo al quadriennio 1998-2001, continuano ad applicarsi al personale della scuola le procedure di cui all'articolo 484 del decreto legislativo 16 aprile 1994, n.297.

9. Per i primi due bandi successivi alla data del 22 novembre 1998, relativi alla copertura di posti riservati ai concorsi di cui all'articolo 28, comma 2, lettera b, del presente decreto, con il regolamento governativo di cui al comma 3, del medesimo articolo e' determinata la quota di posti per i quali sono ammessi soggetti anche se non in possesso del previsto titolo di specializzazione.

10. Sino all'applicazione dell'articolo 46, comma 12. l'ARAN utilizza personale in posizione di comando e fuori ruolo nei limiti massimi delle tabelle previste dal decreto del Presidente della Repubblica 25 gennaio 1994. n. 144, come modificato dall'articolo 8, comma 4, della legge 15 maggio 1997, n. 127.

11. In attesa di una organica normativa nella materia, restano ferme le norme che disciplinano, per i dipendenti delle amministrazioni pubbliche, l'esercizio delle professioni per le quali sono richieste l'abilitazione o l'iscrizione ad ordini o albi professionali. Il personale di cui all'articolo 6, comma 5, del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni ed integrazioni, puo' iscriversi, se in possesso dei prescritti requisiti, al relativo ordine professionale.

--------------- AGGIORNAMENTO (3) La L. 15 luglio 2002, n. 145 ha disposto (con l'art. 5, comma 1) che " Nei limiti del 50 per cento dei posti disponibili nell'ambito della dotazione organica dei dirigenti di seconda fascia dei ruoli di ciascuna amministrazione, il personale di cui all'articolo 69, comma 3, del decreto legislativo 30 marzo 2001, n. 165, in servizio alla data di entrata in vigore della presente legge, e' inquadrato, previo superamento di concorso riservato per titoli di servizio e professionali, da espletarsi entro centottanta giorni dalla medesima data, nella seconda fascia dirigenziale."

### Art. 70. - Norme finali (Art. 73, commi 1, 3, 4, 5 e 6-bis del d.lgs n. 29 del 1993, come modificati dall'art. 21 del d.lgs n. 470 del 1993, successivamente sostituiti dall'art. 37 del d.lgs n. 546 del 1993 e modificati dall'art. 9, comma 2 del d.lgs n. 396 del 1997, dall'art. 45, comma 4 del d.lgs n. 80 del 1998 e dall'art. 20 del d.lgs n. 387 del 1998; art. 45, commi 1, 2, 7, 10, 11, 21, 22 e 23 del d.lgs n. 80 del 1998, come modificati dall'art. 22, comma 6 del d.lgs n. 387 del 1998, dall'art. 89 della legge n. 342 del 2000 e dall'art. 51, comma 13, della legge n. 388 del 2000)

1. Restano salve per la regione Valle d'Aosta le competenze in materia, le norme di attuazione e la disciplina sul bilinguismo. Restano comunque salve, per la provincia autonoma di Bolzano, le competenze in materia, le norme di attuazione, la disciplina vigente sul bilinguismo e la riserva proporzionale di' posti nel pubblico impiego.

2. Restano ferme le disposizioni di cui al titolo IV, capo II del decreto legislativo 18 agosto 2000, n.267, riguardanti i segretari comunali e provinciali, e alla legge 7 marzo 1986, n. 65 - esclusi gli articoli 10 e 13 - sull'ordinamento della Polizia municipale. Per il personale disciplinato dalla stessa legge 7 marzo 1986, n. 65 il trattamento economico e normativo e' definito nei contratti collettivi previsti dal presente decreto, nonche', per i segretari comunali e provinciali, dall'art. 11, comma 8 del Decreto del Presidente della Repubblica 4 dicembre 1997, n. 465.

3. Il rapporto di lavoro dei dipendenti degli enti locali e' disciplinato dai contratti collettivi previsti dal presente decreto nonche' dal decreto legislativo 18 agosto 2000, n. 267.

4. Le aziende e gli enti di cui alle leggi 26 dicembre 1936, n. 2174, e successive modificazioni ed integrazioni, 13 luglio 1984. n. 312, 30 maggio 1988, n.l86, 11 luglio 1988, n. 266, 31 gennaio 1992, n. 138, legge 30 dicembre 1986, n. 936 , decreto legislativo 25 luglio 1997, n. 250 , decreto legislativo 12 febbraio 1993, n. 39 adeguano i propri ordinamenti ai principi di cui al titolo I. I rapporti di lavoro dei dipendenti dei predetti enti ed aziende nonche' della Cassa depositi e prestiti sono regolati da contratti collettivi ed individuali in base alle disposizioni di cui agli articoli 2, comma 2, all'articolo 8, comma 2, ed all'articolo 60, comma 3. PERIODO SOPPRESSO DAL D.LGS. 27 OTTOBRE 2009, N. 150. PERIODO SOPPRESSO DAL D.LGS. 27 OTTOBRE 2009, N. 150. PERIODO SOPPRESSO DAL D.LGS. 27 OTTOBRE 2009, N. 150.

5. Le disposizioni di cui all'articolo 7 del decreto-legge 19 settembre 1992, n. 384, convertito, con modificazioni, dalla legge 14 novembre 1992, n. 438, vanno interpretate nel senso che le medesime, salvo quelle di cui al comma 7, non si riferiscono al personale di cui al decreto legislativo 26 agosto 1998, n. 319.

6. A decorrere dal 23 aprile 1998, le disposizioni che conferiscono agli organi di governo l'adozione di atti di gestione e di atti o provvedimenti amministrativi di cui all'articolo 4, comma 2, del presente decreto, si intendono nel senso che la relativa competenza spetta ai dirigenti.

7. A decorrere dal 23 aprile 1998, le disposizioni vigenti a tale data, contenute in leggi, regolamenti, contratti collettivi o provvedimenti amministrativi riferite ai dirigenti generali si intendono riferite ai dirigenti di uffici dirigenziali generali.

8. Le disposizioni del presente decreto si applicano al personale della scuola. Restano ferme le disposizioni di cui all'articolo 21 della legge 15 marzo 1997, n. 59 e del decreto legislativo 12 febbraio 1993, n. 35. Sono fatte salve le procedure di reclutamento del personale della scuola di cui al decreto legislativo 16 aprile 1994, n. 297 e successive modificazioni ed integrazioni.

9. Per il personale della carriera prefettizia di cui all'articolo 3, comma I del presente decreto, gli istituti della partecipazione sindacale di cui all'articolo 9 del medesimo decreto sono disciplinati attraverso apposito regolamento emanato ai sensi dell'articolo 17 della legge 23 agosto 1988, n. 400, e successive modificazioni ed integrazioni.

10. I limiti di cui all'articolo 19, comma 6, del presente decreto non si applicano per la nomina dei direttori degli Enti parco nazionale.

11. Le disposizioni in materia di mobilita' di cui agli articoli 30 e seguenti del presente decreto non si applicano al personale del Corpo nazionale dei vigili del fuoco. (72)((79))

12. In tutti i casi, anche se previsti da normative speciali, nei quali enti pubblici territoriali, enti pubblici non economici o altre amministrazioni pubbliche, dotate di autonomia finanziaria sono tenute ad autorizzare la utilizzazione da parte di altre pubbliche amministrazioni di proprio personale, in posizione di comando, di fuori ruolo, o in altra analoga posizione, l'amministrazione che utilizza il personale rimborsa all'amministrazione di appartenenza l'onere relativo al trattamento fondamentale. La disposizione di cui al presente comma si' applica al personale comandato, fuori ruolo o in analoga posizione presso l'ARAN a decorrere dalla completa attuazione del sistema di finanziamento previsto dall'articolo 46, commi 8 e 9, del presente decreto, accertata dall'organismo di coordinamento di cui all'articolo 41, comma 6 del medesimo decreto. Il trattamento economico complessivo del personale inserito nel ruolo provvisorio ad esaurimento del Ministero delle finanze istituito dall'articolo 4, comma 1, del decreto legislativo 9 luglio 1998, n. 283, in posizione di comando, di' fuori ruolo o in altra analoga posizione, presso enti pubblici territoriali, enti pubblici non economici o altre amministrazioni pubbliche dotate di autonomia finanziaria, rimane a carico dell'amministrazione di appartenenza.

13. In materia di reclutamento, le pubbliche amministrazioni applicano la disciplina prevista dal decreto del Presidente della Repubblica 9 maggio 1994, n. 487, e successive modificazioni ed integrazioni, per le parti non incompatibili con quanto previsto dagli articoli 35 e 36, salvo che la materia venga regolata, in coerenza con i principi ivi previsti, nell'ambito dei rispettivi ordinamenti.

-------------- AGGIORNAMENTO (72) Il D.Lgs. 13 ottobre 2005, n. 217, come modificato dal D.Lgs. 29 maggio 2017, n. 97, ha disposto (con l'art. 132-bis, comma 1) che "In deroga a quanto previsto dall'articolo 70, comma 11, del decreto legislativo 30 marzo 2001, n. 165, alla copertura delle carenze organiche del Corpo nazionale dei vigili del fuoco si provvede, in caso di richiesta da parte degli interessati, anche mediante mobilita' degli appartenenti ai Corpi permanenti dei vigili del fuoco delle province autonome di Trento e di Bolzano e della regione Valle d'Aosta, previo assenso delle amministrazioni di provenienza e di destinazione, limitatamente ai ruoli operativi di cui al Titolo I". -------------- AGGIORNAMENTO (79) Il D.Lgs. 6 ottobre 2018, n. 127, nell'introdurre l'art. 232 al D.Lgs. 13 ottobre 2005, n. 217, ha conseguentemente disposto (con l'art. 4, comma 1) che "In deroga a quanto previsto dall'articolo 70, comma 11, del decreto legislativo 30 marzo 2001, n. 165, alla copertura delle carenze organiche del Corpo nazionale si provvede, in caso di richiesta da parte degli interessati, anche mediante mobilita' degli appartenenti ai Corpi permanenti dei vigili del fuoco delle province autonome di Trento e di Bolzano e della regione Valle d'Aosta, previo assenso delle amministrazioni di provenienza e di destinazione, limitatamente al personale dei ruoli operativi in possesso del prescritto titolo di studio".

### Articolo 71 - Disposizioni inapplicabili a seguito della sottoscrizione di contratti collettivi

1. Ai sensi dell'art. 69, comma 1, secondo periodo, a seguito della stipulazione dei contratti collettivi per il quadriennio 1994-1997, cessano di produrre effetti per ciascun ambito di riferimento le norme di cui agli allegati A) e B) al presente decreto, con le decorrenze ivi previste, in quanto contenenti le disposizioni espressamente disapplicate dagli stessi contratti collettivi. Rimangono salvi gli effetti di quanto previsto dallo stesso comma 1 dell'articolo 69, con riferimento all'inapplicabilita' delle norme incompatibili con quanto disposto dalla contrattazione collettiva nazionale.

2. Per il personale delle Regioni ed autonomie locali, cessano di produrre effetti, a seguito della stipulazione dei contratti collettivi della tornata 1998-2001, le norme contenute nell'allegato C), con le decorrenze ivi previste.

3. Alla fine della tornata contrattuale 1998-2001 per tutti i comparti ed aree di contrattazione verranno aggiornati gli allegati del presente decreto, ai sensi dell'articolo 69, comma 1, ultimo periodo. La contrattazione relativa alla tornata contrattuale 1998-2001, ai sensi dell'articolo 2, comma 2, provvedera' alla disapplicazione espressa delle disposizioni generali o speciali del pubblico impiego, legislative o recepite in decreto del Presidente della Repubblica, che risulteranno incompatibili con la stipula dei contratti collettivi nazionali o dei contratti quadro.

### Articolo 72 - Abrogazioni di norme (Art. 74 del d.lgs n. 29 del 1993, come sostituito dall'art. 38 del d.lgs n. 546 del 1993 e modificato prima dall'art. 43, comma 2 del d.lgs n. 80 del 1998 e poi dall'art. 21 del d.lgs n. 387 del 1998; art. 43, commi 1, 3, 4, 5, 6 e 7 del d.lgs n. 80 del 1998, come modificati dall'art. 22, commi da 1 a 3 del d.lgs n. 387 del 1998; art. 28, comma 2 del d.lgs n. 80 del 1998)

1. Sono abrogate o rimangono abrogate le seguenti norme:

- a) articolo 32 del decreto del Presidente della Repubblica 10 gennaio 1957, n. 3;
- b) capo I, titolo I, del decreto del Presidente della Repubblica 30 giugno 1972, n. 748, e successive modificazioni ed integrazioni, ad eccezione delle disposizioni di cui agli articoli da 4 a 12, nonche' 15, 19, 21, 24 e 25, che, nei limiti di rispettiva applicazione, continuano ad applicarsi al personale dirigenziale delle carriere previste dall'articolo 15, comma 1, secondo periodo del presente decreto, nonche' le altre disposizioni del medesimo decreto n. 748 del 1972 incompatibili con quelle del presente decreto;
- c) articolo 5, commi secondo e terzo della legge 11 agosto 1973, n. 533;
- d) articoli 4, commi decimo, undicesimo, dodicesimo e tredicesimo e 6 della legge 11 luglio 1980, n. 312;
- e) articolo 2 del decreto legge 6 giugno 1981, n. 283, convertito, con modificazioni, dalla legge 6 agosto 1981, n. 432;
- f) articoli da 2 a 15, da 17 a 21, 22, a far data dalla stipulazione dei contratti collettivi per il quadriennio 1994-1997; 23, 26, comma quarto, 27, comma primo, n. 5, 28 e 30, comma terzo della legge 29 marzo 1983, n. 93;
- g) legge 10 luglio 1984, n. 301, ad esclusione delle disposizioni che riguardano l'accesso alla qualifica di primo dirigente del Corpo forestale dello Stato;
- h) articolo 2 della legge 8 marzo 1985, n. 72;
- i) articoli 27 e 28 del decreto del Presidente della Repubblica 8 maggio 1987, n. 266, come integrato dall'articolo 10 del decreto del Presidente della Repubblica 17 settembre 1987, n. 494;
- j) decreto del Presidente della Repubblica 5 dicembre 1987, n. 551;
- k) articoli 4, commi 3 e 4, e articolo 5 della legge 8 luglio 1988, n. 254;
- l) articolo 17, comma 1, lettera e), della legge 23 agosto 1988, n. 400;
- m) articolo 9 della legge 9 maggio 1989, n. 168;
- n) articoli 4, comma 9, limitatamente alla disciplina sui contratti di lavoro riguardanti i dipendenti delle amministrazioni, aziende ed enti del Servizio sanitario nazionale; e 10, comma 2 della legge 30 dicembre 1991, n. 412;
- o) articolo 2, comma 8, del decreto-legge 11 luglio 1992, n. 333, convertito, con modificazioni, dalla legge 8 agosto 1992, n. 359, limitatamente al personale disciplinato dalla legge 4 giugno 1985, n. 281;
- p) articolo 7, comma 1, del decreto-legge 19 settembre 1992, n. 384, convertito, con modificazioni, dalla legge 14 novembre 1992, n. 438, limitatamente al personale disciplinato dalle leggi 4 giugno 1985, n. 281 e 10 ottobre 1990, n. 287;
- q) articolo 10, comma 3, del decreto legislativo 30 dicembre 1992, n. 533;
- r) articolo 10 del decreto legislativo 30 dicembre 1992, n. 534;
- s) articolo 6-bis del decreto legge 18 gennaio 1993, n. 9, convertito, con modificazioni, dalla legge 18 marzo 1993, n. 67;
- t) decreto legislativo 3 febbraio 1993, n. 29;
- u) articolo 3, commi 5, 6, 23, 27, 31 ultimo periodo e da 47 a 52 della legge 24 dicembre 1993, n. 537;
- v) articolo 3, comma 1, lettera e), della legge 14 gennaio 1994, n. 20;
- w) decreto del Presidente del Consiglio dei ministri 16 settembre 1994, n. 716;
- x) articolo 2, lettere b), d) ed e) del decreto del Presidente del Consiglio dei ministri 18 ottobre 1994, n. 692, a decorrere dalla data di attuazione delle disposizioni di cui all'articolo 19 del presente decreto;
- y) articolo 22, comma 15, della legge 23 dicembre 1994, n. 724;
- z) decreto del Ministro per la funzione pubblica 27 febbraio 1995, n. 112;
- aa) decreto legislativo 4 novembre 1997, n. 396; bb)decreto legislativo 31 marzo 1998, n. 80 ad eccezione degli articoli da 33 a 42 e 45, comma 18; cc) decreto legislativo 29 ottobre 1998, n. 387 ad eccezione degli articoli 19, commi da 8 a 18 e 23.

2. Agli adempimenti e alle procedure gia' previsti dall'articolo 31 del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni e integrazioni, continuano ad essere tenute le amministrazioni che non vi hanno ancora provveduto alla data di entrata in vigore del presente decreto.

3. A far data dalla stipulazione dei contratti collettivi per il quadriennio 1994-1997, per ciascun ambito di riferimento, sono abrogate tutte le disposizioni in materia di sanzioni disciplinari per i pubblici impiegati incompatibili con le disposizioni del presente decreto.

4. A far data dalla stipulazione dei contratti collettivi per il quadriennio 1994-1997, per ciascun ambito di riferimento, ai dipendenti di cui all'articolo 2, comma 2, non si applicano gli articoli da 100 a 123 del decreto del Presidente della Repubblica 10 gennaio 1957, n. 3, e le disposizioni ad essi collegate.

5. A far data dalla entrata in vigore dei contratti collettivi del quadriennio 1998-2001, per ciascun ambito di' riferimento, cessano di produrre effetti i commi 7, 8 e 9 dell'articolo 55 del presente decreto.

6. Contestualmente alla definizione della normativa contenente la disciplina di cui all'articolo 50, sono abrogate le disposizioni che regolano la gestione e la fruizione delle aspettative e dei permessi sindacali nelle amministrazioni pubbliche.

### Articolo 73 - Norma di rinvio

1. Quando leggi, regolamenti, decreti, contratti collettivi od altre norme o provvedimenti, fanno riferimento a norme del d.lgs n.29 del 1993 ovvero del d.lgs n.396 del 1997, del d.lgs n.80 del 1998 e 387 del 1998, e fuori dai casi di abrogazione per incompatibilita', il riferimento si intende effettuato alle corrispondenti disposizioni del presente decreto, come riportate da ciascun articolo.

